/*****************************************************************************
 *  rsznl.c
 *
 *  Rohde & Schwarz ZNL Vector Network Analyzer Instrument Driver
 *  Original Release: August 2018
 *  By: Martin Krcmar
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *    see ChangeLog
 *
 *  Copyright (c) 2018, Rohde & Schwarz GmbH & Co. KG
 *  All rights reserved.
 *****************************************************************************/
#include "rsznl.h"
#include "rsznl_internal.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
#include <sys/timeb.h>
#include <sys/types.h>
#include <unistd.h>
#define Sleep sleep
#else                       /* ANSI compatible */
#include <windows.h>
#endif
#include <string.h>
#include <stdlib.h>
#if defined (_CVI_)
#include <utility.h>
#define _strnicmp strnicmp
#endif

 /*****************************************************************************
  *- Value Definition and Range Tables ---------------------------------------*
  *****************************************************************************/
static const ViString gsc_functionTypeArr[] = { "DEEM","EMB", NULL };
static const ViString gsc_limitCheckArr[] = { "","UPP:","LOW:","",NULL };
static const ViString gsc_statusRegister[] = { "", ":LIM", ":LIM2", ":INT", ":INT:HW", NULL };

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

 /*****************************************************************************
  *- User-Callable Functions (Exportable Functions) --------------------------*
  *****************************************************************************/

  /*****************************************************************************
   * Function: rsznl_init
   * Purpose:  VXIplug&play required function. Calls the
   *           rsznl_InitWithOptions function.
   *****************************************************************************/
ViStatus _VI_FUNC rsznl_init(ViRsrc resourceName, ViBoolean IDQuery,
    ViBoolean resetDevice, ViSession* newInstrSession)
{
    ViStatus    error = VI_SUCCESS;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
            VI_ERROR_PARAMETER4, "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rsznl_InitWithOptions(resourceName, IDQuery, resetDevice,
        "QueryInstrStatus=1", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rsznl_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rsznl_InitWithOptions(
    ViRsrc          resourceName,
    ViBoolean       IDQuery,
    ViBoolean       resetDevice,
    ViString        optionString,
    ViSession* newInstrSession
)
{
    ViStatus error = VI_SUCCESS;
    ViSession instrSession = 0;
    RsCoreSessionPtr rsSession = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
            "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rsznl", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        rsznl_RsCoreAttributeList, // List of all attributes from the rsxxx_AttrPropertiesList
        rsznl_RsCoreAttributeListLength, // Length of the attributes list
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "NRP33SN", VI_FALSE: "NRP" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        1000000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSZNL_OPC_TIMEOUT, // OPC timeout
        10000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version for this driver is 4.4.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 4, 0));

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    checkAlloc(rsSession);

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */

    rsSession->autoSystErrQuery = VI_FALSE;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rsznl_RsCoreRepCapTable, rsznl_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // - RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "NRP33SN", false : "NRP"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSZNL_SIMULATION_ID_QUERY, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSZNL_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rsznl_reset(instrSession));
    }
    else
    {
        checkErr(rsznl_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSZNL_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    if (error < VI_SUCCESS)
    {
        // In case of RS_ERROR_INSTRUMENT_STATUS read the error query before you close the session
        if (rsSession)
        {
            if (error == RS_ERROR_INSTRUMENT_STATUS && rsSession->autoSystErrQuery == VI_FALSE)
            {
                rsSession->autoSystErrQuery = VI_TRUE;
                (void)rsznl_CheckStatus(instrSession);
                rsSession->autoSystErrQuery = VI_FALSE;
            }
        }

        if (instrSession != 0)
            (void)RsCore_ViClose(instrSession);
    }
    else
    {
        *newInstrSession = instrSession;
    }

    return error;
}

/// HIFN  This attribute sets the vector network analyzer mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_VectorNetworkAnalyzerMode(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_VECTOR_NETWORK_ANALYZER_MODE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Switches between the MultiView tab and the most recently displayed
/// HIFN  channel setup. If only one channel setup is active, this attribute has
/// HIFN  no effect.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR modeMultiviewEnabled/Switches between the MultiView tab and the most recently displayed
/// HIPAR modeMultiviewEnabled/channel setup. If only one channel setup is active, this control has no
/// HIPAR modeMultiviewEnabled/effect.
ViStatus _VI_FUNC rsznl_ConfigureOperatingModeMultiviewEnabled(
                            ViSession instrSession,
                            ViBoolean modeMultiviewEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_OPERATING_MODE_MULTIVIEW_ENABLED, modeMultiviewEnabled),
            3, "Mode Multiview Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the number of test ports (Port 1, Port 2 ...) of the analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR numberOfTestPorts/Returns the number of test ports (Port 1, Port 2 ...) of the analyzer.
ViStatus _VI_FUNC rsznl_QueryNumberOfTestPorts(ViSession instrSession,
                                               ViInt32*  numberOfTestPorts)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_NUMBER_OF_TEST_PORTS, numberOfTestPorts),
            2, "Number Of Test Ports");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Adds an additional channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelType/Channel type of the new channel setup. For a list of available channel
/// HIPAR channelType/setup types see RSZNL_ATTR_OPERATING_MODE_LIST_OF_CHANNEL_SETUPS
/// HIPAR channelType/(ListOfChannelSetups).
/// HIPAR channelName/String containing the name of the channel setup. The channel setup
/// HIPAR channelName/name is displayed as the tab label for the channel setup.
ViStatus _VI_FUNC rsznl_AddMeasurementChannel(ViSession instrSession,
                                              ViString  channelType,
                                              ViString  channelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "INST:CRE %s,'%s'", channelType, channelName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates a new channel setup with the defined channel setup type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Channel type of the new channel setup. For a list of available channel
/// HIPAR type/setup types see RSZNL_ATTR_OPERATING_MODE_LIST_OF_CHANNEL_SETUPS
/// HIPAR type/(ListOfChannelSetups).
ViStatus _VI_FUNC rsznl_SelectMeasurementChannelByType(ViSession instrSession,
                                                       ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "INST %s", RsZnl_rngChannelType.entries[type].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates a new channel setup with the specified name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelName/String containing the name of the channel setup. The channel setup
/// HIPAR channelName/name is displayed as the tab label for the channel setup.
ViStatus _VI_FUNC rsznl_SelectMeasurementChannelByName(ViSession instrSession,
                                                       ViString  channelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "INST %s", channelName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Duplicates the currently selected channel setup, i.e creates a new
/// HIFN  channel setup of the same type and with the identical measurement
/// HIFN  settings. The name of the new channel setup is the same as the copied
/// HIFN  channel setup, extended by a consecutive number (e.g. 'IQAnalyzer' ->
/// HIFN  'IQAnalyzer 2').
/// HIFN     The channel setup to be duplicated must be selected first.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_DuplicateMeasurementChannel(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CHANNEL_SETUP_DUPLICATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Replaces a channel setup with another one.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR oldChannelName/String containing the name of the channel setup you want to replace.
/// HIPAR newChannelType/Channel type of the new channel setup. For a list of available channel
/// HIPAR newChannelType/setup types see RSZNL_ATTR_OPERATING_MODE_LIST_OF_CHANNEL_SETUPS
/// HIPAR newChannelType/(ListOfChannelSetups).
/// HIPAR newChannelName/String containing the name of the new channel setup.
ViStatus _VI_FUNC rsznl_ReplaceMeasurementChannel(ViSession instrSession,
                                                  ViString  oldChannelName,
                                                  ViString  newChannelType,
                                                  ViString  newChannelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "INST:CRE:REPL '%s',%s,'%s'", oldChannelName, newChannelType, newChannelName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Renames a channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR oldChannelName/String containing the name of the channel setup you want to rename.
/// HIPAR newChannelName/String containing the new channel setup name. Note that you cannot
/// HIPAR newChannelName/assign an existing channel setup name to a new channel setup; this will
/// HIPAR newChannelName/cause an error.
ViStatus _VI_FUNC rsznl_RenameMeasurementChannel(ViSession instrSession,
                                                 ViString  oldChannelName,
                                                 ViString  newChannelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "INST:REN '%s','%s'", oldChannelName, newChannelName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes a channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelName/Deletes a channel setup.
ViStatus _VI_FUNC rsznl_DeleteMeasurementChannel(ViSession instrSession,
                                                 ViString  channelName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CHANNEL_SETUP_DELETE, channelName),
            2, "Channel Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries all active channel setups. This is useful in order to obtain
/// HIFN  the names of the existing channel setups, which are required in order
/// HIFN  to replace or delete the channel setups.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/This parameter determines the size of array Channel Type and Channel
/// HIPAR arraySize/Name. The Channel Type and Channel Name arrays must contain at least
/// HIPAR arraySize/this number of items.
/// HIPAR channelCatalog/For each channel setup, the command returns the channel setup type and
/// HIPAR channelCatalog/channel setup name.
ViStatus _VI_FUNC rsznl_OperatingModeListOfChannelSetups(ViSession instrSession,
                                                         ViUInt32  arraySize,
                                                         ViChar    channelCatalog[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_OPERATING_MODE_LIST_OF_CHANNEL_SETUPS,
            arraySize, channelCatalog),
            4, "Channel Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects a channel as the active channel. The channel must be created
/// HIFN  before using RSZNL_ATTR_CHANNEL_STATE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR activeChannel/Selects a channel as the active channel. The channel must be created
/// HIPAR activeChannel/before using RSZNL_ATTR_CHANNEL_STATE.
ViStatus _VI_FUNC rsznl_SetupActiveMeasurementChannel(ViSession instrSession,
                                                      ViInt32   activeChannel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_CHANNEL_SETUP_ACTIVE_CHANNEL, activeChannel),
            2, "Active Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Turns the Sequencer on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sequencerEnabled/Turns the Sequencer on and off.
ViStatus _VI_FUNC rsznl_ConfigureSequencerEnabled(ViSession instrSession,
                                                  ViBoolean sequencerEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_SEQUENCER_ENABLED, sequencerEnabled),
            2, "Sequencer Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the way the ZNL application performs measurements
/// HIFN  sequentially.
/// HIFN     Before this command can be executed, the Sequencer must be activated
/// HIFN  (see RSZNL_ATTR_SEQUENCER_ENABLED/Sequencer.Enabled).
/// HIFN     Note: In order to synchronize to the end of a sequential measurement
/// HIFN  using *OPC, *OPC? or *WAI you must use Sinle Sequence mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Selects the way the ZNL application performs measurements
/// HIPAR mode/sequentially.
ViStatus _VI_FUNC rsznl_ConfigureSequencerMode(ViSession instrSession,
                                               ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_SEQUENCER_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts a new sequence of measurements by the Sequencer. Before it can
/// HIFN  be executed, the Sequencer must be activated (see
/// HIFN  RSZNL_ATTR_SEQUENCER_ENABLED/Sequencer.Enabled).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SequencerInit(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SEQUENCER_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops the currently active sequence of measurements. The Sequencer
/// HIFN  itself is not deactivated, so you can start a new sequence immediately
/// HIFN  using RSZNL_ATTR_SEQUENCE_INIT/Sequencer.Init.
/// HIFN     To deactivate the Sequencer use
/// HIFN  RSZNL_ATTR_SEQUENCER_ENABLED/Sequencer.Enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SequencerAbort(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SEQUENCER_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the start and stop frequencies for a frequency
/// HIFN  sweep which is equal to the left and right edges of a Cartesian
/// HIFN  diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR startFrequency/This control defines the start frequency for a frequency sweep which
/// HIPAR startFrequency/is equal to the left edge of a Cartesian diagram.
/// HIPAR stopFrequency/This control defines the stop frequency for a frequency sweep which is
/// HIPAR stopFrequency/equal to the right edge of a Cartesian diagram.
ViStatus _VI_FUNC rsznl_ConfigureFrequencyStartStop(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  startFrequency,
                                                    ViReal64  stopFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_FREQUENCY_START,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_FREQUENCY_START, startFrequency),
            3, "Start Frequency");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_FREQUENCY_STOP, stopFrequency),
            4, "Stop Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN  This function defines the center and width of the measurement and
/// HIFN  display range for a frequency sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR centerFrequency/This control defines the center of the measurement and display range
/// HIPAR centerFrequency/for a frequency sweep.
/// HIPAR span/This control defines the width of the measurement and display range
/// HIPAR span/for a frequency sweep.
ViStatus _VI_FUNC rsznl_ConfigureFrequencyCenterSpan(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  centerFrequency,
                                                     ViReal64  span)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_FREQUENCY_CENTER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_FREQUENCY_CENTER, centerFrequency),
            3, "Center Frequency");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_FREQUENCY_SPAN, span),
            4, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the power of the internal signal source.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR power/This control defines the power of the internal signal source.
ViStatus _VI_FUNC rsznl_ConfigurePower(ViSession instrSession,
                                       ViInt32   channel,
                                       ViReal64  power)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_INTERNAL_SOURCE_POWER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_INTERNAL_SOURCE_POWER, power),
            3, "Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the fixed (Continuous Wave, CW) frequency for
/// HIFN  all sweep types operating at fixed frequency (power sweep, time sweep,
/// HIFN  CW mode sweep).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR cwFrequency/This control defines the fixed (Continuous Wave, CW) frequency for all
/// HIPAR cwFrequency/sweep types operating at fixed frequency (power sweep, time sweep, CW
/// HIPAR cwFrequency/mode sweep).
ViStatus _VI_FUNC rsznl_ConfigureCWFrequency(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  cwFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_FREQUENCY_CW,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_FREQUENCY_CW, cwFrequency),
            3, "CW Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a source port for the stimulus signal (Drive
/// HIFN  Port). The setting acts on the active trace. The effect of the drive
/// HIFN  port selection depends on the measurement parameter associated to the
/// HIFN  active trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sourcePort/This control defines the test port number of the analyzer.
ViStatus _VI_FUNC rsznl_ConfigureSourcePort(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   sourcePort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_SOURCE_PORT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STIMULUS_SOURCE_PORT, sourcePort),
            3, "Source Port");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the minimum and maximum frequency of the network analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR range/Selects if querry maximum or minimum frequency range.
/// HIPAR frequency/Return minimum or maximum frequency of instrument.
ViStatus _VI_FUNC rsznl_QueryFrequencyRange(ViSession instrSession,
                                            ViInt32   range,
                                            ViReal64* frequency)
{
    ViStatus                          error = VI_SUCCESS;
    ViAttr                            attr[] = { RSZNL_ATTR_STIMULUS_FREQUENCY_MIN,
    RSZNL_ATTR_STIMULUS_FREQUENCY_MAX };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, range, RSZNL_VAL_FREQ_MIN, RSZNL_VAL_FREQ_MAX),
            2, "Range");

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, NULL, attr[range], frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets an attenuation factor for the received waves. This function is
/// HIFN  available if at least one of the Receiver Step Attenuatorsis installed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR physicalPortNumber/Selects the physical port number.
/// HIPAR attenuationFactor/Attenuation factor for the received wave.
ViStatus _VI_FUNC rsznl_ConfigureStimulusStepAttenuators(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   physicalPortNumber,
                                                         ViInt32   attenuationFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:POW:ATT %ld,%ld", channel, physicalPortNumber, attenuationFactor);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function turns the internal source power at all ports and the
/// HIFN  power of all external generators on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR rfState/This control turns the internal source power at all ports and the
/// HIPAR rfState/power of all external generators on or off.
ViStatus _VI_FUNC rsznl_ConfigureRFChannelState(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean rfState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_RF_CHANNEL_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STIMULUS_RF_CHANNEL_STATE, rfState),
            3, "RF State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the attenuation for the received waves. This command is available
/// HIFN  if at least one of the Receiver Step Attenuators is installed.
/// HIFN
/// HIFN     Note:
/// HIFN
/// HIFN     INPut<PhyPt>:ATTenuation is not channel-specific; the value is valid
/// HIFN  for all channels. Use [SENSe<Ch>:]POWer:ATTenuation to set or query a
/// HIFN  channel-specific attenuation value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR attenuation/Sets the attenuation for the received waves. This command is available
/// HIPAR attenuation/if at least one of the Receiver Step Attenuators is installed.
ViStatus _VI_FUNC rsznl_ConfigureStimulusAttenuation(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   attenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_ATTENUATION,
            "Port", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Port");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STIMULUS_ATTENUATION, attenuation),
            2, "Attenuation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the start and stop times of the diagram in time
/// HIFN  domain.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR startTime/Defines the start time of the diagram in time domain.
/// HIPAR stopTime/Defines the stop time of the diagram in time domain.
ViStatus _VI_FUNC rsznl_ConfigureTimeDomainStartStopTime(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  startTime,
                                                         ViReal64  stopTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_START_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_START_TIME, startTime),
            3, "Start Time");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_STOP_TIME, stopTime),
            4, "Stop Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the center and span time of the diagram in time
/// HIFN  domain.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR centerTime/Defines the center time of the diagram in time domain.
/// HIPAR timeSpan/Defines the time span of the diagram in time domain.
ViStatus _VI_FUNC rsznl_ConfigureTimeDomainCenterSpanTime(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  centerTime,
                                                          ViReal64  timeSpan)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_CENTER_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_CENTER_TIME, centerTime),
            3, "Center Time");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_TIME_SPAN, timeSpan),
            4, "Time Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function switches over between the x-axis scaling in time units
/// HIFN  or distance units.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR xAxisScaling/Switches over between the x-axis scaling in time units or distance
/// HIPAR xAxisScaling/units.
ViStatus _VI_FUNC rsznl_ConfigureTimeDomainXAxisScaling(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   xAxisScaling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_X_AXIS_SCALING,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STIMULUS_TIME_DOMAIN_X_AXIS_SCALING, xAxisScaling),
            3, "X Axis Scaling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the measurement bandwidth and the shape of
/// HIFN  the IF filter. The settings apply to all filters in the active channel.
/// HIFN  A system error correction (calibration) remains valid when the filter
/// HIFN  settings are changed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR bandwidth/Defines the resolution bandwidth of the analyzer (measurement
/// HIPAR bandwidth/bandwidth). Values between 1 Hz and 1 MHz can be set. Bandwidths can be
/// HIPAR bandwidth/set in 1 1.5 2 3 5 7 steps. The analyzer rounds up any entered value
/// HIPAR bandwidth/between these steps and rounds down values exceeding the maximum
/// HIPAR bandwidth/bandwidth.
/// HIPAR filterSelectivity/Defines the selectivity of the IF filter for an unsegmented sweep. The
/// HIPAR filterSelectivity/value is also used for all segments of a segmented sweep, provided that
/// HIPAR filterSelectivity/separate selectivity setting is disabled.
ViStatus _VI_FUNC rsznl_ConfigureBandwidth(ViSession instrSession,
                                           ViInt32   channel,
                                           ViReal64  bandwidth,
                                           ViInt32   filterSelectivity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RESOLUTION_BANDWIDTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_RESOLUTION_BANDWIDTH, bandwidth),
            3, "Bandwidth");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_FILTER_SELECTIVITY, filterSelectivity),
            4, "Filter Selectivity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures averaging algorithms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR averageMode/Sets averaging algorithms.
ViStatus _VI_FUNC rsznl_ConfigureAverageMode(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   averageMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_AVERAGE_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_AVERAGE_MODE, averageMode),
            3, "Average Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the number of consecutive sweeps to be
/// HIFN  averaged and enables/disables the sweep average.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sweepAverageState/Enable or disable the sweep average.
/// HIPAR averageFactor/Defines the number of consecutive sweeps to be combined for the sweep
/// HIPAR averageFactor/average ('Factor').
ViStatus _VI_FUNC rsznl_ConfigureAverage(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean sweepAverageState,
                                         ViInt32   averageFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_AVERAGE_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_AVERAGE_STATE, sweepAverageState),
            3, "Sweep Average State");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_AVERAGE_FACTOR, averageFactor),
            4, "Average Factor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function starts a new average cycle, clearing all previous
/// HIFN  results and thus eliminating their effect on the new cycle.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_RestartAverage(ViSession instrSession,
                                       ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_AVERAGE_RESET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_SWEEP_AVERAGE_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the total number of measurement points per
/// HIFN  sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR numberOfPoints/Defines the total number of measurement points per sweep.
ViStatus _VI_FUNC rsznl_ConfigureSweepNumberOfPoints(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   numberOfPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_NUMBER_OF_POINTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_NUMBER_OF_POINTS, numberOfPoints),
            3, "Number of Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the distance between two consecutive sweep points.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This setting is valid for sweep types with equidistant sweep
/// HIFN  points only. It does not apply to logarithmic and segmented sweeps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR stepSize/Sets the distance between two consecutive sweep points in a
/// HIPAR stepSize/(non-segmented) linear frequency sweep.
ViStatus _VI_FUNC rsznl_ConfigureFrequencyStepSize(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  stepSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_FREQUENCY_STEP_SIZE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_FREQUENCY_STEP_SIZE, stepSize),
            3, "Step Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the measurement time for a sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR autoSweepTime/When enabled, the (minimum) sweep duration is calculated internally
/// HIPAR autoSweepTime/using the other channel settings and zero delay.
/// HIPAR sweepTime/Sets the duration of the sweep ('Sweep Time'). Setting a sweep time
/// HIPAR sweepTime/disables the automatic calculation of the (minimum) sweep time.
ViStatus _VI_FUNC rsznl_ConfigureSweepTime(ViSession instrSession,
                                           ViInt32   channel,
                                           ViBoolean autoSweepTime,
                                           ViReal64  sweepTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_TIME_AUTO,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_TIME_AUTO, autoSweepTime),
            3, "Auto Sweep Time");

    if (autoSweepTime == VI_FALSE)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_TIME, sweepTime),
                4, "Sweep Time");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the Meas. Delay time for each partial measurement.
/// HIFN  Setting a delay disables the automatic calculation of the (minimum)
/// HIFN  sweep time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR measDelay/Defines the 'Meas. Delay' before each partial measurement or the first
/// HIPAR measDelay/partial measurement. Setting a delay disables the automatic calculation
/// HIPAR measDelay/of the (minimum) sweep time
ViStatus _VI_FUNC rsznl_ConfigureSweepMeasDelay(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  measDelay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY, measDelay),
            3, "Meas Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines whether the measurement delay (previously
/// HIFN  defined via function rsznl_ConfigureSweepMeasDelay is inserted before
/// HIFN  all partial measurements or before the first partial measurement only.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR insertionPoint/Defines whether the measurement delay is inserted before all partial
/// HIPAR insertionPoint/measurements or before the first partial measurement only.
ViStatus _VI_FUNC rsznl_ConfigureSweepMeasDelayInsertionPoint(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   insertionPoint)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY_INSERTION_POINT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY_INSERTION_POINT, insertionPoint),
            3, "Insertion Point");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the sweep type, i.e. the sweep variable
/// HIFN  (frequency/power/time) and the position of the sweep points across the
/// HIFN  sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sweepType/Selects the sweep type, i.e. the sweep variable (frequency/time) and
/// HIPAR sweepType/the position of the sweep points across the sweep range.
ViStatus _VI_FUNC rsznl_ConfigureSweepType(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   sweepType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_TYPE, sweepType),
            3, "Sweep Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the acquisition attributes of the network
/// HIFN  analyzer. Single sweep, continuous sweep, sweep count and the scope of
/// HIFN  the single sweep sequence can be set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR continuousSweepScope/This control selects the scope of the continuous sweep sequence.
/// HIPAR sweepModeContinuous/Turns on/off continuous sweeping.
/// HIPAR sweepCount/Defines the number of consecutive sweeps to be measured.
/// HIPAR sweepScope/Selects the scope of the single sweep sequence. The setting is applied
/// HIPAR sweepScope/in single sweep mode only (RSZNL_ATTR_SWEEP_MODE_CONTINUOUS set to
/// HIPAR sweepScope/Off).
ViStatus _VI_FUNC rsznl_ConfigureAcquisition(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   continuousSweepScope,
                                             ViBoolean sweepModeContinuous,
                                             ViInt32   sweepCount,
                                             ViInt32   sweepScope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   cont_attr[] = { RSZNL_ATTR_SWEEP_MODE_CONTINUOUS_ALL_CHANNELS, RSZNL_ATTR_SWEEP_MODE_CONTINUOUS };
    ViAttr   single_attr[] = { RSZNL_ATTR_SWEEP_COUNT_ALL_CHANNELS, RSZNL_ATTR_SWEEP_COUNT };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, continuousSweepScope, RSZNL_VAL_SWEEP_ALL_CHAN, RSZNL_VAL_SWEEP_SINGLE_CHAN),
            3, "Continuous Sweep Scope");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_MODE_CONTINUOUS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, continuousSweepScope == 0 ? NULL : repCap,
        cont_attr[continuousSweepScope],
        sweepModeContinuous), 4, "sweepModeContinuous");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, sweepScope == 0 ? NULL : repCap,
        single_attr[sweepScope],
        sweepCount), 5, "sweepCount");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_SCOPE, sweepScope),
            6, "Sweep Scope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function starts a new single sweep sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sweepScope/This control selects the scope of the sweep sequence.
ViStatus _VI_FUNC rsznl_InitiateSweep(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   sweepScope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = { RSZNL_ATTR_SWEEP_START_ALL, RSZNL_ATTR_SWEEP_START };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sweepScope, RSZNL_VAL_SWEEP_ALL_CHAN, RSZNL_VAL_SWEEP_SINGLE_CHAN),
            3, "Sweep Scope");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_START,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, sweepScope == 0 ? NULL : repCap,
        attr[sweepScope], NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function starts a new single sweep sequence and waits for the sweep
/// HIFN  sequence to finish.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sweepScope/This control selects the scope of the sweep sequence.
/// HIPAR timeout/Timeout in milliseconds for OPC synchronization.
ViStatus _VI_FUNC rsznl_InitiateSweepAndWait(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   sweepScope,
                                             ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = { RSZNL_ATTR_SWEEP_START_ALL_SYNCHRONIZED, RSZNL_ATTR_SWEEP_START_SYNCHRONIZED };
    ViInt32  oldOPCTimeout = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sweepScope, RSZNL_VAL_SWEEP_ALL_CHAN, RSZNL_VAL_SWEEP_SINGLE_CHAN),
            3, "Sweep Scope");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_START_SYNCHRONIZED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_GetOPCTimeout(instrSession, &oldOPCTimeout));

    if (timeout > 0)
    {
        checkErr(rsznl_SetOPCTimeout(instrSession, timeout));
    }

    checkErr(rsznl_SetAttributeViString(instrSession, sweepScope == 0 ? NULL : repCap, attr[sweepScope], NULL));

Error:
    rsznl_SetOPCTimeout(instrSession, oldOPCTimeout);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the sweep in all or single channel
/// HIFN  of the active recall set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR channelScope/This control selects the scope of the channel.
/// HIPAR enableSweep/Enables or disables the sweep in all or single channel of the active
/// HIPAR enableSweep/recall set.
ViStatus _VI_FUNC rsznl_ConfigureMeasurementInChannel(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   channelScope,
                                                      ViBoolean enableSweep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[] = { RSZNL_ATTR_SWEEP_IN_ALL_CHANNELS, RSZNL_ATTR_SWEEP_IN_SINGLE_CHANNEL };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelScope, RSZNL_VAL_SWEEP_ALL_CHAN, RSZNL_VAL_SWEEP_SINGLE_CHAN),
            3, "Channel Scope");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_IN_SINGLE_CHANNEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, channelScope == 0 ? NULL : repCap,
        attr[channelScope], enableSweep), 3, "Enable Sweep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function inserts a new sweep segment with specific channel
/// HIFN  settings. The new segment must not overlap with any of the existing
/// HIFN  segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
/// HIPAR startFrequency/This control defines the Start frequency of sweep segment no.
/// HIPAR startFrequency/<Segment>.
/// HIPAR stopFrequency/This control defines the Stop frequency of sweep segment no.
/// HIPAR stopFrequency/<Segment>.
/// HIPAR numberOfPoints/This control defines the total number of measurement Points in sweep
/// HIPAR numberOfPoints/segment no. <Segment>.
/// HIPAR power/This control defines the power of the internal signal source in
/// HIPAR power/segment.
/// HIPAR sweepTimeSelect/Defines whether the sweep time of a new segment, i.e. numeric
/// HIPAR sweepTimeSelect/parameter no. 5 of the command [SENSe<Ch>:]SEGMent<Seg>:INSert, is
/// HIPAR sweepTimeSelect/entered as a segment sweep time ('Segment Time') or as a measurement
/// HIPAR sweepTimeSelect/delay ('Meas Delay').
/// HIPAR timeOrDelay/'Sweep Time Select' = 'Segment Time': Sets the duration of the sweep
/// HIPAR timeOrDelay/in sweep segment no. <Segment>. At the same time, the command activates
/// HIPAR timeOrDelay/separate sweep time setting in all sweep segments.
/// HIPAR measBandwidth/This control defines the resolution bandwidth of the analyzer (Meas.
/// HIPAR measBandwidth/Bandwidth).
/// HIPAR localOscillatorFrequency/This control selects the position of the local oscillator frequency LO
/// HIPAR localOscillatorFrequency/relative to the RF frequency (Spur Avoid).
/// HIPAR selectivity/Defines the 'Selectivity' of the IF filter used in sweep segment no.
/// HIPAR selectivity/<Seg>.
/// HIPAR frequencySweepMode/Frequency sweep mode; must be set to STEPped.
ViStatus _VI_FUNC rsznl_InsertNewSegment(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   segment,
                                         ViReal64  startFrequency,
                                         ViReal64  stopFrequency,
                                         ViInt32   numberOfPoints,
                                         ViReal64  power,
                                         ViInt32   sweepTimeSelect,
                                         ViReal64  timeOrDelay,
                                         ViReal64  measBandwidth,
                                         ViInt32   localOscillatorFrequency,
                                         ViInt32   selectivity,
                                         ViInt32   frequencySweepMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString list[] = { "NEG","POS","AUTO",NULL };

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_INSERT_TIME_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_INSERT_TIME_MODE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", segment);

    checkErr(RsCore_AddRepCap(instrSession, "Segment", repCap_segment, repCap_cmd));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INSERT_TIME_MODE, sweepTimeSelect),
            8, "Sweep Time Select");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:SEGM%ld:INS %.12lG,%.12lG,%ld,%.12lG,",
         channel, segment, startFrequency, stopFrequency, numberOfPoints, power);

    switch (sweepTimeSelect)
    {
    case RSZNL_VAL_TIME_MODE_SEGMENT_TIME:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, timeOrDelay, 0, 1000),
                9, "Time Or Delay");

        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%.12lG", timeOrDelay);

        break;
    case RSZNL_VAL_TIME_MODE_MEAS_DELAY:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, timeOrDelay, 0, 2.5e+3), 9, "Time Or Delay");

        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%.12lG", timeOrDelay);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, sweepTimeSelect), 8, "Sweep Time Select");
    }

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, localOscillatorFrequency, RSZNL_VAL_LOCAL_OSCILLATOR_NEGATIVE, RSZNL_VAL_LOCAL_OSCILLATOR_AUTO),
            12, "Local Oscillator Frequency");

    snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",0,%.12lG,%s,%s,%s", measBandwidth,
        list[localOscillatorFrequency],
        RsZnl_rngFilterSelectivity.entries[selectivity].cmdString,
        RsZnl_rngFreqSweepMode.entries[frequencySweepMode].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function re-defines a sweep segment with specific channel
/// HIFN  settings (Insert New Segment). The segment replaces an existing segment
/// HIFN  <Segment> in the segment list. The modified segment must not overlap
/// HIFN  with any of the existing segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
/// HIPAR startFrequency/This control defines the Start frequency of sweep segment no.
/// HIPAR startFrequency/<Segment>.
/// HIPAR stopFrequency/This control defines the Stop frequency of sweep segment no.
/// HIPAR stopFrequency/<Segment>.
/// HIPAR numberOfPoints/This control defines the total number of measurement Points in sweep
/// HIPAR numberOfPoints/segment no. <Segment>.
/// HIPAR power/This control defines the power of the internal signal source in
/// HIPAR power/segment.
/// HIPAR sweepTimeSelect/Defines whether the sweep time of a new segment, i.e. numeric
/// HIPAR sweepTimeSelect/parameter no. 5 of the command [SENSe<Ch>:]SEGMent<Seg>:INSert, is
/// HIPAR sweepTimeSelect/entered as a segment sweep time ('Segment Time') or as a measurement
/// HIPAR sweepTimeSelect/delay ('Meas Delay').
/// HIPAR timeOrDelay/'Sweep Time Select' = 'Segment Time': Sets the duration of the sweep
/// HIPAR timeOrDelay/in sweep segment no. <Segment>. At the same time, the command activates
/// HIPAR timeOrDelay/separate sweep time setting in all sweep segments.
/// HIPAR measBandwidth/This control defines the resolution bandwidth of the analyzer (Meas.
/// HIPAR measBandwidth/Bandwidth).
/// HIPAR localOscillatorFrequency/This control selects the position of the local oscillator frequency LO
/// HIPAR localOscillatorFrequency/relative to the RF frequency (Spur Avoid).
/// HIPAR selectivity/Defines the 'Selectivity' of the IF filter used in sweep segment no.
/// HIPAR selectivity/<Seg>.
/// HIPAR frequencySweepMode/Frequency sweep mode; must be set to STEPped.
ViStatus _VI_FUNC rsznl_RedefineSegment(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32   segment,
                                        ViReal64  startFrequency,
                                        ViReal64  stopFrequency,
                                        ViInt32   numberOfPoints,
                                        ViReal64  power,
                                        ViInt32   sweepTimeSelect,
                                        ViReal64  timeOrDelay,
                                        ViReal64  measBandwidth,
                                        ViInt32   localOscillatorFrequency,
                                        ViInt32   selectivity,
                                        ViInt32   frequencySweepMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString list[] = { "NEG","POS","AUTO",NULL };

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_REDEFINE_TIME_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_REDEFINE_TIME_MODE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_REDEFINE_TIME_MODE, sweepTimeSelect),
            8, "Sweep Time Select");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:SEGM%ld:DEF %.12lG,%.12lG,%ld,%.12lG,",
         channel, segment, startFrequency, stopFrequency, numberOfPoints, power);

    switch (sweepTimeSelect)
    {
    case RSZNL_VAL_TIME_MODE_SEGMENT_TIME:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, timeOrDelay, 0, 1000),
                9, "Time Or Delay");

        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%.12lG", timeOrDelay);

        break;
    case RSZNL_VAL_TIME_MODE_MEAS_DELAY:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, timeOrDelay, 0, 2.5e+3), 9, "Time Or Delay");

        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%.12lG", timeOrDelay);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, sweepTimeSelect), 8, "Sweep Time Select");
    }

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, localOscillatorFrequency, RSZNL_VAL_LOCAL_OSCILLATOR_NEGATIVE, RSZNL_VAL_LOCAL_OSCILLATOR_AUTO),
            12, "Local Oscillator Frequency");

    snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",0,%.12lG,%s,%s,AUTO,%s", measBandwidth,
        list[localOscillatorFrequency],
        RsZnl_rngFilterSelectivity.entries[selectivity].cmdString,
        RsZnl_rngFreqSweepMode.entries[frequencySweepMode].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Inserts a new sweep segment using default channel settings ('Insert
/// HIFN  New Segment'). The added segment covers the frequency interval between
/// HIFN  the maximum frequency of the existing sweep segments and the stop
/// HIFN  frequency of the entire sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
ViStatus _VI_FUNC rsznl_AddNewSegment(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   segment)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_ADD,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_ADD,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", segment);

    checkErr(RsCore_AddRepCap(instrSession, "Segment", repCap_segment, repCap_cmd));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_ADD, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the number of sweep segments in the channel including all
/// HIFN  segments that are switched off
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR numberOfSweepSegments/This control returns of sweep segments in the channel including all
/// HIPAR numberOfSweepSegments/segments that are switched off.
ViStatus _VI_FUNC rsznl_QuerySweepSegmentNumber(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32*  numberOfSweepSegments)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_COUNT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_COUNT, numberOfSweepSegments),
            3, "Number Of Sweep Segments");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes the specified (single) sweep segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
ViStatus _VI_FUNC rsznl_DeleteSelectedSegment(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   segment)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_DELETE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_DELETE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_DELETE, NULL));

    checkErr(RsCore_RemoveRepCap(instrSession, "Segment", repCap_segment));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes all sweep segments in the channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeleteAllSegments(ViSession instrSession,
                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_DELETE_ALL, NULL));

    checkErr(RsCore_ResetRepCapID(instrSession, "Segment", rsznl_RsCoreRepCapTable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates or deactivates the sweep segment <Segment>.
/// HIFN  Sweep points belonging to inactive segments only are not measured.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
/// HIPAR state/This control activates or deactivates the sweep segment <Segment>.
ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentState(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   segment,
                                                   ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_STATE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_STATE, state),
            4, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects either frequency based or point based x-axis for
/// HIFN  segmented sweeps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR xAxis/Selects either frequency based or point based x-axis for segmented
/// HIPAR xAxis/sweeps.
ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentXAxis(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   xAxis)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_X_AXIS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_X_AXIS, xAxis),
            3, "X-Axis");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the center frequency and span of sweep segment no. <Seg>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
/// HIPAR center/Returns the center frequency of sweep segment no. <Seg>.
/// HIPAR span/Returns the span (width) of sweep segment no. <Seg>.
ViStatus _VI_FUNC rsznl_QuerySweepSegmentFrequencyCenterSpan(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   segment,
                                                             ViReal64* center,
                                                             ViReal64* span)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_STATE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_FREQUENCY_CENTER, center),
            4, "Center");

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_FREQUENCY_SPAN, span),
            5, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects common or independent settings for the sweep segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR power/Selects common or independent internal source 'Power' settings for the
/// HIPAR power/sweep segments.
/// HIPAR bandwidth/Selects common or independent 'Meas. Bandwidth' settings for the sweep
/// HIPAR bandwidth/segments.
/// HIPAR selectivity/Selects common or independent 'Selectivity' settings for the
/// HIPAR selectivity/individual sweep segments.
/// HIPAR measDelay/Selects common or independent 'Meas. Delay' settings for the sweep
/// HIPAR measDelay/segments.
/// HIPAR time/Selects common or independent 'Segment Sweep Time' settings for the
/// HIPAR time/sweep segments.
ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentIndependentSettings(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean power,
                            ViBoolean bandwidth,
                            ViBoolean selectivity,
                            ViBoolean measDelay,
                            ViBoolean time)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_POWER_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_POWER_STATE, power),
            3, "Power");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_MEAS_BANDWIDTH_STATE, bandwidth),
            4, "Bandwidth");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_SELECTIVITY_STATE, selectivity),
            5, "Selectivity");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_MEAS_DELAY_STATE, measDelay),
            6, "Meas Delay");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_SEGMENT_TIME_STATE, time),
            7, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the total duration of the segmented sweep, calculated as the
/// HIFN  sum of the sweep times of the individual segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sumTime/Returns the total duration of the segmented sweep, calculated as the
/// HIPAR sumTime/sum of the sweep times of the individual segments.
ViStatus _VI_FUNC rsznl_QuerySweepSegmentSumTime(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* sumTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_SEGMENT_SUM_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_SEGMENT_SUM_TIME, sumTime),
            3, "Sum Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets or queries a channel-dependent eight-bit decimal value to control
/// HIFN  eight independent output signals at the Aux. Port connector (lines 8,
/// HIFN  9, 10, 11 and lines 16, 17, 18,19). The output signals are 3.3 V TTL
/// HIFN  signals which can be used to differentiate
/// HIFN     between up to 255 independent analyzer states. Attribute itself does
/// HIFN  not change the analyzer state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR auxPortChannelBits/Sets or queries a channel-dependent eight-bit decimal value to control
/// HIPAR auxPortChannelBits/eight independent output signals at the Aux. Port connector (lines 8,
/// HIPAR auxPortChannelBits/9, 10, 11 and lines 16, 17, 18,19). The output signals are 3.3 V TTL
/// HIPAR auxPortChannelBits/signals which can be used to differentiate
ViStatus _VI_FUNC rsznl_ConfigureAUXPortChannelBits(ViSession instrSession,
                                                    ViInt32   auxPortChannelBits)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_AUX_PORT_CHANNEL_BITS, auxPortChannelBits),
            3, "AUX Port Channel Bits");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function saves the sweep segment definition of a specified
/// HIFN  channel to a sweep segment file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR fileName/This control specifies the name and directory of the created sweep
/// HIPAR fileName/segment file. The default extension (manual control) for sweep segment
/// HIPAR fileName/files is *.seglist, although other extensions are allowed. If no path
/// HIPAR fileName/is specified the analyzer uses the current directory, to be queried
/// HIPAR fileName/with MMEMory:CDIRectory?.
ViStatus _VI_FUNC rsznl_SaveSegment(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:SEGM %ld,'%s'", channel, fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads a sweep segment definition from a specified file
/// HIFN  and assigns it to a specified channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR fileName/This control specifies the name and directory of the sweep segment
/// HIPAR fileName/file to be loaded. The default extension (manual control) for sweep
/// HIPAR fileName/segment files is *.seglist, although other extensions are allowed. If
/// HIPAR fileName/no path is specified the analyzer searches the current directory, to be
/// HIPAR fileName/queried with MMEMory:CDIRectory?.
ViStatus _VI_FUNC rsznl_LoadSegment(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:SEGM %ld,'%s'", channel, fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the source of the trigger events that the
/// HIFN  analyzer uses to start a measurement sequence.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR triggerSource/Selects the source of the trigger events that the analyzer uses to
/// HIPAR triggerSource/start a measurement sequence.
ViStatus _VI_FUNC rsznl_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   triggerSource)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRIGGER_SOURCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRIGGER_SOURCE, triggerSource),
            3, "Trigger Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function triggers all actions waiting for a trigger event.
/// HIFN  Generates a manual trigger signal (Manual Trigger).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SendTrigger(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_INIT_SOFTWARE_TRIGGER, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function triggers all actions waiting for a trigger event in the
/// HIFN  selected window and waits for operation completed (OPC) before
/// HIFN  returning the status code.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/Sets the timeout for the triggering routine to be finished. If the
/// HIPAR timeout/length of time required for triggering exceeds the timeout value, then
/// HIPAR timeout/the function will return with a timeout error.
ViStatus _VI_FUNC rsznl_SendTriggerWaitOPC(ViSession instrSession,
                                           ViInt32   timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, "*TRG", timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the trigger settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR triggerMeasSequence/This control selects the Triggered Meas. Sequence.
/// HIPAR triggerDelay/This control defines a delay time between the trigger event and the
/// HIPAR triggerDelay/start of the measurement.
/// HIPAR slopeLevel/This control qualifies whether the trigger event occurs on the rising
/// HIPAR slopeLevel/or on the falling edge of the external TTL trigger signal.
ViStatus _VI_FUNC rsznl_ConfigureTriggerSettings(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   triggerMeasSequence,
                                                 ViReal64  triggerDelay,
                                                 ViInt32   slopeLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRIGGER_MEASUREMENT_SEQUENCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRIGGER_MEASUREMENT_SEQUENCE, triggerMeasSequence),
            3, "Trigger Meas Sequence");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TRIGGER_DELAY, triggerDelay),
            4, "Trigger Delay");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRIGGER_SLOPE, slopeLevel),
            5, "Slope/Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the source of the trigger events that the
/// HIFN  analyzer uses to start a measurement sequence in multiple trigger
/// HIFN  mode..
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR triggerMeasSequence/This control selects the Triggered Meas. Sequence.
/// HIPAR source/Selects the source of the trigger events that the analyzer uses to
/// HIPAR source/start a measurement sequence in multiple trigger mode.
ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerSource(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   triggerMeasSequence,
                                                       ViInt32   source)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerMeasSequence, RSZNL_VAL_TRIGGER_SEQUENCE_SWEEP, RSZNL_VAL_TRIGGER_SEQUENCE_PARTIAL_MEAS),
            3, "Trigger Meas Sequence");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, source, RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_IMMEDIATE, RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_MANUAL),
            4, "Source");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG%ld:SEQ:MULT:SOUR %s,%s", channel,
        RsZnl_rngTriggeredMeasSequence.entries[triggerMeasSequence].cmdString,
        RsZnl_rngTriggerMultipleSource.entries[source].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function qualifies whether the multiple trigger events occur on
/// HIFN  the rising or on the falling edge or on the beginning of the high / low
/// HIFN  level periods of the external TTL trigger signal <Num>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR triggerSignal/Channel number.
/// HIPAR triggerMeasSequence/This control selects the Triggered Meas. Sequence.
/// HIPAR slopeLevel/Qualifies whether the multiple trigger events occur on the rising or
/// HIPAR slopeLevel/on the falling edge or on the beginning of the high / low level periods
/// HIPAR slopeLevel/of the external TTL trigger signal <Num>.
ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerSlope(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   triggerSignal,
                                                      ViInt32   triggerMeasSequence,
                                                      ViInt32   slopeLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerSignal, 1, 2),
            3, "Trigger Signal");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerMeasSequence, RSZNL_VAL_TRIGGER_SEQUENCE_SWEEP, RSZNL_VAL_TRIGGER_SEQUENCE_PARTIAL_MEAS),
            4, "Trigger Meas Sequence");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, slopeLevel, RSZNL_VAL_TRIGGER_SLOPE_POSITIVE, RSZNL_VAL_TRIGGER_SLOPE_LOW),
            5, "Slope/Level");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG%ld:SEQ:MULT:SLOP%ld %s,%s", channel, triggerSignal,
        RsZnl_rngTriggeredMeasSequence.entries[triggerMeasSequence].cmdString,
        RsZnl_rngTriggerSlope.entries[slopeLevel].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets a delay time between the trigger event and the
/// HIFN  start of the measurement (Trigger Delay) in multiple trigger mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR triggerMeasSequence/This control selects the Triggered Meas. Sequence.
/// HIPAR triggerDelay/Sets a delay time between the trigger event and the start of the
/// HIPAR triggerDelay/measurement (Trigger Delay) in multiple trigger mode.
ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerDelay(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   triggerMeasSequence,
                                                      ViReal64  triggerDelay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerMeasSequence, RSZNL_VAL_TRIGGER_SEQUENCE_SWEEP, RSZNL_VAL_TRIGGER_SEQUENCE_PARTIAL_MEAS),
            4, "Trigger Meas Sequence");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, triggerDelay, 0.0, 13680.0), 4, "Trigger Delay");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG%ld:SEQ:MULT:HOLD %s,%.12lG", channel,
        RsZnl_rngTriggeredMeasSequence.entries[triggerMeasSequence].cmdString,
        triggerDelay);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function creates a new trace in the current diagram area and
/// HIFN  assigns it to the selected channel. The new trace is created with the
/// HIFN  default trace and channel settings. Trace is not displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_TraceAdd(ViSession instrSession,
                                 ViInt32   channel,
                                 ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_RF_CHANNEL_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", channel);

    checkErr(RsCore_AddRepCap(instrSession, "Channel", repCap, repCap_cmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:SDEF '%s','S21'", channel, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function creates a new trace in a new diagram area and assigns
/// HIFN  the trace to the selected channel. The new trace is created with the
/// HIFN  default trace and channel settings and displayed in the new diagram
/// HIFN  area.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     A trace can be assigned to a diagram only once. If a attempt is made
/// HIFN  to assign the same trace a second time an error message -114,"Header
/// HIFN  suffix out of range" is generated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_TraceAddDiagramArea(ViSession instrSession,
                                            ViInt32   window,
                                            ViInt32   channel,
                                            ViString  traceName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_TraceAdd(instrSession, channel, traceName));

    checkErr(rsznl_TraceAssignDiagramArea(instrSession, window, traceName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function assigns an existing trace to a diagram area, and
/// HIFN  displays the trace. Use DISPlay[:WINDow<Wnd>]:TRACe<WndTr>:FEED to
/// HIFN  assign the trace to a diagram area using a numeric suffix
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) You can open the trace manager (DISPlay:MENU:KEY:EXECute 'Trace
/// HIFN  Manager') to obtain an overview of all channels and traces, including
/// HIFN  the traces that are not displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_TraceAssignDiagramArea(ViSession instrSession,
                                               ViInt32   window,
                                               ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Win%ld", window);
    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", window);

    checkErr(RsCore_AddRepCap(instrSession, "Window", repCap, repCap_cmd));

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TRACE_DIAGRAM_STATE, VI_TRUE));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_ASSIGN_DIAGRAM, traceName),
            3, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function releases the assignment between a trace and a diagram
/// HIFN  area, as defined by means of DISPlay:WINDow<Wnd>:TRACe<WndTr>:FEED
/// HIFN  <Trace_Name> and expressed by the <WndTr> suffix. The trace itself is
/// HIFN  not deleted; this must be done via function rsznl_TraceDelete.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR window_Trace/Trace number used to distinguish the traces of the same diagram area
/// HIPAR window_Trace/<Wnd>.
ViStatus _VI_FUNC rsznl_TraceUnassignDiagramArea(ViSession instrSession,
                                                 ViInt32   window,
                                                 ViInt32   window_Trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:DEL", window, window_Trace);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides an existing trace, identified by its trace name
/// HIFN  (CALCulate<Ch>:PARameter:SDEFine <Trace_Name>), or a group of traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceType/This control selects the type of trace.
/// HIPAR singleTraceName/Define trace name.
/// HIPAR showTrace/This control displays or hides trace(s).
ViStatus _VI_FUNC rsznl_ConfigureTraceDisplayState(ViSession instrSession,
                                                   ViInt32   traceType,
                                                   ViString  singleTraceName,
                                                   ViBoolean showTrace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (traceType)
    {
    case RSZNL_VAL_DISP_TRAC_DATA:
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:SHOW DALL,%s", showTrace ? "ON" : "OFF");
        break;
    }
    case RSZNL_VAL_DISP_TRAC_MEM:
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:SHOW MALL,%s", showTrace ? "ON" : "OFF");
        break;
    }
    case RSZNL_VAL_DISP_TRAC_SING:
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:SHOW '%s',%s", singleTraceName, showTrace ? "ON" : "OFF");
        break;
    }
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, traceType), 2, "Trace Type");
        break;
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects an existing trace as the active trace of the channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_TraceSelect(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_SELECT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_SELECT, traceName),
            3, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes a trace with a specified trace name and channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_TraceDelete(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_DELETE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_DELETE, traceName),
            3, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes all traces in channel no. <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_TraceDeleteAll(ViSession instrSession,
                                       ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_DELETE_ALL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_DELETE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes all traces in all channels of the active recall
/// HIFN  set, including the default trace Trc1 in channel 1. The manual control
/// HIFN  screen shows "No Trace".
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_TraceDeleteAllChannels(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_TRACE_DELETE_ALL_CHANNELS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the trace names and measurement parameters of
/// HIFN  all traces assigned to a particular channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR catalog/Response is a string parameter with comma-separated list of trace
/// HIPAR catalog/names and measurement parameters, e.g. 'CH4TR1,S11,CH4TR2,S12'. The
/// HIPAR catalog/measurement parameters are returned according to the naming convention
/// HIPAR catalog/of CALCulate<Ch>:PARameter:SDEFine. The order of traces in the list
/// HIPAR catalog/reflects their creation time: The oldest trace is the first, the newest
/// HIPAR catalog/trace is the last trace in the list.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_TraceList(ViSession instrSession,
                                  ViInt32   channel,
                                  ViChar    catalog[],
                                  ViInt32   bufferSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_CHANNEL_CATALOG,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_CHANNEL_CATALOG,
            bufferSize, catalog),
            4, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the trace names and measurement parameters of
/// HIFN  all traces assigned to a particular channel. In presence of balanced
/// HIFN  ports, this function distinguishes between:
/// HIFN
/// HIFN     - single-ended S-parameters for logical ports (SSS<Li><Lj>)
/// HIFN     - "raw" single-ended S-parameters referring to physical ports
/// HIFN  (S<Pi><Pj>)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR catalog/Response is a string parameter with comma-separated list of trace
/// HIPAR catalog/names and measurement parameters, e.g. 'CH4TR1,S11,CH4TR2,S12'. The
/// HIPAR catalog/measurement parameters are returned according to the naming convention
/// HIPAR catalog/of CALCulate<Ch>:PARameter:SDEFine. The order of traces in the list
/// HIPAR catalog/reflects their creation time: The oldest trace is the first, the newest
/// HIPAR catalog/trace is the last trace in the list.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_TraceListBalancedPorts(ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar    catalog[],
                                               ViInt32   bufferSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_CHANNEL_CATALOG_BALANCED_PORTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_CHANNEL_CATALOG_BALANCED_PORTS,
            bufferSize, catalog),
            4, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function assigns a new name to a trace. The trace does not have
/// HIFN  to be the active trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR oldTraceName/Define old trace name name.
/// HIPAR newTraceName/Define new trace name.
ViStatus _VI_FUNC rsznl_TraceRename(ViSession instrSession,
                                    ViString  oldTraceName,
                                    ViString  newTraceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:REN '%s','%s'", oldTraceName, newTraceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function assigns a new name to the active trace in channel <ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define new trace name.
ViStatus _VI_FUNC rsznl_ChannelTraceRename(ViSession instrSession,
                                           ViInt32   channel,
                                           ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_CHANNEL_RENAME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_CHANNEL_RENAME, traceName),
            3, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the numbers and names of all traces in the
/// HIFN  current setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR catalog/Returns string with comma-separated list of trace numbers and names.
/// HIPAR catalog/If all traces have been deleted the response is an empty string ("")
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_TraceListCatalog(ViSession instrSession,
                                         ViChar    catalog[],
                                         ViInt32   bufferSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_TRACE_CATALOG,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the numbers and names of all traces in channel
/// HIFN  no. <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR catalog/Returns the numbers and names of all traces in channel no. <Ch>. The
/// HIPAR catalog/response is a string containing a comma-separated list of trace numbers
/// HIPAR catalog/and names. If all traces have been deleted the response is an empty
/// HIPAR catalog/string ("").
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_TraceListChannelCatalog(ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    catalog[],
                                                ViInt32   bufferSize)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_NAME_CATALOG,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_NAME_CATALOG,
            bufferSize, catalog),
            4, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the trace <Trc> name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceNumber/Trace number.
/// HIPAR traceName/Returns the trace name.
ViStatus _VI_FUNC rsznl_QueryTraceName(ViSession instrSession,
                                       ViInt32   traceNumber,
                                       ViChar    traceName[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE + 2];
    ViUInt32 count = 0;
    ViChar   fmtString[RS_MAX_MESSAGE_LEN];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC%ld:NAME?", traceNumber);
    checkErr(rsznl_QueryViString(instrSession, cmd, RS_MAX_MESSAGE_BUF_SIZE + 2, rd_buffer, &count));

    snprintf(fmtString, 50, "'%%%ld[^']", RS_MAX_MESSAGE_BUF_SIZE);

    (void)sscanf(rd_buffer, fmtString, traceName);  // NOLINT(clang-diagnostic-format-nonliteral)

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the trace number (numeric suffix) of a trace
/// HIFN  with known trace name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Sets the trace name.
/// HIPAR traceNumber/Returns the trace number (numeric suffix) of a trace with known trace
/// HIPAR traceNumber/name.
ViStatus _VI_FUNC rsznl_QueryTraceNumber(ViSession instrSession,
                                         ViString  traceName,
                                         ViInt32*  traceNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:NAME:ID? '%s'", traceName);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, traceNumber));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the number of the diagram which the trace is
/// HIFN  assigned to. A zero is returned when the trace is not
/// HIFN  assigned/displayed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Sets the trace name.
/// HIPAR traceNumber/Returns the trace number within a diagram which is assigned to the
/// HIPAR traceNumber/trace <TraceName> is assigned to. A zero is returned when the trace is
/// HIPAR traceNumber/not assigned/displayed.
/// HIPAR diagramNumber/Returns the number of the diagram which the trace is assigned to. A
/// HIPAR diagramNumber/zero is returned when the trace is not assigned/displayed.
ViStatus _VI_FUNC rsznl_QueryTraceDiagramNumber(ViSession instrSession,
                                                ViString  traceName,
                                                ViInt32*  traceNumber,
                                                ViInt32*  diagramNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:WIND? '%s'", traceName);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, traceNumber));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:WIND:TRAC? '%s'", traceName);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, diagramNumber));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the channel name for an existing trace named
/// HIFN  '<Trc_name>'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Sets the trace name.
/// HIPAR channelName/Returns the channel name for an existing trace.
ViStatus _VI_FUNC rsznl_QueryTraceChannelName(ViSession instrSession,
                                              ViString  traceName,
                                              ViChar    channelName[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE + 2];
    ViUInt32 count = 0;
    ViChar   formaString[RS_MAX_MESSAGE_LEN] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:CHAN:NAME? '%s'", traceName);
    checkErr(rsznl_QueryViString(instrSession, cmd, RS_MAX_MESSAGE_BUF_SIZE + 2, rd_buffer, &count));

    snprintf(formaString, 50, "'%%%ld[^']", RS_MAX_MESSAGE_BUF_SIZE);

    (void)sscanf(rd_buffer, formaString, channelName);  // NOLINT(clang-diagnostic-format-nonliteral)

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns channel number (numeric suffix) for an existing
/// HIFN  trace named '<Trc_name>'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Sets the trace name.
/// HIPAR channelNumber/Returns the channel number (numeric suffix) for an existing trace.
ViStatus _VI_FUNC rsznl_QueryTraceChannelNumber(ViSession instrSession,
                                                ViString  traceName,
                                                ViInt32*  channelNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TRAC:CHAN:NAME:ID? '%s'", traceName);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, channelNumber));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Copies the current state of the active data trace to a memory trace.
/// HIFN  If a mathematical trace is active, the data trace associated with the
/// HIFN  mathematical trace is copied.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_TraceDataToMemory(ViSession instrSession,
                                          ViInt32   channel_Trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_COPY_TO_MEMORY,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_COPY_TO_MEMORY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function copies a data trace to a memory trace. The trace to be
/// HIFN  copied is specified as a trace with a name (string variable). The
/// HIFN  created memory trace is specified as a memory trace with an arbitrary
/// HIFN  name (string variable). An existing memory trace with the same name is
/// HIFN  overwritten.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The copied trace is the data trace which is not modified by any
/// HIFN  mathematical operations. To copy a mathematical trace to a memory
/// HIFN  trace, use rsznl_TraceMathToMemoryTrace function. To copy the active
/// HIFN  trace to the memory using an automatic memory trace name, use
/// HIFN  rsznl_TraceDataToMemory function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memoryTrace/Name of the memory trace.
/// HIPAR dataTrace/Name of the data trace.
ViStatus _VI_FUNC rsznl_TraceDataToMemoryTrace(ViSession instrSession,
                                               ViString  memoryTrace,
                                               ViString  dataTrace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRAC:COPY '%s','%s'", memoryTrace, dataTrace);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function copies a mathematical trace to a memory trace. The trace
/// HIFN  to be copied is specified as a trace with a name (string variable). The
/// HIFN  created memory trace is specified as a memory trace with an arbitrary
/// HIFN  name (string variable). An existing memory trace with the same name is
/// HIFN  overwritten.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) To copy a data trace which is not modified by any mathematical
/// HIFN  operations, use rsznl_TraceDataToMemoryTrace function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memoryTrace/Name of the memory trace.
/// HIPAR dataTrace/Name of the data trace.
ViStatus _VI_FUNC rsznl_TraceMathToMemoryTrace(ViSession instrSession,
                                               ViString  memoryTrace,
                                               ViString  dataTrace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRAC:COPY:MATH '%s','%s'", memoryTrace, dataTrace);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes one of the memory traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memTraceDelete/Deletes one of the memory traces.
ViStatus _VI_FUNC rsznl_DeleteMemoryTrace(ViSession instrSession,
                                          ViInt32   memTraceDelete)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_MEM_TRACE_DELETE, memTraceDelete),
            2, "Mem Trace Delete");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes all memory traces in channel <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeleteMemoryTraceAll(ViSession instrSession,
                                             ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_DELETE_ALL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_DELETE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function deletes all memory traces in all channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_DeleteMemoryTraceAllChannel(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_MEM_TRACE_DELETE_ALL_CHANNELS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the trace Math Formatted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR enabled/Activates or deactivates trace math for unformatted and/or formatted
/// HIPAR enabled/trace data, i.e. the trace formulae defined via
/// HIPAR enabled/CALCulate<Chn>:MATH[:EXPRession]:SDEFine and/or
/// HIPAR enabled/CALCulate<Chn>:MATH:FORMatted[:EXPRession]:SDEFine, respectively.
/// HIPAR expression/This control activates the mathematical mode where the active data
/// HIPAR expression/trace is divided by the last generated memory trace. The division is
/// HIPAR expression/calculated on a point-to-point basis: Each measurement point of the
/// HIPAR expression/active trace is divided by the corresponding measurement point of the
/// HIPAR expression/memory trace. The result of the division is a mathematical trace and
/// HIPAR expression/replaces the active data trace in the diagram area. The mathematical
/// HIPAR expression/trace is updated as the measurement goes on and the analyzer provides
/// HIPAR expression/new active trace data.
/// HIPAR function/Defines a simple mathematical trace based on the active trace and its
/// HIPAR function/active memory trace. The first command applies to raw, unformatted
/// HIPAR function/trace data (complex data), the second to formatted trace data. Both
/// HIPAR function/methods can be combined.
ViStatus _VI_FUNC rsznl_ConfigureMemoryTraceMathFormatted(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViBoolean enabled,
                                                          ViString  expression,
                                                          ViInt32   function)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_EXPRESSION, expression),
            4, "Expression");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_FUNCTION, function),
            5, "Function");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates the mathematical mode where the active data
/// HIFN  trace is divided by the last generated memory trace. The division is
/// HIFN  calculated on a point-to-point basis: Each measurement point of the
/// HIFN  active trace is divided by the corresponding measurement point of the
/// HIFN  memory trace. The result of the division is a mathematical trace and
/// HIFN  replaces the active data trace in the diagram area. The mathematical
/// HIFN  trace is updated as the measurement goes on and the analyzer provides
/// HIFN  new active trace data.
/// HIFN
/// HIFN     This function is disabled unless a memory trace is coupled to the
/// HIFN  active data trace. Trace coupling ensures that the two traces have the
/// HIFN  same number of points so that the mathematical trace Data/Mem.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR mathematicalExpression/String parameter for the mathematical expression, enclosed in
/// HIPAR mathematicalExpression/brackets. Defines a general mathematical relation between traces.
ViStatus _VI_FUNC rsznl_TraceUserDefinedMath(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViString  mathematicalExpression)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_MATH_EXPRESSION,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_EXPRESSION, mathematicalExpression),
            3, "Mathematical Expression");

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_MODE_STATE, VI_TRUE));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates or deactivates the mathematical mode where the
/// HIFN  mathematical trace defined via rsznl_TraceUserDefinedMath function is
/// HIFN  calculated and displayed instead of the active data trace.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function is not valid for mathematical traces calculated via
/// HIFN  rsznl_ConfigureTraceMathFunction function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR mathState/Activates or deactivates the mathematical mode (ON - Display the
/// HIPAR mathState/active data trace, OFF - Display the mathematical trace).
ViStatus _VI_FUNC rsznl_ConfigureTraceMathState(ViSession instrSession,
                                                ViInt32   channel_Trace,
                                                ViBoolean mathState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_MATH_MODE_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_MODE_STATE, mathState),
            3, "Math State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines a simple mathematical relation between the
/// HIFN  active trace and the active memory trace to calculate a new
/// HIFN  mathematical trace and displays the mathematical trace.
/// HIFN
/// HIFN     Notes:
/// HIFN
/// HIFN     (1) This command places some restrictions on the mathematical
/// HIFN  expression and the operands. Use rsznl_TraceUserDefinedMath function to
/// HIFN  define general expressions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR mathematicalFunction/This control defines a simple mathematical relation between the active
/// HIPAR mathematicalFunction/trace and the active memory trace to calculate a new mathematical trace
/// HIPAR mathematicalFunction/and displays the mathematical trace.
ViStatus _VI_FUNC rsznl_ConfigureTraceMathFunction(ViSession instrSession,
                                                   ViInt32   channel_Trace,
                                                   ViInt32   mathematicalFunction)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_MATH_FUNCTIONS,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_FUNCTIONS, mathematicalFunction),
            3, "Mathematical Function");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function controls the conversion and formatting of the mathematic
/// HIFN  expression defined via rsznl_TraceUserDefinedMath function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR mathWaveQuantityState/Controls the conversion and formatting of the mathematic expression.
ViStatus _VI_FUNC rsznl_ConfigureTraceMathWaveQuantityState(ViSession instrSession,
                                                            ViInt32   channel_Trace,
                                                            ViBoolean mathWaveQuantityState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MEM_TRACE_MATH_WAVE_QUANTITY_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MEM_TRACE_MATH_WAVE_QUANTITY_STATE, mathWaveQuantityState),
            3, "Math Wave Quantity State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the time domain settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR timeDomain/This control determines whether the time domain transformation for
/// HIPAR timeDomain/trace no. <Channel> is enabled.
/// HIPAR type/Selects the time domain transformation type.
/// HIPAR impulseResponse/Selects the window type for filtering the data in the frequency domain
/// HIPAR impulseResponse/prior to the time domain transformation.
/// HIPAR sideLobeLevel/This control sets the sideband suppression for the Dolph-Chebyshev
/// HIPAR sideLobeLevel/window.
/// HIPAR resolutionEnhancement/This control sets the resolution enhancement factor.
ViStatus _VI_FUNC rsznl_ConfigureTimeDomain(ViSession instrSession,
                                            ViInt32   channel,
                                            ViBoolean timeDomain,
                                            ViInt32   type,
                                            ViInt32   impulseResponse,
                                            ViReal64  sideLobeLevel,
                                            ViReal64  resolutionEnhancement)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_STATE, timeDomain),
            3, "Time Domain");

    switch (type)
    {
    case RSZNL_VAL_TYPE_BPAS_IMP:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_TYPE, RSZNL_VAL_TYPE_BAND_PASS),
                4, "Type");

        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_STIMULUS, RSZNL_VAL_STIMULUS_IMPULSE),
                4, "Type - Stimulus");
        break;

    case RSZNL_VAL_TYPE_LPAS_IMP:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_TYPE, RSZNL_VAL_TYPE_LOW_PASS),
                4, "Type");

        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_STIMULUS, RSZNL_VAL_STIMULUS_IMPULSE),
                4, "Type - Stimulus");
        break;

    case RSZNL_VAL_TYPE_LPAS_STEP:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_TYPE, RSZNL_VAL_TYPE_LOW_PASS),
                4, "Type");

        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_STIMULUS, RSZNL_VAL_STIMULUS_STEP),
                4, "Type - Stimulus");
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, type), 4, "Type");
    }

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_IMPULSE_RESPONSE, impulseResponse),
            5, "Impulse Response");

    if (impulseResponse == RSZNL_VAL_FILTER_DCHEBYSHEV)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_SIDE_LOBE_LEVEL, sideLobeLevel),
                6, "Side Lobe Level");
    }

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_RESOLUTION_ENHANCEMENT, resolutionEnhancement),
            7, "Resolution Enhancement");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function calculates the harmonic grid for low pass time domain
/// HIFN  transforms according to one of the three alternative algorithms.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR calculationMethod/Calculates the harmonic grid for low pass time domain transforms
/// HIPAR calculationMethod/according to one of the three alternative algorithms.
ViStatus _VI_FUNC rsznl_ConfigureHarmonicGridAndKeep(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   calculationMethod)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_HARMONIC_GRID_AND_KEEP,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_HARMONIC_GRID_AND_KEEP, calculationMethod),
            3, "Calculation Method");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Extrapolates the measured trace towards f = 0 and overwrites the
/// HIFN  current DC value (RSZNL_ATTR_TIME_DOMAIN_DC_VALUE).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_ExtrapolateDCValue(ViSession instrSession,
                                           ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_EXTRAPOLATE_DC_VALUE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_EXTRAPOLATE_DC_VALUE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the DC value for low pass transforms. The attribute is enabled
/// HIFN  only if the sweep points are on a harmonic grid (to be set explicitly
/// HIFN  or using RSZNL_ATTR_TIME_DOMAIN_HARMONIC_GRID_AND_KEEP).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR dcValue/Defines the DC value for low pass transforms. The control is enabled
/// HIPAR dcValue/only if the sweep points are on a harmonic grid (to be set explicitly
/// HIPAR dcValue/or using RSZNL_ATTR_TIME_DOMAIN_HARMONIC_GRID_AND_KEEP).
ViStatus _VI_FUNC rsznl_ConfigureDCValue(ViSession instrSession,
                                         ViInt32   channel,
                                         ViReal64  dcValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_DC_VALUE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DC_VALUE, dcValue),
            3, "DC Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Calculates the harmonic grid for low pass time domain transforms,
/// HIFN  keeping the stop frequency and the number of points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_CalculateHarmonicGrid(ViSession instrSession,
                                              ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_CALCULATE_HARMONIC_GRID,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_CALCULATE_HARMONIC_GRID, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Turns the 'Automatic Harmonic Grid'  function ON or OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR automatic/Turns the 'Automatic Harmonic Grid'  function ON or OFF.
ViStatus _VI_FUNC rsznl_ConfigureAutomaticHarmonicGrid(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean automatic)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_AUTOMATIC_HARMONIC_GRID,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_AUTOMATIC_HARMONIC_GRID, automatic),
            3, "Automatic");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries whether the current frequency grid is harmonic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR harmonicGrid/Queries whether the current frequency grid is harmonic.
ViStatus _VI_FUNC rsznl_QueryHarmonicGrid(ViSession  instrSession,
                                          ViInt32    channel,
                                          ViBoolean* harmonicGrid)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_GRID_HARMONIC,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_GRID_HARMONIC, harmonicGrid),
            3, "Harmonic Grid");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Determines whether continuous extrapolation for the DC value is
/// HIFN  enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR continuousExtrapolation/Determines whether continuous extrapolation for the DC value is
/// HIPAR continuousExtrapolation/enabled.
ViStatus _VI_FUNC rsznl_ConfigureContinuousExtrapolation(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean continuousExtrapolation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_CONTINUOUS_EXTRAPOLATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_CONTINUOUS_EXTRAPOLATION, continuousExtrapolation),
            3, "Continuous Extrapolation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the harmonic of the DUT.
/// HIFN
/// HIFN     It automatically activates the 'Automatic Harmonic Grid'  function,
/// HIFN  i.e. it sets RSZNL_ATTR_TIME_DOMAIN_AUTOMATIC_HARMONIC_GRID to ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR expectedMaxTimeDelay/Sets/gets the expected maximum time delay through the DUT.
/// HIPAR expectedMaxElectricalLength/Sets/gets the expected maximum electrical length of the DUT.
/// HIPAR expectedMaxMechanicalLength/Sets/gets the expected maximum mechanical length of the DUT.
/// HIPAR relativePermitivity/Sets/gets the (relative) permittivity of the DUT.
/// HIPAR minimumRiseTime/Sets/gets the minimum rise time the user wishes to measure on the DUT.
/// HIPAR riseTimeThreshold/Defines how the rise time that is set using
/// HIPAR riseTimeThreshold/RSZNL_ATTR_TIME_DOMAIN_DUT_MINIMUM_RISE_TIME shall be interpreted.
/// HIPAR riseTimeThreshold/Allows to select between rise time definitions 20%-80% (default) and
/// HIPAR riseTimeThreshold/10%-90%.
/// HIPAR velocityFactor/Sets/gets the velocoty factor of the DUT.
ViStatus _VI_FUNC rsznl_ConfigureHarmonicDUT(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  expectedMaxTimeDelay,
                                             ViReal64  expectedMaxElectricalLength,
                                             ViReal64  expectedMaxMechanicalLength,
                                             ViReal64  relativePermitivity,
                                             ViReal64  minimumRiseTime,
                                             ViInt32   riseTimeThreshold,
                                             ViReal64  velocityFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_TIME_DELAY,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_TIME_DELAY, expectedMaxTimeDelay),
            3, "Expected Max Time Delay");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_ELECTRICAL_LENGTH, expectedMaxElectricalLength),
            4, "Expected Max Electrical Length");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_MECHANICAL_LENGTH, expectedMaxMechanicalLength),
            5, "Expected Max Mechanical Length");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_RELATIVE_PERMITTIVITY, relativePermitivity),
            6, "Relative Permitivity");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_MINIMUM_RISE_TIME, minimumRiseTime),
            7, "Minimum Rise Time");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_RISE_TIME_THRESHOLD, riseTimeThreshold),
            8, "Rise Time Threshold");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_DOMAIN_DUT_VELOCITY_FACTOR, velocityFactor),
            9, "Velocity Factor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the time gate settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR timeGate/This control determines whether the time gate is enabled.
/// HIPAR timeGateType/Selects the time gate filter type, defining what occurs to the data in
/// HIPAR timeGateType/the specific time region.
/// HIPAR rangeLines/This control enables or disables permanent display of the gate limits.
/// HIPAR filterType/Selects the time gate to be applied to the time domain transform.
/// HIPAR sideLobeLevel/Sets the sideband suppression for the Dolph-Chebyshev time gate. The
/// HIPAR sideLobeLevel/control is only available if a Dolph-Chebyshev time gate is active
/// HIPAR sideLobeLevel/(RSZNL_ATTR_TIME_GATE_FILTER_TYPE set to Arbitrary Sidelobes
/// HIPAR sideLobeLevel/(Dolph-Chebychev)).
ViStatus _VI_FUNC rsznl_ConfigureTimeGate(ViSession instrSession,
                                          ViInt32   channel,
                                          ViBoolean timeGate,
                                          ViInt32   timeGateType,
                                          ViBoolean rangeLines,
                                          ViInt32   filterType,
                                          ViReal64  sideLobeLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_GATE_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_GATE_STATE, timeGate),
            3, "Time Gate");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_GATE_TYPE, timeGateType),
            4, "Time Gate Type");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TIME_GATE_SHOW_RANGE_LINES, rangeLines),
            5, "Range Lines");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TIME_GATE_FILTER_TYPE, filterType),
            6, "Filter Type");

    if (filterType == RSZNL_VAL_FILTER_DCHEBYSHEV)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_GATE_SIDE_LOBE_LEVEL, sideLobeLevel),
                7, "Side Lobe Level");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the start and stop times of the time gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR startTime/This control define the start time of the time gate.
/// HIPAR stopTime/This control define the stop time of the time gate.
ViStatus _VI_FUNC rsznl_ConfigureTimeGateStartStop(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  startTime,
                                                   ViReal64  stopTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_GATE_START_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_GATE_START_TIME, startTime),
            3, "Start Time");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_GATE_STOP_TIME, stopTime),
            4, "Stop Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the center and span times of the time gate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR centerTime/Defines the center time of the time gate.
/// HIPAR span/Defines the span of the time gate.
ViStatus _VI_FUNC rsznl_ConfigureTimeGateCenterSpan(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  centerTime,
                                                    ViReal64  span)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_GATE_CENTER_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_GATE_CENTER_TIME, centerTime),
            3, "Center Time");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TIME_GATE_SPAN, span),
            4, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the operating mode where the time gate is moved in the
/// HIFN  opposite direction when the "Delay" setting is changed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR adjustTimeGate/This control enables or disables "Adjust Time Gate".
ViStatus _VI_FUNC rsznl_ConfigureTimeGateOffsetActivation(ViSession instrSession,
                                                          ViBoolean adjustTimeGate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_TIME_GATE_OFFSET_STATE, adjustTimeGate),
            2, "Adjust Time Gate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If channel <Chn> is performing an unsegmented frequency sweep, this
/// HIFN  attribute allows to transform its active trace into a Distance to Fault
/// HIFN  (DtF) trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR state/If channel <Chn> is performing an unsegmented frequency sweep, this
/// HIPAR state/control allows to transform its active trace into a Distance to Fault
/// HIPAR state/(DtF) trace.
ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultState(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the window of the Distance to Fault measurement using its
/// HIFN  start and stop distance.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR startDistance/Defines the window of the Distance to Fault measurement using its
/// HIPAR startDistance/start distance.
/// HIPAR stopDistance/Defines the window of the Distance to Fault measurement using its stop
/// HIPAR stopDistance/distance.
ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultStartStopDistance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  startDistance,
                            ViReal64  stopDistance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_START_DISTANCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_START_DISTANCE, startDistance),
            3, "Start Distance");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_STOP_DISTANCE, stopDistance),
            3, "Stop Distance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the distance window of the Distance to Fault measurement using
/// HIFN  its center and span.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR center/Defines the distance window of the Distance to Fault measurement using
/// HIPAR center/its center.
/// HIPAR span/Defines the distance window of the Distance to Fault measurement using
/// HIPAR span/its span.
ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultCenterSpan(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64  center,
                                                           ViReal64  span)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_CENTER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_CENTER, center),
            3, "Center");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_SPAN, span),
            3, "Span");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIFN  trace, this attribute starts the 'Auto Number of Points' calculation.
/// HIFN  An execution error is raised, if the calculated number of points is
/// HIFN  higher than the maximum number of sweep points the firmware allows
/// HIFN  (100001).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_DistanceToFaultAutoNumberOfPoints(ViSession instrSession,
                                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_AUTO_NUMBER_OF_POINTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_AUTO_NUMBER_OF_POINTS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects one of the available (predefined or user-defined) cable types
/// HIFN  for Distance to Fault measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR cableType/Selects one of the available (predefined or user-defined) cable types
/// HIPAR cableType/for Distance to Fault measurements.
ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultCableType(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViString  cableType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_SELECT_CABLE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_SELECT_CABLE, cableType),
            3, "Cable Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a new user-defined cable type for Distance to Fault (DtF)
/// HIFN  measurements. The cable's frequency-dependent attenuation is defined
/// HIFN  via attenuation/frequency pairs <cableAttenuation1>, <cableFrequency1>,
/// HIFN  <cableAttenuation2>, <cableFrequency2>, .... At least one pair has to
/// HIFN  be specified.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR name/Name of the cable type. Must be unique among all DtF cable types, with
/// HIPAR name/case insensitive match.
/// HIPAR permittivity/Relative permittivity of the cable type.
/// HIPAR arraySize/Sets the number of elements in following arrays.
/// HIPAR attenuation/Array of attenuation values in the frequency-dependent attenuation
/// HIPAR attenuation/table of the cable type.
/// HIPAR frequency/Array of frequencies in the frequency-dependent attenuation table of
/// HIPAR frequency/the cable type.
ViStatus _VI_FUNC rsznl_DistanceToFaultDefineUserDefinedCableType(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  name,
                            ViReal64  permittivity,
                            ViInt32   arraySize,
                            ViReal64  attenuation[],
                            ViReal64  frequency[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:DTF:DEF '%s',%.12lG,%.12lG,%.12lG",
        channel, name, permittivity, attenuation[0], frequency[0]);

    for (i = 1; i < arraySize; i++)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%.12lG,%.12lG", attenuation[i], frequency[i]);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes the user-defined cable type with the given name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR name/Deletes the user-defined cable type with the given name.
ViStatus _VI_FUNC rsznl_DistanceToFaultDeleteUserDefinedCableType(
                            ViSession instrSession,
                            ViString  name)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DISTANCE_TO_FAULT_DELETE_USER_DEFINED_CABLE_TYPE, name),
            3, "Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Saves all predefined and user-defined Distance to Fault (DtF) cable
/// HIFN  types to the specified output directory. Each DtF cable type is stored
/// HIFN  in a separate ASCII file <cable name>.rsc. The attribute silently
/// HIFN  overwrites files of the same name previously existing in the output
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Saves all predefined and user-defined Distance to Fault (DtF) cable
/// HIPAR path/types to the specified output directory. Each DtF cable type is stored
/// HIPAR path/in a separate ASCII file <cable name>.rsc. The control silently
/// HIPAR path/overwrites files of the same name previously existing in the output
/// HIPAR path/directory.
ViStatus _VI_FUNC rsznl_DistanceToFaultExportCableTypes(ViSession instrSession,
                                                        ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DISTANCE_TO_FAULT_EXPORT_CABLE_TYPES, path),
            2, "Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Loads Distance to Fault (DtF) cable type files (*.rsc) from the
/// HIFN  specified input directory. Cable types are loaded 'by name',
/// HIFN  overwriting user-defined cable types of the same name. Predefined cable
/// HIFN  types of the same name will not be overwritten.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Loads Distance to Fault (DtF) cable type files (*.rsc) from the
/// HIPAR path/specified input directory. Cable types are loaded 'by name',
/// HIPAR path/overwriting user-defined cable types of the same name. Predefined cable
/// HIPAR path/types of the same name will not be overwritten.
ViStatus _VI_FUNC rsznl_DistanceToFaultImportCableTypes(ViSession instrSession,
                                                        ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DISTANCE_TO_FAULT_IMPORT_CABLE_TYPES, path),
            2, "Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Congigures the Distance to Fault limit check.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR state/If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIPAR state/trace, this control allows to enable/disable DtF limit checking.
/// HIPAR limit/If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIPAR limit/trace, this control allows to set the fault limit for DtF limit
/// HIPAR limit/checking. Use RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE to enable
/// HIPAR limit/DtF limit checking.
ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultLimitCheck(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean state,
                                                           ViReal64  limit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE, state),
            3, "State");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK, limit),
            4, "Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIFN  trace and DtF limit checking is enabled, this query returns the number
/// HIFN  of DtF limit violations of this trace. Use
/// HIFN  RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE to enable DtF limit
/// HIFN  checking and RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK to set the fault
/// HIFN  limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR count/If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIPAR count/trace and DtF limit checking is enabled, this query returns the number
/// HIPAR count/of DtF limit violations of this trace. Use
/// HIPAR count/RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE to enable DtF limit
/// HIPAR count/checking and RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK to set the fault
/// HIPAR count/limit.
ViStatus _VI_FUNC rsznl_QueryDistanceToFaultLimitViolationsCount(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_VIOLATIONS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_VIOLATIONS, count),
            3, "Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If the active trace of channel <Chn> is a Distance to Fault (DtF)
/// HIFN  trace and DtF limit checking is enabled, this function returns the peak
/// HIFN  data of DtF limit violation <FaultNo>. Peaks are numbered according to
/// HIFN  their distance (fault no. 1 has the smallest distance).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR faultNumber/Fault number - must be between 1 and
/// HIPAR faultNumber/RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_VIOLATIONS.
/// HIPAR distance/Returned distance of the limit violation.
/// HIPAR response/Returned response value of the limit violation.
ViStatus _VI_FUNC rsznl_DistanceToFaultLimitViolationsPeakData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   faultNumber,
                            ViReal64  distance[],
                            ViReal64  response[])
{
    ViStatus  error = VI_SUCCESS;
    ViChar    cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViReal64* results = NULL;
    ViInt32   count = 0;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:DTF:PEAK:DATA%ld?", channel, faultNumber);
    checkErr(RsCore_QueryAsciiViReal64Array(instrSession, cmd, &results, &count));

    *distance = results[0];
    *response = results[1];

Error:
    if (results) free(results);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides the results in the diagram area of trace no. <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR minMaxPeakPeak/Displays or hides the 'Min/Max/PeakPeak' results in the diagram area
/// HIPAR minMaxPeakPeak/of trace no. <Chn>.
/// HIPAR meanStdDev/Displays or hides the 'Mean/Std Dev' results in the diagram area of
/// HIPAR meanStdDev/trace no. <Chn>.
/// HIPAR phaseElectricalLength/Displays or hides the 'Phase/El Length' results in the diagram area of
/// HIPAR phaseElectricalLength/trace no. <Chn>.
/// HIPAR rms/Displays or hides the 'RMS' results in the diagram area of trace no.
/// HIPAR rms/<Chn>.
/// HIPAR flatnesGainSlope/Displays or hides the 'Flatness/Gain/Slope' results in the diagram
/// HIPAR flatnesGainSlope/area of trace no. <Chn>.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsDisplayedResults(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean minMaxPeakPeak,
                                                            ViBoolean meanStdDev,
                                                            ViBoolean phaseElectricalLength,
                                                            ViBoolean rms,
                                                            ViBoolean flatnesGainSlope)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_DISPLAY_MIN_MAX_PEAK_PEAK_RESULTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_MIN_MAX_PEAK_PEAK_RESULTS, minMaxPeakPeak),
            3, "Min Max Peak-Peak");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_MEAN_STD_DEV_RESULTS, meanStdDev),
            4, "Mean Std Dev");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_PHASE_ELECTRICAL_LENGTH_RESULTS, phaseElectricalLength),
            5, "Phase Electrical Length");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_RMS_RESULTS, rms),
            6, "RMS");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_FLATNES_GAIN_SLOPE_RESULTS, flatnesGainSlope),
            7, "Flatnes Gain Slope");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function displays or hides all statistical results and moves the
/// HIFN  statistics info field for the active trace <Chn> to one of nine
/// HIFN  predefined positions in the active diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR infoField/Displays or hides all statistical results in the diagram area of trace
/// HIPAR infoField/no. <Ch/Tr>.
/// HIPAR horizontalPosition/Selects the horizontal position of the info field.
/// HIPAR verticalPosition/Selects the vertical position of the info field.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsInfoField(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean infoField,
                                                     ViInt32   horizontalPosition,
                                                     ViInt32   verticalPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, horizontalPosition, RSZNL_VAL_HORIZONTAL_LEFT, RSZNL_VAL_HORIZONTAL_RIGHT),
            4, "Horizontal Position");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, verticalPosition, RSZNL_VAL_VERTICAL_TOP, RSZNL_VAL_VERTICAL_BOTTOM),
            5, "Vertical Position");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_DISPLAY_ALL_RESULTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_DISPLAY_ALL_RESULTS, infoField),
            3, "Info Field");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:STAT:STAT:AREA %s,%s", channel,
        RsZnl_rngHorizontalPosition.entries[horizontalPosition].cmdString,
        RsZnl_rngVerticalPosition.entries[verticalPosition].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  For complex-valued traces (Smith, Polar) this determines how the MEAN,
/// HIFN  STDDev, MAX, MIN, RMS and PTPeak statistics are calculated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR format/For complex-valued traces (Smith, Polar) this determines how the MEAN,
/// HIPAR format/STDDev, MAX, MIN, RMS and PTPeak statistics are calculated.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsFormat(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   format)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_FORMAT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_FORMAT, format),
            3, "Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides range limit lines for the evaluation range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showLimitLines/Displays or hides range limit lines for the evaluation range.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsEvaluationRangeLimitLinesState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean showLimitLines)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_SHOW_LIMIT_LINES,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_SHOW_LIMIT_LINES, showLimitLines),
            3, "Show Limit Lines");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function define the range for the statistical and phase
/// HIFN  evaluation. The evaluation range is a continuous interval of the sweep
/// HIFN  variable.
/// HIFN
/// HIFN     It is possible to define and select up to ten different evaluation
/// HIFN  ranges for each setup. Full Span means that the search range is equal
/// HIFN  to the sweep range. The statistical and phase evaluation takes into
/// HIFN  account all measurement points with stimulus values xi between the
/// HIFN  Start and Stop value of the evaluation range:
/// HIFN
/// HIFN         Start  <= xi <= Stop
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR evaluationRange/Selects one out of 10 evaluation ranges.
/// HIPAR start/Defines the start value of the evaluation range.
/// HIPAR stop/Defines the stop value of the evaluation range.
ViStatus _VI_FUNC rsznl_ConfigureTraceEvaluationRange(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   evaluationRange,
                                                      ViReal64  start,
                                                      ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE, evaluationRange),
            3, "Evaluation Range");

    if (evaluationRange != RSZNL_VAL_FULL_SPAN)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_START, start),
                4, "Start");

        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_STOP, stop),
                5, "Stop");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns a single statistical parameters of the trace no.
/// HIFN  <Chn>. It is not necessary to display the info field before using this
/// HIFN  function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR statisticalParameter/Define statistical parameter.
/// HIPAR responseValue/The data is returned as a list of real numbers. The unit is the
/// HIPAR responseValue/default unit of the measured parameter.
ViStatus _VI_FUNC rsznl_QueryTraceStatisticalParameter(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   statisticalParameter,
                                                       ViReal64* responseValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:STAT:RES? %s", channel, RsZnl_rngStatisticsResults.entries[statisticalParameter].cmdString);
    checkErr(rsznl_QueryViReal64(instrSession, cmd, responseValue));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns all statistical parameters of the trace no.
/// HIFN  <Chn>. It is not necessary to display the info field before using this
/// HIFN  function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Response
/// HIPAR bufferSize/Values'.
/// HIPAR responseValues/The data is returned as a list of real numbers. The unit is the
/// HIPAR responseValues/default unit of the measured parameter.
ViStatus _VI_FUNC rsznl_QueryTraceStatisticalAllParameters(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   bufferSize,
                                                           ViReal64  responseValues[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:STAT:RES? ALL", channel);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, bufferSize, responseValues, NULL));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function activates the smoothing function for the active trace,
/// HIFN  which may be a data or a memory trace. With active smoothing function,
/// HIFN  each measurement point is replaced by the arithmetic mean value of all
/// HIFN  measurement points located in a symmetric interval centered on the
/// HIFN  stimulus value. The width of the smoothing interval is referred to as
/// HIFN  the Smoothing Apertureand can be adjusted according to the properties
/// HIFN  of the trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR smoothing/Enables or disables smoothing for trace no. <Ch/Tr>.
/// HIPAR aperture/Defines how many measurement points are averaged to smooth the trace.
ViStatus _VI_FUNC rsznl_ConfigureTraceSmoothing(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean smoothing,
                                                ViReal64  aperture)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_SMOOTHING_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TRACE_SMOOTHING_STATE, smoothing),
            3, "Smoothing");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_TRACE_SMOOTHING_APERTURE, aperture),
            4, "Aperture");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables, disables, or restarts the max hold and the min hold
/// HIFN  functions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR traceHold/Enables, disables, or restarts the max hold and the min hold
/// HIPAR traceHold/functions.
ViStatus _VI_FUNC rsznl_ConfigureTraceHold(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   traceHold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_HOLD,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRACE_HOLD, traceHold),
            3, "Trace Hold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function shifts the active trace in horizontal direction, leaving
/// HIFN  the positions of all markers unchanged. The positive or negative offset
/// HIFN  value for the stimulus variable is entered into an input field. The
/// HIFN  unit depends on the sweep type.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Window:
/// HIFN     Number of an existing diagram area (defined by means of
/// HIFN  DISPlay:WINDow<Wnd>:STATe ON).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR shiftStimulusValue/Stimulus offset value.
ViStatus _VI_FUNC rsznl_TraceShiftStimulusValue(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   channel_Trace,
                                                ViReal64  shiftStimulusValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:X:OFFS %.12lG", window, channel_Trace, shiftStimulusValue);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function modifies all points of the trace <WndTr> by means of an
/// HIFN  added and/or a multiplied complex constant. The response values M of
/// HIFN  the trace are transformed according to:
/// HIFN
/// HIFN     M_new = M_old * 10^(<Magnitude> / 20dB) * a * e^(j <Phase> / 180Deg) +
/// HIFN  <Real> + j <Imaginary>
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR magnitude/The magnitude factor shifts a dB Mag trace in vertical direction,
/// HIPAR magnitude/leaving the phase of a complex parameter unchanged.
/// HIPAR phase/The phase factor rotates a trace that is displayed in a polar diagram
/// HIPAR phase/around the origin, leaving the magnitude unchanged.
/// HIPAR real/The real added constant shifts a real trace in vertical direction,
/// HIPAR real/leaving the imaginary part unchanged.
/// HIPAR imaginary/The imaginary added constant shifts a imaginary trace in vertical
/// HIPAR imaginary/direction, leaving the real part unchanged.
ViStatus _VI_FUNC rsznl_TraceShiftResponseValue(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   channel_Trace,
                                                ViReal64  magnitude,
                                                ViReal64  phase,
                                                ViReal64  real,
                                                ViReal64  imaginary)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, magnitude, -300, 300), 3, "Magnitude");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, phase, -3.4e38, 3.4e38), 4, "Phase");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, real, -3.4e38, 3.4e38), 4, "Real");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, imaginary, -3.4e38, 3.4e38), 4, "Imaginary");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:Y:OFFS %.12lG,%.12lG,%.12lG,%.12lG",
            window, channel_Trace, magnitude, phase, real, imaginary);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the current response values of the active data
/// HIFN  trace or memory trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the current response values of the active data trace
/// HIPAR traceData/or memory trace.
ViStatus _VI_FUNC rsznl_TraceResponseData(ViSession instrSession,
                                          ViInt32   channel_Trace,
                                          ViInt32   arraySize,
                                          ViInt32   dataFormat,
                                          ViInt32*  noofValues,
                                          ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            4, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA? %s", channel_Trace, RsZnl_rngDataFormat.entries[dataFormat].cmdString);
    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the current response values of the active data
/// HIFN  trace or memory trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR errorTerm/Denotes the error terms generated during a calibration.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the current response values of the active data trace
/// HIPAR traceData/or memory trace.
ViStatus _VI_FUNC rsznl_TraceResponseDataError(ViSession instrSession,
                                               ViInt32   channel_Trace,
                                               ViInt32   errorTerm,
                                               ViInt32   arraySize,
                                               ViInt32*  noofValues,
                                               ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1),
        2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, errorTerm, 1, 27),
            3, "Error Term");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 4, "Array size");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA? SCORr%ld", channel_Trace, errorTerm);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the current response values of all traces of the
/// HIFN  current test setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR recallSet/Name of a VNA channel setup.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all traces of the current test
/// HIPAR traceData/setup.
ViStatus _VI_FUNC rsznl_TraceResponseDataAll(ViSession instrSession,
                                             ViInt32   arraySize,
                                             ViInt32   dataFormat,
                                             ViString  recallSet,
                                             ViInt32*  noofValues,
                                             ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 2, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            3, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:DATA:ALL? %s,'%s'", RsZnl_rngDataFormat.entries[dataFormat].cmdString, recallSet);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the current response values of all traces of the
/// HIFN  selected channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all traces of the selected
/// HIPAR traceData/channel.
ViStatus _VI_FUNC rsznl_TraceChannelResponseDataAll(ViSession instrSession,
                                                    ViInt32   channel_Trace,
                                                    ViInt32   arraySize,
                                                    ViInt32   dataFormat,
                                                    ViInt32*  noofValues,
                                                    ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            4, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:CHAN:ALL? %s", channel_Trace, RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads the current response values of all data traces of the current
/// HIFN  test setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all traces of the current test
/// HIPAR traceData/setup.
ViStatus _VI_FUNC rsznl_TraceResponseDataAllData(ViSession instrSession,
                                                 ViInt32   arraySize,
                                                 ViInt32   dataFormat,
                                                 ViInt32*  noofValues,
                                                 ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 2, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            3, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:DATA:DALL? %s", RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads the current response values of all data traces of the selected
/// HIFN  channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all data traces of the selected
/// HIPAR traceData/channel.
ViStatus _VI_FUNC rsznl_TraceChannelResponseDataAllData(ViSession instrSession,
                                                        ViInt32   channel_Trace,
                                                        ViInt32   arraySize,
                                                        ViInt32   dataFormat,
                                                        ViInt32*  noofValues,
                                                        ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            4, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:CHAN:DALL? %s", channel_Trace, RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads the current response values of all S-parameter data traces in
/// HIFN  channel no. <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all S-parameter data traces in
/// HIPAR traceData/channel no. <Ch>.
ViStatus _VI_FUNC rsznl_TraceResponseDataAllSData(ViSession instrSession,
                                                  ViInt32   channel_Trace,
                                                  ViInt32   arraySize,
                                                  ViInt32   dataFormat,
                                                  ViInt32*  noofValues,
                                                  ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 2, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            3, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:CALL? %s", channel_Trace, RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns all traces which are available for
/// HIFN  rsznl_TraceResponseDataAllSData in channel no.<Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Response is a string parameter with all S-parameter traces in the
/// HIPAR catalog/current channel or in the active system error correction.
ViStatus _VI_FUNC rsznl_TraceResponseSDataCatalog(ViSession instrSession,
                                                  ViInt32   channel_Trace,
                                                  ViInt32   bufferSize,
                                                  ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_RESPONSE_S_DATA_CATALOG,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_TRACE_RESPONSE_S_DATA_CATALOG,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads the current response values of all S-parameters associated to a
/// HIFN  group of logical ports (S-parameter group). The S-parameter group must
/// HIFN  be created before using rsznl_CreateTraceSParametersGroup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns the current response values of all S-parameters associated to
/// HIPAR traceData/a group of logical ports (S-parameter group).
ViStatus _VI_FUNC rsznl_TraceSParameterGroupResponseData(ViSession instrSession,
                                                         ViInt32   channel_Trace,
                                                         ViInt32   arraySize,
                                                         ViInt32   dataFormat,
                                                         ViInt32*  noofValues,
                                                         ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            4, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:SGR? %s", channel_Trace, RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the response values of a trace acquired in single
/// HIFN  sweep mode (INITiate<Ch>:CONTinuous OFF).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR sweepNumber/Number of sweep to be read.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the response values of a trace acquired in single
/// HIPAR traceData/sweep mode.
ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepData(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   sweepNumber,
                                                     ViInt32   arraySize,
                                                     ViInt32*  noofValues,
                                                     ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:NSW? SDATa,%ld", channel_Trace, sweepNumber);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function the number of completed sweeps in single sweep mode
/// HIFN  (RSZNL_ATTR_SWEEP_MODE_CONTINUOUS set to OFF). The trace can be any of
/// HIFN  the traces acquired during the single sweep cycle.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR sweepCount/Reads the number of completed sweeps in single sweep mode
/// HIPAR sweepCount/(RSZNL_ATTR_SWEEP_MODE_CONTINUOUS set to OFF). The trace can be any of
/// HIPAR sweepCount/the traces acquired during the single sweep cycle.
ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepDataCount(ViSession instrSession,
                                                          ViInt32   channel_Trace,
                                                          ViInt32*  sweepCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_RESPONSE_SINGLE_SWEEP_DATA_COUNT,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRACE_RESPONSE_SINGLE_SWEEP_DATA_COUNT, sweepCount),
            3, "Sweep Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the response values of a trace acquired in single
/// HIFN  sweep mode (INITiate<Ch>:CONTinuous OFF).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR firstSweep/Number of first sweep to be read. 1 denotes the first sweep acquired,
/// HIPAR firstSweep/2 denotes the second and so forth.
/// HIPAR lastSweep/Number of last sweep to be read.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the response values of a trace acquired in single
/// HIPAR traceData/sweep mode.
ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepDataFirstLast(
                            ViSession instrSession,
                            ViInt32   channel_Trace,
                            ViInt32   firstSweep,
                            ViInt32   lastSweep,
                            ViInt32   arraySize,
                            ViInt32*  noofValues,
                            ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:NSW:FIRS? SDAT,%ld,%ld", channel_Trace, firstSweep, lastSweep);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the current response values of the active data
/// HIFN  trace or memory trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Trace name.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the current response values of the active data trace
/// HIPAR traceData/or memory trace.
ViStatus _VI_FUNC rsznl_ArbitraryTraceResponseData(ViSession instrSession,
                                                   ViString  traceName,
                                                   ViInt32   arraySize,
                                                   ViInt32   dataFormat,
                                                   ViInt32*  noofValues,
                                                   ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, dataFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_UNFORMATTED_MATH),
            4, "Data Format");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:DATA:TRAC? '%s',%s", traceName, RsZnl_rngDataFormat.entries[dataFormat].cmdString);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reads the stimulus values of the active data or memory
/// HIFN  trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR noofValues/Returns number of taken trace data values.
/// HIPAR traceData/Returns array of the current stimnulus values of the active data trace
/// HIPAR traceData/or memory trace.
ViStatus _VI_FUNC rsznl_TraceStimulusData(ViSession instrSession,
                                          ViInt32   channel_Trace,
                                          ViInt32   arraySize,
                                          ViInt32*  noofValues,
                                          ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel_Trace, 1), 2, "Channel Trace");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 3, "Array size");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:DATA:STIM?", channel_Trace);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function writes a memory trace data to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR dataFormat/Selects trace data format.
/// HIPAR noofPoints/Sets the number of trace points to be written to the instrument.
/// HIPAR traceData/Trace data array.
ViStatus _VI_FUNC rsznl_WriteMemoryTraceData(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   dataFormat,
                                             ViInt32   noofPoints,
                                             ViReal64  traceData[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    dataFormat++;
    checkErr(rsznl_WriteMemoryTraceDataExt(instrSession, channel_Trace,
        RSZNL_VAL_UNFORMATTED, noofPoints, traceData));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Uses linear inter-/extrapolation to 'regrid' all memory traces of the
/// HIFN  related channel to the channel's current stimulus values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_RegridMemoryTraces(ViSession instrSession,
                                           ViInt32   channel_Trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REGRID_MEMORY_TRACES,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_REGRID_MEMORY_TRACES, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads trace data from a specified trace file and assigns
/// HIFN  it to a trace with a specified name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Name of an existing data trace in the active setup (string parameter).
/// HIPAR traceName/The trace data is loaded into a memory trace associated with the
/// HIPAR traceName/specified data trace. If one or more memory traces are already
/// HIPAR traceName/associated with the specified data trace, the last generated memory
/// HIPAR traceName/trace is overwritten.
/// HIPAR fileName/String parameter to specify the name and directory of the trace file
/// HIPAR fileName/to be loaded. Several file formats for trace files are supported. If no
/// HIPAR fileName/path is specified the analyzer searches the current directory, to be
/// HIPAR fileName/queried with MMEMory:CDIRectory?.
/// HIPAR sparamortracename/Optional string parameter: For imported Touchstone files for more than
/// HIPAR sparamortracename/one port (*.s2p, *.s3p, *.s4p), the parameter denotes the imported
/// HIPAR sparamortracename/S-parameter ('S11', 'S12', ...). For ASCII (*.csv) and Matlab (*dat)
/// HIPAR sparamortracename/files, the parameter references a trace name in the file (case
/// HIPAR sparamortracename/sensitive). If the parameter is omitted (pass NULL to parameter),
/// HIPAR sparamortracename/the first trace in the specified file is imported.
ViStatus _VI_FUNC rsznl_TraceImportData(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViString  sparamortracename)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (strlen(sparamortracename) > 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:TRAC '%s','%s','%s'", traceName, fileName, sparamortracename);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:TRAC '%s','%s'", traceName, fileName);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads the specified trace file and automatically
/// HIFN  distributes the imported S-parameter traces Sij to all diagrams in the
/// HIFN  active channel that are currently displaying Sij.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Loads the specified trace file and automatically distributes the
/// HIPAR traceName/imported S-parameter traces Sij to all diagrams in the active channel
/// HIPAR traceName/that are currently displaying Sij.
ViStatus _VI_FUNC rsznl_TraceImportDataAutoDistribute(ViSession instrSession,
                                                      ViString  traceName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_TRACE_IMPORT_DATA_AUTO_DISTRIBUTE, traceName),
            2, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function stores the trace data of a specified trace to a trace
/// HIFN  file.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Traces are created using the CALCulte<Ch>:PARameter:SDEFine...
/// HIFN  command.
/// HIFN
/// HIFN     (2) *.s<n>p touchstone files (<n> = 2, 3, 4) are intended for a
/// HIFN  complete set of <n>-port S-parameters. Data export fails if the active
/// HIFN  channel does not contain the full set of <n>^2 traces. If the necessary
/// HIFN  trace are available, '<trc_name>' can be the name of any of the traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Name of an existing data trace in the active recall set.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/trace file. Several file formats for trace files are supported. If no
/// HIPAR fileName/path is specified the analyzer uses the current directory.
/// HIPAR exportFormat/This control selects the export format.
/// HIPAR exportData/This control selects the export data.
/// HIPAR decimalSeparator/This control selects the decimal separator.
/// HIPAR fieldSeparator/This control selects the field separator.
ViStatus _VI_FUNC rsznl_TraceExportData(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViInt32   exportFormat,
                                        ViInt32   exportData,
                                        ViInt32   decimalSeparator,
                                        ViInt32   fieldSeparator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_FORMATTED),
            4, "Export Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportData, RSZNL_VAL_COMPLEX, RSZNL_VAL_LOG_PHASE),
            5, "Export Data");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, decimalSeparator, RSZNL_VAL_POINT, RSZNL_VAL_COMMA),
            6, "Decimal Separator");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, fieldSeparator, RSZNL_VAL_SEMICOLON, RSZNL_VAL_SPACE),
            7, "Field Separator");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:TRAC '%s','%s',%s,%s,%s,%s", traceName, fileName,
        RsZnl_rngExportFormat.entries[exportFormat].cmdString,
        RsZnl_rngOutputFormat.entries[exportData].cmdString,
        RsZnl_rngDecimalSeparator.entries[decimalSeparator].cmdString,
        RsZnl_rngFieldSeparator.entries[fieldSeparator].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function stores the trace data to a Touchstone file for the
/// HIFN  specified ports. The Touchstone file (.s<n>p where <n> is the number of
/// HIFN  ports) contains a full set of <n>2 single-ended S-parameters for the
/// HIFN  selected ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Traces are created using the CALCulte<Ch>:PARameter:SDEFine...
/// HIFN  command.
/// HIFN
/// HIFN     (2) The function fails unless the following conditions are met:
/// HIFN
/// HIFN     - For a one-port Touchstone file, the reflection coefficient for the
/// HIFN  specified port (e.g. S11 for port no. 1) must be measured. If a full
/// HIFN  one-port system error correction is available for the specified port,
/// HIFN  it is also possible to export transmission parameters that are related
/// HIFN  to the calibrated port (e.g. S12 or S21 for port no. 1).
/// HIFN
/// HIFN     - For a multiport Touchstone file, a full multiport system error
/// HIFN  correction must be available. It is not necessary to measure the full
/// HIFN  set of S-parameters. Moreover, if the port configuration contains
/// HIFN  balanced ports, the Touchstone file will contain the converted
/// HIFN  single-ended S-parameters.
/// HIFN
/// HIFN     (3) This function uses fixed number of 4 ports. To use a different
/// HIFN  number of ports, use function rsznl_TraceExportDataPortsVariable
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelNumber/Channel number used to identify the active recall set.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/trace file. Several file formats for trace files are supported. If no
/// HIPAR fileName/path is specified the analyzer uses the current directory.
/// HIPAR exportData/This control selects the export data.
/// HIPAR impedanceMode/This control selects the impedance mode.
/// HIPAR port1/First port number.
/// HIPAR port2/Second port number.
/// HIPAR port3/Third port number.
/// HIPAR port4/Fourth port number.
ViStatus _VI_FUNC rsznl_TraceExportDataPorts(ViSession instrSession,
                                             ViInt32   channelNumber,
                                             ViString  fileName,
                                             ViInt32   exportData,
                                             ViInt32   impedanceMode,
                                             ViInt32   port1,
                                             ViInt32   port2,
                                             ViInt32   port3,
                                             ViInt32   port4)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportData, RSZNL_VAL_COMPLEX, RSZNL_VAL_LOG_PHASE),
            4, "Export Data");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, impedanceMode, RSZNL_VAL_COMMON_IMPEDANCE, RSZNL_VAL_PORT_IMPEDANCE),
            5, "Impedance Mode");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:TRAC:PORT %ld,'%s',%s,%s,%ld,%ld,%ld,%ld", channelNumber, fileName,
        RsZnl_rngOutputFormat.entries[exportData].cmdString,
        RsZnl_rngImpedanceMode.entries[impedanceMode].cmdString,
        port1, port2, port3, port4);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function stores the trace data to a Touchstone file for the
/// HIFN  specified ports. The Touchstone file (.s<n>p where <n> is the number of
/// HIFN  ports) contains a full set of <n>2 single-ended S-parameters for the
/// HIFN  selected ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Traces are created using the CALCulte<Ch>:PARameter:SDEFine...
/// HIFN  command.
/// HIFN
/// HIFN     (2) The function fails unless the following conditions are met:
/// HIFN
/// HIFN     - For a one-port Touchstone file, the reflection coefficient for the
/// HIFN  specified port (e.g. S11 for port no. 1) must be measured. If a full
/// HIFN  one-port system error correction is available for the specified port,
/// HIFN  it is also possible to export transmission parameters that are related
/// HIFN  to the calibrated port (e.g. S12 or S21 for port no. 1).
/// HIFN
/// HIFN     - For a multiport Touchstone file, a full multiport system error
/// HIFN  correction must be available. It is not necessary to measure the full
/// HIFN  set of S-parameters. Moreover, if the port configuration contains
/// HIFN  balanced ports, the Touchstone file will contain the converted
/// HIFN  single-ended S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelNumber/Channel number used to identify the active recall set.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/trace file. Several file formats for trace files are supported. If no
/// HIPAR fileName/path is specified the analyzer uses the current directory.
/// HIPAR exportData/This control selects the export data.
/// HIPAR impedanceMode/This control selects the impedance mode.
/// HIPAR arraySize/Sets the number of elements of the Ports array.
/// HIPAR ports/Port numbers in an array.
ViStatus _VI_FUNC rsznl_TraceExportDataPortsVariable(ViSession instrSession,
                                                     ViInt32   channelNumber,
                                                     ViString  fileName,
                                                     ViInt32   exportData,
                                                     ViInt32   impedanceMode,
                                                     ViInt32   arraySize,
                                                     ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportData, RSZNL_VAL_COMPLEX, RSZNL_VAL_LOG_PHASE),
            4, "Export Data");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, impedanceMode, RSZNL_VAL_COMMON_IMPEDANCE, RSZNL_VAL_PORT_IMPEDANCE),
            5, "Impedance Mode");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:TRAC:PORT %ld,'%s',%s,%s", channelNumber, fileName,
        RsZnl_rngOutputFormat.entries[exportData].cmdString,
        RsZnl_rngImpedanceMode.entries[impedanceMode].cmdString);

    for (i = 0; i < arraySize; i++)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", ports[i]);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function stores the trace data of all data traces in the
/// HIFN  specified channel to a trace file.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Traces are created using the CALCulte<Ch>:PARameter:SDEFine...
/// HIFN  command.
/// HIFN
/// HIFN     (2) *.s<n>p Touchstone files (<n> = 1, 2, 3, ...) are intended for a
/// HIFN  complete set of <n>-port S-parameters. Data export fails if the active
/// HIFN  channel does not contain the full set of <n>^2 traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selectChannel/This control selects the channel in the active setup.
/// HIPAR channelNumber/Channel number used to identify the active recall set.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/trace file. Several file formats for trace files are supported. If no
/// HIPAR fileName/path is specified the analyzer uses the current directory.
/// HIPAR exportFormat/This control selects the export format.
/// HIPAR exportData/This control selects the export data.
/// HIPAR decimalSeparator/This control selects the decimal separator.
/// HIPAR fieldSeparator/This control selects the field separator.
ViStatus _VI_FUNC rsznl_ChannelTraceExportData(ViSession instrSession,
                                               ViInt32   selectChannel,
                                               ViInt32   channelNumber,
                                               ViString  fileName,
                                               ViInt32   exportFormat,
                                               ViInt32   exportData,
                                               ViInt32   decimalSeparator,
                                               ViInt32   fieldSeparator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   chan[10];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, selectChannel, RSZNL_VAL_CHANNEL_TRACE_SINGLE, RSZNL_VAL_CHANNEL_TRACE_ALL),
            2, "Select Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportFormat, RSZNL_VAL_UNFORMATTED, RSZNL_VAL_FORMATTED),
            5, "Export Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, exportData, RSZNL_VAL_COMPLEX, RSZNL_VAL_LOG_PHASE),
            6, "Export Data");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, decimalSeparator, RSZNL_VAL_POINT, RSZNL_VAL_COMMA),
            7, "Decimal Separator");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, fieldSeparator, RSZNL_VAL_SEMICOLON, RSZNL_VAL_SPACE),
            8, "Field Separator");

    if (selectChannel == RSZNL_VAL_CHANNEL_TRACE_ALL)
        snprintf(chan, 10, "ALL");
    else
        snprintf(chan, 10, "%ld", channelNumber);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:TRAC:CHAN %s,'%s',%s,%s,%s,%s", chan, fileName,
        RsZnl_rngExportFormat.entries[exportFormat].cmdString,
        RsZnl_rngOutputFormat.entries[exportData].cmdString,
        RsZnl_rngDecimalSeparator.entries[decimalSeparator].cmdString,
        RsZnl_rngFieldSeparator.entries[fieldSeparator].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function converts S-parameters into matched-circuit (converted)
/// HIFN  Y-parameters or Z-parameters and vice versa.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR conversion/This control converts S-parameters into matched-circuit (converted)
/// HIPAR conversion/Y-parameters or Z-parameters and vice versa.
ViStatus _VI_FUNC rsznl_ConfigureParametersConversion(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   conversion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_PARAMETER_CONVERSION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_PARAMETER_CONVERSION, conversion),
            3, "Conversion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables/disables time domain site VSWR measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Enables/disables time domain site VSWR measurements.
ViStatus _VI_FUNC rsznl_ConfigureVSWREnabled(ViSession instrSession,
                                             ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_VSWR_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select one of the four elements of the standard 2-port
/// HIFN  scattering matrix (S-parameters) or select S-parameters for multiport
/// HIFN  measurements.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The S-parameters are the basic measured quantities of a network
/// HIFN  analyzer. They describe how the DUT modifies a signal that is
/// HIFN  transmitted or reflected in forward or reverse direction. S-parameters
/// HIFN  are expressed as S<out><in>, where <out> and <in> denote the output and
/// HIFN  input port numbers of the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR outPort/the output and input port numbers of the DUT.
/// HIPAR inPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR inPort/the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectSParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outPort,
                                          ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','S%02ld%02ld'", traceName, outPort, inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select S-parameters for multiport measurements
/// HIFN  (including the 2-port S-parameters) or mixed mode S-parameters. All
/// HIFN  possible combinations of mixed mode parameters (e.g. Sss, Scs, Sds,
/// HIFN  Sdd,...) are provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general S-parameter is S<mout><min><out><in>, where
/// HIFN  <mout> and <min> denote the output and input port modes, <out> and <in>
/// HIFN  denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR outPort/the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR inPort/the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectMoreSParameters(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  traceName,
                                              ViInt32   outMode,
                                              ViInt32   outPort,
                                              ViInt32   inMode,
                                              ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            6, "In Mode");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','S%s%s%02ld%02ld'",
        traceName,
        RsZnl_rngInOutMode.entries[outMode].cmdString,
        RsZnl_rngInOutMode.entries[inMode].cmdString,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select S-parameters for multiport measurements
/// HIFN  (including the 2-port S-parameters) or mixed mode S-parameters. All
/// HIFN  possible combinations of mixed mode parameters (e.g. Sss, Scs, Sds,
/// HIFN  Sdd,...) are provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general S-parameter is S<mout><min><out><in>, where
/// HIFN  <mout> and <min> denote the output and input port modes, <out> and <in>
/// HIFN  denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIFN
/// HIFN     In presence of balanced ports, this function distinguishes between:
/// HIFN
/// HIFN     - single-ended S-parameters for logical ports (SSS<Li><Lj>)
/// HIFN     - "raw" single-ended S-parameters referring to physical ports
/// HIFN  (S<Pi><Pj>)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR outPort/the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/S-parameters are expressed as S<out><in>, where <out> and <in> denote
/// HIPAR inPort/the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectBalancedPortsSParameters(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViString  traceName,
                                                       ViInt32   outMode,
                                                       ViInt32   outPort,
                                                       ViInt32   inMode,
                                                       ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_SINGLE_ENDED_RAW),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_SINGLE_ENDED_RAW),
            6, "In Mode");

    checkErr(rsznl_TraceList(instrSession, channel, rd_buffer, RS_MAX_MESSAGE_BUF_SIZE));

    if (outMode == RSZNL_VAL_SINGLE_ENDED_RAW || inMode == RSZNL_VAL_SINGLE_ENDED_RAW)
    {
        if (strstr(rd_buffer, traceName))
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:MEAS:SEND '%s','S%02ld%02ld'", channel, traceName, outPort, inPort);
        else
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:SDEF:SEND '%s','S%02ld%02ld'", channel, traceName, outPort, inPort);
    }
    else
    {
        if (strstr(rd_buffer, traceName))
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:MEAS:SEND '%s','S%s%s%02ld%02ld'", channel, traceName, RsZnl_rngInOutRawMode.entries[outMode].cmdString, RsZnl_rngInOutRawMode.entries[inMode].cmdString, outPort, inPort);
        else
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:SDEF:SEND '%s','S%s%s%02ld%02ld'", channel, traceName, RsZnl_rngInOutRawMode.entries[outMode].cmdString, RsZnl_rngInOutRawMode.entries[inMode].cmdString, outPort, inPort);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Creates the traces for all S-parameters associated with a group of
/// HIFN  logical ports (Sparameter group).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR numberofLogicalPorts/Sets number of logical ports in argument 'Logical Ports'.
/// HIPAR logicalPorts/Logical (balanced or unbalanced) port numbers.
ViStatus _VI_FUNC rsznl_CreateTraceSParametersGroup(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   numberofLogicalPorts,
                                                    ViInt32   logicalPorts[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:DEF:SGR ", channel);

    for (i = 0; i < numberofLogicalPorts; i++)
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%ld,", logicalPorts[i]);

    *p2buf = '\0';
    *--p2buf = '\n';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes a group of logical ports (S-parameter group), previously
/// HIFN  defined via rsznl_CreateTraceSParametersGroup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeleteSParametersGroup(ViSession instrSession,
                                               ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELETE_S_PARAMETER_GROUP,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DELETE_S_PARAMETER_GROUP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select predefined complex ratios of the standard 2-port
/// HIFN  wave quantities a1, a2, b1, and b2.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The predefined wave quantities are all obtained with the same test set
/// HIFN  configuration, port 1 providing the stimulus signal (source port 1,
/// HIFN  forward measurement if the stimulus signal is fed to the input of the
/// HIFN  DUT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR ratios/Select predefined complex ratios of the standard 2-port wave
/// HIPAR ratios/quantities a1, a2, b1, and b2.
ViStatus _VI_FUNC rsznl_SelectRatios(ViSession instrSession,
                                     ViInt32   channel,
                                     ViString  traceName,
                                     ViInt32   ratios)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ratios, RSZNL_VAL_RATIO_B1_A1_SRC_PORT_1, RSZNL_VAL_RATIO_B1_A2_SRC_PORT_2),
            4, "Ratios");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s'", traceName, RsZnl_rngRatios.entries[ratios].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select arbitrary ratios of wave quantities, e.g. for
/// HIFN  different detectors and source ports or more than 2 ports.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for ratios and the functionality of the More Ratios
/// HIFN  dialog is analogous to the definition of S-parameters.
/// HIFN
/// HIFN     Ratio of wave quantities with port numbers and source port numbers
/// HIFN  (D<no> for drive port; the source port for the numerator and the
/// HIFN  denominator can be equal or different).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR sourcePort/Source Port selects one of the available test ports of the analyzer as
/// HIPAR sourcePort/a source of the stimulus signal.
/// HIPAR numeratorType/Selects the type of the wave that forms the numerator of the ratio.
/// HIPAR numeratorPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR numeratorPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR numeratorPortNumber/on the analyzer model.
/// HIPAR denominatorType/Selects the type of the wave that forms the denominator of the ratio.
/// HIPAR denominatorPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR denominatorPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR denominatorPortNumber/on the analyzer model.
ViStatus _VI_FUNC rsznl_SelectMoreRatios(ViSession instrSession,
                                         ViInt32   channel,
                                         ViString  traceName,
                                         ViInt32   sourcePort,
                                         ViInt32   numeratorType,
                                         ViInt32   numeratorPortNumber,
                                         ViInt32   denominatorType,
                                         ViInt32   denominatorPortNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numeratorType, RSZNL_VAL_A, RSZNL_VAL_B),
            5, "Numerator Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, denominatorType, RSZNL_VAL_A, RSZNL_VAL_B),
            7, "Denominator Type");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s%ldD%ld/%s%ldD%ld'", traceName,
        RsZnl_rngNumerator.entries[numeratorType].cmdString,
        numeratorPortNumber,
        sourcePort,
        RsZnl_rngDenominator.entries[denominatorType].cmdString,
        denominatorPortNumber,
        sourcePort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select arbitrary ratios of wave quantities with
/// HIFN  detector, e.g. for different detectors and source ports or more than 2
/// HIFN  ports.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for ratios and the functionality of the More Ratios
/// HIFN  dialog is analogous to the definition of S-parameters.
/// HIFN
/// HIFN     Ratio of wave quantities with port numbers and source port numbers
/// HIFN  (D<no> for drive port; the source port for the numerator and the
/// HIFN  denominator can be equal or different).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR sourcePort/Source Port selects one of the available test ports of the analyzer as
/// HIPAR sourcePort/a source of the stimulus signal.
/// HIPAR numeratorType/Selects the type of the wave that forms the numerator of the ratio.
/// HIPAR numeratorPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR numeratorPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR numeratorPortNumber/on the analyzer model.
/// HIPAR denominatorType/Selects the type of the wave that forms the denominator of the ratio.
/// HIPAR denominatorPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR denominatorPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR denominatorPortNumber/on the analyzer model.
/// HIPAR detector/Selects the algorithm that is used to calculate the displayed
/// HIPAR detector/measurement points from the raw data.
/// HIPAR measurementTime/This control sets the detector observation time ratios and wave
/// HIPAR measurementTime/quantities if a Peak or RMS detector is active.
ViStatus _VI_FUNC rsznl_SelectMoreRatiosWithDetector(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  traceName,
                                                     ViInt32   sourcePort,
                                                     ViInt32   numeratorType,
                                                     ViInt32   numeratorPortNumber,
                                                     ViInt32   denominatorType,
                                                     ViInt32   denominatorPortNumber,
                                                     ViInt32   detector,
                                                     ViReal64  measurementTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numeratorType, RSZNL_VAL_A, RSZNL_VAL_B),
            5, "Numerator Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, denominatorType, RSZNL_VAL_A, RSZNL_VAL_B),
            7, "Denominator Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, detector, RSZNL_VAL_DET_RMS, RSZNL_VAL_DET_AVG),
            9, "Detector");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s%ldD%ld/%s%ldD%ld%s'", traceName,
        RsZnl_rngNumerator.entries[numeratorType].cmdString,
        numeratorPortNumber,
        sourcePort,
        RsZnl_rngDenominator.entries[denominatorType].cmdString,
        denominatorPortNumber,
        sourcePort,
        RsZnl_rngDetector.entries[detector].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SWEEP_DETECTOR_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_DETECTOR_TIME, measurementTime),
            10, "Measurement Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select the standard 2-port wave quantities a1, a2, b1,
/// HIFN  and b2 for different source ports.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The predefined wave quantities are obtained with different source
/// HIFN  ports. a1 Src Port 1, b1 Src Port 1 and b1 Src Port 2 are measured at
/// HIFN  Port 1 of the analyzer. a2 Src Port 2, b2 Src Port 1 and b2 Src Port 2
/// HIFN  are measured at Port 2 of the analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR waveQuantities/Select the standard 2-port wave quantities a1, a2, b1, and b2 for
/// HIPAR waveQuantities/different source ports.
ViStatus _VI_FUNC rsznl_SelectWaveQuantities(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  traceName,
                                             ViInt32   waveQuantities)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, waveQuantities, RSZNL_VAL_WQUANTITY_A1_SRC_PORT_1, RSZNL_VAL_WQUANTITY_B2_SRC_PORT_2),
            4, "Wave Quantities");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s'", traceName, RsZnl_rngWaveQuantities.entries[waveQuantities].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select arbitrary wave quantities, e.g. for different
/// HIFN  detectors and source ports or more than 2 ports, frequency offsets, or
/// HIFN  mixed mode measurements.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for wave quantities and the functionality of the More
/// HIFN  Wave Quantities is analogous to the definition of S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR waveQuantityType/Selects the type of the wave quantity.
/// HIPAR waveQuantityPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR waveQuantityPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR waveQuantityPortNumber/on the analyzer model.
/// HIPAR sourcePort/Source Port selects one of the available test ports of the analyzer as
/// HIPAR sourcePort/a source of the stimulus signal. The analyzer places no restriction on
/// HIPAR sourcePort/the combination of source ports and port numbers of the measured wave
/// HIPAR sourcePort/quantity, so it is even possible to measure a2 while the source port is
/// HIPAR sourcePort/port 1 (e.g. in order to estimate the directivity of the coupler).
/// HIPAR showAs/Selects the physical unit of the displayed trace. It is possible to
/// HIPAR showAs/display the measured "Voltage" V or convert the wave quantity into an
/// HIPAR showAs/effective power according to P = V2/Re(Z0). Z0 denotes the reference
/// HIPAR showAs/impedance of the source port (for wave quantities an) or of the receive
/// HIPAR showAs/port (for wave quantities bn).
ViStatus _VI_FUNC rsznl_SelectMoreWaveQuantities(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViString  traceName,
                                                 ViInt32   waveQuantityType,
                                                 ViInt32   waveQuantityPortNumber,
                                                 ViInt32   sourcePort,
                                                 ViInt32   showAs)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_WAVE_QUANTITIES_UNIT_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, waveQuantityType, RSZNL_VAL_A, RSZNL_VAL_B),
            4, "Wave Quantity Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, showAs, RSZNL_VAL_WAVE_UNIT_TYPE_POWER, RSZNL_VAL_WAVE_UNIT_TYPE_VOLTAGE),
            7, "Show As");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s%ldD%ld'", traceName,
        RsZnl_rngWaveQuantityType.entries[waveQuantityType].cmdString,
        waveQuantityPortNumber,
        sourcePort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_WAVE_QUANTITIES_UNIT_TYPE, showAs),
            7, "Show As");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select arbitrary wave quantities with detector, e.g. for
/// HIFN  different detectors and source ports or more than 2 ports, frequency
/// HIFN  offsets, or mixed mode measurements.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for wave quantities and the functionality of the More
/// HIFN  Wave Quantities is analogous to the definition of S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR waveQuantityType/Selects the type of the wave quantity.
/// HIPAR waveQuantityPortNumber/Port number assignment. The input (stimulus) or output (response) port
/// HIPAR waveQuantityPortNumber/number is selected. The range of output and input port numbers depends
/// HIPAR waveQuantityPortNumber/on the analyzer model.
/// HIPAR sourcePort/Source Port selects one of the available test ports of the analyzer as
/// HIPAR sourcePort/a source of the stimulus signal. The analyzer places no restriction on
/// HIPAR sourcePort/the combination of source ports and port numbers of the measured wave
/// HIPAR sourcePort/quantity, so it is even possible to measure a2 while the source port is
/// HIPAR sourcePort/port 1 (e.g. in order to estimate the directivity of the coupler).
/// HIPAR showAs/Selects the physical unit of the displayed trace. It is possible to
/// HIPAR showAs/display the measured "Voltage" V or convert the wave quantity into an
/// HIPAR showAs/effective power according to P = V2/Re(Z0). Z0 denotes the reference
/// HIPAR showAs/impedance of the source port (for wave quantities an) or of the receive
/// HIPAR showAs/port (for wave quantities bn).
/// HIPAR detector/Selects the algorithm that is used to calculate the displayed
/// HIPAR detector/measurement points from the raw data.
/// HIPAR measurementTime/This control sets the detector observation time ratios and wave
/// HIPAR measurementTime/quantities if a Peak or RMS detector is active.
ViStatus _VI_FUNC rsznl_SelectMoreWaveQuantitiesWithDetector(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViString  traceName,
                                                             ViInt32   waveQuantityType,
                                                             ViInt32   waveQuantityPortNumber,
                                                             ViInt32   sourcePort,
                                                             ViInt32   showAs,
                                                             ViInt32   detector,
                                                             ViReal64  measurementTime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, waveQuantityType, RSZNL_VAL_A, RSZNL_VAL_B),
            4, "Wave Quantity Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, showAs, RSZNL_VAL_WAVE_UNIT_TYPE_POWER, RSZNL_VAL_WAVE_UNIT_TYPE_VOLTAGE),
            7, "Show As");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, detector, RSZNL_VAL_WAVE_UNIT_TYPE_POWER, RSZNL_VAL_WAVE_UNIT_TYPE_VOLTAGE),
            8, "Detector");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','%s%ldD%ld%s'", traceName,
        RsZnl_rngWaveQuantityType.entries[waveQuantityType].cmdString,
        waveQuantityPortNumber,
        sourcePort,
        RsZnl_rngDetector.entries[detector].cmdString);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_WAVE_QUANTITIES_UNIT_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_WAVE_QUANTITIES_UNIT_TYPE, showAs),
            7, "Show As");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_SWEEP_DETECTOR_TIME, measurementTime),
            9, "Measurement Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select the 2-port (or more ports) matched-circuit,
/// HIFN  converted impedances. The parameters describe the impedances of a
/// HIFN  2-port (or more ports) DUT, obtained in forward and reverse
/// HIFN  transmission and reflection measurements:
/// HIFN
/// HIFN     Z11 is the input impedance of a 2-port DUT that is terminated at its
/// HIFN  output with the reference impedance Z0 (matched-circuit impedance
/// HIFN  measured in a forward reflection measurement).
/// HIFN
/// HIFN     Z22 is the output impedance of a 2-port DUT that is terminated at its
/// HIFN  input with the reference impedance Z0 (matched-circuit impedance
/// HIFN  measured in a reverse reflection measurement).
/// HIFN
/// HIFN     Z12 and Z21 denote the forward and reverse transfer impedances,
/// HIFN  respectively.
/// HIFN
/// HIFN     The analyzer can also provide matched-circuit impedances for more
/// HIFN  drive ports or balanced port configurations.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for converted impedance parameters and the functionality
/// HIFN  is analogous to the definition of S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outPort/Z-S-parameters are expressed as Z-S<out><in>, where <out> and <in>
/// HIPAR outPort/denote the output and input port numbers of the DUT.
/// HIPAR inPort/Z-S-parameters are expressed as Z-S<out><in>, where <out> and <in>
/// HIPAR inPort/denote the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectImpedances(ViSession instrSession,
                                         ViInt32   channel,
                                         ViString  traceName,
                                         ViInt32   outPort,
                                         ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Z-S%02ld%02ld'", traceName,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select converted, matched-circuit impedance parameters
/// HIFN  for more ports or balanced port measurements. All possible combinations
/// HIFN  of mixed mode parameters (e.g. Z-Sss, Z-Scs, Z-Sds, Z-Sdd,...) are
/// HIFN  provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general Z-S-parameter is Z-S<mout><min><out><in>,
/// HIFN  where <mout> and <min> denote the output and input port modes, <out>
/// HIFN  and <in> denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/Z-S-parameters are expressed as Z-S<out><in>, where <out> and <in>
/// HIPAR outPort/denote the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/Z-S-parameters are expressed as Z-S<out><in>, where <out> and <in>
/// HIPAR inPort/denote the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectMoreImpedances(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  traceName,
                                             ViInt32   outMode,
                                             ViInt32   outPort,
                                             ViInt32   inMode,
                                             ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            6, "In Mode");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Z-S%s%s%02ld%02ld'", traceName,
        RsZnl_rngInOutMode.entries[outMode].cmdString,
        RsZnl_rngInOutMode.entries[inMode].cmdString,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select the 2-port (or more ports) converted
/// HIFN  matched-circuit admittance parameters. The parameters describe the
/// HIFN  admittances of a 2-port (or more ports) DUT, obtained in forward and
/// HIFN  reverse transmission and reflection measurements:
/// HIFN
/// HIFN     Y11 is the input admittance of a 2-port DUT that is terminated at its
/// HIFN  output with the reference impedance Z0 (matched-circuit admittance
/// HIFN  measured in a forward reflection measurement).
/// HIFN
/// HIFN     Y22 is the output admittance of a 2-port DUT that is terminated at its
/// HIFN  input with the reference impedance Z0 (matched-circuit admittance
/// HIFN  measured in a reverse reflection measurement).
/// HIFN
/// HIFN     Y12 and Y21 denote the forward and reverse transfer admittances,
/// HIFN  respectively.
/// HIFN
/// HIFN     The analyzer can also provide matched-circuit admittances for more
/// HIFN  drive ports or balanced port configurations.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     The notation for converted admittance parameters and the functionality
/// HIFN  is analogous to the definition of S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outPort/Y-S-parameters are expressed as Y-S<out><in>, where <out> and <in>
/// HIPAR outPort/denote the output and input port numbers of the DUT.
/// HIPAR inPort/Y-S-parameters are expressed as Y-S<out><in>, where <out> and <in>
/// HIPAR inPort/denote the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectAdmittances(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outPort,
                                          ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Y-S%02ld%02ld'", traceName,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select converted, matched-circuit admittance parameters
/// HIFN  for more ports or balanced port measurements. All possible combinations
/// HIFN  of mixed mode parameters (e.g. Y-Sss, Y-Scs, Y-Sds, Y-Sdd,...) are
/// HIFN  provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general Y-S-parameter is Y-S<mout><min><out><in>,
/// HIFN  where <mout> and <min> denote the output and input port modes, <out>
/// HIFN  and <in> denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/Y-S-parameters are expressed as Y-S<out><in>, where <out> and <in>
/// HIPAR outPort/denote the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/Y-S-parameters are expressed as Y-S<out><in>, where <out> and <in>
/// HIPAR inPort/denote the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectMoreAdmittances(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  traceName,
                                              ViInt32   outMode,
                                              ViInt32   outPort,
                                              ViInt32   inMode,
                                              ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            6, "In Mode");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Y-S%s%s%02ld%02ld'", traceName,
        RsZnl_rngInOutMode.entries[outMode].cmdString,
        RsZnl_rngInOutMode.entries[inMode].cmdString,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select open-circuit Z-parameters for multiport
/// HIFN  measurements (including the 2-port Z-parameters) or mixed mode
/// HIFN  Z-parameters. All possible combinations of mixed mode parameters (e.g.
/// HIFN  Zss, Zcs, Zds, Zdd,...) are provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general Z-parameter is Z<mout><min><out><in>, where
/// HIFN  <mout> and <min> denote the output and input port modes, <out> and <in>
/// HIFN  denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/Z-parameters are expressed as Z<out><in>, where <out> and <in> denote
/// HIPAR outPort/the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/Z-parameters are expressed as Z<out><in>, where <out> and <in> denote
/// HIPAR inPort/the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectZParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outMode,
                                          ViInt32   outPort,
                                          ViInt32   inMode,
                                          ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            6, "In Mode");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Z%s%s%02ld%02ld'", traceName,
        RsZnl_rngInOutMode.entries[outMode].cmdString,
        RsZnl_rngInOutMode.entries[inMode].cmdString,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select short-circuit Y-parameters for multiport
/// HIFN  measurements (including the 2-port Y-parameters) or mixed mode
/// HIFN  Y-parameters. All possible combinations of mixed mode parameters (e.g.
/// HIFN  Yss, Ycs, Yds, Ydd,...) are provided.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Mixed mode parameters are used to distinguish the following three port
/// HIFN  modes:
/// HIFN
/// HIFN     Single-ended (for unbalanced ports)
/// HIFN     Differential mode (for balanced ports)
/// HIFN     Common mode (for balanced ports)
/// HIFN
/// HIFN     The notation of a general Y-parameter is Y<mout><min><out><in>, where
/// HIFN  <mout> and <min> denote the output and input port modes, <out> and <in>
/// HIFN  denote the output and input port numbers.
/// HIFN
/// HIFN     The selected modes must be compatible with the port configuration. If
/// HIFN  an attempt is made to select an incompatible parameter (e.g. a
/// HIFN  single-ended parameter for a balanced port), the analyzer displays an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outMode/Define port mode.
/// HIPAR outPort/Y-parameters are expressed as Y<out><in>, where <out> and <in> denote
/// HIPAR outPort/the output and input port numbers of the DUT.
/// HIPAR inMode/Define port mode.
/// HIPAR inPort/Y-parameters are expressed as Y<out><in>, where <out> and <in> denote
/// HIPAR inPort/the output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectYParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outMode,
                                          ViInt32   outPort,
                                          ViInt32   inMode,
                                          ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            4, "Out Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, inMode, RSZNL_VAL_SINGLE_ENDED, RSZNL_VAL_COMMON),
            6, "In Mode");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Y%s%s%02ld%02ld'", traceName,
        RsZnl_rngInOutMode.entries[outMode].cmdString,
        RsZnl_rngInOutMode.entries[inMode].cmdString,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select an imbalance parameter as a measured quantity for
/// HIFN  the active trace. For a balanced port configuration with k balanced
/// HIFN  ports plus m single-ended ports (2 * k + m = n, where n is the number
/// HIFN  of analyzer ports), the pull-down list provides the full set of k * (k
/// HIFN  - 1 + 2 * m) imbalance parameters.
/// HIFN
/// HIFN     Imbalance parameters are expressed as "Imb<out><in>", where <out> and
/// HIFN  <in> denote the logical output and input port numbers of the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR outPort/Imbalance parameters are expressed as "Imb<out><in>", where <out> and
/// HIPAR outPort/<in> denote the logical output and input port numbers of the DUT.
/// HIPAR inPort/Imbalance parameters are expressed as "Imb<out><in>", where <out> and
/// HIPAR inPort/<in> denote the logical output and input port numbers of the DUT.
ViStatus _VI_FUNC rsznl_SelectImbalance(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  traceName,
                                        ViInt32   outPort,
                                        ViInt32   inPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','IMB%ld%ld'", traceName,
        outPort,
        inPort);

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select one of the three two port stability factors K, u1
/// HIFN  or u2.
/// HIFN
/// HIFN     Stability factors are calculated as functions of the frequency or
/// HIFN  another stimulus parameter. They provide criteria for linear stability
/// HIFN  of two-ports such as amplifiers. A linear circuit is said to be
/// HIFN  unconditionally stable if no combination of passive source or load can
/// HIFN  cause the circuit to oscillate.
/// HIFN
/// HIFN     Assigns a measurement parameter to an existing trace or creates a
/// HIFN  trace and assigns a channel number, a name and a measurement parameter
/// HIFN  to it. The trace is not displayed.
/// HIFN
/// HIFN     Stability factors can be calculated for unbalanced ports only. If a
/// HIFN  balanced port configuration is selected, the analyzer generates an
/// HIFN  error message.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR dutOut/Selects the test port number of the analyzer to be connected to the
/// HIPAR dutOut/input (DUT Input) and the output of the DUT (DUT Output). The ports can
/// HIPAR dutOut/be arbitrary, however, the stability factor calculation is based on
/// HIPAR dutOut/2-port reflection and transmission S-parameters so that the input and
/// HIPAR dutOut/output port numbers must be different.
/// HIPAR dutIn/Selects the test port number of the analyzer to be connected to the
/// HIPAR dutIn/input (DUT Input) and the output of the DUT (DUT Output). The ports can
/// HIPAR dutIn/be arbitrary, however, the stability factor calculation is based on
/// HIPAR dutIn/2-port reflection and transmission S-parameters so that the input and
/// HIPAR dutIn/output port numbers must be different.
/// HIPAR stabilityFactor/Selects the stability factor to be calculated.
ViStatus _VI_FUNC rsznl_SelectStabilityFactors(ViSession instrSession,
                                               ViInt32   channel,
                                               ViString  traceName,
                                               ViInt32   dutOut,
                                               ViInt32   dutIn,
                                               ViInt32   stabilityFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, stabilityFactor, RSZNL_VAL_SFACTOR_K, RSZNL_VAL_SFACTOR_U2),
            6, "Stability Factor");

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    if (stabilityFactor == RSZNL_VAL_SFACTOR_K)
    {
        snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','KFAC%ld%ld'", traceName,
            dutOut,
            dutIn);
    }
    else
    {
        snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','MUF%ld%ld%ld'", traceName,
            stabilityFactor,
            dutOut,
            dutIn);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function select an power sensor measurement using a power meter
/// HIFN  'Pmtr<no>' and either an
/// HIFN     external generator 'G<no>' or an analyzer source port 'D<no>'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceName/Define trace name.
/// HIPAR powerSensor/Power source parameter Pmtr<n>.
/// HIPAR source/Selects the source.
/// HIPAR sourcePort/Selectrs the port number of selected Source. 'G<no>' for External
/// HIPAR sourcePort/Generator, 'D<no>' for Analyzer.
ViStatus _VI_FUNC rsznl_SelectPowerSensorMeasurement(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  traceName,
                                                     ViInt32   powerSensor,
                                                     ViInt32   source,
                                                     ViInt32   sourcePort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  offset;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_traceCommandSelect(instrSession, channel,
        traceName, cmd,
        &offset));

    switch (source) {
    case RSZNL_VAL_PMET_EXT_GEN:
        snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Pmtr%ldG%02ld'", traceName,
            powerSensor, sourcePort);
        break;
    case RSZNL_VAL_PMET_ANALYZER:
        snprintf(cmd + offset, RS_MAX_MESSAGE_BUF_SIZE, "'%s','Pmtr%ldD%02ld'", traceName,
            powerSensor, sourcePort);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, source), 5, "Source");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts auto zeroing of the external power meter.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerMeterNumber/This control sets the number of the configured power meter. Power
/// HIPAR powerMeterNumber/meters must be numbered in ascending order, starting with 1. If a
/// HIPAR powerMeterNumber/number is re-used, the previous generator configuration is overwritten.
ViStatus _VI_FUNC rsznl_PowerMeterAutoZero(ViSession instrSession,
                                           ViInt32   powerMeterNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_SENSOR_AUTO_ZERO,
            "PowMeter", powerMeterNumber - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_POWER_SENSOR_AUTO_ZERO, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the numbers of all configured external power meters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR bufferSize/This control defines size of buffer in 'Power Meter Number' argument.
/// HIPAR powerMeterNumbers/Returns a comma-separated list of power meter numbers.
ViStatus _VI_FUNC rsznl_QueryPowerMeterNumbers(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    powerMeterNumbers[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_POWER_METER_NUMBERS,
            bufferSize, powerMeterNumbers),
            3, "Power Meter Numbers");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the number of configured external power meters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR powerMeterCount/Number of power meters.
ViStatus _VI_FUNC rsznl_QueryPowerMeterCount(ViSession instrSession,
                                             ViInt32*  powerMeterCount)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_METER_COUNT, powerMeterCount),
            2, "Power Meter Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the state of the built-in S-parameter correction that is
/// HIFN  available on certain R&S NRP-Z power sensors. Note that this state is
/// HIFN  persistently stored on the power sensor (and NOT on the R&S ZNL/ZNLE).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR powerMeterNumber/This control sets the number of the configured power meter. Power
/// HIPAR powerMeterNumber/meters must be numbered in ascending order, starting with 1. If a
/// HIPAR powerMeterNumber/number is re-used, the previous generator configuration is overwritten.
/// HIPAR state/Sets the state of the built-in S-parameter correction that is
/// HIPAR state/available on certain R&S NRP-Z power sensors. Note that this state is
/// HIPAR state/persistently stored on the power sensor (and NOT on the R&S ZNL/ZNLE).
ViStatus _VI_FUNC rsznl_ConfigurePowerMeterSParameterCorrection(
                            ViSession instrSession,
                            ViInt32   powerMeterNumber,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_METER_S_PARAMETER_CORRECTION_ENABLED,
            "PowMeter", powerMeterNumber - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_POWER_METER_S_PARAMETER_CORRECTION_ENABLED, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines a balanced port numbered <Logicalog Port>,
/// HIFN  combining two physical ports <Physical Port 1> and <Physical Port 2>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR logicalPort/Logical port number used to number balanced ports.
/// HIPAR physicalPort1/This control defines the port number.
/// HIPAR physicalPort2/This control defines the port number.
ViStatus _VI_FUNC rsznl_DefineBalancedPort(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   logicalPort,
                                           ViInt32   physicalPort1,
                                           ViInt32   physicalPort2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (physicalPort2 > 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:LPOR%ld %ld,%ld", channel, logicalPort, physicalPort1, physicalPort2);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:LPOR%ld %ld", channel, logicalPort, physicalPort1);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function dissolves selected balanced port.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR logicalPort/Logical port number used to number balanced ports.
ViStatus _VI_FUNC rsznl_DeleteBalancedPort(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   logicalPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:LPOR%ld:CLE", channel, logicalPort);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function dissolves all balanced ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeleteAllBalancedPorts(ViSession instrSession,
                                               ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:LPOR:CLE ALL", channel);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the complex common mode reference impedance
/// HIFN  for the balanced (logical) port numbered <log_port>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR logicalPort/This control defines the logical port number.
/// HIPAR real/This control defines the real part of the port impedance.
/// HIPAR imaginary/This control defines the imaginary part of the port impedance.
ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceCommonMode(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViReal64  real,
                            ViReal64  imaginary)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, real, 1.0e-3, 10.0e6), 4, "Real");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, imaginary, -10.0e6, 10.0e6), 4, "Imaginary");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:LPOR%ld:ZCOM %.12lG,%.12lG", channel, logicalPort, real, imaginary);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the complex differential mode reference
/// HIFN  impedance for the balanced (logical) port numbered <log_port>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR logicalPort/This control defines the logical port number.
/// HIPAR real/This control defines the real part of the port impedance.
/// HIPAR imaginary/This control defines the imaginary part of the port impedance.
ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceDifferentialMode(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViReal64  real,
                            ViReal64  imaginary)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, real, 1.0e-3, 10.0e6), 4, "Real");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, imaginary, -10.0e6, 10.0e6), 4, "Imaginary");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:LPOR%ld:ZDIF %.12lG,%.12lG", channel, logicalPort, real, imaginary);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the theory for the renormalization of port
/// HIFN  impedances. The selection has an impact on the conversion formulas for
/// HIFN  wave quantities and S-parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR theory/This control selects the theory for the renormalization of port
/// HIPAR theory/impedances. The selection has an impact on the conversion formulas for
/// HIPAR theory/wave quantities and S-parameters.
ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceRenormalization(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   theory)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_RENORMALIZATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_RENORMALIZATION, theory),
            3, "Theory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function allows to toggle between default and renormalized
/// HIFN  reference impedance(s) for logical port <LogPt>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR logicalPort/This control defines the logical port number.
/// HIPAR useDefault/Allows to toggle between default and renormalized reference
/// HIPAR useDefault/impedance(s) for logical port <LogPt>.
ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceDefault(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViBoolean useDefault)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_logicalPort[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_USE_DEFAULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_USE_DEFAULT,
            "LogicalPort", logicalPort - 1, RS_REPCAP_BUF_SIZE, repCap_logicalPort));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_logicalPort, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_USE_DEFAULT, useDefault),
            4, "Use Default");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the complex reference impedance for the
/// HIFN  physical port numbered <phys_port>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR physicalPort/Physical port number. The number of ports depends on the analyzer
/// HIPAR physicalPort/model.
/// HIPAR real/This control defines the real part of the port impedance.
/// HIPAR imaginary/This control defines the imaginary part of the port impedance.
ViStatus _VI_FUNC rsznl_ConfigurePhysicalPortReferenceImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   physicalPort,
                            ViReal64  real,
                            ViReal64  imaginary)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, real, 1.0e-3, 10.0e6), 4, "Real");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, imaginary, -10.0e6, 10.0e6), 4, "Imaginary");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:PORT%ld:ZREF %.12lG,%.12lG", channel, physicalPort, real, imaginary);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines how the measured result at any sweep point is
/// HIFN  post-processed and presented in the graphical display.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The analyzer allows arbitrary combinations of display formats and
/// HIFN  measured quantities. Nevertheless, it is advisable to check which
/// HIFN  display formats are generally appropriate for an analysis of a
/// HIFN  particular measured quantity.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR format/Defines how the measured data is presented in the graphical display.
/// HIPAR aperturePoints/Defines an aperture for the calculation of the group delay as an
/// HIPAR aperturePoints/integer number of frequency sweep steps.
ViStatus _VI_FUNC rsznl_ConfigureTraceFormat(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   format,
                                             ViInt32   aperturePoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TRACE_FORMAT,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_TRACE_FORMAT, format),
            3, "Format");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_GROUP_DELAY_APERTURE_POINTS, aperturePoints),
            4, "Aperture Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the default marker format of the active trace. 'Default' means
/// HIFN  formatted according to the selected trace format.
/// HIFN     New markers will be formatted with the trace's 'Default ...ker Frmt';
/// HIFN  existing markers will be reformatted if (and only if) their Marker
/// HIFN  Format is set to (Trace) 'Default'.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR format/Defines the default marker format of the active trace. 'Default' means
/// HIPAR format/formatted according to the selected trace format.
ViStatus _VI_FUNC rsznl_ConfigureDefaultMarkerFormat(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   format)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEFAULT_MARKER_FORMAT,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DEFAULT_MARKER_FORMAT, format),
            3, "Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the marker state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerState/Creates the marker numbered <Mk> and assigns it to trace no. <Chn>.
ViStatus _VI_FUNC rsznl_ConfigureMarkerState(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   marker,
                                             ViBoolean markerState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_STATE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_STATE, markerState),
            4, "Marker State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function creates the marker numbered <Mk> and assigns it to trace
/// HIFN  no. <Ch/Tr> and sets the stimulus (in Cartesian diagrams: x-axis)
/// HIFN  value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerState/Creates or removes the marker.
/// HIPAR markerStimulus/Stimulus value of marker no. <Mk>.
ViStatus _VI_FUNC rsznl_ConfigureMarker(ViSession instrSession,
                                        ViInt32   channel_Trace,
                                        ViInt32   marker,
                                        ViBoolean markerState,
                                        ViReal64  markerStimulus)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_STATE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_STATE, markerState),
            4, "Marker State");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_STIMULUS, markerStimulus),
            5, "Marker Stimulus");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the response (in Cartesian diagrams: y-axis)
/// HIFN  value of marker no. <Mk>. The marker must be created before using
/// HIFN  CALCulate<Ch/Tr>:MARKer<Mk>[:STATe] ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerResponse/Response value(s) of marker no. <Mk>. Unit is depending on the marker
/// HIPAR markerResponse/format; see CALCulate<Ch/Tr>:MARKer<Mk>:FORMat.
ViStatus _VI_FUNC rsznl_QueryMarkerResponse(ViSession instrSession,
                                            ViInt32   channel_Trace,
                                            ViInt32   marker,
                                            ViReal64  markerResponse[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 10),
            3, "Marker");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:Y?", channel_Trace, marker);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 3, markerResponse, NULL));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function creates the reference marker and assigns it to trace no.
/// HIFN  <Ch/Tr> and defines the stimulus (in Cartesian diagrams: x-axis) value
/// HIFN  of the reference marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR referenceMarkerState/Creates or removes the reference marker.
/// HIPAR referenceMarkerStimulus/Stimulus value of reference marker no. <Mk>.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarker(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean referenceMarkerState,
                                                 ViReal64  referenceMarkerStimulus)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_STATE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_STATE, referenceMarkerState),
            4, "Reference Marker State");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_STIMULUS, referenceMarkerStimulus),
            5, "Reference Marker Stimulus");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the response (in Cartesian diagrams: y-axis)
/// HIFN  value of the reference marker. The reference marker must be created
/// HIFN  before using  CALCulate<Ch/Tr>:MARKer<Mk>:REFerence[:STATe] ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR referenceMarkerResponse/Response value of reference marker no. <Mk>. Where unit is:
ViStatus _VI_FUNC rsznl_QueryReferenceMarkerResponse(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   marker,
                                                     ViReal64  referenceMarkerResponse[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 10),
            3, "Marker");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:REF:Y?", channel_Trace, marker);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 3, referenceMarkerResponse, NULL));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the delta mode for marker <Mk> on trace no.
/// HIFN  <Ch/Tr> on or off. The marker must be created before using
/// HIFN  CALCulate<Ch/Tr>:MARKer<Mk>[:STATe] ON. If the active trace contains no
/// HIFN  reference marker, the command also creates a reference marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR deltaMarkerState/Enables or disables the delta mode.
ViStatus _VI_FUNC rsznl_ConfigureMarkerDeltaMode(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean deltaMarkerState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELTA_MARKER_STATE,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELTA_MARKER_STATE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DELTA_MARKER_STATE, deltaMarkerState),
            4, "Delta Marker State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function couples the markers of all traces in the active channel
/// HIFN  setup to the markers of trace no. <Chn>, provided that they have the
/// HIFN  same sweep type
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerCoupling/Couples the markers of all traces in the active channel setup to the
/// HIPAR markerCoupling/markers of trace no. <Chn>, provided that they have the same sweep type
ViStatus _VI_FUNC rsznl_ConfigureMarkerCoupling(ViSession instrSession,
                                                ViInt32   channel_Trace,
                                                ViInt32   marker,
                                                ViBoolean markerCoupling)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_COUPLING,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_COUPLING,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_COUPLING, markerCoupling),
            4, "Marker Coupling");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the output format for the (complex) value of the
/// HIFN  related marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR format/Defines the output format for the (complex) value of the related
/// HIPAR format/marker.
ViStatus _VI_FUNC rsznl_ConfigureMarkerFormat(ViSession instrSession,
                                              ViInt32   channel_Trace,
                                              ViInt32   marker,
                                              ViInt32   format)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_FORMAT,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_FORMAT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_FORMAT, format),
            4, "Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function removes all markers from all traces of the active setup.
/// HIFN  The removed markers remember their properties (stimulus value, format,
/// HIFN  delta mode, number) when they are restored (CALC<Ch/Tr>:MARK<Mk> ON).
/// HIFN  The marker properties are definitely lost if the associated trace is
/// HIFN  deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_SetAllMarkersOff(ViSession instrSession,
                                         ViInt32   channel_Trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_DISABLE_ALL,
            "Channel", channel_Trace - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_MARKER_DISABLE_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function specifies the name and directory of the created ASCII
/// HIFN  file. The default extension (manual control) for marker files is *.txt,
/// HIFN  although other extensions are allowed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/This control specifies the name and directory of the created ASCII
/// HIPAR fileName/file. The default extension (manual control) for marker files is *.txt,
/// HIPAR fileName/although other extensions are allowed.
ViStatus _VI_FUNC rsznl_MarkerExport(ViSession instrSession,
                                     ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_MARKER_EXPORT, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function moves the marker info field for the active trace <Chn>
/// HIFN  to one of nine predefined positions in the active diagram.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR horizontalPosition/Selects the horizontal position of the info field.
/// HIPAR verticalPosition/Selects the vertical position of the info field.
ViStatus _VI_FUNC rsznl_ConfigureMarkerInfoFieldPosition(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   horizontalPosition,
                                                         ViInt32   verticalPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, horizontalPosition, RSZNL_VAL_HORIZONTAL_LEFT, RSZNL_VAL_HORIZONTAL_RIGHT),
            3, "Horizontal Position");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, verticalPosition, RSZNL_VAL_VERTICAL_TOP, RSZNL_VAL_VERTICAL_BOTTOM),
            4, "Vertical Position");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK:STAT:AREA %s,%s", channel,
        RsZnl_rngHorizontalPosition.entries[horizontalPosition].cmdString,
        RsZnl_rngVerticalPosition.entries[verticalPosition].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the properies of a marker created previously.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerType/This control selects the type of a marker to be used.
/// HIPAR markerName/Defines a name for (reference) marker no. <Mk>.
/// HIPAR discreteMode/Sets marker no. <Mk> to continuous or discrete mode.
/// HIPAR fixedMarker/Sets marker no. <Mk> to normal or fixed mode.
ViStatus _VI_FUNC rsznl_ConfigureMarkerProperties(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   marker,
                                                  ViInt32   markerType,
                                                  ViString  markerName,
                                                  ViInt32   discreteMode,
                                                  ViInt32   fixedMarker)
{
    ViStatus                           error = VI_SUCCESS;
    ViChar                             repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar                             repCap_marker[RS_REPCAP_BUF_SIZE] = "";
    ViAttr                             attr[2][3] = { {RSZNL_ATTR_MARKER_NAME, RSZNL_ATTR_MARKER_MODE, RSZNL_ATTR_MARKER_TYPE},
    {RSZNL_ATTR_REFERENCE_MARKER_NAME, RSZNL_ATTR_REFERENCE_MARKER_MODE, RSZNL_ATTR_REFERENCE_MARKER_TYPE} };

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_NAME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_NAME,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 10),
            3, "Marker");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, markerType, RSZNL_VAL_MARKER, RSZNL_VAL_REFERENCE_MARKER),
            4, "Marker Type");

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, attr[markerType][0], markerName),
            5, "Marker Name");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, attr[markerType][1], discreteMode),
            6, "Discrete Mode");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, attr[markerType][2], fixedMarker),
            7, "Fixed Marker");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the marker coupling type to be used in the current channel
/// HIFN  setup.
/// HIFN
/// HIFN     Marker coupling is enabled using CALCulate:MARKer:COUPled[:STATe] ON.
/// HIFN  Changing the coupling type automatically disables marker coupling
/// HIFN  throughout the channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR couplingType/Selects the marker coupling type to be used in the current channel
/// HIPAR couplingType/setup.
ViStatus _VI_FUNC rsznl_ConfigureMarkerCouplingType(ViSession instrSession,
                                                    ViInt32   couplingType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_MARKER_COUPLING_TYPE, couplingType),
            2, "Coupling Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns those sweep points that have caused a limit violation of the
/// HIFN  given <LimitFailType> for trace <TraceName>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR limitFailSweepPoints/Returns those sweep points that have caused a limit violation of the
/// HIPAR limitFailSweepPoints/given <LimitFailType> for trace <TraceName>.
ViStatus _VI_FUNC rsznl_QueryLimitFailSweepPoints(ViSession instrSession,
                                                  ViString  traceName,
                                                  ViInt32   limitFailType,
                                                  ViInt32   bufferSize,
                                                  ViChar    limitFailSweepPoints[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViPChar  paramBand;
    ViInt32  length = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngLimitFailType,
        limitFailType, &paramBand),
        3, "Limit Fail Type");

    snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s", traceName, paramBand);

    checkErr(RsCore_GetAttributeViRawStringWithQparam(instrSession, NULL, RSZNL_ATTR_HIDDEN_LIMIT_FAIL_SWEEP_POINTS,
        param, bufferSize, limitFailSweepPoints, &length));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the output format for the (complex) value of the
/// HIFN  reference marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR format/Sets the output format for the (complex) value of the
/// HIPAR format/reference marker.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerFormat(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   marker,
                                                       ViInt32   format)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_FORMAT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_FORMAT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_FORMAT, format),
            4, "Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates or deactivates the marker-specific minimum excursion for
/// HIFN  peak searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR enabled/Activates or deactivates the marker-specific minimum excursion for
/// HIPAR enabled/peak searches.
/// HIPAR excursion/Defines a marker-specific minimum excursion value for peak searches.
ViStatus _VI_FUNC rsznl_ConfigureMarkerExcursion(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   marker,
                                                 ViBoolean enabled,
                                                 ViReal64  excursion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_EXCURSION_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_EXCURSION_ENABLED,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_EXCURSION_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_EXCURSION, excursion),
            5, "Excursion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates or deactivates the marker-specific threshold for (single)
/// HIFN  peak searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR enabled/Activates or deactivates the marker-specific threshold for (single)
/// HIPAR enabled/peak searches.
/// HIPAR threshold/Defines a marker-specific threshold value for (single) peak searches.
ViStatus _VI_FUNC rsznl_ConfigureMarkerThreshold(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   marker,
                                                 ViBoolean enabled,
                                                 ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_EXCURSION_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_EXCURSION_ENABLED,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_THRESHOLD_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_THRESHOLD, threshold),
            5, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates or deactivates the reference marker-specific minimum
/// HIFN  excursion for peak searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR enabled/Activates or deactivates the reference marker-specific minimum
/// HIPAR enabled/excursion for peak searches.
/// HIPAR excursion/Defines a reference marker-specific minimum excursion value for peak
/// HIPAR excursion/searches.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerExcursion(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   marker,
                                                          ViBoolean enabled,
                                                          ViReal64  excursion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_EXCURSION_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_EXCURSION_ENABLED,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_EXCURSION_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_EXCURSION, excursion),
            5, "Excursion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates or deactivates the reference marker-specific threshold for
/// HIFN  (single) peak searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR enabled/Activates or deactivates the reference marker-specific threshold for
/// HIPAR enabled/(single) peak searches.
/// HIPAR threshold/Defines a reference marker-specific threshold value for (single) peak
/// HIPAR threshold/searches.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerThreshold(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   marker,
                                                          ViBoolean enabled,
                                                          ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD_ENABLED,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD, threshold),
            5, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates search with the active marker for specific
/// HIFN  points on the trace.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The marker must be created before using function
/// HIFN  rsznl_ConfigureMarker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR search/Selects a search mode for marker no. <Mk> and initiates the search.
/// HIPAR search/The marker must be created before.
ViStatus _VI_FUNC rsznl_MarkerSearch(ViSession instrSession,
                                     ViInt32   channel,
                                     ViInt32   marker,
                                     ViInt32   search)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH, search),
            4, "Search");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates search with the active reference marker for
/// HIFN  specific points on the trace.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The marker must be created before using function
/// HIFN  rsznl_ConfigureReferenceMarker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR search/Selects a search mode for reference marker no. <Mk> and initiates the
/// HIPAR search/search. The reference marker must be created before.
ViStatus _VI_FUNC rsznl_ReferenceMarkerSearch(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   marker,
                                              ViInt32   search)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH, search),
            4, "Search");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates search with the active marker for target value
/// HIFN  on the trace.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     The marker must be created before using function
/// HIFN  rsznl_ConfigureMarker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR search/Sets the active marker to specific points on the trace.
ViStatus _VI_FUNC rsznl_MarkerTargetSearch(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   marker,
                                           ViInt32   search)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH, search),
            4, "Search");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the target value for the target search of marker
/// HIFN  no. <Mk>, which can be activated using function
/// HIFN  rsznl_MarkerTargetSearch.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR targetValue/Defines the target value for the target search.
ViStatus _VI_FUNC rsznl_ConfigureMarkerTargetValue(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   marker,
                                                   ViReal64  targetValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TARGET_VALUE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TARGET_VALUE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_TARGET_VALUE, targetValue),
            4, "Target Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the format in which the "Target Value" shall
/// HIFN  be specified.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR targetFormat/This control selects the search format for the target value of the
/// HIPAR targetFormat/marker.
ViStatus _VI_FUNC rsznl_ConfigureMarkerTargetFormat(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   targetFormat)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TARGET_FORMAT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TARGET_FORMAT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_TARGET_FORMAT, targetFormat),
            4, "Target Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates search with the active reference marker for
/// HIFN  target value on the trace.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     The marker must be created before using function
/// HIFN  rsznl_ConfigureReferenceMarker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR search/Sets the active reference marker to specific points on the trace.
ViStatus _VI_FUNC rsznl_ReferenceMarkerTargetSearch(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   search)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH, search),
            4, "Search");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the target value for the target search of
/// HIFN  reference marker no. <Mk>, which can be activated using function
/// HIFN  rsznl_ReferenceMarkerTargetSearch.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR targetValue/Defines the target value for the target search.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTargetValue(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   marker,
                                                            ViReal64  targetValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TARGET_VALUE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TARGET_VALUE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_TARGET_VALUE, targetValue),
            4, "Target Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the format in which the "Target Value" shall
/// HIFN  be specified.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR targetFormat/This control selects the search format for the target value of the
/// HIPAR targetFormat/marker.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTargetFormat(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   marker,
                                                             ViInt32   targetFormat)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TARGET_FORMAT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TARGET_FORMAT,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_TARGET_FORMAT, targetFormat),
            4, "Target Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates a bandfilter search with the active marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_MarkerBandfilterSearch(ViSession instrSession,
                                               ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",M1", NULL, NULL);

    checkErr(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH, RSZNL_VAL_MARKER_BFILTER));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function initiates a bandfilter search with the active reference
/// HIFN  marker.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_ReferenceMarkerBandfilterSearch(ViSession instrSession,
                                                        ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",M1", NULL, NULL);

    checkErr(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH, RSZNL_VAL_MARKER_BFILTER));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects the bandfilter search mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR searchMode/This control selects the bandfilter search mode.
ViStatus _VI_FUNC rsznl_ConfigureMarkerBandfilterSearchMode(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   searchMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_MODE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_MODE,
            "Marker", 0 , RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_MODE, searchMode),
            3, "Search Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the bandfilter level, i.e. the minimum excursion
/// HIFN  for the bandpass and bandstop peaks.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR xdBBandwidth/Defines x dB Bandwidth parameter. The x dB Bandwidth is the difference
/// HIPAR xdBBandwidth/between the band edges and the center response value of a bandfilter
/// HIPAR xdBBandwidth/peak; it must be negative for a bandpass search and positive for a
/// HIPAR xdBBandwidth/bandstop search.
ViStatus _VI_FUNC rsznl_ConfigureMarkerxdBBandwidth(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  xdBBandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_BANDWIDTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_BANDWIDTH,
            "Marker", 0 , RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_BANDWIDTH, xdBBandwidth),
            3, "x dB Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the results of a bandpass or a bandstop filter
/// HIFN  search. Result is only available after a bandfilter search has been
/// HIFN  executed.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Units of the result values depends on the sweep type and the
/// HIFN  marker format; see RSZNL_ATTR_MARKER_FORMAT attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR bandwidth/Returns n-dB bandwidth of the bandpass/bandstop region, where n is the
/// HIPAR bandwidth/selected x dB Bandwidth (setting command
/// HIPAR bandwidth/CALCulate<Ch/Tr>:MARKer<Mk>:BWIDth <x dB Bandwidth>).
/// HIPAR centerStimulus/Returns stimulus frequency at the center of the bandpass/bandstop
/// HIPAR centerStimulus/region (the stimulus value of marker no. 4).
/// HIPAR qualityFactor/Returns quality factor, i.e. the ratio between the center frequency
/// HIPAR qualityFactor/and the 3-dB bandwidth.
/// HIPAR loss/Returns loss at the center of the bandpass/bandstop region (the
/// HIPAR loss/response value of marker no. 4 at the time of the bandfilter search).
/// HIPAR lowerEdge/Returns lower band edge.
/// HIPAR upperEdge/Returns upper band edge.
ViStatus _VI_FUNC rsznl_QueryMarkerBandfilterResults(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64* bandwidth,
                                                     ViReal64* centerStimulus,
                                                     ViReal64* qualityFactor,
                                                     ViReal64* loss,
                                                     ViReal64* lowerEdge,
                                                     ViReal64* upperEdge)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViReal64* result = NULL;
    ViInt32   count = 0;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK:BWID?", channel);
    checkErr(RsCore_QueryFloatArray(instrSession, cmd, &result, &count));
    viCheckErrElab(RsCore_InvalidViInt32Value(count, 6), "Invalid response, 6 values expected");
    checkErr(rsznl_CheckStatus(instrSession));

    if (bandwidth)
        *bandwidth = result[0];
    if (centerStimulus)
        *centerStimulus = result[1];
    if (qualityFactor)
        *qualityFactor = result[2];
    if (loss)
        *loss = result[3];
    if (lowerEdge)
        *lowerEdge = result[4];
    if (upperEdge)
        *upperEdge = result[5];

Error:
    if (result) free(result);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function shows or hides the bandfilter search results in the
/// HIFN  diagram area.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR searchResults/Shows or hides the bandfilter search results in the diagram area.
/// HIPAR horizontalPosition/Selects the horizontal position of the info field.
/// HIPAR verticalPosition/Selects the vertical position of the info field.
ViStatus _VI_FUNC rsznl_ConfigureMarkerBandfilterSearchResultState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean searchResults,
                            ViInt32   horizontalPosition,
                            ViInt32   verticalPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_RESULT_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, horizontalPosition, RSZNL_VAL_HORIZONTAL_LEFT, RSZNL_VAL_HORIZONTAL_RIGHT),
            4, "Horizontal Position");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, verticalPosition, RSZNL_VAL_VERTICAL_TOP, RSZNL_VAL_VERTICAL_BOTTOM),
            5, "Vertical Position");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_RESULT_STATE, searchResults),
            3, "Search Result");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK:SEAR:BFIL:RES:STAT:AREA %s,%s", channel,
        RsZnl_rngHorizontalPosition.entries[horizontalPosition].cmdString,
        RsZnl_rngVerticalPosition.entries[verticalPosition].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the marker tracking mode for marker
/// HIFN  no. <Mk>. Tracking mode causes the active minimum/maximum or target
/// HIFN  search of the active marker to be repeated after each sweep.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) A marker must be created and a search mode must be active
/// HIFN  (CALCulate<Ch/Tr>:MARKer<Mk>:FUNCtion:EXECute ...) to use this
/// HIFN  function.
/// HIFN
/// HIFN     (2) If the current search mode is a bandfilter search this function
/// HIFN  enables or disables bandfilter tracking.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerTracking/Enables or disables the marker tracking mode.
ViStatus _VI_FUNC rsznl_ConfigureMarkerTracking(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   marker,
                                                ViBoolean markerTracking)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TRACKING,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_TRACKING,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_TRACKING, markerTracking),
            4, "Marker Tracking");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines search ranges for the maximum/minimum or target
/// HIFN  search. Assigns a search range to marker and define the start and stop
/// HIFN  values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR searchRange/Selects one out of 10 search ranges.
/// HIPAR start/Defines the start value of the selected search range.
/// HIPAR stop/Defines the stop value of the selected search range.
ViStatus _VI_FUNC rsznl_ConfigureMarkerSearchRange(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   marker,
                                                   ViInt32   searchRange,
                                                   ViReal64  start,
                                                   ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH_RANGE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH_RANGE, searchRange),
            4, "Search Range");

    if (searchRange != RSZNL_VAL_FULL_SPAN)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH_RANGE_START, start),
                5, "Start");

        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH_RANGE_STOP, stop),
                6, "Stop");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides range limit lines for the search range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/Marker number.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showLimitLines/Displays or hides range limit lines for the search range.
ViStatus _VI_FUNC rsznl_ConfigureMarkerSearchLimitLinesState(ViSession instrSession,
                                                             ViInt32   marker,
                                                             ViInt32   channel,
                                                             ViBoolean showLimitLines)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES, showLimitLines),
            4, "Show Limit Lines");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the result (stimulus and response value) of a
/// HIFN  search started by means of function rsznl_MarkerSearch. The search must
/// HIFN  be executed before the command is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR bufferSize/The size of the buffers allocated for the results arrays.
/// HIPAR markerStimulus/Stimulus values of marker no. <Mk>.
/// HIPAR markerResponse/Response value(s) of marker no. <Mk>. Unit is depending on the marker
/// HIPAR markerResponse/format; see RSZNL_ATTR_MARKER_FORMAT attribute.
/// HIPAR returnedValues/The number of returned values for each result array that was read from
/// HIPAR returnedValues/the instrument. If this value is larger than the allocated buffer size,
/// HIPAR returnedValues/not all values returned by the instrument could be stored in the
/// HIPAR returnedValues/arrays.
ViStatus _VI_FUNC rsznl_QueryMarkerSearchResults(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   marker,
                                                 ViInt32   bufferSize,
                                                 ViReal64  markerStimulus[],
                                                 ViReal64  markerResponse[],
                                                 ViInt32*  returnedValues)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViReal64* outDblArray = NULL;
    ViInt32   outArraySize = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 10),
            3, "Marker");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 1), 4, "Buffer Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, markerStimulus), 5, "Marker Stimulus");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, markerResponse), 6, "Marker Response");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:FUNC:RES?", channel, marker);
    checkErr(RsCore_QueryFloatArray(instrSession, cmd, &outDblArray, &outArraySize));
    checkErr(rsznl_CheckStatus(instrSession));

    checkErr(RsCore_DecimateViReal64ArrayToUserBuffers(outDblArray, outArraySize,
        bufferSize, returnedValues,
        markerStimulus, markerResponse, NULL,
        NULL, NULL, NULL));

Error:
    if (outDblArray) free(outDblArray);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the reference marker tracking mode
/// HIFN  for reference marker no. <Mk>. Tracking mode causes the active
/// HIFN  minimum/maximum or target search of the active reference marker to be
/// HIFN  repeated after each sweep.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) A reference marker must be created and a search mode must be
/// HIFN  active (CALCulate<Ch/Tr>:MARKer<Mk>:FUNCtion:EXECute ...) to use this
/// HIFN  function.
/// HIFN
/// HIFN     (2) If the current search mode is a bandfilter search this function
/// HIFN  enables or disables bandfilter tracking.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR markerTracking/Enables or disables the reference marker tracking mode for reference
/// HIPAR markerTracking/marker no. <Mk>. Tracking mode causes the active minimum/maximum or
/// HIPAR markerTracking/target search of the active reference marker to be repeated after each
/// HIPAR markerTracking/sweep.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTracking(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   marker,
                                                         ViBoolean markerTracking)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TRACKING,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_TRACKING,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_TRACKING, markerTracking),
            4, "Marker Tracking");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines search ranges for the maximum/minimum or target
/// HIFN  search. Assigns a search range to reference marker and define the start
/// HIFN  and stop values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR searchRange/Selects one out of 10 search ranges.
/// HIPAR start/Defines the start value of the selected search range.
/// HIPAR stop/Defines the stop value of the selected search range.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerSearchRange(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   marker,
                                                            ViInt32   searchRange,
                                                            ViReal64  start,
                                                            ViReal64  stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE, searchRange),
            4, "Search Range");

    if (searchRange != RSZNL_VAL_FULL_SPAN)
    {
        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_START, start),
                5, "Start");

        viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_STOP, stop),
                6, "Stop");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides range limit lines for the search range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/Marker number.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showLimitLines/Displays or hides range limit lines for the search range.
ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerSearchLimitLinesState(
                            ViSession instrSession,
                            ViInt32   marker,
                            ViInt32   channel,
                            ViBoolean showLimitLines)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_marker[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES, showLimitLines),
            4, "Show Limit Lines");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the result (stimulus and response value) of a
/// HIFN  search started by means of function rsznl_ReferenceMarkerSearch. The
/// HIFN  search must be executed before the command is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR bufferSize/The size of the buffers allocated for the results arrays.
/// HIPAR markerStimulus/Stimulus values of marker no. <Mk>.
/// HIPAR markerResponse/Response value(s) of marker no. <Mk>. Unit is depending on the marker
/// HIPAR markerResponse/format; see RSZNL_ATTR_MARKER_FORMAT attribute.
/// HIPAR returnedValues/The number of returned values for each result array that was read from
/// HIPAR returnedValues/the instrument. If this value is larger than the allocated buffer size,
/// HIPAR returnedValues/not all values returned by the instrument could be stored in the
/// HIPAR returnedValues/arrays.
ViStatus _VI_FUNC rsznl_QueryReferenceMarkerSearchResults(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   marker,
                                                          ViInt32   bufferSize,
                                                          ViReal64  markerStimulus[],
                                                          ViReal64  markerResponse[],
                                                          ViInt32*  returnedValues)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViReal64* outDblArray = NULL;
    ViInt32   outArraySize = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, marker, 1, 10),
            3, "Marker");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 1), 4, "Buffer Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, markerStimulus), 5, "Marker Stimulus");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, markerResponse), 6, "Marker Response");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:MARK%ld:REF:FUNC:RES?", channel, marker);
    checkErr(RsCore_QueryFloatArray(instrSession, cmd, &outDblArray, &outArraySize));
    checkErr(rsznl_CheckStatus(instrSession));

    checkErr(RsCore_DecimateViReal64ArrayToUserBuffers(outDblArray, outArraySize,
        bufferSize, returnedValues,
        markerStimulus, markerResponse, NULL,
        NULL, NULL, NULL));

Error:
    if (outDblArray) free(outDblArray);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the beginning (start), end (stop), span and center
/// HIFN  of the sweep range equal to the stimulus value of the marker <Mk> on
/// HIFN  trace no. <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR setByMarker/Sets the beginning (start), end (stop), span and center of the sweep
/// HIPAR setByMarker/range equal to the stimulus value of the marker <Mk> on trace no. <Chn>
ViStatus _VI_FUNC rsznl_ConfigureSweepRangeToMarker(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   setByMarker)
{
    ViStatus                              error = VI_SUCCESS;
    ViChar                                repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar                                repCap_marker[RS_REPCAP_BUF_SIZE] = "";
    ViAttr                                attr[] = { RSZNL_ATTR_START_SWEEP_RANGE_TO_MARKER,
                                          RSZNL_ATTR_STOP_SWEEP_RANGE_TO_MARKER,
                                          RSZNL_ATTR_CENTER_SWEEP_RANGE_TO_MARKER,
    RSZNL_ATTR_SPAN_SWEEP_RANGE_TO_MARKER };

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_START_SWEEP_RANGE_TO_MARKER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_START_SWEEP_RANGE_TO_MARKER,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, attr[setByMarker], NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the beginning (start), end (stop) and center of the
/// HIFN  sweep range equal to the stimulus value of the reference marker <Mk> on
/// HIFN  trace no. <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR marker/Marker number.
/// HIPAR setByMarker/Sets the beginning (start), end (stop) and center of the sweep range
/// HIPAR setByMarker/equal to the stimulus value of the reference marker <Mk> on trace no.
/// HIPAR setByMarker/<Chn>
ViStatus _VI_FUNC rsznl_ConfigureSweepRangeToReferenceMarker(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   marker,
                                                             ViInt32   setByMarker)
{
    ViStatus                                          error = VI_SUCCESS;
    ViChar                                            repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar                                            repCap_marker[RS_REPCAP_BUF_SIZE] = "";
    ViAttr                                            attr[] = { RSZNL_ATTR_REFERENCE_START_SWEEP_RANGE_TO_MARKER,
                                                      RSZNL_ATTR_REFERENCE_STOP_SWEEP_RANGE_TO_MARKER,
    RSZNL_ATTR_REFERENCE_CENTER_SWEEP_RANGE_TO_MARKER };

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_START_SWEEP_RANGE_TO_MARKER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REFERENCE_START_SWEEP_RANGE_TO_MARKER,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap_marker));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_marker, NULL);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, attr[setByMarker], NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates or deactivates the minimum excursion for multiple peak
/// HIFN  searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR enabled/Activates or deactivates the minimum excursion for multiple peak
/// HIPAR enabled/searches.
/// HIPAR excursion/Defines a minimum excursion value for multiple peak searches.
ViStatus _VI_FUNC rsznl_ConfigureMarkerMultiplePeakExcursion(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViBoolean enabled,
                                                             ViReal64  excursion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_EXCURSION_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_EXCURSION_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_EXCURSION, excursion),
            4, "Excursion");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates or deactivates the threshold for multiple peak searches.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel_Trace/Channel number used to identify the active trace.
/// HIPAR enabled/Activates or deactivates the threshold for multiple peak searches.
/// HIPAR threshold/Defines a threshold value for multiple peak searches.
ViStatus _VI_FUNC rsznl_ConfigureMarkerMultiplePeakThreshold(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViBoolean enabled,
                                                             ViReal64  threshold)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_THRESHOLD_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_THRESHOLD_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_MARKER_MULTIPLE_PEAK_THRESHOLD, threshold),
            4, "Threshold");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function adjusts the Scale Divisions and the Ref. Value in order
/// HIFN  to display the entire active trace in the diagram area, leaving an
/// HIFN  appropriate display margin.
/// HIFN
/// HIFN     In Cartesian diagrams, the analyzer re-calculates the values of the
/// HIFN  vertical divisions so that the trace fits onto 80% of the vertical
/// HIFN  grid. The reference value is chosen to center the trace in the diagram.
/// HIFN
/// HIFN     In circular diagrams (Polar, Smith, Inverted Smith), the analyzer
/// HIFN  re-calculates the values of the radial divisions so that the diagram is
/// HIFN  confined to approx. 80% of the outer circumference. The reference value
/// HIFN  is set to the value of the outer circumference.
/// HIFN
/// HIFN     Autoscale does not affect the stimulus values and the horizontal axis.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The trace is referenced by its name <trace_name>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/This control sets the trace name.
ViStatus _VI_FUNC rsznl_AutoScaleTrace(ViSession instrSession,
                                       ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:AUTO ONCE,'%s'", traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures trace parameters.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The trace is referenced by its name <trace_name>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/This control sets the trace name.
/// HIPAR scaleDivisions/Scale /Div corresponds to the increment between two consecutive grid
/// HIPAR scaleDivisions/lines. The unit depends on the display format: dB for display format dB
/// HIPAR scaleDivisions/Mag, degrees for Phase and Unwrapped Phase, ns for Delay, U (units) for
/// HIPAR scaleDivisions/all other (dimensionless) formats.
/// HIPAR referenceLevel/Sets the reference level (or reference value) for a particular
/// HIPAR referenceLevel/displayed trace. Setting a new reference level does not affect the
/// HIPAR referenceLevel/value of PDIVision.
/// HIPAR referencePosition/Sets the point on the y-axis to be used as the reference position as a
/// HIPAR referencePosition/percentage of the length of the y-axis. The reference position is the
/// HIPAR referencePosition/point on the y-axis which should equal the RLEVel.
ViStatus _VI_FUNC rsznl_ConfigureTrace(ViSession instrSession,
                                       ViString  traceName,
                                       ViReal64  scaleDivisions,
                                       ViReal64  referenceLevel,
                                       ViReal64  referencePosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:PDIV %.12lG,'%s'", scaleDivisions, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:RLEV %.12lG,'%s'", referenceLevel, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:RPOS %.12lG,'%s'", referencePosition, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the upper and lower edge of the diagram area.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The trace is referenced by its name <trace_name>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/This control sets the trace name.
/// HIPAR top/Value for the upper (maximum) edge of the diagram area <Wnd>.
/// HIPAR bottom/Value for the lower (minimum) edge of the diagram area <Wnd>.
ViStatus _VI_FUNC rsznl_ConfigureTraceMaxMin(ViSession instrSession,
                                             ViString  traceName,
                                             ViReal64  top,
                                             ViReal64  bottom)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:TOP %.12lG,'%s'", top, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND:TRAC:Y:BOTT %.12lG,'%s'", bottom, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures infinite averaging.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR enabled/Turns infinite averaging on or off.
/// HIPAR mode/Selects the quantities to be averaged if infinite averaging is enabled
/// HIPAR mode/(CALCulate<Chn>:IAVerage[:STATe] ON.
ViStatus _VI_FUNC rsznl_ConfigureInfiniteAverage(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean enabled,
                                                 ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_INFINITE_AVERAGE_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_INFINITE_AVERAGE_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_INFINITE_AVERAGE_MODE, mode),
            4, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows/hides the Info Window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Shows/hides the Info Window.
ViStatus _VI_FUNC rsznl_ConfigureTraceInfoWindowEnabled(ViSession instrSession,
                                                        ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_DISPLAY_INFO_WINDOW_ENABLED, enabled),
            2, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the bandfilter search results to be displayed in the Info
/// HIFN  Window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Sets if Info Window is displayed.
/// HIPAR tracename/Name of the related trace.
/// HIPAR bandfilteritem/Bandfilter search result.
ViStatus _VI_FUNC rsznl_TraceInfoWindowContentSelection(ViSession instrSession,
                                                        ViBoolean enabled,
                                                        ViString  traceName,
                                                        ViInt32   bandFilterItem)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViPChar  paramBand;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngInfoWindowBandFilter,
        bandFilterItem, &paramBand),
        5, "Band Filter Item");

    snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s,%s", traceName, paramBand, enabled ? "OFF" : "ON");

    checkErr(RsCore_SetAttributeViString(instrSession, repCap,
        RSZNL_ATTR_HIDDEN_DISPLAY_INFO_WINDOW_CONTENT_SELECTION,
        RS_VAL_DIRECT_USER_CALL,
        param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the markers to be displayed in the Info Window.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR marker/Marker number.
/// HIPAR enabled/Sets if Info Window is displayed.
/// HIPAR tracename/Name of the related trace.
ViStatus _VI_FUNC rsznl_MarkerInfoWindowEnabled(ViSession instrSession,
                                                ViInt32   marker,
                                                ViBoolean enabled,
                                                ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_HIDDEN_MARKER_INFO_WINDOW_ENABLED,
            "Marker", marker - 1, RS_REPCAP_BUF_SIZE, repCap));

    snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s", traceName, enabled ? "ON" : "OFF");

    checkErr(RsCore_SetAttributeViString(instrSession, repCap,
        RSZNL_ATTR_HIDDEN_MARKER_INFO_WINDOW_ENABLED,
        RS_VAL_DIRECT_USER_CALL,
        param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a one-port, two-port, three-port or four-port
/// HIFN  calibration type at arbitrary analyzer ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) For an n-port calibration type (n = 1 to 4), n port numbers must
/// HIFN  be specified. If more than n numbers are defined, the spare numbers
/// HIFN  (the last in the list) are ignored.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationName/This control defines the name of the calibration (string parameter).
/// HIPAR calibrationName/The name serves as a reference to delete a particular set of system
/// HIPAR calibrationName/correction data.
/// HIPAR calibrationType/This control selects a calibration type.
/// HIPAR arraySize/Sets the number of elements of the Ports array.
/// HIPAR ports/Port numbers. The number of elements should correspond with Array Size
/// HIPAR ports/number.
/// HIPAR adapterCalKit/This control sets a adapter cal kit file name, it will be overwritten.
/// HIPAR adapterCalKit/After completing the calibration, the VNA will generate this file in
/// HIPAR adapterCalKit/addition to the correction parameters. This file characterizes the
/// HIPAR adapterCalKit/Adapter which was used for calibration and can thus be used for
/// HIPAR adapterCalKit/deembedding during measurement with a DUT.
ViStatus _VI_FUNC rsznl_SelectCalibrationType(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  calibrationName,
                                              ViInt32   calibrationType,
                                              ViInt32   arraySize,
                                              ViInt32   ports[],
                                              ViString  adapterCalKit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, calibrationType, RSZNL_VAL_CALTYPE_TOSM, RSZNL_VAL_CALTYPE_UTR),
            4, "Calibration Type");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:METH:DEF '%s',%s", channel,
        calibrationName, RsZnl_rngCalibrationType.entries[calibrationType].cmdString);

    for (i = 0; i < arraySize; i++)
    {
        if (i == 2 && adapterCalKit != NULL)
            p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",'%s'", adapterCalKit);
        else
            p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", ports[i]);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function starts a calibration measurement in order to acquire
/// HIFN  measurement data for the selected standards. The
/// HIFN     standards are reflection or transmission standards and can be
/// HIFN  connected to arbitrary analyzer ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR standard/This control selects a standard from the selected calibration kit.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR timeout/This control sets the timeout in miliseconds for the operation to
/// HIPAR timeout/finish.
ViStatus _VI_FUNC rsznl_StartCalibration(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   standard,
                                         ViInt32   port1,
                                         ViInt32   port2,
                                         ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (standard)
    {
    case RSZNL_VAL_CAL_STD_THR:
    case RSZNL_VAL_CAL_STD_NET:
    case RSZNL_VAL_CAL_STD_ATT:
    case RSZNL_VAL_CAL_STD_ISOLATION:
    case RSZNL_VAL_CAL_STD_UTHR:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:SEL %s,%ld,%ld", channel, RsZnl_rngCalibrationStandard.entries[standard].cmdString, port1, port2);
        break;
    case RSZNL_VAL_CAL_STD_OPEN:
    case RSZNL_VAL_CAL_STD_SHORT:
    case RSZNL_VAL_CAL_STD_MATCH:
    case RSZNL_VAL_CAL_STD_REFL:
    case RSZNL_VAL_CAL_STD_OSH:
    case RSZNL_VAL_CAL_STD_OSH_2:
    case RSZNL_VAL_CAL_STD_OSH_3:
    case RSZNL_VAL_CAL_STD_SLID:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:SEL %s,%ld", channel, RsZnl_rngCalibrationStandard.entries[standard].cmdString, port1);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, standard), 3, "Standard");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function starts a calibration measurement in order to acquire
/// HIFN  measurement data for the selected standards. The
/// HIFN     standards are reflection or transmission standards and can be
/// HIFN  connected to arbitrary analyzer ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR standard/This control selects a standard from the selected calibration kit.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR dispersion/This control selects if unknown through standard is non-dispersive or
/// HIPAR dispersion/dispersive.
/// HIPAR delayPhase/This controle selects automatic or manual settings of delay time and
/// HIPAR delayPhase/phase.
/// HIPAR delayPhaseValue/This control sets the delay time or phase, depending on the Dispersion
/// HIPAR delayPhaseValue/settings.
/// HIPAR timeout/This control sets the timeout in miliseconds for the operation to
/// HIPAR timeout/finish.
ViStatus _VI_FUNC rsznl_StartCalibrationWithOptions(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   standard,
                                                    ViInt32   port1,
                                                    ViInt32   port2,
                                                    ViBoolean dispersion,
                                                    ViInt32   delayPhase,
                                                    ViReal64  delayPhaseValue,
                                                    ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (standard != RSZNL_VAL_CAL_STD_UTHR)
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, channel), 3, "Standard");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, delayPhase, RSZNL_VAL_UTHR_AUTO, RSZNL_VAL_UTHR_MAN),
            7, "Delay Phase");

    if (delayPhase == RSZNL_VAL_UTHR_AUTO)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:SEL %s,%ld,%ld,%s,AUTO",
            channel, RsZnl_rngCalibrationStandard.entries[standard].cmdString,
            port1, port2, (dispersion == VI_TRUE) ? "ON" : "OFF");
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:SEL %s,%ld,%ld,%s,%lf",
            channel, RsZnl_rngCalibrationStandard.entries[standard].cmdString,
            port1, port2, (dispersion == VI_TRUE) ? "ON" : "OFF", delayPhaseValue);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the system error correction for
/// HIFN  channel <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR correctionState/This control enables (ON) or disables (OFF) the correction.
ViStatus _VI_FUNC rsznl_ConfigureSystemErrorCorrectionState(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean correctionState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SYSTEM_ERROR_CORRECTION_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SYSTEM_ERROR_CORRECTION_STATE, correctionState),
            3, "Correction State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function reloads a set of previously acquired calibration data
/// HIFN  for a particular standard from a file in the cal pool. The loaded data
/// HIFN  may be combined with new calibration measurement data (function
/// HIFN  rsznl_StartCalibration) in order to simplify and speed up the new
/// HIFN  calibration procedure. The channel settings for loaded and new
/// HIFN  calibrations (e.g. the number of sweep points) must be identical.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calPoolFile/Calibration pool file.
/// HIPAR standard/This control selects a standard from the selected calibration kit.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
ViStatus _VI_FUNC rsznl_LoadCalibrationDataFromCalGroupFile(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViString  calPoolFile,
                                                            ViInt32   standard,
                                                            ViInt32   port1,
                                                            ViInt32   port2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (standard)
    {
    case RSZNL_VAL_CAL_STD_THR:
    case RSZNL_VAL_CAL_STD_NET:
    case RSZNL_VAL_CAL_STD_ATT:
    case RSZNL_VAL_CAL_STD_ISOLATION:
    case RSZNL_VAL_CAL_STD_UTHR:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:LOAD:SEL '%s',%s,%ld,%ld", channel, calPoolFile, RsZnl_rngCalibrationStandard.entries[standard].cmdString, port1, port2);
        break;
    case RSZNL_VAL_CAL_STD_OPEN:
    case RSZNL_VAL_CAL_STD_SHORT:
    case RSZNL_VAL_CAL_STD_MATCH:
    case RSZNL_VAL_CAL_STD_REFL:
    case RSZNL_VAL_CAL_STD_OSH:
    case RSZNL_VAL_CAL_STD_OSH_2:
    case RSZNL_VAL_CAL_STD_OSH_3:
    case RSZNL_VAL_CAL_STD_SLID:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:LOAD:SEL '%s',%s,%ld", channel, calPoolFile, RsZnl_rngCalibrationStandard.entries[standard].cmdString, port1);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, standard), 3, "Standard");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function provides operations which allows to store system error
/// HIFN  correction data to the cal pool and to assign stored correction data to
/// HIFN  channels:
/// HIFN
/// HIFN       Copy
/// HIFN       Apply
/// HIFN       Resolve Pool Link
/// HIFN       Merge
/// HIFN       Delete
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR operationtobePerformed/This control selects the type of operation to be performed.
/// HIPAR fileName/This control specifies the file name for the file operation to be
/// HIPAR fileName/performed. Cal group files must have the extension *.cal. The file
/// HIPAR fileName/extensions must be specified as part of the string parameters. In
/// HIPAR fileName/contrast the directory path must not be specified; the analyzer always
/// HIPAR fileName/uses the default path C:\Documents and Settings\All
/// HIPAR fileName/Users\Documents\Rohde-Schwarz\Vna\CALibration\DATA.
/// HIPAR secondFileName/This control is used for merge operation only.
ViStatus _VI_FUNC rsznl_CalibrationManager(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   operationtobePerformed,
                                           ViString  fileName,
                                           ViString  secondFileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (operationtobePerformed)
    {
    case RSZNL_VAL_CORR_MAN_COPY:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:CORR %ld,'%s'", channel, fileName);
        break;
    case RSZNL_VAL_CORR_MAN_APPLY:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CORR %ld,'%s'", channel, fileName);
        break;
    case RSZNL_VAL_CORR_MAN_RESOLVE:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CORR:RES %ld,'%s'", channel, fileName);
        break;
    case RSZNL_VAL_CORR_MAN_MERGE:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CORR:MERG %ld,'%s','%s'", channel, fileName, secondFileName);
        break;
    case RSZNL_VAL_CORR_MAN_DELETE:
        viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_DELETE_CALIBRATION_GROUP_FILE, fileName),
                4, "File Name");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, operationtobePerformed), 3, "Operation To Be Performed");
    }

    if (operationtobePerformed != RSZNL_VAL_CORR_MAN_DELETE)
    {
        checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a calibration from the calibration pool that
/// HIFN  shall be restored during a user-defined preset.
/// HIFN
/// HIFN     The corresponding cal group file (<PresetUserCal>.cal) must be
/// HIFN  available in the cal pool directory
/// HIFN
/// HIFN     C:\Users\Public\Documents\Rohde-Schwarz\Vna\Calibration\Data\
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR userDefinedPresetCalibration/Name of the cal group (i.e. the name of the cal group file without
/// HIPAR userDefinedPresetCalibration/path and extension).
ViStatus _VI_FUNC rsznl_ConfigureUserDefinedPresetCalibration(
                            ViSession instrSession,
                            ViString  userDefinedPresetCalibration)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_USER_DEFINED_PRESET_CAL, userDefinedPresetCalibration),
            2, "User Defined Preset Calibration");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Toggles the Multiple Calibration Types mode that allows calibrate a
/// HIFN  subset of the available channels using channel-specific ports and
/// HIFN  calibration types. Enable the MCTYpes mode before defining the
/// HIFN  calibrations to be performed (using RSZNL_FUNC_SELECT_CALIBRATION_TYPE,
/// HIFN  disable it after the calibrations were saved (using
/// HIFN  RSZNL_ATTR_SAVE_CALIBRATION_DATA once). Also make sure to call
/// HIFN  RSZNL_ATTR_SAVE_CALIBRATION_DATA with <Ch> pointing to one of the
/// HIFN  calibrated channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Toggles the Multiple Calibration Types mode that allows calibrate a
/// HIPAR mode/subset of the available channels using channel-specific ports and
/// HIPAR mode/calibration types. Enable the MCTYpes mode before defining the
/// HIPAR mode/calibrations to be performed (using RSZNL_FUNC_SELECT_CALIBRATION_TYPE,
/// HIPAR mode/disable it after the calibrations were saved (using
/// HIPAR mode/RSZNL_ATTR_SAVE_CALIBRATION_DATA once). Also make sure to call
/// HIPAR mode/RSZNL_ATTR_SAVE_CALIBRATION_DATA with <Ch> pointing to one of the
/// HIPAR mode/calibrated channels.
ViStatus _VI_FUNC rsznl_MultipleCalibrationTypesMode(ViSession instrSession,
                                                     ViBoolean mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_MULTIPLE_CALIBRATION_TYPES_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects and initiates a one-port, two-port, three-port
/// HIFN  or four-port automatic calibration at arbitrary analyzer and
/// HIFN  calibration unit ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Port numbers of the analyzer:
/// HIFN     For an n-port automatic calibration (n = 1 to 4), n arbitrary (not
/// HIFN  necessarily consecutive) port numbers must be specified.
/// HIFN
/// HIFN     (2) Port numbers of the cal unit:
/// HIFN     For an n-port automatic calibration (n = 1 to 4), n arbitrary (not
/// HIFN  necessarily consecutive) port numbers must be specified. It is possible
/// HIFN  to combine arbitrary (not necessarily matching) pairs of analyzer and
/// HIFN  cal unit ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR calUnitPort1/Port number of the cal unit.
/// HIPAR calUnitPort2/Port number of the cal unit.
/// HIPAR calUnitPort3/Port number of the cal unit.
/// HIPAR calUnitPort4/Port number of the cal unit.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_CalibrationAuto(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  calibrationKitName,
                                        ViInt32   analyzerPort1,
                                        ViInt32   analyzerPort2,
                                        ViInt32   analyzerPort3,
                                        ViInt32   analyzerPort4,
                                        ViInt32   calUnitPort1,
                                        ViInt32   calUnitPort2,
                                        ViInt32   calUnitPort3,
                                        ViInt32   calUnitPort4,
                                        ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:AUTO:PORT '%s',%ld,%ld",
        channel,
        calibrationKitName,
        analyzerPort1,
        calUnitPort1);

    if (analyzerPort2 && calUnitPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort2, calUnitPort2);
    }

    if (analyzerPort3 && calUnitPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort3, calUnitPort3);
    }

    if (analyzerPort4 && calUnitPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort4, calUnitPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects and initiates a one-port, two-port, three-port
/// HIFN  or four-port automatic calibration at arbitrary analyzer ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) If the test setup contains a high attenuation the analyzer may
/// HIFN  fail to detect the cal unit ports connected to each of its ports. In
/// HIFN  this case use the extended function rsznl_CalibrationAuto (command
/// HIFN  [SENSe<Ch>:]CORRection:COLLect:AUTO:PORTs)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_CalibrationAutoSimplified(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  calibrationKitName,
                                                  ViInt32   analyzerPort1,
                                                  ViInt32   analyzerPort2,
                                                  ViInt32   analyzerPort3,
                                                  ViInt32   analyzerPort4,
                                                  ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:AUTO '%s',%ld",
        channel,
        calibrationKitName,
        analyzerPort1);

    if (analyzerPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort2);
    }

    if (analyzerPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort3);
    }

    if (analyzerPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects and initiates a one-port, two-port, three-port
/// HIFN  or four-port automatic calibration at arbitrary analyzer and
/// HIFN  calibration unit ports.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Port numbers of the analyzer:
/// HIFN     For an n-port automatic calibration (n = 1 to 4), n arbitrary (not
/// HIFN  necessarily consecutive) port numbers must be specified.
/// HIFN
/// HIFN     (2) Port numbers of the cal unit:
/// HIFN     For an n-port automatic calibration (n = 1 to 4), n arbitrary (not
/// HIFN  necessarily consecutive) port numbers must be specified. It is possible
/// HIFN  to combine arbitrary (not necessarily matching) pairs of analyzer and
/// HIFN  cal unit ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR parameters/This control selects a calibration type.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR calUnitPort1/Port number of the cal unit.
/// HIPAR calUnitPort2/Port number of the cal unit.
/// HIPAR calUnitPort3/Port number of the cal unit.
/// HIPAR calUnitPort4/Port number of the cal unit.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_CalibrationAutoType(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   parameters,
                                            ViString  calibrationKitName,
                                            ViInt32   analyzerPort1,
                                            ViInt32   analyzerPort2,
                                            ViInt32   analyzerPort3,
                                            ViInt32   analyzerPort4,
                                            ViInt32   calUnitPort1,
                                            ViInt32   calUnitPort2,
                                            ViInt32   calUnitPort3,
                                            ViInt32   calUnitPort4,
                                            ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameters, RSZNL_VAL_CALTYPE_TOSM, RSZNL_VAL_CALTYPE_RSH),
            3, "Parameters");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:AUTO:PORT:TYPE %s,'%s',%ld,%ld",
        channel,
        RsZnl_rngCalibrationType.entries[parameters].cmdString,
        calibrationKitName,
        analyzerPort1,
        calUnitPort1);

    if (analyzerPort2 && calUnitPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort2, calUnitPort2);
    }

    if (analyzerPort3 && calUnitPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort3, calUnitPort3);
    }

    if (analyzerPort4 && calUnitPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort4, calUnitPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function Selects and initiates a one-port, two-port, three-port
/// HIFN  or four-port automatic calibration at arbitrary analyzer and cal unit
/// HIFN  ports. This command also selects the calibration type.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) If the test setup contains a high attenuation the analyzer may
/// HIFN  fail to detect the cal unit ports connected to each of its ports. In
/// HIFN  this case use the extended function rsznl_CalibrationAutoType (command
/// HIFN  [SENSe<Ch>:]CORRection:COLLect:AUTO:PORTs:TYPE)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR parameters/This control selects a calibration type.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_CalibrationAutoTypeSimplified(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   parameters,
                                                      ViString  calibrationKitName,
                                                      ViInt32   analyzerPort1,
                                                      ViInt32   analyzerPort2,
                                                      ViInt32   analyzerPort3,
                                                      ViInt32   analyzerPort4,
                                                      ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameters, RSZNL_VAL_CALTYPE_TOSM, RSZNL_VAL_CALTYPE_RSH),
            3, "Parameters");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:AUTO:TYPE %s,'%s',%ld",
        channel,
        RsZnl_rngCalibrationType.entries[parameters].cmdString,
        calibrationKitName,
        analyzerPort1);

    if (analyzerPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort2);
    }

    if (analyzerPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort3);
    }

    if (analyzerPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", analyzerPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Use this command to reuse measurement data of the active automatic
/// HIFN  calibration (if available) for the next automatic calibration. This
/// HIFN  data reuse allows an automatic calibration to be repeated without
/// HIFN  repeating all measurements.
/// HIFN
/// HIFN     Reusing existing calibration data is particularly useful for inline
/// HIFN  calibrations, whose OSM measurements can be repeated without
/// HIFN  reconnections, but whose unknown through measurements can not.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_RepeatCalibration(ViSession instrSession,
                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_REPEAT_CALIBRATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_REPEAT_CALIBRATION, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Available if the calibration unit selected using
/// HIFN  RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration system
/// HIFN  (ICS) only. Applies to all inline calibration units (ICUs) that are
/// HIFN  connected to the selected ICS and that are used with factory
/// HIFN  characterization data .
/// HIFN
/// HIFN     If set to ON (1), the R&S ZNL/ZNLE firmware adjusts the factory
/// HIFN  characterization data according to the ICU temperatures.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR temperatureCompensation/Available if the calibration unit selected using
/// HIPAR temperatureCompensation/RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration system
/// HIPAR temperatureCompensation/(ICS) only. Applies to all inline calibration units (ICUs) that are
/// HIPAR temperatureCompensation/connected to the selected ICS and that are used with factory
/// HIPAR temperatureCompensation/characterization data .
ViStatus _VI_FUNC rsznl_ConfigureCalibrationTemperatureCompensation(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean temperatureCompensation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_TEMPERATURE_COMPENSATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CALIBRATION_TEMPERATURE_COMPENSATION, temperatureCompensation),
            3, "Temperature Compensation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  The Unknown Through measurement can be performed during an automatic
/// HIFN  UOSM calibration.
/// HIFN
/// HIFN     Although it works for all calibration units, it is only useful if the
/// HIFN  calibration unit selected using RSZNL_ATTR_SELECT_CALIBRATION_UNIT is
/// HIFN  an inline calibration system (ICS).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR testPort1/VNA test port 1
/// HIPAR testPort2/VNA test port 2
ViStatus _VI_FUNC rsznl_CalibrationUnknownThroughMeasurement(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   testPort1,
                                                             ViInt32   testPort2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   parameters[RS_MAX_MESSAGE_LEN] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_HIDDEN_CALIBRATION_UNKNOWN_THROUGH_MEASUREMENT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    snprintf(parameters, RS_MAX_MESSAGE_LEN, "%ld,%ld", testPort1, testPort2);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_HIDDEN_CALIBRATION_UNKNOWN_THROUGH_MEASUREMENT, parameters));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables calibration of all channels in the active channel setup. The
/// HIFN  attribute is valid for the following calibration methods:
/// HIFN     - Manual system error correction
/// HIFN     - Automatic system error correction (cal unit)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Enables calibration of all channels in the active channel setup. The
/// HIPAR state/control is valid for the following calibration methods:
ViStatus _VI_FUNC rsznl_ConfigureCalibrationAllChannelsState(ViSession instrSession,
                                                             ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_ALL_CHANNELS_STATE, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the assignment between the network analyzer
/// HIFN  ports and the ports of the connected automatic calibration unit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR analyzerPort1/Returns the port number of the cal unit that is connected to analyzer
/// HIPAR analyzerPort1/port number 1.
/// HIPAR analyzerPort2/Returns the port number of the cal unit that is connected to analyzer
/// HIPAR analyzerPort2/port number 2.
/// HIPAR analyzerPort3/Returns the port number of the cal unit that is connected to analyzer
/// HIPAR analyzerPort3/port number 3.
/// HIPAR analyzerPort4/Returns the port number of the cal unit that is connected to analyzer
/// HIPAR analyzerPort4/port number 4.
ViStatus _VI_FUNC rsznl_QueryCalibrationConnection(ViSession instrSession,
                                                   ViInt32*  analyzerPort1,
                                                   ViInt32*  analyzerPort2,
                                                   ViInt32*  analyzerPort3,
                                                   ViInt32*  analyzerPort4)
{
    ViStatus error = VI_SUCCESS;
    ViChar   ext_buf[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  p2buf;
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_QueryWithOPCSync(instrSession, "SENS:CORR:COLL:AUTO:PORT:CONN?", 0,
        RS_MAX_MESSAGE_BUF_SIZE, ext_buf, &buffRead));

    p2buf = strtok(ext_buf, ",");
    *analyzerPort1 = atoi(p2buf);

    p2buf = strtok(NULL, ",");
    *analyzerPort2 = atoi(p2buf);

    p2buf = strtok(NULL, ",");
    *analyzerPort3 = atoi(p2buf);

    p2buf = strtok(NULL, ",");
    *analyzerPort4 = atoi(p2buf);

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries date and time of the channel's calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Calibration
/// HIPAR bufferSize/Kit Name'.
/// HIPAR calibrationDate/This control returns the data and time, e.g. '03/20/06,18:30:39'.
ViStatus _VI_FUNC rsznl_QueryCalibrationDate(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   bufferSize,
                                             ViChar    calibrationDate[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_DATE_AND_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_CALIBRATION_DATE_AND_TIME,
            bufferSize, calibrationDate),
            4, "Calibration Date");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries state of the channel's calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationState/This control returns the state of the channel's calibration.
ViStatus _VI_FUNC rsznl_QueryCalibrationState(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32*  calibrationState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_STATUS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CALIBRATION_STATUS, calibrationState),
            4, "Calibration State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the calibration unit with given address as active
/// HIFN  calibration unit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationUnit/This control sets the active calibration unit.
ViStatus _VI_FUNC rsznl_ConfigureActiveCalibrationUnit(ViSession instrSession,
                                                       ViString  calibrationUnit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_SELECT_CALIBRATION_UNIT, calibrationUnit),
            3, "Calibration Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the USB addresses of all calibration units
/// HIFN  connected to the VNA.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Calibration
/// HIPAR bufferSize/Kit Name'.
/// HIPAR calibrationUnits/This control returns the USB addresses of all calibration units
/// HIPAR calibrationUnits/connected to the VNA.
ViStatus _VI_FUNC rsznl_QueryAllCalibrationUnits(ViSession instrSession,
                                                 ViInt32   bufferSize,
                                                 ViChar    calibrationUnits[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, "", RSZNL_ATTR_CALIBRATION_UNIT_LIST,
            bufferSize, calibrationUnits),
            3, "Calibration Units");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If the calibration unit selected using
/// HIFN  RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration system
/// HIFN  (ICS), this query returns the addresses of the connected ICUs.
/// HIFN  Otherwise it returns the empty string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Calibration
/// HIPAR bufferSize/Submodule Units'.
/// HIPAR calibrationSubmoduleUnits/If the calibration unit selected using
/// HIPAR calibrationSubmoduleUnits/RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration system
/// HIPAR calibrationSubmoduleUnits/(ICS), this query returns the addresses of the connected ICUs.
/// HIPAR calibrationSubmoduleUnits/Otherwise it returns the empty string.
ViStatus _VI_FUNC rsznl_QueryAllCalibrationSubmoduleUnits(ViSession instrSession,
                                                          ViInt32   bufferSize,
                                                          ViChar    calibrationSubmoduleUnits[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, "", RSZNL_ATTR_CALIBRATION_UNIT_SUBMODULE_LIST,
            bufferSize, calibrationSubmoduleUnits),
            3, "Calibration Submodule Units");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines calibration unit standard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/This control selects a calibration unit standard
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR calkitID/For calibration units that are equipped with more than one calibration
/// HIPAR calkitID/kit, this indicates the 1-based index of the cal kit to be used
/// HIPAR calkitID/(mandatory!). For other calibration units this parameter is optional,
/// HIPAR calkitID/but if it is provided, it must be set to 1.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationUnitStandard(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   port1,
                                                         ViInt32   port2,
                                                         ViInt32   calkitID)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, standard, RSZNL_VAL_CALUNIT_STD_THR, RSZNL_VAL_CALUNIT_STD_MATC),
            2, "Standard");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:AKAL:CONN %s,%ld",
        RsZnl_rngCalUnitStandard.entries[standard].cmdString, port1);

    if (port2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", port2);
    }

    if (calkitID)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", calkitID);
    }

    *++p2buf = '\n';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows or hides the memory of the active calibration unit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Shows or hides the memory of the active calibration unit.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationAutomaticMemoryState(
                            ViSession instrSession,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_CALIBRATION_AUTOMATIC_MEMORY_STATE, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If the calibration unit selected using
/// HIFN  RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration unit (ICU),
/// HIFN  this function sets the characterization to be used for calibrations
/// HIFN  with this ICU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterizations/If the calibration unit selected using
/// HIPAR calUnitCharacterizations/RSZNL_ATTR_SELECT_CALIBRATION_UNIT is an inline calibration unit (ICU),
/// HIPAR calUnitCharacterizations/this function sets the characterization to be used for calibrations
/// HIPAR calUnitCharacterizations/with this ICU.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationUnitCharacterization(
                            ViSession instrSession,
                            ViString  calUnitCharacterizations)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_UNIT_CHARACTERIZATION, calUnitCharacterizations),
            2, "Cal Unit Characterization");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries all characterizations (cal kit files) which are stored on the
/// HIFN  connected calibration unit, either on the calibration unit's internal
/// HIFN  (flash) memory or on an SD card inserted at the calibration unit
/// HIFN  (prefix: 'SD'). A possible response is
/// HIFN  'Factory,ZN-Z51_custom,Throughs,SD:test'. The factory characterization
/// HIFN  is always available; an empty string denotes that no calibration unit
/// HIFN  is connected.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Cal Unit
/// HIPAR bufferSize/Characterizations'.
/// HIPAR calUnitCharacterizations/Queries all characterizations (cal kit files) which are stored on the
/// HIPAR calUnitCharacterizations/connected calibration unit, either on the calibration unit's internal
/// HIPAR calUnitCharacterizations/(flash) memory or on an SD card inserted at the calibration unit
/// HIPAR calUnitCharacterizations/(prefix: 'SD'). A possible response is
/// HIPAR calUnitCharacterizations/'Factory,ZN-Z51_custom,Throughs,SD:test'. The factory characterization
/// HIPAR calUnitCharacterizations/is always available; an empty string denotes that no calibration unit
/// HIPAR calUnitCharacterizations/is connected.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizations(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizations[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, "", RSZNL_ATTR_CALIBRATION_UNIT_CHARACTERIZATIONS_LIST,
            bufferSize, calUnitCharacterizations),
            4, "calUnitCharacterizations");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries all calibration standards of a characterization
/// HIFN  (cal kit file) that is stored in a connected
/// HIFN     calibration unit R&S ZV-Z5x.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterization/The name of a cal unit characterization. 'Factory' denotes the factory
/// HIPAR calUnitCharacterization/characterization; an empty string ' ' denotes the last referenced
/// HIPAR calUnitCharacterization/characterization.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Cal Unit
/// HIPAR bufferSize/Characterizations'.
/// HIPAR calUnitCharacterizations/Queries all calibration standards of a characterization stored on the
/// HIPAR calUnitCharacterizations/connected calibration unit.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationsStandards(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizations[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:CKIT:STAN:CAT? '%s'", calUnitCharacterization);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        calUnitCharacterizations, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the creation date and time of a cal unit
/// HIFN  characterization (cal kit file). A possible response is 'Friday, May
/// HIFN  26, 2011, 10:13:40'. An empty string is returned if no calibration unit
/// HIFN  is connected.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Use function rsznl_QueryCalibrationUnitCharacterizations to get a
/// HIFN  list of possible characterizations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterization/The name of a cal unit characterization. 'Factory' denotes the factory
/// HIPAR calUnitCharacterization/characterization; an empty string ' ' denotes the last referenced
/// HIPAR calUnitCharacterization/characterization.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Cal Unit
/// HIPAR bufferSize/Characterization Date'.
/// HIPAR calUnitCharacterizationDate/Queries the creation date and time of a cal unit characterization (cal
/// HIPAR calUnitCharacterizationDate/kit file). A possible response is 'Friday, May 26, 2011, 10:13:40'. An
/// HIPAR calUnitCharacterizationDate/empty string is returned if no calibration unit is connected.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationDate(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizationDate[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:DATE? '%s'", calUnitCharacterization);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        calUnitCharacterizationDate, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the frequency range of a cal unit
/// HIFN  characterization (cal kit file). The response consists of the start and
/// HIFN  stop frequencies in Hz, separated by a comma. 0,0 is returned if no
/// HIFN  calibration unit is connected.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Use function rsznl_QueryCalibrationUnitCharacterizations to get a
/// HIFN  list of possible characterizations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterization/The name of a cal unit characterization. 'Factory' denotes the factory
/// HIPAR calUnitCharacterization/characterization; an empty string ' ' denotes the last referenced
/// HIPAR calUnitCharacterization/characterization.
/// HIPAR startFrequency/Returns the start frequency of the cal unit characterization.
/// HIPAR stopFrequency/Returns the stop frequency of the cal unit characterization.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationFrequencyRange(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViReal64* startFrequency,
                            ViReal64* stopFrequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:FRAN? '%s'", calUnitCharacterization);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, RS_MAX_MESSAGE_BUF_SIZE,
        rd_buffer, &buffRead));

    p2buf = strtok(rd_buffer, ",");

    *startFrequency = atof(p2buf);

    p2buf = strtok(NULL, ",");

    *stopFrequency = atof(p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the number of ports of a cal unit
/// HIFN  characterization (cal kit file), the assigned connector types, and
/// HIFN  their gender. A possible response for a two-port calibration is '1,N 50
/// HIFN  Ohm,MALE,2,N 50 Ohm,MALE'. An empty string is returned if no
/// HIFN  calibration unit is connected.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Use function rsznl_QueryCalibrationUnitCharacterizations to get a
/// HIFN  list of possible characterizations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterization/The name of a cal unit characterization. 'Factory' denotes the factory
/// HIPAR calUnitCharacterization/characterization; an empty string ' ' denotes the last referenced
/// HIPAR calUnitCharacterization/characterization.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Cal Unit
/// HIPAR bufferSize/Characterization Ports'.
/// HIPAR calUnitCharacterizationPorts/Queries the number of ports of a cal unit characterization (cal kit
/// HIPAR calUnitCharacterizationPorts/file), the assigned connector types, and their gender. A possible
/// HIPAR calUnitCharacterizationPorts/response for a two-port calibration is '1,N 50 Ohm,MALE,2,N 50
/// HIPAR calUnitCharacterizationPorts/Ohm,MALE'. An empty string is returned if no calibration unit is
/// HIPAR calUnitCharacterizationPorts/connected.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationPorts(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizationPorts[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:PORT? '%s'", calUnitCharacterization);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        calUnitCharacterizationPorts, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads the calibration data for a particular standard
/// HIFN  from a cal unit characterization.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calUnitCharacterization/The name of a cal unit characterization. 'Factory' denotes the factory
/// HIPAR calUnitCharacterization/characterization; an empty string ' ' denotes the last referenced
/// HIPAR calUnitCharacterization/characterization.
/// HIPAR standard/This control selects a standard.
/// HIPAR sParameter/Sets the S-parameter of the standard.
/// HIPAR firstPortNumber/First port number (sufficient for one-port standards).
/// HIPAR secondPortNumber/Second port number, for two-port standards.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Cal Unit
/// HIPAR bufferSize/Characterization Ports'.
/// HIPAR calibrationData/Returns the calibration data for a particular standard from a cal unit
/// HIPAR calibrationData/characterization.
/// HIPAR noofValues/Returns number of Cal Unit Characterization Ports values.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationData(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   standard,
                            ViInt32   sParameter,
                            ViInt32   firstPortNumber,
                            ViInt32   secondPortNumber,
                            ViInt32   bufferSize,
                            ViReal64  calibrationData[],
                            ViInt32*  noofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, standard, RSZNL_VAL_CALSTD_MMTH, RSZNL_VAL_CALSTD_FSM),
            3, "Standard");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, sParameter, RSZNL_VAL_S11, RSZNL_VAL_S22),
            4, "S Parameter");

    if (secondPortNumber == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:SDAT? '%s',%s,%s,%ld", calUnitCharacterization,
            RsZnl_rngCalStandard.entries[standard].cmdString,
            RsZnl_rngSParameter.entries[sParameter].cmdString,
            firstPortNumber);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYST:COMM:RDEV:AKAL:SDAT? '%s',%s,%s,%ld,%ld", calUnitCharacterization,
            RsZnl_rngCalStandard.entries[standard].cmdString,
            RsZnl_rngSParameter.entries[sParameter].cmdString,
            firstPortNumber, secondPortNumber);
    }

    checkErr(rsznl_dataReadTrace(instrSession, cmd, bufferSize, calibrationData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the warmup state of the connected calibration
/// HIFN  unit R&S ZV_Z5x. If several cal units are USB-connected to the
/// HIFN  analyzer, the function queries the cal unit selected via
/// HIFN  rsznl_ConfigureActiveCalibrationUnit.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Use function rsznl_QueryCalibrationUnitCharacterizations to get a
/// HIFN  list of possible characterizations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR warmupState/Queries the warmup state of the connected calibration unit R&S ZV_Z5x.
ViStatus _VI_FUNC rsznl_QueryCalibrationUnitWarmupState(ViSession  instrSession,
                                                        ViBoolean* warmupState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_UNIT_WARMUP_STATE, warmupState),
            2, "Warmup State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects a calibration type and a cal unit characterization (cal kit
/// HIFN  file) for an automatic calibration.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     [SENSe<Ch>:]CORRection:COLLect:AUTO:CONFigure
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationtype/Calibration Type.
/// HIPAR characterization/Location of the characterization (cal kit file) to be used for the
/// HIPAR characterization/automatic calibration.
/// HIPAR name/Sets the name.
ViStatus _VI_FUNC rsznl_ConfigureAutomaticCalibration(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   calibrationtype,
                                                      ViString  characterization,
                                                      ViString  name)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViPChar  paramCalType;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_HIDDEN_CONFIGURE_AUTOMATIC_CALIBRATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalibrationType,
        calibrationtype, &paramCalType),
        3, "Calibration Type");

    snprintf(param, RS_PARAM_BUF_SIZE, "%s,'%s','%s'", paramCalType, characterization, name);

    checkErr(RsCore_SetAttributeViString(instrSession, repCap,
        RSZNL_ATTR_HIDDEN_CONFIGURE_AUTOMATIC_CALIBRATION,
        RS_VAL_DIRECT_USER_CALL,
        param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Terminates a system error correction, discarding the acquired data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_CorrectionDiscard(ViSession instrSession,
                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CORRECTION_DISCARD,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CORRECTION_DISCARD, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Cleans the channel's existing calibration data and also removes links
/// HIFN  to the calibration pool.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_CorrectionDelete(ViSession instrSession,
                                         ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CORRECTION_DELETE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CORRECTION_DELETE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates or deactivates the wave correction logic for wave quantities
/// HIFN  and ratios.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR enabled/Activates or deactivates the wave correction logic for wave quantities
/// HIPAR enabled/and ratios.
ViStatus _VI_FUNC rsznl_ConfigureWaveCorrectionLogicEnabled(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_WAVE_CORRECTION_LOGIC_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_WAVE_CORRECTION_LOGIC_ENABLED, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the position of the offset calculation in the Offset Embed
/// HIFN  calculation chain.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calculateAfterDe/Embed/Changes the position of the offset calculation in the Offset Embed
/// HIPAR calculateAfterDe/Embed/calculation chain.
ViStatus _VI_FUNC rsznl_ConfigureCorrectionCalculateAfterDeEmbed(
                            ViSession instrSession,
                            ViBoolean calculateAfterDeEmbed)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CORRECTION_CALCULATE_AFTER_DE_EMBED, calculateAfterDeEmbed),
            2, "Calculate After De/Embed");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects a one-port or two-port calibration type for channel <Ch> at
/// HIFN  ports 1/2.
/// HIFN
/// HIFN     Tip: Use the generalized command
/// HIFN  [SENSe<Ch>:]CORRection:COLLect:METHod:DEFine to select the calibration
/// HIFN  type for arbitrary analyzer ports or a multiport calibration type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR method/Selects a one-port or two-port calibration type for channel <Ch> at
/// HIPAR method/ports 1/2.
ViStatus _VI_FUNC rsznl_ConfigureCorrectionMethod(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   method)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CORRECTION_METHOD,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CORRECTION_METHOD, method),
            3, "Method");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Tries to join the two calibrations.
/// HIFN     If successful, it stores the resulting calibration as <OutputCal> in
/// HIFN  <LocationOutputCal>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR firstCal/String parameter with the channel name (for
/// HIPAR firstCal/<LocationFirstCal>=CHANnel) or the calibration file name (for
/// HIPAR firstCal/<LocationFirstCal>=POOL) of the first calibration
/// HIPAR locationFirstCal/First calibration location
/// HIPAR secondCal/String parameter with the channel name (for
/// HIPAR secondCal/<LocationSecondCal>=CHANnel) or the calibration file name (for
/// HIPAR secondCal/<LocationSecondCal>=POOL) of the first calibration.
/// HIPAR locationSecondCal/Second calibration location
/// HIPAR outputCal/String parameter with the channel name (for
/// HIPAR outputCal/<LocationOutputCal>=CHANnel) or the calibration file name (for
/// HIPAR outputCal/<LocationOutputCal>=POOL) of the resulting calibration.
/// HIPAR locationOutputCal/Output calibration location
ViStatus _VI_FUNC rsznl_JoinCalibrations(ViSession instrSession,
                                         ViString  firstCal,
                                         ViInt32   locationFirstCal,
                                         ViString  secondCal,
                                         ViInt32   locationSecondCal,
                                         ViString  outputCal,
                                         ViInt32   locationOutputCal)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_LEN] = "";
    ViPChar  paramLocationFirstCal;
    ViPChar  paramLocationSecondCal;
    ViPChar  paramLocationOutputCal;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalLocation,
        locationFirstCal, &paramLocationFirstCal),
        3, "Location First Cal");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalLocation,
        locationSecondCal, &paramLocationSecondCal),
        5, "Location Second Cal");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalLocation,
        locationOutputCal, &paramLocationOutputCal),
        7, "Location Output Cal");

    snprintf(cmd, RS_MAX_MESSAGE_LEN, "SYST:CORR:JOIN '%s',%s,'%s',%s,'%s',%s",
        firstCal, paramLocationFirstCal,
        secondCal, paramLocationSecondCal,
        outputCal, paramLocationOutputCal);

    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns whether if the two calibrations <FirstCal> (from
/// HIFN  <LocationFirstCal>) and <SecondCal> (from <LocationSecondCal>) are
/// HIFN  joinable.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR firstCal/String parameter with the channel name (for
/// HIPAR firstCal/<LocationFirstCal>=CHANnel) or the calibration file name (for
/// HIPAR firstCal/<LocationFirstCal>=POOL) of the first calibration
/// HIPAR locationFirstCal/First calibration location
/// HIPAR secondCal/String parameter with the channel name (for
/// HIPAR secondCal/<LocationSecondCal>=CHANnel) or the calibration file name (for
/// HIPAR secondCal/<LocationSecondCal>=POOL) of the first calibration.
/// HIPAR locationSecondCal/Second calibration location
/// HIPAR areCalibrationsJoinable/Returns whether if the two calibrations <FirstCal> (from
/// HIPAR areCalibrationsJoinable/<LocationFirstCal>) and <SecondCal> (from <LocationSecondCal>) are
/// HIPAR areCalibrationsJoinable/joinable.
ViStatus _VI_FUNC rsznl_AreCalibrationsJoinable(ViSession  instrSession,
                                                ViString   firstCal,
                                                ViInt32    locationFirstCal,
                                                ViString   secondCal,
                                                ViInt32    locationSecondCal,
                                                ViBoolean* areCalibrationsJoinable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_LEN] = "";
    ViPChar  paramLocationFirstCal;
    ViPChar  paramLocationSecondCal;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalLocation,
        locationFirstCal, &paramLocationFirstCal),
        3, "Location First Cal");
    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngCalLocation,
        locationSecondCal, &paramLocationSecondCal),
        5, "Location Second Cal");

    snprintf(cmd, RS_MAX_MESSAGE_LEN, "SYST:CORR:JOIN? '%s',%s,'%s',%s",
        firstCal, paramLocationFirstCal,
        secondCal, paramLocationSecondCal);

    checkErr(rsznl_QueryViBoolean(instrSession, cmd, areCalibrationsJoinable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function selects a connector type at a specified port <Port> and
/// HIFN  its gender.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR connector/This control selects a connector type at a specified port <Port> and
/// HIPAR connector/its gender.
ViStatus _VI_FUNC rsznl_ConfigureConnector(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   port,
                                           ViInt32   connector)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_CONNECTOR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_CONNECTOR,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CALIBRATION_CONNECTOR, connector),
            4, "Connector");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the user-defined connector types.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR connectorName/Name of the user-defined connectors.
/// HIPAR propagationMode/This control selects a propagation mode.
/// HIPAR connectorType/This control selects a connector type.
/// HIPAR relativePermittivity/This control sets the relative permittivity.
/// HIPAR impedance/This control sets the reference impedance or cutoff frequency.
ViStatus _VI_FUNC rsznl_ConfigureUserConnectorType(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViString  connectorName,
                                                   ViInt32   propagationMode,
                                                   ViInt32   connectorType,
                                                   ViReal64  relativePermittivity,
                                                   ViReal64  impedance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, propagationMode, RSZNL_VAL_CONNECTION_MODE_TEM, RSZNL_VAL_CONNECTION_MODE_WGUIDE),
            4, "Propagation Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectorType, RSZNL_VAL_CONNECTION_CONNECTOR_GENDER, RSZNL_VAL_CONNECTION_CONNECTOR_NGENDER),
            5, "Connector Type");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, relativePermittivity, 0.0000000001, 1000), 6, "Relative Permittivity");

    if (propagationMode == RSZNL_VAL_CONNECTION_MODE_TEM)
    {
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, impedance, 1.0e-6, 1000.0e6), 7, "Impedance");
    }

    else if (propagationMode == RSZNL_VAL_CONNECTION_MODE_WGUIDE)
    {
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, impedance, 0.0, 1000.0e9), 7, "Impedance");
    }

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:CONN '%s',%s,%s,%.12lG,%.12lG", channel, connectorName, RsZnl_rngPropagationMode.entries[propagationMode].cmdString,
        RsZnl_rngConnectorType.entries[connectorType].cmdString, relativePermittivity, impedance);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects a user-defined connector type at a specified
/// HIFN  port <Port> and its gender.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR connector/This control selects a connector type at a specified port <Port> and
/// HIPAR connector/gender.
/// HIPAR connectorGender/This control selects the connector gender.
ViStatus _VI_FUNC rsznl_ConfigureUserConnector(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   port,
                                               ViString  connector,
                                               ViInt32   connectorGender)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectorGender, RSZNL_VAL_CONNECTOR_GENDER_MALE, RSZNL_VAL_CONNECTOR_GENDER_FEMALE),
            4, "Connector");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:SCON%ld '%s',%s", channel, port, connector, RsZnl_rngConnectorGender.entries[connectorGender].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes a user-defined connector type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR connectorName/Name of the user-defined connectors.
ViStatus _VI_FUNC rsznl_DeleteUserConnectorType(ViSession instrSession,
                                                ViInt32   channel,
                                                ViString  connectorName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_DELETE_USER_CONNECTOR_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CALIBRATION_DELETE_USER_CONNECTOR_TYPE, connectorName),
            3, "Connector Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Qualifies whether the connector types at the test ports (but not their
/// HIFN  gender) are equal or independent. Some calibration types require
/// HIFN  uniform port connector types.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR connectorType/Qualifies whether the connector types at the test ports (but not their
/// HIPAR connectorType/gender) are equal or independent. Some calibration types require
/// HIPAR connectorType/uniform port connector types.
ViStatus _VI_FUNC rsznl_ConfigurePortConnectorTypes(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   connectorType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_DELETE_USER_CONNECTOR_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CALIBRATION_SAME_CONNECTOR_AT_ALL_PORTS, connectorType),
            3, "Connector Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Qualifies whether the genders at the test ports (but not their
/// HIFN  connector types) are equal or independent.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sameGenderAtAllPorts/Qualifies whether the genders at the test ports (but not their
/// HIPAR sameGenderAtAllPorts/connector types) are equal or independent.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationSameGenderAtAllPorts(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   sameGenderAtAllPorts)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CALIBRATION_SAME_GENDER_AT_ALL_PORTS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CALIBRATION_SAME_GENDER_AT_ALL_PORTS, sameGenderAtAllPorts),
            3, "Same Gender At All Ports");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a list of the connector types of all calibration
/// HIFN  kits in use.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR catalog/Response is a string parameter with comma-separated list of the
/// HIPAR catalog/connector types of all calibration kits in use.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_ConnectorTypesCatalog(ViSession instrSession,
                                              ViInt32   bufferSize,
                                              ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, "", RSZNL_ATTR_CALIBRATION_CONNECTOR_TYPE_CATALOG,
            bufferSize, catalog),
            4, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function calculates the system error correction data from the
/// HIFN  acquired one or two-port measurement results (rsznl_StartCalibration),
/// HIFN  stores them and applies them to the calibrated channel. To avoid
/// HIFN  incompatibilities, older system error correction data is deleted unless
/// HIFN  it has been transferred into a cal pool (MMEMory:STORe:CORRection <Ch>,
/// HIFN  '<file_name>').
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_SaveCalibrationData(ViSession instrSession,
                                            ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SAVE_CALIBRATION_DATA,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_SAVE_CALIBRATION_DATA, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function generates a set of default system error correction data
/// HIFN  for the selected ports and calibration type. The default data set
/// HIFN  corresponds to a test setup which does not introduce any systematic
/// HIFN  errors.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) The main purpose of the default correction data set is to provide
/// HIFN  a dummy system error correction which you can replace with your own,
/// HIFN  external correction data. You may have acquired the external data in a
/// HIFN  previous session or even on an other instrument. If you want to use the
/// HIFN  external correction data on the analyzer, simply generate the default
/// HIFN  data set corresponding to your port configuration and calibration type
/// HIFN  and overwrite the default data
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_GenerateDefaultCalibrationData(ViSession instrSession,
                                                       ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_GENERATE_DEFAULT_CALIBRATION_DATA,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_GENERATE_DEFAULT_CALIBRATION_DATA, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes system error correction data generated and
/// HIFN  stored previously.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationName/This control defines the name of the calibration (string parameter)
/// HIPAR calibrationName/defined together with calibration type. If nothing
ViStatus _VI_FUNC rsznl_DeleteCalibrationData(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  calibrationName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELETE_CALIBRATION_DATA,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DELETE_CALIBRATION_DATA, calibrationName),
            3, "Calibration Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries for a given port pair the currently available
/// HIFN  correction buffers. Thus if a buffer name does not appear as a
/// HIFN  response, a query with rsznl_ReadCalibrationData will fail.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR catalog/Catalog number.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR arraySize/This control defines the size of array passed to argument 'Available
/// HIPAR arraySize/Buffers'.
/// HIPAR availableBuffers/This control returns currently available correction buffers.
/// HIPAR numberofValues/Returns number of values. If the number of values is higher than
/// HIPAR numberofValues/number of values in Available Buffers, increase the Array Size.
ViStatus _VI_FUNC rsznl_QueryAvailableCalibrationDataCatalog(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   catalog,
                                                             ViInt32   port1,
                                                             ViInt32   port2,
                                                             ViInt32   arraySize,
                                                             ViChar    availableBuffers[],
                                                             ViInt32*  numberofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = rd_buffer;
    ViChar*  p2buf;
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel, 1), 2, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, catalog, 1, 2),
            3, "Catalog");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:CDAT:CAT%ld? %ld,%ld", channel, catalog, port1, port2);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, RS_MAX_MESSAGE_BUF_SIZE,
        rd_buffer, &buffRead));

    p2buf = strtok(ext_buf, ",");

    *numberofValues = atoi(p2buf);

    if (*numberofValues != 0)
    {
        p2buf = strtok(NULL, "\n");

        strncpy(availableBuffers, p2buf, arraySize);
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads system error correction data for a specific
/// HIFN  channel, calibration method, and port combination <Port 1>, <Port 2>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR errorTerm/This control sets the error terms parameters.
/// HIPAR sourcePort/Source port number.
/// HIPAR loadPort/Load port number.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Calibration
/// HIPAR bufferSize/Data'.
/// HIPAR calibrationData/This control returns the calibration data. For each sweep point (set
/// HIPAR calibrationData/by rsznl_ConfigureSweepNumberOfPoints) real and imaginary part should
/// HIPAR calibrationData/be provided.
/// HIPAR noofValues/Returns number of Calibration Data values.
ViStatus _VI_FUNC rsznl_ReadCalibrationData(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   errorTerm,
                                            ViInt32   sourcePort,
                                            ViInt32   loadPort,
                                            ViInt32   bufferSize,
                                            ViReal64  calibrationData[],
                                            ViInt32*  noofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, errorTerm, RSZNL_VAL_CAL_DATA_DIRECTIVITY, RSZNL_VAL_CAL_DATA_TRANSTRACK),
            4, "Propagation Mode");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS%ld:CORR:CDAT? %s,%ld,%ld", channel,
        RsZnl_rngErrorTerm.entries[errorTerm].cmdString,
        sourcePort, loadPort);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, bufferSize, calibrationData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function writes system error correction data for a specific
/// HIFN  channel, calibration method, and port combination <Port 1>, <Port 2>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR errorTerm/This control sets the error terms parameters.
/// HIPAR sourcePort/Source port number.
/// HIPAR loadPort/Load port number.
/// HIPAR calibrationData/This control defines the calibration data. For each sweep point (set
/// HIPAR calibrationData/by rsznl_ConfigureSweepNumberOfPoints) real and imaginary part should
/// HIPAR calibrationData/be provided.
ViStatus _VI_FUNC rsznl_WriteCalibrationData(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   errorTerm,
                                             ViInt32   sourcePort,
                                             ViInt32   loadPort,
                                             ViReal64  calibrationData[])
{
    ViStatus         error = VI_SUCCESS;
    ViChar           cmd[RS_MAX_MESSAGE_BUF_SIZE];
    RsCoreSessionPtr rsSession;
    ViInt32          dataSize = 0;
    ViInt32          pointsCount;
    ViByte*          data = NULL;
    ViChar           repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*          p2ErrTerm;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_NUMBER_OF_POINTS, &pointsCount));

    checkErr(RsCore_InvalidViInt32Range(instrSession, pointsCount, 1, 250000));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngErrorTerm, errorTerm, &p2ErrTerm),
        3, "Error Term");

    if (rsSession->sessionType == RS_INTF_ASRL)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":FORMAT ASC;:SENS%ld:CORR:CDAT %s,%ld,%ld,", channel, p2ErrTerm, sourcePort, loadPort);
        checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, calibrationData, pointsCount));
    }
    else
    {
        if (rsSession->sessionType == RS_INTF_GPIB)
        {
            checkErr(RsCore_Write(instrSession, ":SYST:COMM:GPIB:SELF:RTER EOI"));
        }

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":FORM REAL,32;:SENS%ld:CORR:CDAT %s,%ld,%ld,", channel, p2ErrTerm, sourcePort, loadPort);
        checkErr(RsCore_Convert_Float32Array_To_BinaryDataBlock(instrSession, calibrationData, pointsCount, &data, &dataSize, VI_FALSE));
        checkErr(RsCore_WriteBinaryDataBlock(instrSession, cmd, data, dataSize));

        if (rsSession->sessionType == RS_INTF_GPIB)
        {
            checkErr(RsCore_Write(instrSession, ":SYST:COMM:GPIB:SELF:RTER LFEOI"));
        }
    }

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    if (data)
        free(data);
    RsCore_Write(instrSession, "FORM ASC");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries for a given port pair the currently available
/// HIFN  correction buffers. Thus if a buffer name does not appear as a
/// HIFN  response, a query with rsznl_ReadCalibrationDataPort will fail.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR physicalPort/Physical port number.
/// HIPAR catalog/Catalog number.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR arraySize/This control defines the size of array passed to argument 'Available
/// HIPAR arraySize/Buffers'.
/// HIPAR availableBuffers/This control returns currently available correction buffers.
/// HIPAR numberofValues/Returns number of values. If the number of values is higher than
/// HIPAR numberofValues/number of values in Available Buffers, increase the Array Size.
ViStatus _VI_FUNC rsznl_QueryAvailableCalibrationDataCatalogPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   physicalPort,
                            ViInt32   catalog,
                            ViInt32   port1,
                            ViInt32   port2,
                            ViInt32   arraySize,
                            ViChar    availableBuffers[],
                            ViInt32*  numberofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = rd_buffer;
    ViChar*  p2buf;
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel, 1), 2, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, catalog, 1, 2),
            4, "Catalog");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:CDAT:PORT%ld:CAT%ld? %ld,%ld", channel, physicalPort, catalog, port1, port2);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, RS_MAX_MESSAGE_BUF_SIZE,
        ext_buf, &buffRead));

    p2buf = strtok(ext_buf, ",");

    *numberofValues = atoi(p2buf);

    if (*numberofValues != 0)
    {
        p2buf = strtok(NULL, "\n");

        strncpy(availableBuffers, p2buf, arraySize);
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads system error correction data for a specific
/// HIFN  channel, calibration method, and port combination <Port 1>, <Port 2>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR physicalPort/Physical port number, used to select a specific frequency axis in
/// HIPAR physicalPort/arbitrary mode.
/// HIPAR errorTermParameters/This control sets the error terms parameters.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Calibration
/// HIPAR bufferSize/Data'.
/// HIPAR calibrationData/This control returns the calibration data. For each sweep point (set
/// HIPAR calibrationData/by rsznl_ConfigureSweepNumberOfPoints) real and imaginary part should
/// HIPAR calibrationData/be provided.
/// HIPAR noofValues/Returns number of Calibration Data values.
ViStatus _VI_FUNC rsznl_ReadCalibrationDataPort(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   physicalPort,
                                                ViInt32   errorTermParameters,
                                                ViInt32   port1,
                                                ViInt32   port2,
                                                ViInt32   bufferSize,
                                                ViReal64  calibrationData[],
                                                ViInt32*  noofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, errorTermParameters, RSZNL_VAL_CAL_DATA_DIRECTIVITY, RSZNL_VAL_CAL_DATA_TRANSTRACK),
            4, "Propagation Mode");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":SENS%ld:CORR:CDAT:PORT%ld? %s,%ld,%ld", channel, physicalPort,
        RsZnl_rngErrorTerm.entries[errorTermParameters].cmdString,
        port1, port2);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, bufferSize, calibrationData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function writes system error correction data for a specific
/// HIFN  channel, calibration method, and port combination <Port 1>, <Port 2>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR physicalPort/Physical port number, used to select a specific frequency axis in
/// HIPAR physicalPort/arbitrary mode.
/// HIPAR errorTermParameters/This control sets the error terms parameters.
/// HIPAR port1/Port number.
/// HIPAR port2/Port number.
/// HIPAR calibrationData/This control defines the calibration data. For each sweep point (set
/// HIPAR calibrationData/by rsznl_ConfigureSweepNumberOfPoints) real and imaginary part should
/// HIPAR calibrationData/be provided.
ViStatus _VI_FUNC rsznl_WriteCalibrationDataPort(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   physicalPort,
                                                 ViInt32   errorTerm,
                                                 ViInt32   port1,
                                                 ViInt32   port2,
                                                 ViReal64  calibrationData[])
{
    ViStatus         error = VI_SUCCESS;
    ViChar           cmd[RS_MAX_MESSAGE_BUF_SIZE];
    RsCoreSessionPtr rsSession;
    ViInt32          dataSize = 0;
    ViInt32          pointsCount;
    ViByte*          data = NULL;
    ViChar           repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*          p2ErrTerm;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_SWEEP_NUMBER_OF_POINTS, &pointsCount));

    checkErr(RsCore_InvalidViInt32Range(instrSession, pointsCount, 1, 250000));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngErrorTerm, errorTerm, &p2ErrTerm),
        4, "Error Term Parameters");

    if (rsSession->sessionType == RS_INTF_ASRL)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":FORMAT ASC;:SENS%ld:CORR:CDAT:PORT%ld %s,%ld,%ld,",
            channel, physicalPort, p2ErrTerm, port1, port2);
        checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, calibrationData, pointsCount));
    }
    else
    {
        if (rsSession->sessionType == RS_INTF_GPIB)
        {
            checkErr(RsCore_Write(instrSession, ":SYST:COMM:GPIB:SELF:RTER EOI"));
        }

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":FORM REAL,32;:SENS%ld:CORR:CDAT:PORT%ld %s,%ld,%ld,",
            channel, physicalPort, p2ErrTerm, port1, port2);
        checkErr(RsCore_Convert_Float32Array_To_BinaryDataBlock(instrSession, calibrationData, pointsCount, &data, &dataSize, VI_FALSE));
        checkErr(RsCore_WriteBinaryDataBlock(instrSession, cmd, data, dataSize));

        if (rsSession->sessionType == RS_INTF_GPIB)
        {
            checkErr(RsCore_Write(instrSession, ":SYST:COMM:GPIB:SELF:RTER LFEOI"));
        }
    }

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    if (data)
        free(data);
    RsCore_Write(instrSession, "FORM ASC");
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function exports the factory calibration data of the standards in
/// HIFN  the active calibration unit in Touchstone format into the given
/// HIFN  directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/This control sets the directory.
ViStatus _VI_FUNC rsznl_ExportFactoryCalibrationDataToTouchstoneFile(
                            ViSession instrSession,
                            ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_EXPORT_FACTORY_CALIBRATION_DATA_TO_TOUCHSTONE_FILE, directory),
            3, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function exports an arbitrary (e.g. user-defined) set of
/// HIFN  calibration data of the standards in the active calibration unit in
/// HIFN  Touchstone format into the given directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/This control sets the directory.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
ViStatus _VI_FUNC rsznl_ExportUserDefinedCalibrationDataToTouchstoneFile(
                            ViSession instrSession,
                            ViString  directory,
                            ViString  calibrationKitName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (strncmp(calibrationKitName, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:AKAL:USER:CONV '%s'", directory);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:AKAL:USER:CONV '%s','%s'", directory, calibrationKitName);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the stimulus values of the active calibration. A
/// HIFN  calibration must be selected before the function is executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR bufferSize/This control defines the size of array passed to argument 'Stimulus
/// HIPAR bufferSize/Frequencies'.
/// HIPAR stimulusFrequencies/This control returns the stimulus frequencies.
/// HIPAR noofValues/Returns number of stimulus frequencies.
ViStatus _VI_FUNC rsznl_QueryCalibrationStimulusFrequencies(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   bufferSize,
                                                            ViReal64  stimulusFrequencies[],
                                                            ViInt32*  noofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:STIM?", channel);

    checkErr(rsznl_dataReadTrace(instrSession, cmd, bufferSize, stimulusFrequencies, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the parameters of the channel's calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR frequencyStart/This control returns Frequency Start value.
/// HIPAR frequencyStop/This control returns Frequency Stop value.
/// HIPAR numberOfPoints/This control returns Number Of Points.
/// HIPAR internalSignalSourcePower/This control returns Initial Signal Source Power value.
/// HIPAR sweepType/This control returns Sweep Type.
ViStatus _VI_FUNC rsznl_QueryCalibrationDataParameters(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64* frequencyStart,
                                                       ViReal64* frequencyStop,
                                                       ViInt32*  numberOfPoints,
                                                       ViReal64* internalSignalSourcePower,
                                                       ViInt32*  sweepType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   ext_buf[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  p2buf;
    ViUInt32 buffRead;
    ViString sweepTypeArr[] = { "LIN", "LOG", "SEGM", NULL };

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:DATA:PAR?", channel);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, RS_MAX_MESSAGE_BUF_SIZE,
        ext_buf, &buffRead));

    p2buf = strtok(ext_buf, ",");
    *frequencyStart = atof(p2buf);
    p2buf = strtok(NULL, ",");
    *frequencyStop = atof(p2buf);
    p2buf = strtok(NULL, ",");
    *numberOfPoints = atoi(p2buf);
    p2buf = strtok(NULL, ",");
    *internalSignalSourcePower = atof(p2buf);
    p2buf = strtok(NULL, ",\n\r");
    *sweepType = RsCore_FindStringIndex(sweepTypeArr, p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the parameters of the channel's calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR systemErrorCorrection/Channel number.
/// HIPAR index/If one or more external switch matrices were used during calibration,
/// HIPAR index/this refers to the index of a particular switch matrix.
/// HIPAR type/Selects the type.
/// HIPAR bufferSize/Sets the buffer size.
/// HIPAR info/Returns the calibration informations.
ViStatus _VI_FUNC rsznl_QueryCalibrationDataParametersSpecific(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   systemErrorCorrection,
                            ViInt32   index,
                            ViInt32   type,
                            ViInt32   bufferSize,
                            ViChar    info[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;
             index++;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSZNL_VAL_CAL_PARAM_ACAL, RSZNL_VAL_CAL_PARAM_CKIT),
            4, "Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:DATA:PAR%ld? %s", channel, systemErrorCorrection, RsZnl_rngCalibrationParameter.entries[type].cmdString);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        info, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Gets the number of active system error corrections for channel <Ch>.
/// HIFN  For the R&S ZNL/ZNLE the result is 0 (uncalibrated) or 1 (calibrated).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR parametersCount/Returns the calibration data parameters count.
ViStatus _VI_FUNC rsznl_QueryCalibrationDataParametersCount(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32*  parametersCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ACTIVE_CALIBRATION_COUNT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_ACTIVE_CALIBRATION_COUNT, parametersCount),
            3, "Parameters Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the calibration kit to be used for a specified
/// HIFN  connector type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connector/This control selects a connector type.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKit(ViSession instrSession,
                                                ViInt32   connector,
                                                ViString  calibrationKitName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connector, RSZNL_VAL_CONNECTOR_KIT_N50, RSZNL_VAL_CONNECTOR_KIT_SMA),
            2, "Connector");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:SEL '%s'", RsZnl_rngConnectorKit.entries[connector].cmdString, calibrationKitName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects and initiates a one-port, two-port, three-port
/// HIFN  or four-port automatic calibration at arbitrary analyzer and
/// HIFN  calibration unit ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/Name and (possibly) directory of the cal kit file to be used for the
/// HIPAR calibrationKitName/automatic calibration:
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR calUnitPort1/Port number of the cal unit.
/// HIPAR calUnitPort2/Port number of the cal unit.
/// HIPAR calUnitPort3/Port number of the cal unit.
/// HIPAR calUnitPort4/Port number of the cal unit.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitAuto(ViSession instrSession,
                                                    ViString  calibrationKitName,
                                                    ViInt32   analyzerPort1,
                                                    ViInt32   analyzerPort2,
                                                    ViInt32   analyzerPort3,
                                                    ViInt32   analyzerPort4,
                                                    ViInt32   calUnitPort1,
                                                    ViInt32   calUnitPort2,
                                                    ViInt32   calUnitPort3,
                                                    ViInt32   calUnitPort4,
                                                    ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENSe:CORR:COLL:AUTO:CKIT:PORT '%s',%ld,%ld",
        calibrationKitName,
        analyzerPort1,
        calUnitPort1);

    if (analyzerPort2 && calUnitPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort2, calUnitPort2);
    }

    if (analyzerPort3 && calUnitPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort3, calUnitPort3);
    }

    if (analyzerPort4 && calUnitPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort4, calUnitPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function extends an existing characterization of the active
/// HIFN  calibration unit (rsznl_ConfigureActiveCalibrationUnit) with
/// HIFN  additional, previously uncharacterized cal unit ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR characterization/Name and (possibly) directory of an existing characterization.
/// HIPAR analyzerPort1/Port number.
/// HIPAR analyzerPort2/Port number.
/// HIPAR analyzerPort3/Port number.
/// HIPAR analyzerPort4/Port number.
/// HIPAR calUnitPort1/Number of the (previously uncharacterized!) calibration unit port, to
/// HIPAR calUnitPort1/whom the first additional test port (<TestPort1>) is assigned.
/// HIPAR calUnitPort2/Number of the (previously uncharacterized!) calibration unit port, to
/// HIPAR calUnitPort2/whom the first additional test port (<TestPort2>) is assigned.
/// HIPAR calUnitPort3/Number of the (previously uncharacterized!) calibration unit port, to
/// HIPAR calUnitPort3/whom the first additional test port (<TestPort3>) is assigned.
/// HIPAR calUnitPort4/Number of the (previously uncharacterized!) calibration unit port, to
/// HIPAR calUnitPort4/whom the first additional test port (<TestPort4>) is assigned.
/// HIPAR timeout/This control sets the timeout for the operation to finish.
ViStatus _VI_FUNC rsznl_AddCalibrationKitAuto(ViSession instrSession,
                                              ViString  characterization,
                                              ViInt32   analyzerPort1,
                                              ViInt32   analyzerPort2,
                                              ViInt32   analyzerPort3,
                                              ViInt32   analyzerPort4,
                                              ViInt32   calUnitPort1,
                                              ViInt32   calUnitPort2,
                                              ViInt32   calUnitPort3,
                                              ViInt32   calUnitPort4,
                                              ViUInt32  timeout)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:COLL:AUTO:CKIT:PORT:ADD '%s',%ld,%ld",
        characterization,
        analyzerPort1,
        calUnitPort1);

    if (analyzerPort2 && calUnitPort2)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort2, calUnitPort2);
    }

    if (analyzerPort3 && calUnitPort3)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort3, calUnitPort3);
    }

    if (analyzerPort4 && calUnitPort4)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld,%ld", analyzerPort4, calUnitPort4);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the calibration kit to be used for a specified
/// HIFN  connector type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connector/This control sets a user-defined connector type.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitUserConnectorType(
                            ViSession instrSession,
                            ViString  connector,
                            ViString  calibrationKitName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:SEL '%s','%s'", connector, calibrationKitName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a list of all cal kits for a given connector
/// HIFN  type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connectorName/This control sets the name of the connector type. Use function
/// HIPAR connectorName/rsznl_ConnectorTypesCatalog to query connector names.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Response is a string parameter with comma-separated list of all cal
/// HIPAR catalog/kits for a given connector type.
ViStatus _VI_FUNC rsznl_CalibrationKitCatalog(ViSession instrSession,
                                              ViString  connectorName,
                                              ViInt32   bufferSize,
                                              ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:CAT? '%s'", connectorName);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        catalog, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the parameters of a (possibly non-ideal) 1 port or 2-port
/// HIFN  calibration standard <StandardType>within a particular cal kit.
/// HIFN  Depending on the standard type, only a subset of the parameters may be
/// HIFN  used
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/This control selects a standard.
/// HIPAR connectorType/Name of the connector type.
/// HIPAR calibrationKitName/Name of the calibration kit.
/// HIPAR serialNumber/Label (e.g. the serial number) of the standard.
/// HIPAR minFrequency/This control specifies min. frequency of the standard.
/// HIPAR maxFrequency/This control specifies max. frequency of the standard.
/// HIPAR delayParam/Depending on the cal kit's model type (selected using
/// HIPAR delayParam/RSZNL_FUNC_CALIBRATION_DELAY_MODE) this parameter is interpreted as:
/// HIPAR loss/This control specifies losses.
/// HIPAR z0/This control specifies reference impedance.
/// HIPAR capacitances/This control specifies constant parasitic capacitance. The array must
/// HIPAR capacitances/contain the total of 4 values {C0,C1,C2,C3}.
/// HIPAR residualInductances/This control specifies constant parasitic inductance. The array must
/// HIPAR residualInductances/contain the total of 4 values {L0,L1,L2,L3}.
/// HIPAR approximation/This control specifies approximate modeling of the standard.
/// HIPAR resistance/Indicates the general load circuit model.
/// HIPAR ports/Port restriction: one port number for one port standards, two port
/// HIPAR ports/numbers for two port standards
ViStatus _VI_FUNC rsznl_DefineCalibrationStandard(ViSession instrSession,
                                                  ViInt32   standard,
                                                  ViString  connectorType,
                                                  ViString  calibrationKitName,
                                                  ViString  serialNumber,
                                                  ViReal64  minFrequency,
                                                  ViReal64  maxFrequency,
                                                  ViReal64  delayParam,
                                                  ViReal64  loss,
                                                  ViReal64  z0,
                                                  ViReal64  capacitances[],
                                                  ViReal64  residualInductances[],
                                                  ViInt32   approximation,
                                                  ViReal64  resistance,
                                                  ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, approximation, RSZNL_VAL_OPEN, RSZNL_VAL_RESISTANCE),
            13, "Approximation");

    switch (standard)
    {
    case RSZNL_VAL_CALSTD_MMTH:
    case RSZNL_VAL_CALSTD_FFTH:
    case RSZNL_VAL_CALSTD_MFTH:
    case RSZNL_VAL_CALSTD_MMLI:
    case RSZNL_VAL_CALSTD_FFLI:
    case RSZNL_VAL_CALSTD_MFLI:
    case RSZNL_VAL_CALSTD_MMLI_2:
    case RSZNL_VAL_CALSTD_FFLI_2:
    case RSZNL_VAL_CALSTD_MFLI_2:
    case RSZNL_VAL_CALSTD_MMLI_3:
    case RSZNL_VAL_CALSTD_FFLI_3:
    case RSZNL_VAL_CALSTD_MFLI_3:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, serialNumber,
            minFrequency, maxFrequency,
            delayParam, loss, z0);
        break;
    case RSZNL_VAL_CALSTD_MOSH:
    case RSZNL_VAL_CALSTD_FOSH:
    case RSZNL_VAL_CALSTD_OSH:
    case RSZNL_VAL_CALSTD_OSH_2:
    case RSZNL_VAL_CALSTD_OSH_3:
    case RSZNL_VAL_CALSTD_MOP:
    case RSZNL_VAL_CALSTD_FOP:
    case RSZNL_VAL_CALSTD_MSH:
    case RSZNL_VAL_CALSTD_FSH:
    case RSZNL_VAL_CALSTD_MOSH_2:
    case RSZNL_VAL_CALSTD_FOSH_2:
    case RSZNL_VAL_CALSTD_MOSH_3:
    case RSZNL_VAL_CALSTD_FOSH_3:
    case RSZNL_VAL_CALSTD_MMTC:
    case RSZNL_VAL_CALSTD_FMTC:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, serialNumber,
            minFrequency, maxFrequency,
            delayParam, loss, z0,
            capacitances[0], capacitances[1], capacitances[2], capacitances[3],
            residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3]);
        break;
    case RSZNL_VAL_CALSTD_MMAT:
    case RSZNL_VAL_CALSTD_FFAT:
    case RSZNL_VAL_CALSTD_MFAT:
    case RSZNL_VAL_CALSTD_MSM:
    case RSZNL_VAL_CALSTD_FSM:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, serialNumber,
            minFrequency, maxFrequency);
        break;
    case RSZNL_VAL_CALSTD_MMSN: //canbe two ports
    case RSZNL_VAL_CALSTD_FFSN:
    case RSZNL_VAL_CALSTD_MFSN:
        if (approximation == RSZNL_VAL_RESISTANCE)
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%ld,%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                resistance, ports[0], ports[1]);
        }
        else
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%s",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                RsZnl_rngApproximationModelling.entries[approximation].cmdString);
        }
        break;
    case RSZNL_VAL_CALSTD_MREF: //only one port
    case RSZNL_VAL_CALSTD_FREF:
        if (approximation == RSZNL_VAL_RESISTANCE)
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                resistance, ports[0]);
        }
        else
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s '%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%s",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                RsZnl_rngApproximationModelling.entries[approximation].cmdString);
        }
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, standard), 3, "Standard");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a list of all standards in a given calibration
/// HIFN  kit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control sets the name of the cal kit. Use function
/// HIPAR calibrationKitName/rsznl_CalibrationKitCatalog to query cal kit names.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Response is a string parameter with comma-separated list of all
/// HIPAR catalog/standards in a given calibration kit.
ViStatus _VI_FUNC rsznl_CalibrationStandardsCatalog(ViSession instrSession,
                                                    ViString  calibrationKitName,
                                                    ViInt32   bufferSize,
                                                    ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:STAN:CAT? '%s'", calibrationKitName);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize, catalog, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function assigns a label to an imported or user-defined
/// HIFN  calibration kit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control defines the name of the imported or user-defined
/// HIPAR calibrationKitName/calibration kit.
/// HIPAR label/This control defines the label of the calibration kit.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitLabel(ViSession instrSession,
                                                     ViString  calibrationKitName,
                                                     ViString  label)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LAB '%s','%s'", calibrationKitName, label);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a password to enable a single password-protected
/// HIFN  action in the automatic calibration
/// HIFN     or in the characterization wizard.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR password/This control defines the password. Enter an empty string (no password)
/// HIPAR password/to deactivate password protection.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitPassword(ViSession instrSession,
                                                        ViString  password)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_KIT_PASSWORD, password),
            2, "Password");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the delay mode for the related cal kit (identified
/// HIFN  by connector type, name and label), i.e allows to toggle between ZVR
/// HIFN  compatible and Agilent modelling. Subsequent standard definitions
/// HIFN  interpret the specified <DelayParam> accordingly.
/// HIFN     If a cal kit with the given connector type, name and label is not
/// HIFN  available on the analyzer, it is created automatically. Cal kits that
/// HIFN  are not created/modified using this function use the ZVR compatible
/// HIFN  modelling.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connectortype/This control specifies the name of the connector type.
/// HIPAR calibrationKitName/This control specifies the name of a calibration kit available on the
/// HIPAR calibrationKitName/analyzer.
/// HIPAR calibrationKitLabel/This control a label for the cal kit data. An empty string means that
/// HIPAR calibrationKitLabel/no label is defined.
/// HIPAR delayMode/Sets the delay mode for the related cal kit.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDelayMode(ViSession instrSession,
                                                      ViString  connectorType,
                                                      ViString  calibrationKitName,
                                                      ViString  calibrationKitLabel,
                                                      ViInt32   delayMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, delayMode, RSZNL_VAL_AGILENT, RSZNL_VAL_ZVR),
            5, "Delay Mode");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:DMOD '%s','%s','%s',%s", connectorType,
        calibrationKitName, calibrationKitLabel,
        RsZnl_rngDelayMode.entries[delayMode].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function generates a characterization (cal kit file) with the
/// HIFN  specified name containing the cal kit data of the active calibration
/// HIFN  unit.
/// HIFN     The cal kit file can be stored in the calibration unit or written to a
/// HIFN  directory on the analyzer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR fileName/Name and (possibly) directory of the created characterization / cal
/// HIPAR fileName/kit file (string parameter, extension *.calkit): If no path and
/// HIPAR fileName/directory is specified, the file is stored in the calibration unit .
/// HIPAR fileName/The factory calibration data on the unit is not overwritten. If a path
/// HIPAR fileName/and directory is specified, the file is stored in the directory on the
/// HIPAR fileName/analyzer's hard disk. The default directory is not used.
ViStatus _VI_FUNC rsznl_SaveCalibrationKit(ViSession instrSession,
                                           ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERATE_CALIBRATION_KIT_FILE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes an imported or user-defined cal kit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
ViStatus _VI_FUNC rsznl_DeleteCalibrationKit(ViSession instrSession,
                                             ViString  calibrationKitName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DELETE_CALIBRATION_KIT, calibrationKitName),
            2, "Calibration Kit Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads cal kit data for a specific connector type, cal
/// HIFN  kit, and calibration standard from a specified Touchstone file,
/// HIFN  assigning a label for the cal data. A restriction on the port
/// HIFN  assignment may be defined in addition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connectorType/Name of the connector type.
/// HIPAR calibrationKitName/This control specifies the name of a calibration kit available on the
/// HIPAR calibrationKitName/analyzer.
/// HIPAR standard/This control selects a standard.
/// HIPAR calibrationKitLabel/This control a label for the cal kit data. An empty string means that
/// HIPAR calibrationKitLabel/no label is defined.
/// HIPAR fileName/This control specifies the name and directory of the Touchstone file
/// HIPAR fileName/to be loaded. A *.s1p file must be used for one-port standards, a *.s2p
/// HIPAR fileName/file for two-port standards. If no path is specified the analyzer
/// HIPAR fileName/searches the current directory, to be queried with MMEMory:CDIRectory?.
/// HIPAR portNumber1/This control specifies the port assignment: One port number for
/// HIPAR portNumber1/one-port standards, two port number for two-port standards. If the port
/// HIPAR portNumber1/numbers are omitted, the cal kit data is valid for all ports.
/// HIPAR portNumber2/This control specifies the port assignment: One port number for
/// HIPAR portNumber2/one-port standards, two port number for two-port standards. If the port
/// HIPAR portNumber2/numbers are omitted, the cal kit data is valid for all ports.
ViStatus _VI_FUNC rsznl_LoadCalibrationKit(ViSession instrSession,
                                           ViString  connectorType,
                                           ViString  calibrationKitName,
                                           ViInt32   standard,
                                           ViString  calibrationKitLabel,
                                           ViString  fileName,
                                           ViInt32   portNumber1,
                                           ViInt32   portNumber2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (portNumber2 != 0)
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CKIT:SDAT '%s','%s',%s,'%s','%s',%ld,%ld",
            connectorType, calibrationKitName, RsZnl_rngCalStandard.entries[standard].cmdString,
            calibrationKitLabel, fileName, portNumber1, portNumber2);
    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CKIT:SDAT '%s','%s',%s,'%s','%s',%ld", connectorType, calibrationKitName, RsZnl_rngCalStandard.entries[standard].cmdString,
            calibrationKitLabel, fileName, portNumber1);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function allows to load cal kit data by gender from the given
/// HIFN  file and to the given ports or all ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationKitFile/This control sets the path to the cal kit file, either absolute or
/// HIPAR calibrationKitFile/relative to the current directory (see MMEMory:CDIRectory)
/// HIPAR gender/This control selects a gender.
/// HIPAR portSelector/This control selects whether cal kit is loaded for all ports or given
/// HIPAR portSelector/ports.
/// HIPAR arraySize/Sets the number of elements of the Ports array.
/// HIPAR ports/This control specifies the ports for cal kit. The number of elements
/// HIPAR ports/should correspond to Array Size number.
ViStatus _VI_FUNC rsznl_LoadCalibrationKitByGenderFromFile(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViString  calibrationKitFile,
                                                           ViInt32   gender,
                                                           ViInt32   portSelector,
                                                           ViInt32   arraySize,
                                                           ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gender, RSZNL_VAL_GENDER_NGENDER, RSZNL_VAL_GENDER_FEMALE),
            4, "Gender");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, portSelector, RSZNL_VAL_ALL_PORTS, RSZNL_VAL_SELECTED_PORTS),
            5, "Port Selector");

    if (portSelector == RSZNL_VAL_ALL_PORTS)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:CKIT:INST '%s',%s,ALL", channel,
            calibrationKitFile, RsZnl_rngKitGender.entries[gender].cmdString);
    }
    else
    {
        p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:CKIT:INST '%s',%s", channel,
            calibrationKitFile, RsZnl_rngKitGender.entries[gender].cmdString);

        for (i = 0; i < arraySize; i++)
        {
            p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", ports[i]);
        }
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function allows to load cal kit data by gender from the given
/// HIFN  file and to the given ports or all ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibrationKitName/This control defines the name of the calibration kit.
/// HIPAR label/This control defines the label of the calibration kit.
/// HIPAR gender/This control selects a gender.
/// HIPAR portSelector/This control selects whether cal kit is loaded for all ports or given
/// HIPAR portSelector/ports.
/// HIPAR arraySize/Sets the number of elements of the Ports array.
/// HIPAR ports/This control specifies the ports for cal kit. The number of elements
/// HIPAR ports/should correspond with Array Size number.
ViStatus _VI_FUNC rsznl_LoadCalibrationKitByGenderFromPool(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViString  calibrationKitName,
                                                           ViString  label,
                                                           ViInt32   gender,
                                                           ViInt32   portSelector,
                                                           ViInt32   arraySize,
                                                           ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, gender, RSZNL_VAL_GENDER_NGENDER, RSZNL_VAL_GENDER_FEMALE),
            5, "Gender");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, portSelector, RSZNL_VAL_ALL_PORTS, RSZNL_VAL_SELECTED_PORTS),
            6, "Port Selector");

    if (portSelector == RSZNL_VAL_ALL_PORTS)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:CKIT:LOAD '%s','%s',%s,ALL", channel,
            calibrationKitName, label, RsZnl_rngKitGender.entries[gender].cmdString);
    }
    else
    {
        p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:CKIT:LOAD '%s','%s',%s", channel,
            calibrationKitName, label, RsZnl_rngKitGender.entries[gender].cmdString);

        for (i = 0; i < arraySize; i++)
        {
            p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, ",%ld", ports[i]);
        }
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the cal kit data assigned to the given port via
/// HIFN  rsznl_LoadCalibrationKitByGenderFromFile or
/// HIFN  rsznl_LoadCalibrationKitByGenderFromPool.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number.
/// HIPAR detail/This control selects a data to be queried.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Result' parameter.
/// HIPAR result/This control returns the value of the cal kit depending on the
/// HIPAR result/selected detail.
ViStatus _VI_FUNC rsznl_QueryCalibrationKitData(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   port,
                                                ViInt32   detail,
                                                ViInt32   bufferSize,
                                                ViChar    result[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, detail, RSZNL_VAL_CONNECTOR, RSZNL_VAL_GENDER),
            4, "Detail");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:CKIT:PORT%ld? %s", channel, port, RsZnl_rngDetail.entries[detail].cmdString);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        result, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads cal kit data from a specified R&S ZVR cal kit file. The loaded
/// HIFN  file must be a R&S ZVR-specific cal kit file with the extension *.ck.
/// HIFN  NWA cal kit files (*.calkit) can be imported using the
/// HIFN  RSZNL_ATTR_IMPORT_KIT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR file/Loads cal kit data from a specified R&S ZVR cal kit file. The loaded
/// HIPAR file/file must be a R&S ZVR-specific cal kit file with the extension *.ck.
/// HIPAR file/NWA cal kit files (*.calkit) can be imported using the
/// HIPAR file/RSZNL_ATTR_IMPORT_KIT.
ViStatus _VI_FUNC rsznl_LoadZVRCalibrationKit(ViSession instrSession,
                                              ViString  file)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_LOAD_ZVR_CALIBRATION_KIT, file),
            2, "File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads cal kit data from a specified NVA cal kit file.
/// HIFN
/// HIFN     Notes:
/// HIFN     (1) The loaded file must be a NVA-specific cal kit file with the
/// HIFN  extension *.calkit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/This control specifies the name and directory of the cal kit file to
/// HIPAR fileName/be loaded. If no path is specified the analyzer searches the current
/// HIPAR fileName/directory, to be queried with MMEMory:CDIRectory?.
ViStatus _VI_FUNC rsznl_ImportKit(ViSession instrSession,
                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_IMPORT_KIT, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function stores the data of a calibration kit to a specified
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR kitName/This control specifies the name of a user-defined calibration kit
/// HIPAR kitName/available on the analyzer. If no path is specified the analyzer uses
/// HIPAR kitName/the current directory, to be queried with MMEMory:CDIRectory?.
/// HIPAR fileName/This control specifies the name and directory of the cal kit file to
/// HIPAR fileName/be created. The file is a NWA-specific cal kit file with the extension
/// HIPAR fileName/*.calkit.
ViStatus _VI_FUNC rsznl_ExportKit(ViSession instrSession,
                                  ViString  kitName,
                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:CKIT '%s','%s'", kitName, fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries type, name, label and gender of a cal kit
/// HIFN  defined in the specified cal kit file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calKitFile/This control sets the path to the cal kit file, either absolute or
/// HIPAR calKitFile/relative to the current directory (see MMEMory:CDIRectory)
/// HIPAR detail/Selects the property to be returned.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the 'Cal
/// HIPAR bufferSize/Kit Name' and 'Cal Kit Label' parameter.
/// HIPAR connectorType/This control returns a connector type.
/// HIPAR calKitName/This control returns the name of a calibration kit.
/// HIPAR calKitLabel/This control defines the label of the calibration kit.
/// HIPAR calKitGender/This control returns a cal kit gender.
ViStatus _VI_FUNC rsznl_QueryCalibrationKitInfo(ViSession instrSession,
                                                ViString  calKitFile,
                                                ViInt32   bufferSize,
                                                ViChar    connectorType[],
                                                ViChar    calKitName[],
                                                ViChar    calKitLabel[],
                                                ViInt32*  calKitGender)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  result = NULL;
    ViChar*  p2buf;
    ViInt32  size = 2 * bufferSize + 15;
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CKIT:INFO? '%s'", calKitFile);

    size = (RS_MAX_MESSAGE_BUF_SIZE < size) ? size : RS_MAX_MESSAGE_BUF_SIZE;

    result = (ViChar*)malloc(size);

    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, size,
        result, &buffRead));

    p2buf = strtok(result, ",");

    if (p2buf != NULL)
        strncpy(connectorType, p2buf, (size_t)(bufferSize - 1));
    else
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);

    p2buf = strtok(NULL, ",");

    if (p2buf != NULL)
        strncpy(calKitName, p2buf, (size_t)(bufferSize - 1));
    else
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);

    p2buf = strtok(NULL, ",");

    if (p2buf != NULL)
        strncpy(calKitLabel, p2buf, (size_t)(bufferSize - 1));
    else
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);

    p2buf = strtok(NULL, ",");

    if (p2buf != NULL)
        *calKitGender = atoi(p2buf);
    else
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);

Error:
    if (result)
        free(result);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the calibration kit to be used for a specified
/// HIFN  connector type.
/// HIFN     [SENSe<Ch>:]CORRection:CKIT:<ConnType>:LSELect
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connector/This control selects a connector type.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
/// HIPAR calibrationKitLabel/This control defines the label of a calibration kit available
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitWithLabel(ViSession instrSession,
                                                         ViInt32   connector,
                                                         ViString  calibrationKitName,
                                                         ViString  calibrationKitLabel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, connector, RSZNL_VAL_CONNECTOR_KIT_N50, RSZNL_VAL_CONNECTOR_KIT_SMA),
            2, "Connector");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:LSEL '%s','%s'", RsZnl_rngConnectorKit.entries[connector].cmdString, calibrationKitName, calibrationKitLabel);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the calibration kit to be used for a specified
/// HIFN  connector type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connector/This control sets a user-defined connector type.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
/// HIPAR calibrationKitLabel/This control defines the label of a calibration kit available
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitUserConnectorTypeWithLabel(
                            ViSession instrSession,
                            ViString  connector,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LSEL '%s','%s','%s'", connector, calibrationKitName, calibrationKitLabel);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a list of all cal kits and their labels for a
/// HIFN  given connector type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connectorName/This control sets the name of the connector type. Use function
/// HIPAR connectorName/rsznl_ConnectorTypesCatalog to query connector names.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Response is a string parameter with comma-separated list of all cal
/// HIPAR catalog/kits and their labels for a given connector type.
ViStatus _VI_FUNC rsznl_CalibrationKitCatalogWithLabel(ViSession instrSession,
                                                       ViString  connectorName,
                                                       ViInt32   bufferSize,
                                                       ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LCAT? '%s'", connectorName);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        catalog, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the parameters of a non-ideal 1 port or 2-port
/// HIFN  calibration standard <std_type>
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/This control selects a standard.
/// HIPAR connectorType/Name of the connector type.
/// HIPAR calibrationKitName/Name of the calibration kit.
/// HIPAR calibrationkitlabel/This control specifies the label (e.g. the serial number) of the
/// HIPAR calibrationkitlabel/calibration kit.
/// HIPAR serialNumber/Label (e.g. the serial number) of the standard.
/// HIPAR minFrequency/This control specifies min. frequency of the standard.
/// HIPAR maxFrequency/This control specifies max. frequency of the standard.
/// HIPAR delayParam/Depending on the cal kit's model type (selected using
/// HIPAR delayParam/RSZNL_FUNC_CALIBRATION_DELAY_MODE) this parameter is interpreted as:
/// HIPAR loss/This control specifies losses.
/// HIPAR z0/This control specifies reference impedance.
/// HIPAR capacitances/This control specifies constant parasitic capacitance. The array must
/// HIPAR capacitances/contain the total of 4 values {C0,C1,C2,C3}.
/// HIPAR residualInductances/This control specifies constant parasitic inductance. The array must
/// HIPAR residualInductances/contain the total of 4 values {L0,L1,L2,L3}.
/// HIPAR approximation/This control specifies approximate modeling of the standard.
/// HIPAR resistance/Indicates the general load circuit model.
/// HIPAR ports/Port restriction: one port number for one port standards, two port
/// HIPAR ports/numbers for two port standards
ViStatus _VI_FUNC rsznl_ConfigureCalibrationStandardWithLabel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  connectorType,
                            ViString  calibrationKitName,
                            ViString  calibrationkitlabel,
                            ViString  serialNumber,
                            ViReal64  minFrequency,
                            ViReal64  maxFrequency,
                            ViReal64  delayParam,
                            ViReal64  loss,
                            ViReal64  z0,
                            ViReal64  capacitances[],
                            ViReal64  residualInductances[],
                            ViInt32   approximation,
                            ViReal64  resistance,
                            ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, approximation, RSZNL_VAL_OPEN, RSZNL_VAL_RESISTANCE),
            13, "Approximation");

    switch (standard)
    {
    case RSZNL_VAL_CALSTD_MMTH:
    case RSZNL_VAL_CALSTD_FFTH:
    case RSZNL_VAL_CALSTD_MFTH:
    case RSZNL_VAL_CALSTD_MMLI:
    case RSZNL_VAL_CALSTD_FFLI:
    case RSZNL_VAL_CALSTD_MFLI:
    case RSZNL_VAL_CALSTD_MMLI_2:
    case RSZNL_VAL_CALSTD_FFLI_2:
    case RSZNL_VAL_CALSTD_MFLI_2:
    case RSZNL_VAL_CALSTD_MMLI_3:
    case RSZNL_VAL_CALSTD_FFLI_3:
    case RSZNL_VAL_CALSTD_MFLI_3:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
            minFrequency, maxFrequency,
            delayParam, loss, z0);
        break;
    case RSZNL_VAL_CALSTD_MOSH:
    case RSZNL_VAL_CALSTD_FOSH:
    case RSZNL_VAL_CALSTD_OSH:
    case RSZNL_VAL_CALSTD_OSH_2:
    case RSZNL_VAL_CALSTD_OSH_3:
    case RSZNL_VAL_CALSTD_MOP:
    case RSZNL_VAL_CALSTD_FOP:
    case RSZNL_VAL_CALSTD_MSH:
    case RSZNL_VAL_CALSTD_FSH:
    case RSZNL_VAL_CALSTD_MOSH_2:
    case RSZNL_VAL_CALSTD_FOSH_2:
    case RSZNL_VAL_CALSTD_MOSH_3:
    case RSZNL_VAL_CALSTD_FOSH_3:
    case RSZNL_VAL_CALSTD_MMTC:
    case RSZNL_VAL_CALSTD_FMTC:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
            minFrequency, maxFrequency,
            delayParam, loss, z0,
            capacitances[0], capacitances[1], capacitances[2], capacitances[3],
            residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3]);
        break;
    case RSZNL_VAL_CALSTD_MMAT:
    case RSZNL_VAL_CALSTD_FFAT:
    case RSZNL_VAL_CALSTD_MFAT:
    case RSZNL_VAL_CALSTD_MSM:
    case RSZNL_VAL_CALSTD_FSM:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG",
            RsZnl_rngCalStandard.entries[standard].cmdString,
            connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
            minFrequency, maxFrequency);
        break;
    case RSZNL_VAL_CALSTD_MMSN: //canbe two ports
    case RSZNL_VAL_CALSTD_FFSN:
    case RSZNL_VAL_CALSTD_MFSN:
        if (approximation == RSZNL_VAL_RESISTANCE)
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%ld,%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                resistance, ports[0], ports[1]);
        }
        else
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%s",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                RsZnl_rngApproximationModelling.entries[approximation].cmdString);
        }
        break;
    case RSZNL_VAL_CALSTD_MREF: //only one port
    case RSZNL_VAL_CALSTD_FREF:
        if (approximation == RSZNL_VAL_RESISTANCE)
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                resistance, ports[0]);
        }
        else
        {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB '%s','%s','%s','%s',%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%s",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorType, calibrationKitName, calibrationkitlabel, serialNumber,
                minFrequency, maxFrequency,
                delayParam, loss, z0,
                capacitances[0], capacitances[1], capacitances[2], capacitances[3],
                residualInductances[0], residualInductances[1], residualInductances[2], residualInductances[3],
                RsZnl_rngApproximationModelling.entries[approximation].cmdString);
        }
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, standard), 3, "Standard");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a list of all standards in a given calibration
/// HIFN  kit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control sets the name of the cal kit. Use function
/// HIPAR calibrationKitName/rsznl_CalibrationKitCatalogWithLabel to query cal kit names.
/// HIPAR calibrationKitLabel/This control defines the label of a calibration kit available
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Response is a string parameter with comma-separated list of all
/// HIPAR catalog/standards in a given calibration kit.
ViStatus _VI_FUNC rsznl_CalibrationStandardsCatalogWithLabel(ViSession instrSession,
                                                             ViString  calibrationKitName,
                                                             ViString  calibrationKitLabel,
                                                             ViInt32   bufferSize,
                                                             ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:STAN:LCAT? '%s','%s'", calibrationKitName, calibrationKitLabel);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, bufferSize,
        catalog, &buffRead));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function assigns a calibration kit label - usually the serial
/// HIFN  number - to an imported or user-defined calibration kit or renames an
/// HIFN  existing calibration kit label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control defines the name of the imported or user-defined
/// HIPAR calibrationKitName/calibration kit.
/// HIPAR calibrationKitLabel/This control defines the current label, usually the serial number of
/// HIPAR calibrationKitLabel/the calibration kit.
/// HIPAR newLabel/This control defines the new calibration kit label.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitLabelWithLabel(
                            ViSession instrSession,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel,
                            ViString  newLabel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (newLabel == NULL)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LLAB '%s','%s'", calibrationKitName, calibrationKitLabel);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LLAB '%s','%s','%s'",
            calibrationKitName, calibrationKitLabel, newLabel);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes an imported or user-defined cal kit including
/// HIFN  label.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationKitName/This control defines the name of calibration kit.
/// HIPAR calibrationKitLabel/This control defines the label of an imported or user-defined
/// HIPAR calibrationKitLabel/calibration kit available on the analyzer.
ViStatus _VI_FUNC rsznl_DeleteCalibrationKitWithLabel(ViSession instrSession,
                                                      ViString  calibrationKitName,
                                                      ViString  calibrationKitLabel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:LDEL '%s','%s'", calibrationKitName, calibrationKitLabel);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads cal kit data for a specific connector type, cal
/// HIFN  kit, and calibration standard from a specified Touchstone file,
/// HIFN  assigning a label for the cal data. A restriction on the port
/// HIFN  assignment may be defined in addition.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR connectorName/This control specifies the name of the connector type.
/// HIPAR calibrationKitName/This control specifies the name of a calibration kit available on the
/// HIPAR calibrationKitName/analyzer.
/// HIPAR calibrationKitLabel/This control defines the label of a calibration kit available
/// HIPAR standard/This control selects a standard.
/// HIPAR standardLabel/String parameter addressing a particular calibration standard by
/// HIPAR fileName/This control specifies the name and directory of the Touchstone file
/// HIPAR fileName/to be loaded. A *.s1p file must be used for one-port standards, a *.s2p
/// HIPAR fileName/file for two-port standards. If no path is specified the analyzer
/// HIPAR fileName/searches the current directory, to be queried with MMEMory:CDIRectory?.
/// HIPAR portNumber1/This control specifies the port assignment: One port number for
/// HIPAR portNumber1/one-port standards, two port number for two-port standards. If the port
/// HIPAR portNumber1/numbers are omitted, the cal kit data is valid for all ports.
/// HIPAR portNumber2/This control specifies the port assignment: One port number for
/// HIPAR portNumber2/one-port standards, two port number for two-port standards. If the port
/// HIPAR portNumber2/numbers are omitted, the cal kit data is valid for all ports.
ViStatus _VI_FUNC rsznl_LoadCalibrationKitWithLabel(ViSession instrSession,
                                                    ViString  connectorName,
                                                    ViString  calibrationKitName,
                                                    ViString  calibrationKitLabel,
                                                    ViInt32   standard,
                                                    ViString  standardLabel,
                                                    ViString  fileName,
                                                    ViInt32   portNumber1,
                                                    ViInt32   portNumber2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (portNumber2 != 0)
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CKIT:SDAT:WLAB '%s','%s','%s',%s,'%s','%s',%ld,%ld",
            connectorName, calibrationKitName, calibrationKitLabel,
            RsZnl_rngCalStandard.entries[standard].cmdString, standardLabel,
            fileName, portNumber1, portNumber2);
    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CKIT:SDAT:WLAB '%s','%s',%s,'%s','%s','%s',%ld", connectorName, calibrationKitName, calibrationKitLabel,
            RsZnl_rngCalStandard.entries[standard].cmdString, standardLabel,
            fileName, portNumber1);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function reads the S-parameter data for a particular cal kit
/// HIFN  standard previously loaded from Touchstone file using
/// HIFN  rsznl_LoadCalibrationKit or rsznl_LoadCalibrationKitWithLabel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/This control selects a standard.
/// HIPAR connectorName/This control specifies the name of the connector type.
/// HIPAR calibrationKitName/This control specifies the name of a calibration kit available on the
/// HIPAR calibrationKitName/analyzer.
/// HIPAR calibrationKitLabel/This control defines the label of a calibration kit available
/// HIPAR sParameter/S-parameter of the 2-port standard. Two-port standards are either MM =
/// HIPAR sParameter/connector/connector, FF = socket/socket or MF = connector/socket.
/// HIPAR portNumber1/Numbers of the physical ports for which the S-parameter data is
/// HIPAR portNumber2/Numbers of the physical ports for which the S-parameter data is
/// HIPAR arraySize/This control sets the number of values returned in array. The array
/// HIPAR arraySize/size has to be at least equal to this number.
/// HIPAR traceData/Returns array of the S-parameter data.
/// HIPAR noofValues/Returns number of taken trace data values.
ViStatus _VI_FUNC rsznl_ReadCalibrationKitWithLabelSParameterData(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  connectorName,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel,
                            ViInt32   sParameter,
                            ViInt32   portNumber1,
                            ViInt32   portNumber2,
                            ViInt32   arraySize,
                            ViReal64  traceData[],
                            ViInt32*  noofValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (standard)
    {
    case RSZNL_VAL_CALSTD_MMTH:
    case RSZNL_VAL_CALSTD_FFTH:
    case RSZNL_VAL_CALSTD_MFTH:
    case RSZNL_VAL_CALSTD_MMLI:
    case RSZNL_VAL_CALSTD_FFLI:
    case RSZNL_VAL_CALSTD_MFLI:
    case RSZNL_VAL_CALSTD_MMLI_2:
    case RSZNL_VAL_CALSTD_FFLI_2:
    case RSZNL_VAL_CALSTD_MFLI_2:
    case RSZNL_VAL_CALSTD_MMLI_3:
    case RSZNL_VAL_CALSTD_FFLI_3:
    case RSZNL_VAL_CALSTD_MFLI_3:
    case RSZNL_VAL_CALSTD_MMAT:
    case RSZNL_VAL_CALSTD_FFAT:
    case RSZNL_VAL_CALSTD_MFAT:
    case RSZNL_VAL_CALSTD_MMSN:
    case RSZNL_VAL_CALSTD_FFSN:
    case RSZNL_VAL_CALSTD_MFSN:
        if (portNumber1 != 0)
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB:SDAT? '%s','%s','%s',%s,%ld,%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString,
                connectorName, calibrationKitName, calibrationKitLabel, RsZnl_rngSParameter.entries[sParameter].cmdString,
                portNumber1, portNumber2);
        else
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB:SDAT? '%s','%s','%s',%s",
                RsZnl_rngCalStandard.entries[standard].cmdString, connectorName, calibrationKitName,
                calibrationKitLabel, RsZnl_rngSParameter.entries[sParameter].cmdString);
        break;

    case RSZNL_VAL_CALSTD_MOSH:
    case RSZNL_VAL_CALSTD_FOSH:
    case RSZNL_VAL_CALSTD_MOSH_2:
    case RSZNL_VAL_CALSTD_FOSH_2:
    case RSZNL_VAL_CALSTD_MOSH_3:
    case RSZNL_VAL_CALSTD_FOSH_3:
    case RSZNL_VAL_CALSTD_OSH:
    case RSZNL_VAL_CALSTD_OSH_2:
    case RSZNL_VAL_CALSTD_OSH_3:
    case RSZNL_VAL_CALSTD_MOP:
    case RSZNL_VAL_CALSTD_FOP:
    case RSZNL_VAL_CALSTD_MSH:
    case RSZNL_VAL_CALSTD_FSH:
    case RSZNL_VAL_CALSTD_MREF:
    case RSZNL_VAL_CALSTD_FREF:
    case RSZNL_VAL_CALSTD_MMTC:
    case RSZNL_VAL_CALSTD_FMTC:
    case RSZNL_VAL_CALSTD_MSM:
    case RSZNL_VAL_CALSTD_FSM:
        if (portNumber1 != 0)
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB:SDAT? '%s','%s','%s',%ld",
                RsZnl_rngCalStandard.entries[standard].cmdString, connectorName, calibrationKitName,
                calibrationKitLabel, portNumber1);
        else
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:CORR:CKIT:%s:WLAB:SDAT? '%s','%s','%s'",
                RsZnl_rngCalStandard.entries[standard].cmdString, connectorName, calibrationKitName,
                calibrationKitLabel);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, standard), 2, "Standard");
    }

    checkErr(rsznl_dataReadTrace(instrSession, cmd, arraySize, traceData, noofValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function stores the data of a calibration kit to a specified
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR kitName/This control specifies the name of a user-defined calibration kit
/// HIPAR kitName/available on the analyzer. If no path is specified the analyzer uses
/// HIPAR kitName/the current directory, to be queried with MMEMory:CDIRectory?.
/// HIPAR calkitLabel/This control specifies the label (e.g. the serial number) of the
/// HIPAR calkitLabel/calibration kit.
/// HIPAR fileName/This control specifies the name and directory of the cal kit file to
/// HIPAR fileName/be created. The file is a NWA-specific cal kit file with the extension
/// HIPAR fileName/*.calkit.
ViStatus _VI_FUNC rsznl_ExportKitWithLabel(ViSession instrSession,
                                           ViString  kitName,
                                           ViString  calkitLabel,
                                           ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:CKIT:WLAB '%s','%s','%s'", kitName, calkitLabel, fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function saves the current power loss list to a specified power
/// HIFN  meter correction list file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceFile/Specifies the name and directory of the created power meter correction
/// HIPAR traceFile/list file. The file extension *.pmcl is mandatory.
ViStatus _VI_FUNC rsznl_PowerMeterSavePowerLossList(ViSession instrSession,
                                                    ViString  traceFile)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SAVE_POWER_METER_CORRECTION_LIST, traceFile),
            2, "Trace File");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads trace data from a specified power meter correction file or trace
/// HIFN  file and assigns it to a trace with a specified name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceFile/Specifies the name and directory of the loaded power meter correction
/// HIPAR traceFile/list file. If no path is specified the analyzer searches the current
/// HIPAR traceFile/directory. The file extensions *.s<n>p, *csv, and *.pmcl for
/// HIPAR traceFile/Touchstone, ASCII, and power meter correction list files are mandatory.
/// HIPAR traceFile/
/// HIPAR trace/This control specifies optional string parameter: For imported
/// HIPAR trace/Touchstone files for more than one port (*.s2p, *.s3p, *.s4p), the
/// HIPAR trace/parameter denotes the imported S-parameter ('S11', 'S12', ...). For
/// HIPAR trace/ASCII (*.csv) files, the parameter references a trace name in the file
/// HIPAR trace/(case sensitive). If the parameter is omitted, the first trace in the
/// HIPAR trace/specified file is imported. The parameter is not used for power meter
/// HIPAR trace/correction list files (*.pmcl).
ViStatus _VI_FUNC rsznl_PowerMeterLoadPowerLossList(ViSession instrSession,
                                                    ViString  traceFile,
                                                    ViString  trace)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (trace != NULL)
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CORR:TCO '%s','%s'", traceFile, trace);
    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:CORR:TCO '%s'", traceFile);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates channel and selects it as the active channel. It
/// HIFN  also assigns a name to channel number.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR channelName/Define channel name.
ViStatus _VI_FUNC rsznl_ChannelAdd(ViSession instrSession,
                                   ViInt32   channel,
                                   ViString  channelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", channel);

    checkErr(RsCore_AddRepCap(instrSession, "Channel", repCap, repCap_cmd));

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CHANNEL_STATE, VI_TRUE));

    if (strncmp(channelName, "", 1) != 0)
    {
        viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CHANNEL_NAME, channelName),
                3, "Channel Name");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates a new channel and a new trace. The new channel
/// HIFN  settings (including a possible channel calibration) is preset to the
/// HIFN  default settings; the trace is created with the default trace settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR channelName/Define channel name.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_ChannelAddTrace(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  channelName,
                                        ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_ChannelAdd(instrSession, channel, channelName));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:PAR:SDEF '%s','S21'", channel, traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates a new channel and a new trace, which is
/// HIFN  displayed in a new diagram area. The new channel settings (including a
/// HIFN  possible channel calibration) is preset to the default settings; the
/// HIFN  trace is created with the default trace settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR channel/Channel number.
/// HIPAR channelName/Define channel name.
/// HIPAR traceName/Define trace name.
ViStatus _VI_FUNC rsznl_ChannelAddTraceDiagramArea(ViSession instrSession,
                                                   ViInt32   window,
                                                   ViInt32   channel,
                                                   ViString  channelName,
                                                   ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap_window[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_ChannelAddTrace(instrSession, channel, channelName, traceName));

    snprintf(repCap_window, RS_REPCAP_BUF_SIZE, "Win%ld", window);

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", window);

    checkErr(RsCore_AddRepCap(instrSession, "Window", repCap_window, repCap_cmd));  // NOLINT(readability-suspicious-call-argument)

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap_window, RSZNL_ATTR_TRACE_DIAGRAM_STATE, VI_TRUE));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap_window, RSZNL_ATTR_TRACE_ASSIGN_DIAGRAM, traceName),
            5, "Trace Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes the current channel including all traces
/// HIFN  assigned to the channel and removes all display elements related to the
/// HIFN  channel from the diagram area.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ChannelDelete(ViSession instrSession,
                                      ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CHANNEL_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CHANNEL_STATE, VI_FALSE));

    checkErr(RsCore_RemoveRepCap(instrSession, "Channel", repCap));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function assigns a name to channel number. The channel must be
/// HIFN  created before. Moreover it is not possible to assign the same name to
/// HIFN  two different channels.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR channelName/Assigns a name to channel number.
ViStatus _VI_FUNC rsznl_ChannelRename(ViSession instrSession,
                                      ViInt32   channel,
                                      ViString  channelName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CHANNEL_NAME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CHANNEL_NAME, channelName),
            3, "Channel Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the numbers and names of all channels in the
/// HIFN  current setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR catalog/Returns string with comma-separated list of channel numbers and names.
/// HIPAR catalog/If all channels have been deleted the response is an empty string ("").
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_ChannelList(ViSession instrSession,
                                    ViInt32   bufferSize,
                                    ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_CHANNEL_LIST,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the channel number (numeric suffix) of a channel
/// HIFN  with known channel name. A channel name must be assigned before.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelName/Sets the channel name.
/// HIPAR channelNumber/Returns the channel number (numeric suffix) of a channel with known
/// HIPAR channelNumber/channel name.
ViStatus _VI_FUNC rsznl_QueryChannelNumber(ViSession instrSession,
                                           ViString  channelName,
                                           ViInt32*  channelNumber)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViUInt32 buffRead;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:CHAN:NAME:ID? '%s'", channelName);
    checkErr(rsznl_QueryWithOPCSync(instrSession, cmd, 0, RS_MAX_MESSAGE_BUF_SIZE,
        rd_buffer, &buffRead));

    *channelNumber = atoi(rd_buffer);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects a channel <Ch> as the active channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ConfigureActiveChannel(ViSession instrSession,
                                               ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_CHANNEL_SETUP_ACTIVE_CHANNEL, channel),
            2, "Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  De/activates the 'Fixture Simulator' switch that allows to disable and
/// HIFN  (re-)enable the configured deembedding, embedding, balanced ports, and
/// HIFN  port impedance settings for the selected channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR fixtureSimulator/De/activates the 'Fixture Simulator' switch that allows to disable and
/// HIPAR fixtureSimulator/(re-)enable the configured deembedding, embedding, balanced ports, and
/// HIPAR fixtureSimulator/port impedance settings for the selected channel.
ViStatus _VI_FUNC rsznl_ConfigureChannelFixtureSimulator(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean fixtureSimulator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CHANNEL_FIXTURE_SIMULATOR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CHANNEL_FIXTURE_SIMULATOR, fixtureSimulator),
            3, "Fixture Simulator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Determines the order of partial measurements and sweeps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR drivingMode/Determines the order of partial measurements and sweeps.
ViStatus _VI_FUNC rsznl_ConfigureDrivingMode(ViSession instrSession,
                                             ViInt32   drivingMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_DRIVING_MODE, drivingMode),
            2, "Driving Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines whether the analyzer measures with a local oscillator
/// HIFN  frequency LO below or above the RF input frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR imageSuppression/Defines whether the analyzer measures with a local oscillator
/// HIPAR imageSuppression/frequency LO below or above the RF input frequency.
ViStatus _VI_FUNC rsznl_ConfigureImageSuppression(ViSession instrSession,
                                                  ViInt32   imageSuppression)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_IMAGE_SUPPRESSION, imageSuppression),
            2, "Image Suppression");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets a channel-dependent eight-bit binary value
/// HIFN  (00000000 ... 11111111) to control eight independent
/// HIFN     output signals at the USER PORT connector (lines 8, 9, 10, 11 and
/// HIFN  lines 16, 17, 18, 19).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR channelBits/This control sets a channel-dependent eight-bit binary value to
/// HIPAR channelBits/control eight independent output signals at the USER PORT connector
/// HIPAR channelBits/(lines 8, 9, 10, 11 and lines 16, 17, 18, 19). The output signals are
/// HIPAR channelBits/3.3 V TTL signals which can be used to differentiate between up to 255
/// HIPAR channelBits/independent analyzer states.
/// HIPAR pin1617/Defines the usage of pins pins 16 to 19 of the USER PORT connector.
ViStatus _VI_FUNC rsznl_ConfigureChannelBits(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  channelBits,
                                             ViInt32   pin1617)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_USER_PORT_CHANNEL_BITS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_USER_PORT_CHANNEL_BITS, channelBits),
            3, "Channel Bits");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap,
        RSZNL_ATTR_USER_PORT_PINS_USAGE,
        (ViBoolean)pin1617), 4, "Pin 1617");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the channel segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR segment/Sweep segment number. Segment numbers must be sequential. The
/// HIPAR segment/specified segment number must be smaller or equal to the number of
/// HIPAR segment/existing segments plus 1. Moreover, segment numbers must selected such
/// HIPAR segment/that the corresponding frequency ranges are in ascending order.
/// HIPAR enabled/Enables or disables segment bits for the sweep segments in channel no.
/// HIPAR enabled/<Ch>; see OUTPut<Ch>:UPORt:SEGMent<Seg>[:VALue]. The command is valid
/// HIPAR enabled/for segmented frequency sweep.
/// HIPAR segmentValue/Sets or queries a sweep segment-dependent four-bit binary value to
/// HIPAR segmentValue/control four independent output signals at the USER PORT connector
/// HIPAR segmentValue/(lines 16, 17, 18, 19). The output signals are 3.3 V TTL signals which
/// HIPAR segmentValue/can be used to differentiate between up to 16 independent analyzer
/// HIPAR segmentValue/states for each channel. The command is valid for segmented frequency
/// HIPAR segmentValue/sweeps. It is analogous to the channel-dependent command
/// HIPAR segmentValue/OUTPut<Ch>:UPORt[:VALue].
ViStatus _VI_FUNC rsznl_ConfigureChannelSegment(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   segment,
                                                ViBoolean enabled,
                                                ViString  segmentValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CHANNEL_SEGMENT_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CHANNEL_SEGMENT_ENABLED,
            "RippleSegment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CHANNEL_SEGMENT_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CHANNEL_SEGMENT_VALUE, segmentValue),
            5, "Segment Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the set of active logical ports (the 'master group') as the
/// HIFN  continuous range from <log_port1> to <log_port2>, i.e. logical ports
/// HIFN  outside this range are disabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR group/Logical port group number.
/// HIPAR arraySize/Defines size of array in argument 'Logical Ports'.
/// HIPAR logicalPorts/Array of logical ports.
ViStatus _VI_FUNC rsznl_DefinePortGroupContinuous(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   group,
                                                  ViInt32   arraySize,
                                                  ViInt32   logicalPorts[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:GRO%ld ", channel, group);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, logicalPorts, arraySize));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the set of active logical ports (the 'master group') as an
/// HIFN  arbitrary selection of logical ports. The ports do not have to be
/// HIFN  numbered consecutively.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR group/Logical port group number.
/// HIPAR arraySize/Defines size of array in argument 'Logical Ports'.
/// HIPAR logicalPorts/Array of logical ports.
ViStatus _VI_FUNC rsznl_DefinePortGroupArbitrary(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   group,
                                                 ViInt32   arraySize,
                                                 ViInt32   logicalPorts[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR%ld:GRO%ld:PORT ", channel, group);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, logicalPorts, arraySize));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Dissolves all groups of measured ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeleteAllPortGroups(ViSession instrSession,
                                            ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELETE_ALL_PORT_GROUPS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DELETE_ALL_PORT_GROUPS, NULL),
            2, "Delete All Port Groups");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the offset parameter for test port <Port> as
/// HIFN  a delay time.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR delay/Defines the offset parameter for test port <PhyPt> as a delay time.
ViStatus _VI_FUNC rsznl_ConfigureOffsetDelay(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   port,
                                             ViReal64  delay)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_DELAY_TIME,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_DELAY_TIME,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_OFFSET_DELAY_TIME, delay),
            4, "Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the offset parameter for test port <PhyPt> as an electrical
/// HIFN  length.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR electricalLength/Defines the offset parameter for test port <PhyPt> as an electrical
/// HIPAR electricalLength/length.
ViStatus _VI_FUNC rsznl_ConfigureOffsetElectricalLength(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   port,
                                                        ViReal64  electricalLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EFFSET_ELECTRICAL_LENGTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EFFSET_ELECTRICAL_LENGTH,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_EFFSET_ELECTRICAL_LENGTH, electricalLength),
            4, "Electrical Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the offset parameter for test port <PhyPt> as a mechanical
/// HIFN  length.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR mechanicalLength/Defines the offset parameter for test port <PhyPt> as a mechanical
/// HIPAR mechanicalLength/length.
ViStatus _VI_FUNC rsznl_ConfigureOffsetMechanicalLength(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   port,
                                                        ViReal64  mechanicalLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_MECHANICAL_LENGTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_MECHANICAL_LENGTH,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_OFFSET_MECHANICAL_LENGTH, mechanicalLength),
            4, "Mechanical Length");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the permittivity for the offset correction at test port
/// HIFN  <PhyPt>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR permittivity/Defines the permittivity for the offset correction at test port
/// HIPAR permittivity/<PhyPt>.
ViStatus _VI_FUNC rsznl_ConfigureOffsetPermittivity(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   port,
                                                    ViReal64  permittivity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_PERMITTIVITY,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_PERMITTIVITY,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_OFFSET_PERMITTIVITY, permittivity),
            4, "Permittivity");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures parameters of One-way Loss.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number of the offset-corrected channel.
/// HIPAR port/Port number of the analyzer.
/// HIPAR lossAtDC/This control defines the frequency-independent part (DC value) of the
/// HIPAR lossAtDC/offset loss.
/// HIPAR lossAtFrequency/This control defines the offset loss at the reference frequency.
/// HIPAR frequencyForLoss/This control defines the reference frequency.
ViStatus _VI_FUNC rsznl_ConfigureOneWayLoss(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   port,
                                            ViReal64  lossAtDC,
                                            ViReal64  lossAtFrequency,
                                            ViReal64  frequencyForLoss)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ONE_WAY_LOSS_AT_DC,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ONE_WAY_LOSS_AT_DC,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_AT_DC, lossAtDC),
            4, "Loss At DC");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_AT_FREQUENCY, lossAtFrequency),
            5, "Loss At Frequency");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_FREQUENCY_FOR_LOSS, frequencyForLoss),
            6, "Frequency For Loss");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the offset parameter for the active test port such that the
/// HIFN  residual delay of the active trace (defined as the negative derivative
/// HIFN  of the phase response) is minimized across the entire sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_AutoLength(ViSession instrSession,
                                   ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_AUTO_LENGTH,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_AUTO_LENGTH, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the offset parameters for the active test port such that the
/// HIFN  residual delay of the active trace (defined as the negative derivative
/// HIFN  of the phase response) is minimized and the measured loss is reproduced
/// HIFN  as far as possible across the entire sweep range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number of the offset-corrected channel.
ViStatus _VI_FUNC rsznl_AutoLengthAndLoss(ViSession instrSession,
                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_AUTO_LENGTH_AND_LOSS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_AUTO_LENGTH_AND_LOSS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the offset parameters for all test ports to zero and the
/// HIFN  reference frequency to 1 GHz or queries whether any of the offset
/// HIFN  parameters are different from zero.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR resetOffset/Resets the offset parameters for all test ports to zero and the
/// HIPAR resetOffset/reference frequency to 1 GHz or queries whether any of the offset
/// HIPAR resetOffset/parameters are different from zero.
ViStatus _VI_FUNC rsznl_ConfigureResetOffsets(ViSession instrSession,
                                              ViInt32   channel,
                                              ViBoolean resetOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RESET_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_RESET_OFFSET, resetOffset),
            3, "Reset Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Toggles length/loss/fixture compensation for physical port <PhyPt>
/// HIFN  ON/OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR compensation/Toggles length/loss/fixture compensation for physical port <PhyPt>
/// HIPAR compensation/ON/OFF.
ViStatus _VI_FUNC rsznl_ConfigureOffsetCompensation(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   port,
                                                    ViBoolean compensation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_COMPENSATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_OFFSET_COMPENSATION,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_OFFSET_COMPENSATION, compensation),
            4, "Compensation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the operating mode where the time gate is moved in the
/// HIFN  opposite direction when the 'Delay' setting is changed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR adjustTimeGate/Activates the operating mode where the time gate is moved in the
/// HIPAR adjustTimeGate/opposite direction when the 'Delay' setting is changed.
ViStatus _VI_FUNC rsznl_ConfigureTimeGateAdjust(ViSession instrSession,
                                                ViBoolean adjustTimeGate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_ADJUST_TIME_GATE, adjustTimeGate),
            2, "Adjust Time Gate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the second frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port number of the analyzer.
/// HIPAR enabled/Defines whether the second reference frequency f2 is used for the
/// HIPAR enabled/offset loss approximation.
/// HIPAR secondFrequency/These control define the offset loss at the reference frequencies f1
/// HIPAR secondFrequency/and f2.
/// HIPAR frequencyForLoss/These commands define the reference frequencies f1 and f2 for the
/// HIPAR frequencyForLoss/offset loss approximation.
ViStatus _VI_FUNC rsznl_ConfigureOneWayLossAtSecondFrequency(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   port,
                                                             ViBoolean enabled,
                                                             ViReal64  secondFrequency,
                                                             ViReal64  frequencyForLoss)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ONE_WAY_LOSS_SECOND_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ONE_WAY_LOSS_SECOND_ENABLED,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_SECOND_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_AT_SECOND_FREQUENCY, secondFrequency),
            5, "Second Frequency");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_ONE_WAY_LOSS_SECOND_FREQUENCY_FOR_LOSS, frequencyForLoss),
            6, "Frequency For Loss");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures offset compensation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR offsetCompensation/Selects the type of compensation that the network analyzer calculates
/// HIPAR offsetCompensation/from the acquired compensation data.
ViStatus _VI_FUNC rsznl_ConfigureFixtureCompensationOffsetCorrection(
                            ViSession instrSession,
                            ViInt32   offsetCompensation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    switch (offsetCompensation)
    {
    case RSZNL_VAL_OFFSET_COMPENSATION_AUTO_LENGTH:
        checkErr(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_FIXTURE_COMPENSATION_AUTO_LENGTH_AND_LOSS, VI_FALSE));
        checkErr(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPENSATION, VI_FALSE));
        break;

    case RSZNL_VAL_OFFSET_COMPENSATION_AUTO_LENGTH_LOSS:
        checkErr(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_FIXTURE_COMPENSATION_AUTO_LENGTH_AND_LOSS, VI_TRUE));
        checkErr(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPENSATION, VI_FALSE));
        break;

    case RSZNL_VAL_OFFSET_COMPENSATION_DIRECT:
        checkErr(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPENSATION, VI_TRUE));
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, offsetCompensation), 2, "Offset Compensation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Prepares the analyzer for fixture compensation comprising a single or
/// HIFN  a series of fixture compensation sweeps. Previous compensation data is
/// HIFN  deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ResetFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_FIXTURE_COMPENSATION_RESET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_FIXTURE_COMPENSATION_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts a fixture compensation sweep in order to acquire  measurement
/// HIFN  data for a test fixture that has its inner conductor terminated with
/// HIFN  the selected standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR arraySize/Size of array containing port numbers.
/// HIPAR terminatedType/Selects standard type, open or short circuit.
/// HIPAR portNumbers/Array of port numbers for perform calibration.
ViStatus _VI_FUNC rsznl_StartFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   arraySize,
                                                 ViInt32   terminatedType,
                                                 ViInt32   portNumbers[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:FIXT %s,", channel, terminatedType ? "SHOR" : "OPEN");
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, portNumbers, arraySize));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Completes a fixture compensation, storing and applying the acquired
/// HIFN  data.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ApplyFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_FIXTURE_COMPENSATION_RESET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_FIXTURE_COMPENSATION_APPLY, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads "Direct Compensation" data from the specified file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR fixtureFile/Path to the "Direct Compensation" data file, either absolute or
/// HIPAR terminatedType/Selects standard type, open or short circuit.
/// HIPAR arraySize/Size of array containing port numbers.
/// HIPAR portNumbers/Array of port numbers for perform calibration.
ViStatus _VI_FUNC rsznl_ImportFixtureCompensation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  fixtureFile,
                                                  ViInt32   terminatedType,
                                                  ViInt32   arraySize,
                                                  ViInt32   portNumbers[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:FIXT:IMP '%s',%s,", channel, fixtureFile, terminatedType ? "SHOR" : "OPEN");
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, portNumbers, arraySize));

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves "Direct Compensation" data from the specified file. The function
/// HIFN  first acquires the required data, just as a function
/// HIFN  rsznl_StartFixtureCompensation would do.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR fixtureFile/Path to the "Direct Compensation" data file, either absolute or
/// HIPAR terminatedType/Selects standard type, open or short circuit.
/// HIPAR arraySize/Size of array containing port numbers.
/// HIPAR portNumbers/Array of port numbers for perform calibration.
ViStatus _VI_FUNC rsznl_ExportFixtureCompensation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  fixtureFile,
                                                  ViInt32   terminatedType,
                                                  ViInt32   arraySize,
                                                  ViInt32   portNumbers[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS%ld:CORR:COLL:FIXT:EXP '%s',%s,", channel, fixtureFile, terminatedType ? "SHOR" : "OPEN");
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, portNumbers, arraySize));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns whether a direct fixture compensation has been carried out at
/// HIFN  port no. <PhyPt>. A direct fixture compensation resets the offset
/// HIFN  parameters to zero, the analyzer uses calculated transmission factors
/// HIFN  instead.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR status/Returns whether a direct fixture compensation has been carried out at
/// HIPAR status/port no. <PhyPt>. A direct fixture compensation resets the offset
/// HIPAR status/parameters to zero, the analyzer uses calculated transmission factors
/// HIPAR status/instead.
ViStatus _VI_FUNC rsznl_QueryFixtureCompensationDirectCompansationStatus(
                            ViSession  instrSession,
                            ViInt32    channel,
                            ViInt32    port,
                            ViBoolean* status)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPANSATION_STATUS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPANSATION_STATUS,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    viCheckParm(rsznl_GetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPANSATION_STATUS, status),
            2, "Status");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables the deembedding/embedding function
/// HIFN  for single ended ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR physicalPortNumber/Physical port number.
/// HIPAR state/This control enables or disables the deembedding function for single
/// HIPAR state/ended ports.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_ENABLED,
            "Port", physicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_ENABLED, state),
                5, "State");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_EMBEDDING_SINGLE_ENDED_ENABLED, state),
                5, "State");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the capacitance, inductance, resistance or
/// HIFN  conductance values C1, C2, L1, L2, R1, R2 or G1, G2 in the different
/// HIFN  circuit models for single ended port deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR physicalPortNumber/Physical port number.
/// HIPAR parameterType/Parameter type, capacitance, inductance, resistance or conductance.
/// HIPAR parameterNumber/Number of capacitances, inductances, resistances or conductances in
/// HIPAR parameterNumber/circuit model.
/// HIPAR circuitModel/This control defines the possible circuit model.
/// HIPAR value/Capacitance C<no>, Inductance L<no>, Resistance R<no> or Conductance
/// HIPAR value/G<no> for the specified circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   parameterType,
                            ViInt32   parameterNumber,
                            ViInt32   circuitModel,
                            ViReal64  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameterNumber, 1, 3),
            6, "Parameter Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, circuitModel, RSZNL_VAL_SENDED_CIRCUIT_CSL, RSZNL_VAL_SENDED_CIRCUIT_SGG),
            7, "Circuit Model");

    switch (parameterType)
    {
    case RSZNL_VAL_VNET_PARAM_C:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e-3, 1.0e-3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:SEND:%s%ld:PAR:C%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], physicalPortNumber,
            parameterNumber, RsZnl_rngCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_L:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0, 1.0), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:SEND:%s%ld:PAR:L%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], physicalPortNumber,
            parameterNumber, RsZnl_rngCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_R:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -10.0e+6, 10.0e+6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:SEND:%s%ld:PAR:R%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], physicalPortNumber,
            parameterNumber, RsZnl_rngCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_G:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e3, 1.0e3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:SEND:%s%ld:PAR:G%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], physicalPortNumber,
            parameterNumber, RsZnl_rngCircuitModel.entries[circuitModel].cmdString, value);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, parameterType), 5, "Parameter Type");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines an embedding network for a single-ended port
/// HIFN  based on the given S-Parameter traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR physicalPortNumber/Physical port number.
/// HIPAR interchange/This control defines the interchange of port numbers.
/// HIPAR touchstoneFile/Content of a Touchstone file (*.s2p or *.s4p)
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   interchange,
                            ViString  touchstoneFile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, interchange, RSZNL_VAL_PORT_NUMBERS_NOT_INTERCHANGED, RSZNL_VAL_PORT_NUMBERS_INTERCHANGED),
            5, "Interchange");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":CALC%ld:TRAN:VNET:SEND:%s%ld:PAR:DATA %s",
        channel,
        gsc_functionTypeArr[functionType],
        physicalPortNumber,
        RsZnl_rngPortInterchange.entries[interchange].cmdString);

    checkErr(rsznl_SendTouchstoneFileToInstrument(instrSession, cmd, touchstoneFile));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the circuit model for single ended port
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR physicalPortNumber/Physical port number.
/// HIPAR circuitModel/This control defines the possible circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   circuitModel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL,
            "Port", physicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_EMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads data from a specified two-port (*.sp2) Touchstone
/// HIFN  file defining the characteristics of the current embedded/deembedded
/// HIFN  single ended port circuit model. The single ended port circuit model
/// HIFN  involving file import (FIMPort) must be selected before using this
/// HIFN  function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR physicalPortNumber/Physical port number.
/// HIPAR fileName/This control specifies the name and directory of the loaded Touchstone
/// HIPAR fileName/file. If no path is specified the analyzer searches the current
/// HIPAR fileName/directory, to be queried with MMEMory:CDIRectory?.
/// HIPAR interchange/Interchange port numbers of loaded *.s2p file.
ViStatus _VI_FUNC rsznl_LoadSingleEndedPortCircuitModelData(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   physicalPortNumber,
                                                            ViString  fileName,
                                                            ViBoolean interchange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:LOAD:VNET%ld:SEND:%s%ld '%s',%s", channel,
        gsc_functionTypeArr[functionType],
        physicalPortNumber, fileName,
        RsZnl_rngPortInterchange.entries[interchange].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables the deembedding/embedding function
/// HIFN  for balanced ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR state/This control enables or disables the deembedding function for balanced
/// HIPAR state/ports.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkABalancedState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_BALANCED_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_BALANCED_ENABLED,
            "LogicalPort", logicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_BALANCED_ENABLED, state),
                5, "State");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_EMBEDDING_BALANCED_ENABLED, state),
                5, "State");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the capacitance, inductance or resistance
/// HIFN  values C1, C2, C3, L1, L2, L3, R1, R2, R3  or G1, G2, G3 in the
/// HIFN  different circuit models for balanced port deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR parameterType/Parameter type, capacitance, inductance, resistance  or conductance.
/// HIPAR parameterNumber/Number of capacitances, inductances, resistances or conductance in
/// HIPAR parameterNumber/circuit model.
/// HIPAR circuitModel/This control defines the possible circuit model.
/// HIPAR value/Capacitance C<no>, Inductance L<no>, Resistance R<no> or Conductance
/// HIPAR value/G<no> for the specified circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedPort(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   logicalPortNumber,
                                                            ViInt32   parameterType,
                                                            ViInt32   parameterNumber,
                                                            ViInt32   circuitModel,
                                                            ViReal64  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameterNumber, 1, 3),
            6, "Parameter Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, circuitModel, RSZNL_VAL_BALANCED_CIRCUIT_STSL, RSZNL_VAL_BALANCED_CIRCUIT_SGGS),
            7, "Circuit Model");

    switch (parameterType)
    {
    case RSZNL_VAL_VNET_PARAM_C:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e-3, 1.0e-3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:BAL:%s%ld:PAR:C%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_L:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0, 1.0), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:BAL:%s%ld:PAR:L%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_R:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -10.0e+6, 10.0e+6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:BAL:%s%ld:PAR:R%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_G:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e3, 1.0e3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:BAL:%s%ld:PAR:G%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, parameterType), 5, "Parameter Type");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a deembedding network for a balanced port based
/// HIFN  on the given S-Parameter traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR portAssignment/Port assignment for 2-port networks
/// HIPAR interchange/This control defines the interchange of port numbers.
/// HIPAR touchstoneFile/Content of a Touchstone file (*.s2p or *.s4p)
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedData(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   logicalPortNumber,
                                                            ViInt32   portAssignment,
                                                            ViInt32   interchange,
                                                            ViString  touchstoneFile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, portAssignment, 1, 2),
            5, "Port Assignment");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, interchange, RSZNL_VAL_PORT_NUMBERS_NOT_INTERCHANGED, RSZNL_VAL_PORT_NUMBERS_INTERCHANGED),
            6, "Interchange");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":CALC%ld:TRAN:VNET:BAL:%s%ld:PAR:DATA%ld %s",
        channel,
        gsc_functionTypeArr[functionType],
        logicalPortNumber, portAssignment,
        RsZnl_rngPortInterchange.entries[interchange].cmdString);

    checkErr(rsznl_SendTouchstoneFileToInstrument(instrSession, cmd, touchstoneFile));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the circuit model for balanced port
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR circuitModel/This control defines the possible circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   circuitModel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_BALANCED_CIRCUIT_MODEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_BALANCED_CIRCUIT_MODEL,
            "LogicalPort", logicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_BALANCED_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_EMBEDDING_BALANCED_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads data from a specified Touchstone file defining the
/// HIFN  characteristics of the current embedded/deembedded  balanced port
/// HIFN  circuit model. A balanced port circuit model involving file import must
/// HIFN  be selected before using this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR fileName/This control specifies the name and directory of the loaded Touchstone
/// HIPAR fileName/file. The balanced port circuit models STSL | STSC | SLST | SCST
/// HIPAR fileName/require two 2-port (*.s2p) files, to be assigned to the different ports
/// HIPAR fileName/PMAin and PSECondary; the FIMPort model requires a single 4-port
/// HIPAR fileName/(*.s4p) file but no additional port assignment.
/// HIPAR parameter/Port assignment for two 2-port (*.s2p) files.
ViStatus _VI_FUNC rsznl_LoadBalancedPortCircuitModelData(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   functionType,
                                                         ViInt32   logicalPortNumber,
                                                         ViString  fileName,
                                                         ViInt32   parameter,
                                                         ViBoolean interchange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameter, RSZNL_VAL_VNET_PARAM_PMAIN, RSZNL_VAL_VNET_PARAM_PSECOND),
            6, "Circuit Model");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:LOAD:VNET%ld:BAL:%s%ld '%s',%s,%s", channel,
        gsc_functionTypeArr[functionType],
        logicalPortNumber, fileName,
        RsZnl_rngEmbedSingleEndedLoadPort.entries[parameter].cmdString,
        RsZnl_rngPortInterchange.entries[interchange].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines port set <ListId> for port set
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portSet/Current number of the defined port set within the channel's overall
/// HIPAR portSet/list of port sets for deembedding/embedding.
/// HIPAR arraySize/Number of ports to be defined.
/// HIPAR ports/An array of port set, a port set consist of two, three or four
/// HIPAR ports/different ports. A port may be an element of multiple port sets.
ViStatus _VI_FUNC rsznl_DefineVirtualNetworkPortSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   functionType,
                                                    ViInt32   portSet,
                                                    ViInt32   arraySize,
                                                    ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap_name[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd_value[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PSET:%s%ld:DEF ", channel, gsc_functionTypeArr[functionType], portSet);
    checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, ports, arraySize));

    if (functionType == RSZNL_VAL_VNET_FUNC_DEEMBED)
    {
        snprintf(repCap_name, RS_REPCAP_BUF_SIZE, "PPairDeembedding%ld", portSet);
        snprintf(cmd_value, RS_REPCAP_BUF_SIZE, "%ld", portSet);
        checkErr(RsCore_AddRepCap(instrSession, "List_idx_deembedding", repCap_name, cmd_value));
    }
    else
    {
        snprintf(repCap_name, RS_REPCAP_BUF_SIZE, "PPairEmbedding%ld", portSet);
        snprintf(cmd_value, RS_REPCAP_BUF_SIZE, "%ld", portSet);
        checkErr(RsCore_AddRepCap(instrSession, "List_idx_embedding", repCap_name, cmd_value));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a list of port pairs for port pair
/// HIFN  embedding/deembedding. The function can be used
/// HIFN     repeatedly to extend or (partially) overwrite the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portPair/Current number of a port pair in the list.
/// HIPAR arraySize/Number of ports to be defined.
/// HIPAR ports/An array of port pairs, each one consisting of two different
ViStatus _VI_FUNC rsznl_DefineVirtualNetworkPortPair(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType,
                                                     ViInt32   portPair,
                                                     ViInt32   arraySize,
                                                     ViInt32   ports[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap_name[RS_REPCAP_BUF_SIZE] = "";
    ViChar   cmd_value[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PPA:%s%ld:DEF ",
        channel, gsc_functionTypeArr[functionType], portPair);

    for (i = 0; i < arraySize; i++)
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%ld,", ports[i]);

    *p2buf = '\0';
    *--p2buf = '\n';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    if (functionType == RSZNL_VAL_VNET_FUNC_DEEMBED)
    {
        snprintf(repCap_name, RS_REPCAP_BUF_SIZE, "PPairDeembedding%ld", portPair);
        snprintf(cmd_value, RS_REPCAP_BUF_SIZE, "%ld", portPair);
        checkErr(RsCore_AddRepCap(instrSession, "List_idx_deembedding", repCap_name, cmd_value));
    }
    else
    {
        snprintf(repCap_name, RS_REPCAP_BUF_SIZE, "PPairEmbedding%ld", portPair);
        snprintf(cmd_value, RS_REPCAP_BUF_SIZE, "%ld", portPair);
        checkErr(RsCore_AddRepCap(instrSession, "List_idx_embedding", repCap_name, cmd_value));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the previously defined list of port pairs for port pair
/// HIFN  embedding/deembedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
ViStatus _VI_FUNC rsznl_DeleteVirtualNetworkPortPair(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr   attr[2] =
             {
             RSZNL_ATTR_DEEMBEDDING_PORT_SETS_DELETE_ALL_PORT_SETS,
             RSZNL_ATTR_EMBEDDING_PORT_SETS_DELETE_ALL_PORT_SETS
             };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, attr[functionType], NULL));

    if (functionType == RSZNL_VAL_VNET_FUNC_DEEMBED)
    {
        checkErr(RsCore_ResetRepCapID(instrSession, "List_idx_deembedding", rsznl_RsCoreRepCapTable));
    }
    else
    {
        checkErr(RsCore_ResetRepCapID(instrSession, "List_idx_embedding", rsznl_RsCoreRepCapTable));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function enables or disables the deembedding/embedding function
/// HIFN  for for port pairs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portPair/Current number of a port pair in the list.
/// HIPAR state/This control enables or disables the deembedding function for port
/// HIPAR state/pair.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPairState(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   functionType,
                                                             ViInt32   portPair,
                                                             ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_ENABLED,
                "List_idx_deembedding", portPair - 1, RS_REPCAP_BUF_SIZE, repCap_port));

        RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_ENABLED, state),
                5, "State");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_PORT_SETS_ENABLED,
                "List_idx_embedding", portPair - 1, RS_REPCAP_BUF_SIZE, repCap_port));

        RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_EMBEDDING_PORT_SETS_ENABLED, state),
                5, "State");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the capacitance, inductance or resistance
/// HIFN  values C1, C2, C3, L1, L2, L3, R1, R2, R3 or G1, G2, G3 in the
/// HIFN  different circuit models for port pair deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portPair/Current number of a port pair in the list.
/// HIPAR parameterType/Parameter type, capacitance, inductance, resistance or conductance.
/// HIPAR parameterNumber/Number of capacitances, inductances, resistances or conductance in
/// HIPAR parameterNumber/circuit model.
/// HIPAR circuitModel/This control defines the possible circuit model.
/// HIPAR value/Capacitance C<no>, Inductance L<no>, Resistance R<no> or Conductance
/// HIPAR value/G<no> for the specified circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPair(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   functionType,
                                                        ViInt32   portPair,
                                                        ViInt32   parameterType,
                                                        ViInt32   parameterNumber,
                                                        ViInt32   circuitModel,
                                                        ViReal64  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameterNumber, 1, 3),
            6, "Parameter Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, circuitModel, RSZNL_VAL_BALANCED_CIRCUIT_STSL, RSZNL_VAL_BALANCED_CIRCUIT_SGGS),
            7, "Circuit Model");

    switch (parameterType)
    {
    case RSZNL_VAL_VNET_PARAM_C:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e-3, 1.0e-3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PPA:%s%ld:PAR:C%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], portPair,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_L:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0, 1.0), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PPA:%s%ld:PAR:L%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], portPair,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_R:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -10.0e+6, 10.0e+6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PPA:%s%ld:PAR:R%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], portPair,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_G:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e3, 1.0e3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:PPA:%s%ld:PAR:G%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], portPair,
            parameterNumber, RsZnl_rngPortSetsCircuitModel.entries[circuitModel].cmdString, value);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, parameterType), 5, "Parameter Type");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the circuit model for port pair
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portPair/Current number of a port pair in the list.
/// HIPAR circuitModel/This control defines the possible circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPairCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   portPair,
                            ViInt32   circuitModel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_CIRCUIT_MODEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_CIRCUIT_MODEL,
                "List_idx_deembedding", portPair - 1, RS_REPCAP_BUF_SIZE, repCap_port));

        RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_PORT_SETS_CIRCUIT_MODEL, circuitModel),
                5, "Circuit Model");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_PORT_SETS_CIRCUIT_MODEL,
                "List_idx_embedding", portPair - 1, RS_REPCAP_BUF_SIZE, repCap_port));

        RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_EMBEDDING_PORT_SETS_CIRCUIT_MODEL, circuitModel),
                5, "Circuit Model");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads data from a specified Touchstone file defining the
/// HIFN  characteristics of the current embedded/deembedded  port pair circuit
/// HIFN  model. A balanced port circuit model involving file import must be
/// HIFN  selected before using this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR portPair/Current number of a port pair in the list.
/// HIPAR fileName/This control specifies the name and directory of the loaded Touchstone
/// HIPAR fileName/file. The balanced port circuit models STSL | STSC | SLST | SCST
/// HIPAR fileName/require two 2-port (*.s2p) files, to be assigned to the different ports
/// HIPAR fileName/PMAin and PSECondary; the FIMPort model requires a single 4-port
/// HIPAR fileName/(*.s4p) file but no additional port assignment.
/// HIPAR parameter/Port assignment for two 2-port (*.s2p) files.
/// HIPAR interchangePortNumbers/Interchange port numbers of loaded *.s2p file. If the parameter is
/// HIPAR interchangePortNumbers/omitted, the port numbers are not interchanged. The parameter must not
/// HIPAR interchangePortNumbers/be used for 4-port files.
ViStatus _VI_FUNC rsznl_LoadPortPairCircuitModelData(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType,
                                                     ViInt32   portPair,
                                                     ViString  fileName,
                                                     ViInt32   parameter,
                                                     ViBoolean interchangePortNumbers)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameter, RSZNL_VAL_VNET_PARAM_PMAIN, RSZNL_VAL_VNET_PARAM_PSECOND),
            6, "Circuit Model");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:LOAD:VNET%ld:PPA:%s%ld '%s',%s,%s", channel,
        gsc_functionTypeArr[functionType],
        portPair, fileName,
        RsZnl_rngEmbedSingleEndedLoadPort.entries[parameter].cmdString,
        RsZnl_rngPortInterchange.entries[interchangePortNumbers].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables the deembedding/embedding function
/// HIFN  for ground loops. It is allowed to change the circuit model and its
/// HIFN  parameters while deembedding is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR state/This control enables or disables the deembedding function for ground
/// HIPAR state/loop.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoopState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_ENABLED, state),
                5, "State");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_EMBEDDING_GROUND_LOOP_ENABLED, state),
                4, "State");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the capacitance C, inductance L, resistance R
/// HIFN  or conductance G value in the different circuit models for ground loop
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR parameterType/Parameter type, capacitance, inductance, resistance or conductance.
/// HIPAR circuitModel/This control defines the possible circuit model.
/// HIPAR groundLoopValue/Capacitance C, Inductance L, Resistance R or Conductance G for the
/// HIPAR groundLoopValue/specified circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoop(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   functionType,
                                                          ViInt32   parameterType,
                                                          ViInt32   circuitModel,
                                                          ViReal64  groundLoopValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_DEEMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, circuitModel, RSZNL_VAL_GLOOP_CIRCUIT_SL, RSZNL_VAL_GLOOP_CIRCUIT_SG),
            5, "Circuit Model");

    switch (parameterType)
    {
    case RSZNL_VAL_VNET_PARAM_C:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, groundLoopValue, -1.0e-3, 1.0e-3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:GLO:%s:PAR:C %s,%.12lG",
            channel, gsc_functionTypeArr[functionType],
            RsZnl_rngGroundLoopCircuitModel.entries[circuitModel].cmdString, groundLoopValue);
        break;

    case RSZNL_VAL_VNET_PARAM_L:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, groundLoopValue, -1.0, 1.0), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:GLO:%s:PAR:L %s,%.12lG",
            channel, gsc_functionTypeArr[functionType],
            RsZnl_rngGroundLoopCircuitModel.entries[circuitModel].cmdString, groundLoopValue);
        break;

    case RSZNL_VAL_VNET_PARAM_R:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, groundLoopValue, -10.0e+6, 10.0e+6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:GLO:%s:PAR:R %s,%.12lG",
            channel, gsc_functionTypeArr[functionType],
            RsZnl_rngGroundLoopCircuitModel.entries[circuitModel].cmdString, groundLoopValue);
        break;

    case RSZNL_VAL_VNET_PARAM_G:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, groundLoopValue, -1.0e3, 1.0e3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:GLO:%s:PAR:G %s,%.12lG",
            channel, gsc_functionTypeArr[functionType],
            RsZnl_rngGroundLoopCircuitModel.entries[circuitModel].cmdString, groundLoopValue);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, parameterType), 5, "Parameter Type");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the circuit model for ground loop
/// HIFN  deembedding/embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR circuitModel/This control defines the possible circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoopCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   circuitModel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_CIRCUIT_MODEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_EMBEDDING_GROUND_LOOP_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads data from a specified one-port (*.s1p) Touchstone
/// HIFN  file defining the characteristics of the current embedded/deembedded
/// HIFN  ground loop circuit model. The ground loop circuit model involving file
/// HIFN  import (FIMPort) must be selected before using this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR fileName/This control specifies the name and directory of the loaded Touchstone
/// HIPAR fileName/file. If no path is specified the analyzer searches the current
/// HIPAR fileName/directory, to be queried with MMEMory:CDIRectory?.
ViStatus _VI_FUNC rsznl_LoadGroundLoopCircuitModelData(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   functionType,
                                                       ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_LOAD,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    switch (functionType)
    {
    case RSZNL_VAL_VNET_FUNC_DEEMBED:
        viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_LOAD, fileName),
                5, "File Name");

        break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_EMBEDDING_GROUND_LOOP_LOAD, fileName),
                5, "File Name");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables differential match embedding for
/// HIFN  balanced port <LogPt>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, only embedding is available at the moment.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR state/This control enables or disables differential match embedding for
/// HIPAR state/balanced port.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViBoolean state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_ENABLED,
            "LogicalPort", logicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
        //case RSZNL_VAL_VNET_FUNC_DEEMBED:
        //    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap,
        //                                         RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_ENABLED,
        //                                         state), 5, "State");
        //
        //    break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_ENABLED, state),
                5, "State");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function specifies the capacitance, inductance, resistance or
/// HIFN  conductance values in the "Shunt L, Shunt C" lumped element model for
/// HIFN  differential match embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, only embedding is available at the moment.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR parameterType/Parameter type, capacitance, inductance, resistance or conductance.
/// HIPAR parameterNumber/Number of capacitances, inductances or resistances in circuit model.
/// HIPAR circuitModel/This control defines the possible circuit model.
/// HIPAR value/Capacitance C<no>, Inductance L<no>, Resistance R<no> or Conductance
/// HIPAR value/G<no> for the specified circuit model.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatch(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   parameterType,
                            ViInt32   parameterNumber,
                            ViInt32   circuitModel,
                            ViReal64  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_EMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameterNumber, 1, 3),
            6, "Parameter Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, circuitModel, RSZNL_VAL_CIRCUIT_SHLC, RSZNL_VAL_CIRCUIT_SHLC),
            7, "Circuit Model");

    switch (parameterType)
    {
    case RSZNL_VAL_VNET_PARAM_C:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0e-3, 1.0e-3), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:DIFF:%s%ld:PAR:C%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngDifferentialMatchCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_L:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -1.0, 1.0), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:DIFF:%s%ld:PAR:L%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngDifferentialMatchCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_R:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -10.0e+6, 10.0e+6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:DIFF:%s%ld:PAR:R%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngDifferentialMatchCircuitModel.entries[circuitModel].cmdString, value);
        break;

    case RSZNL_VAL_VNET_PARAM_G:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, value, -10.0e6, 10.0e6), 8, "Value");

        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:TRAN:VNET:DIFF:%s%ld:PAR:G%ld %s,%.12lG",
            channel, gsc_functionTypeArr[functionType], logicalPortNumber,
            parameterNumber, RsZnl_rngDifferentialMatchCircuitModel.entries[circuitModel].cmdString, value);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, parameterType), 5, "Parameter Type");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines an differential match embedding network for a
/// HIFN  balanced port based on the given S-Parameter traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, only embedding is available at the moment.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR interchange/This control defines the interchange of port numbers.
/// HIPAR touchstoneFile/Content of a Touchstone file (*.s2p or *.s4p)
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   interchange,
                            ViString  touchstoneFile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_EMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, interchange, RSZNL_VAL_PORT_NUMBERS_NOT_INTERCHANGED, RSZNL_VAL_PORT_NUMBERS_INTERCHANGED),
            5, "Interchange");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":CALC%ld:TRAN:VNET:DIFF:%s%ld:PAR:DATA %s",
        channel,
        gsc_functionTypeArr[functionType],
        logicalPortNumber,
        RsZnl_rngPortInterchange.entries[interchange].cmdString);

    checkErr(rsznl_SendTouchstoneFileToInstrument(instrSession, cmd, touchstoneFile));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the circuit model for differential match
/// HIFN  embedding.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, deembedding or embedding.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR circuitModel/Selects the circuit model for differential match embedding.
ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   circuitModel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_CIRCUIT_MODEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_CIRCUIT_MODEL,
            "LogicalPort", logicalPortNumber - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_port, NULL);

    switch (functionType)
    {
        //case RSZNL_VAL_VNET_FUNC_DEEMBED:
        //    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap,
        //                                         RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_CIRCUIT_MODEL,
        //                                         circuitModel), 5, "circuitModel");
        //
        //    break;
    case RSZNL_VAL_VNET_FUNC_EMBED:
        viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_CIRCUIT_MODEL, circuitModel),
                5, "circuitModel");
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, functionType), 3, "functionType");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function loads data from a specified Touchstone file defining the
/// HIFN  characteristics of the current embedded differential match circuit
/// HIFN  model. A differential match circuit model involving file import must be
/// HIFN  selected before using this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR functionType/Function type, only embedding is available at the moment.
/// HIPAR logicalPortNumber/Logical port number.
/// HIPAR fileName/This control specifies the name and directory of the loaded Touchstone
/// HIPAR fileName/file.
/// HIPAR interchangePortNumbers/Interchange port numbers of loaded *.s2p file. If the parameter is
/// HIPAR interchangePortNumbers/omitted, the port numbers are not interchanged. The parameter must not
/// HIPAR interchangePortNumbers/be used for 4-port files.
ViStatus _VI_FUNC rsznl_LoadDifferentialMatchCircuitModelData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViString  fileName,
                            ViBoolean interchangePortNumbers)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, functionType, RSZNL_VAL_VNET_FUNC_EMBED, RSZNL_VAL_VNET_FUNC_EMBED),
            3, "Function Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":MMEM:LOAD:VNET%ld:DIFF:%s%ld '%s',%s", channel,
        gsc_functionTypeArr[functionType],
        logicalPortNumber, fileName,
        RsZnl_rngPortInterchange.entries[interchangePortNumbers].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a new diagram and a new trace which is displayed in the new
/// HIFN  diagram. The trace is created with the channel settings of the previous
/// HIFN  active trace but with default trace settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
ViStatus _VI_FUNC rsznl_DiagramAreaAdd(ViSession instrSession,
                                       ViInt32   window)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ADD_TRACE_AND_DIAGRAM,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap));

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", window);

    checkErr(RsCore_AddRepCap(instrSession, "Window", repCap, repCap_cmd));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_ADD_TRACE_AND_DIAGRAM, NULL),
            2, "Window");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the current diagram area including all traces displayed in the
/// HIFN  diagram area. The remaining diagrams are re-numbered.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
ViStatus _VI_FUNC rsznl_DiagramAreaDelete(ViSession instrSession,
                                          ViInt32   window)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DELETE_DIAGRAM,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_TRACE_DIAGRAM_STATE, VI_FALSE));

    checkErr(RsCore_RemoveRepCap(instrSession, "Window", repCap));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Maximizes all diagram areas in the active channel setup or restores
/// HIFN  the previous display configuration.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) Number of the diagram area to become the active diagram area.
/// HIFN  DISPlay:WINDow<Wnd>:MAXimize acts on all diagrams of the current setup,
/// HIFN  however, the digram no. <Wnd> is displayed on top of the others.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR diagramArea/Maximizes all diagram areas in the active setup or restores the
/// HIPAR diagramArea/previous display configuration.
ViStatus _VI_FUNC rsznl_DiagramAreaMaximize(ViSession instrSession,
                                            ViInt32   window,
                                            ViInt32   diagramArea)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_MAXIMIZE_ALL,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Window");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap,
        RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_MAXIMIZE_ALL,
        diagramArea ? VI_TRUE : VI_FALSE
    ), 3, "Diagram Area");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a title for diagram area <Wnd>.
/// HIFN
/// HIFN     Title provides an input field for the title string. The title may
/// HIFN  comprise a practically unlimited number of characters and is centered
/// HIFN  in a line below the top of the diagram area.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR title/Displays or hides the title for area number <Wnd>.
/// HIPAR titleString/String variable for the title. The length of the title is practically
/// HIPAR titleString/unlimited but should be kept short enough to be displayed in the
/// HIPAR titleString/diagrams.
ViStatus _VI_FUNC rsznl_DiagramAreaTitle(ViSession instrSession,
                                         ViInt32   window,
                                         ViBoolean title,
                                         ViString  titleString)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_SHOW_TITLE,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Window");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_SHOW_TITLE, title),
            3, "Title");

    if (title)
    {
        viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_TITLE, titleString),
                4, "Title String");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a name for diagram area <Wnd>.
/// HIFN
/// HIFN     Note:
/// HIFN
/// HIFN     (1) The name appears in the list of diagram areas, to be queried by
/// HIFN  RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_CATALOG.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR areaName/String variable for the name.
ViStatus _VI_FUNC rsznl_DiagramAreaName(ViSession instrSession,
                                        ViInt32   window,
                                        ViString  areaName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_NAME,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Window");

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_NAME, areaName),
            3, "Area Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the numbers and names of all diagram areas in
/// HIFN  the current recall set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR catalog/Returns string with comma-separated list of trace numbers and names.
/// HIPAR catalog/If all traces have been deleted the response is an empty string ("").
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
ViStatus _VI_FUNC rsznl_DiagramAreaCatalog(ViSession instrSession,
                                           ViChar    catalog[],
                                           ViInt32   bufferSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_CATALOG,
            bufferSize, catalog),
            2, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the numbers and names of all traces in diagram
/// HIFN  area no. <Wnd>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufferSize/'Catalog' parameter.
/// HIPAR catalog/Returns string with comma-separated list of trace numbers and names.
/// HIPAR catalog/If all traces have been deleted the response is an empty string ("").
ViStatus _VI_FUNC rsznl_TraceDiagramAreaCatalog(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   bufferSize,
                                                ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_TRACE_DIAGRAM_AREA_CATALOG,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Window");

    viCheckParm(rsznl_GetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISPLAY_TRACE_DIAGRAM_AREA_CATALOG,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides the label of an existing trace, identified by its
/// HIFN  <TraceName>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR tracename/Trace name.
/// HIPAR enabled/Display or hide the label of the related trace.
ViStatus _VI_FUNC rsznl_DisplayTraceLabel(ViSession instrSession,
                                          ViString  traceName,
                                          ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s", traceName, enabled ? "ON" : "OFF");

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HIDDEN_DISPLAY_TRACE_LABEL, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function magnifies a rectangular portion of the diagram (zoom
/// HIFN  window) to fill the entire diagram area.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR window_Trace/Trace number used to distinguish the traces of the same diagram area
/// HIPAR window_Trace/<Wnd>.
/// HIPAR zoomState/This control displays or hides trace(s).
/// HIPAR topEdge/Specifies the upper edge of the zoom window. In contrast to manual
/// HIPAR topEdge/control, all or part of the zoom window may be outside the original
/// HIPAR topEdge/diagram.
/// HIPAR bottomEdge/Specifies the lower edge of the zoom window. In contrast to manual
/// HIPAR bottomEdge/control, all or part of the zoom window may be outside the original
/// HIPAR bottomEdge/diagram.
/// HIPAR leftEdge/Specifies the start value of the zoom window (left border). In
/// HIPAR leftEdge/contrast to manual control, all or part of the zoom window may be
/// HIPAR leftEdge/outside the original diagram.
/// HIPAR rightEdge/Specifies the stop value of the zoom window (right border). In
/// HIPAR rightEdge/contrast to manual control, all or part of the zoom window may be
/// HIPAR rightEdge/outside the original diagram.
ViStatus _VI_FUNC rsznl_ConfigureTraceZoom(ViSession instrSession,
                                           ViInt32   window,
                                           ViInt32   window_Trace,
                                           ViBoolean zoomState,
                                           ViReal64  topEdge,
                                           ViReal64  bottomEdge,
                                           ViReal64  leftEdge,
                                           ViReal64  rightEdge)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, topEdge, -89.99, 232.0), 4, "Top Edge");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, bottomEdge, -390.0, 9.99), 5, "Bottom Edge");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:ZOOM:TOP %.12lG", window, window_Trace, topEdge);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:ZOOM:BOTT %.12lG", window, window_Trace, bottomEdge);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:ZOOM:STAR %.12lG", window, window_Trace, leftEdge);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:ZOOM:STOP %.12lG", window, window_Trace, rightEdge);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:WIND%ld:TRAC%ld:ZOOM:STAT %s", window, window_Trace, (zoomState == VI_TRUE) ? "ON" : "OFF");
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables the zoom overview. The upper part of the diagram
/// HIFN  shows the original diagram for comparison. You can move the zoomed part
/// HIFN  of the trace by moving the marked zoom area in the overview.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR window/Number of the diagram area.
/// HIPAR zoomOverviewState/This control activates the zoom overview for the selected window.
ViStatus _VI_FUNC rsznl_ConfigureZoomOverview(ViSession instrSession,
                                              ViInt32   window,
                                              ViBoolean zoomOverviewState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_ZOOM_OVERVIEW,
            "Window", window - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Window");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_ZOOM_OVERVIEW, zoomOverviewState),
            3, "Zoom Overview State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function arranges the display windows.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layoutMode/Arranges the display windows.
ViStatus _VI_FUNC rsznl_ConfigureSplitType(ViSession instrSession,
                                           ViInt32   layoutMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_DISPLAY_SPLIT_TYPE, layoutMode),
            2, "Layout Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the number of rows and columns if split type
/// HIFN  is set to "Rows + Columns".
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR rows/Defines the number of rows.
/// HIPAR columns/Defines the number of columns.
ViStatus _VI_FUNC rsznl_ConfigureSplitGrid(ViSession instrSession,
                                           ViInt32   rows,
                                           ViInt32   columns)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:LAY:GRID %ld,%ld", rows, columns);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates a horizontal or vertical display layout and
/// HIFN  provides it with an identifier (<LayoutId>) and selects it.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layoutID/Current number, used by other DISPlay:LAYout... commands to reference
/// HIPAR layoutID/the created layout.
/// HIPAR layoutFormatMode/Selects the horizontal or vertical layout. Layouts are defined row by
/// HIPAR layoutFormatMode/row (horizontal layouts) or column by column (vertical layouts).
/// HIPAR layoutData/Layouts are defined row by row (horizontal layouts) or column by
/// HIPAR layoutData/column (vertical layouts).
ViStatus _VI_FUNC rsznl_ConfigureLayoutSimplified(ViSession instrSession,
                                                  ViInt32   layoutID,
                                                  ViInt32   layoutFormatMode,
                                                  ViString  layoutData)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViString layoutFormatModeArr[] = { "Horizontal", "Vertical" };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, layoutFormatMode, RSZNL_VAL_LAYOUT_FORMAT_HORIZONTAL, RSZNL_VAL_LAYOUT_FORMAT_VERTICAL),
            2, "Layout Format Mode");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:LAY:DEF %ld,%s,'%s'", layoutID, layoutFormatModeArr[layoutFormatMode], layoutData);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_SELECT_DISPLAY_LAYOUT, layoutID),
            2, "Layout ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates and displays a horizontal or vertical display
/// HIFN  layout.
/// HIRET Returns the status code of this operation.   Select More Wave Quantities With Detector
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR layoutData/Creates and displays a horizontal or vertical display layout.
ViStatus _VI_FUNC rsznl_ConfigureLayout(ViSession instrSession,
                                        ViString  layoutData)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:LAY:EXEC '%s'", layoutData);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function creates a nested layout, inserting a sub-layout into one
/// HIFN  of the diagrams of a main layout and selects it. Main layout and
/// HIFN  sub-layout must be defined previously - for example using function
/// HIFN  rsznl_ConfigureLayoutSimplified.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mainLayoutID/Current number of main layout.
/// HIPAR diagramNumber/Diagram number in the main layout.
/// HIPAR subLayoutID/Current number of sub-layout.
ViStatus _VI_FUNC rsznl_JoinLayouts(ViSession instrSession,
                                    ViInt32   mainLayoutID,
                                    ViInt32   diagramNumber,
                                    ViInt32   subLayoutID)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:LAY:JOIN %ld,%ld,%ld", mainLayoutID, diagramNumber, subLayoutID);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_SELECT_DISPLAY_LAYOUT, mainLayoutID),
            2, "Main Layout ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the name and index of all active windows. Implements the
/// HIFN  correspondent spectrum analysis command for VNA channel setups.
/// HIFN
/// HIFN     The result is a comma-separated list of window names and numbers:
/// HIFN
/// HIFN     '<Name of Window 1>',1,...,'<Name of Window n>',n
/// HIFN
/// HIFN     If the marker info table is active, it is returned at the last
/// HIFN  position (...,'Info',n).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR catalog/Queries the name and index of all active windows. Implements the
/// HIPAR catalog/correspondent spectrum analysis command for VNA channel setups.
ViStatus _VI_FUNC rsznl_QueryLayoutCatalog(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_LAYOUT_CATALOG,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays all traces of the active channel setup in a single diagram,
/// HIFN  which is maximized to occupy the whole screen.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_LayoutOverlayAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_LAYOUT_OVERLAY_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Creates a separate diagram for each trace in the active channel setup
/// HIFN  and automatically arranges those diagrams in the diagram area. Existing
/// HIFN  diagrams are deleted.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_LayoutSplitAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_LAYOUT_SPLIT_ALL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Unmasks or masks all stimulus values in the VNA GUI for the active
/// HIFN  channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Unmasks or masks all stimulus values in the VNA GUI for the active
/// HIPAR state/channel setup.
ViStatus _VI_FUNC rsznl_ConfigureDisplayFrequencyInfoState(ViSession instrSession,
                                                           ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_FREQUENCY_INFO_STATE, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows or hides the channel list(s) in all diagrams of the current
/// HIFN  channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Shows or hides the channel list(s) in all diagrams of the current
/// HIPAR state/channel setup.
ViStatus _VI_FUNC rsznl_ConfigureDisplayChannelInfoState(ViSession instrSession,
                                                         ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_CHANNEL_INFO_STATE, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shows or hides the trace list(s) in all diagrams of the current
/// HIFN  channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR state/Shows or hides the trace list(s) in all diagrams of the current
/// HIPAR state/channel setup.
ViStatus _VI_FUNC rsznl_ConfigureDisplayTraceInfoState(ViSession instrSession,
                                                       ViBoolean state)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_TRACE_INFO_STATE, state),
            2, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the size of the fonts in the diagram on a relative scale.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fontSize/Defines the size of the fonts in the diagram on a relative scale.
ViStatus _VI_FUNC rsznl_ConfigureDisplayFontSize(ViSession instrSession,
                                                 ViReal64  fontSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, "", RSZNL_ATTR_DISPLAY_FONT_SIZE, fontSize),
            2, "Font Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines whether the Display Update function remains available in
/// HIFN  remote operation or not.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayLock/Defines whether the Display Update function remains available in
/// HIPAR displayLock/remote operation or not.
ViStatus _VI_FUNC rsznl_ConfigureDisplayLock(ViSession instrSession,
                                             ViBoolean displayLock)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_DISPLAY_LOCK, displayLock),
            2, "Display Lock");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function configures the display settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR statusBarEnabled/Turns the status bar on and off.
/// HIPAR softkeyBarEnabled/Turns the softkey bar on and off.
/// HIPAR toolbarEnabled/Turns the toolbar on or off.
/// HIPAR touchEnabled/Controls the touch screen functionality.
/// HIPAR channelInformationEnabled/Hides or displays the channel bar information.
/// HIPAR xAxisLabelEnabled/Turns the label of the x-axis on and off.
/// HIPAR dateAndTimeEnabled/Adds or removes the date and time from the display.
/// HIPAR frontPanelKeysEnabled/Includes or excludes the front panel keys when working with the remote
/// HIPAR frontPanelKeysEnabled/desktop.
ViStatus _VI_FUNC rsznl_ConfigureDisplay(ViSession instrSession,
                                         ViBoolean statusBarEnabled,
                                         ViBoolean softkeyBarEnabled,
                                         ViBoolean toolbarEnabled,
                                         ViInt32   touchEnabled,
                                         ViBoolean channelInformationEnabled,
                                         ViBoolean xAxisLabelEnabled,
                                         ViBoolean dateAndTimeEnabled,
                                         ViBoolean frontPanelKeysEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_STATUS_BAR_ENABLED, statusBarEnabled),
            2, "Status Bar Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_SOFTKEY_BAR_ENABLED, softkeyBarEnabled),
            3, "Softkey Bar Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_TOOLBAR_ENABLED, toolbarEnabled),
            4, "Toolbar Enabled");

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_DISPLAY_TOUCH_ENABLED, touchEnabled),
            5, "Touch Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_CHANNEL_BAR_INFORMATION_ENABLED, channelInformationEnabled),
            6, "Channel Information Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_X_AXIS_LABEL_ENABLED, xAxisLabelEnabled),
            7, "X Axis Label Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_DATE_AND_TIME_ENABLED, dateAndTimeEnabled),
            8, "Date and Time Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, "", RSZNL_ATTR_DISPLAY_FRONT_PANEL_KEYS_ENABLED, frontPanelKeysEnabled),
            9, "Front Panel Keys Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the brightness of the display in eight steps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayBrightness/Changes the brightness of the display in eight steps.
ViStatus _VI_FUNC rsznl_ConfigureDisplayBrightness(ViSession instrSession,
                                                   ViInt32   displayBrightness)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_DISPLAY_BACKGROUND_LIGHTING, displayBrightness),
            2, "Display Brightness");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the time and date format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dateAndTimeFormat/Selects the time and date format.
ViStatus _VI_FUNC rsznl_ConfigureDisplayDateAndTimeFormat(ViSession instrSession,
                                                          ViInt32   dateAndTimeFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_DISPLAY_DATE_AND_TIME_FORMAT, dateAndTimeFormat),
            2, "Date and Time Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries all available display themes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Catalog.
/// HIPAR catalog/Queries all available display themes.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryColorsAndThemesCatalog(ViSession instrSession,
                                                    ViUInt32  arraySize,
                                                    ViChar    catalog[],
                                                    ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_COLORS_AND_THEMES_CATALOG,
            arraySize, catalog),
            3, "Catalog");

    *returnedValues = (ViUInt32)strlen(catalog);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the display theme.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selectedTheme/Selects the display theme.
ViStatus _VI_FUNC rsznl_ConfigureColorsAndThemesSelectedTheme(
                            ViSession instrSession,
                            ViString  selectedTheme)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_COLORS_AND_THEMES_SELECTED_THEME, selectedTheme),
            2, "Selected Theme");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the color scheme for the display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR color/Selects the color.
ViStatus _VI_FUNC rsznl_ResetColorScheme(ViSession instrSession,
                                         ViInt32   displayItem,
                                         ViInt32   color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, color, 1, 4),
            3, "Color");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:CMAP%ld:DEF%ld", displayItem, color);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the color for various screen elements in the display.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR tint/Tint
/// HIPAR saturation/Saturation
/// HIPAR brightness/Brightness
ViStatus _VI_FUNC rsznl_SelectColor(ViSession instrSession,
                                    ViInt32   displayItem,
                                    ViReal64  tint,
                                    ViReal64  saturation,
                                    ViReal64  brightness)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, tint, 0.0, 1.0), 3, "Tint");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, saturation, 0.0, 1.0), 4, "Saturation");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, brightness, 0.0, 1.0), 5, "Brightness");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:CMAP%ld:HSL %.12lG,%.12lG,%.12lG", displayItem, tint,
        saturation, brightness);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects a predefined color for various screen elements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR color/Selects the color.
ViStatus _VI_FUNC rsznl_SelectPredefinedColor(ViSession instrSession,
                                              ViInt32   displayItem,
                                              ViInt32   color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, color, RSZNL_VAL_COLOR_BLACK, RSZNL_VAL_COLOR_LMAGENTA),
            3, "Color");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:CMAP%ld:PDEF %s", displayItem, RsZnl_rngPredefinedColor.entries[color].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function displays or hides the entire limit line (including all
/// HIFN  segments) associated to the active trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showLimitLine/Displays or hides the entire limit line.
ViStatus _VI_FUNC rsznl_ShowLimitLine(ViSession instrSession,
                                      ViInt32   channel,
                                      ViBoolean showLimitLine)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SHOW_LIMIT_LINE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SHOW_LIMIT_LINE, showLimitLine),
            3, "Show Limit Line");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the limit check (or individual upper and lower
/// HIFN  limits) on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR limitLine/Select limit line.
/// HIPAR limitCheck/Switches the limit check on or off.
/// HIPAR horizontalPosition/Selects the horizontal position of the info field.
/// HIPAR verticalPosition/Selects the vertical position of the info field.
ViStatus _VI_FUNC rsznl_ConfigureLimitCheck(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   limitLine,
                                            ViBoolean limitCheck,
                                            ViInt32   horizontalPosition,
                                            ViInt32   verticalPosition)
{
    ViStatus               error = VI_SUCCESS;
    ViChar                 cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar                 repCap[RS_REPCAP_BUF_SIZE] = "";
    ViAttr                 attribute[] = { 0,
                           RSZNL_ATTR_UPPER_LIMIT_CHECK,
                           RSZNL_ATTR_LOWER_LIMIT_CHECK,
    RSZNL_ATTR_LIMIT_CHECK };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limitLine, RSZNL_VAL_LIMIT_UPPER, RSZNL_VAL_LIMIT_ALL),
            3, "Limit Line");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, horizontalPosition, RSZNL_VAL_HORIZONTAL_LEFT, RSZNL_VAL_HORIZONTAL_RIGHT),
            5, "Horizontal Position");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, verticalPosition, RSZNL_VAL_VERTICAL_TOP, RSZNL_VAL_VERTICAL_BOTTOM),
            6, "Vertical Position");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:STAT:AREA %s,%s", channel,
        RsZnl_rngHorizontalPosition.entries[horizontalPosition].cmdString,
        RsZnl_rngVerticalPosition.entries[verticalPosition].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_CHECK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, attribute[limitLine], limitCheck),
            4, "Limit Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a 0 or 1, to indicate whether the LIMit test has
/// HIFN  failed or not. Sweep must be initiated before reading the result when
/// HIFN  in single sweep mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR limitCheckResult/Returns a 0 or 1, to indicate whether the LIMit test has failed or
/// HIPAR limitCheckResult/not.
ViStatus _VI_FUNC rsznl_QueryLimitCheckResult(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32*  limitCheckResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_CHECK_RESULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_LIMIT_CHECK_RESULT, limitCheckResult),
            3, "Limit Check Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a 0 or 1, to indicate whether or not a global,
/// HIFN  composite limit check on several traces has failed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR globalLimitCheck/Returns a 0 or 1, to indicate whether or not a global, composite limit
/// HIPAR globalLimitCheck/check on several traces has failed.
ViStatus _VI_FUNC rsznl_QueryGlobalLimitCheckResult(ViSession instrSession,
                                                    ViInt32*  globalLimitCheck)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GLOBAL_LIMIT_CHECK_RESULT, globalLimitCheck),
            2, "Global Limit Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Clear the limit check results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_ClearLimitCheckResults(ViSession instrSession,
                                               ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_LIMIT_CHECK_CLEAR, NULL));

    checkErr(RsCore_ResetRepCapID(instrSession, "LimitCheck", rsznl_RsCoreRepCapTable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Reads the effective lower/upper limit points from a limit line test
/// HIFN  for an arbitrary (not necessarily the active) trace, referenced by its
/// HIFN  name <TraceName>.
/// HIFN
/// HIFN     'Effective' means:
/// HIFN     - Only points within the sweep range and only active limit checks are
/// HIFN  considered.
/// HIFN     - Disabled limit line segments (RSZNL_ATTR_LIMIT_LINE_SEGMENT_TYPE set
/// HIFN  to OFF) are ignored.
/// HIFN     - Both linear/logarithmic interpolation and limit line formulae are
/// HIFN  supported.
/// HIFN     - If there are overlapping limit line segments, only the tighter limit
/// HIFN  is reported.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR type/Selects the limit type.
/// HIPAR traceName/Trace name, uniquely identifying the related trace.
/// HIPAR arraySize/Pass the number of segments (segments list size).
/// HIPAR points/Returns the effective lower/upper limit points from a limit line test
/// HIPAR points/for an arbitrary trace.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryLimitEffectivePoints(ViSession instrSession,
                                                  ViInt32   type,
                                                  ViString  traceName,
                                                  ViInt32   arraySize,
                                                  ViReal64  points[],
                                                  ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   queryParam[RS_MAX_MESSAGE_LEN] = "";
    ViAttr   attr[] = { RSZNL_ATTR_HIDDEN_LIMIT_EFFECTIVE_POINTS_UPPER, RSZNL_ATTR_HIDDEN_LIMIT_EFFECTIVE_POINTS_LOWER };

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSZNL_VAL_LIMIT_UPPER, RSZNL_VAL_LIMIT_LOWER),
            2, "Type");
    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 1), 4, "Array Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, points), 5, "Points");

    snprintf(queryParam, RS_MAX_MESSAGE_LEN, "'%s'", traceName);

    viCheckParm(RsCore_GetAttributeViStringAsViReal64ArrayToUserBuffer(instrSession, NULL,
        attr[type - 1], queryParam, arraySize, points, returnedValues), 5, "Points");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function shows or hides the display line associated to the active
/// HIFN  trace in a Cartesian diagram area.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR displayLine/Switches the horizontal line on or off.
/// HIPAR responseValue/Defines the position (response value) of the horizontal line.
ViStatus _VI_FUNC rsznl_ConfigureHorizontalLine(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean displayLine,
                                                ViReal64  responseValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_HORIZONTAL_LINE_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_HORIZONTAL_LINE_STATE, displayLine),
            3, "Display Line");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_HORIZONTAL_LINE_RESPONSE_VALUE, responseValue),
            4, "Response Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a 0 or 1 to indicate whether or not the limit line check has
/// HIFN  failed for at least one channel in the referenced channel setup. 0
/// HIFN  represents pass and 1 represents fail.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR setup/Name of a VNA channel setup.
/// HIPAR result/Returns a 0 or 1 to indicate whether or not the limit line check has
/// HIPAR result/failed for at least one channel in the referenced channel setup. 0
/// HIPAR result/represents pass and 1 represents fail.
ViStatus _VI_FUNC rsznl_QueryLimitCheckResultChannel(ViSession instrSession,
                                                     ViString  setup,
                                                     ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (strncmp(setup, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM:FAIL:ALL?");
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM:FAIL:ALL? '%s'", setup);
    }

    checkErr(rsznl_QueryViInt32(instrSession, cmd, result));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIFN  generated each time the analyzer detects an exceeded limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR failBeep/Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIPAR failBeep/generated each time the analyzer detects an exceeded limit.
ViStatus _VI_FUNC rsznl_ConfigureLimitLineFailBeep(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean failBeep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_FAIL_BEEP,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_FAIL_BEEP, failBeep),
            3, "Fail Beep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Shifts a previously defined limit line in x and y direction,
/// HIFN  respectively, without having to redefine the constituent line segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR horizontalShift/Shifts an existing existing limit line in horizontal direction.
/// HIPAR upperShift/This command shifts all upper limit line segments assigned to the
/// HIPAR upperShift/active trace in vertical direction.
/// HIPAR lowerShift/This command shifts all upper limit line segments assigned to the
/// HIPAR lowerShift/active trace in vertical direction.
ViStatus _VI_FUNC rsznl_ConfigureLimitLineShift(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  horizontalShift,
                                                ViReal64  upperShift,
                                                ViReal64  lowerShift)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_HORIZONTAL_SHIFT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_HORIZONTAL_SHIFT, horizontalShift),
            3, "Horizontal Shift");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_UPPER_SHIFT, upperShift),
            4, "Upper Shift");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_LOWER_SHIFT, lowerShift),
            5, "Lower Shift");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function adds a new segment to the limit line list. In each
/// HIFN  segment the limit line is defined as a straight line connecting two
/// HIFN  points.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function does not overwrite existing limit line segments. The
/// HIFN  defined segment is appended to the segment list as new segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR type/Type indicates whether the segment belongs to an Upper or a Lower
/// HIPAR type/limit line, or if the limit check at the segment is switched Off.
/// HIPAR type/Switching off the limit check does not delete the segment.
/// HIPAR startStimulus/Start Stimulus is the stimulus (x-axis) value of the first point of
/// HIPAR startStimulus/the segment (not necessarily smaller than Stop Stimulus).
/// HIPAR stopStimulus/Stop Stimulus is the stimulus (x-axis) value of the last point of the
/// HIPAR stopStimulus/segment (not necessarily larger than Start Stimulus).
/// HIPAR startResponse/Start Response is the response (y-axis) value of the first point of
/// HIPAR startResponse/the segment.
/// HIPAR stopResponse/Stop Response is the response (y-axis) value of the last point of the
/// HIPAR stopResponse/segment.
ViStatus _VI_FUNC rsznl_AddLimitLineSegment(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   segment,
                                            ViInt32   type,
                                            ViReal64  startStimulus,
                                            ViReal64  stopStimulus,
                                            ViReal64  startResponse,
                                            ViReal64  stopResponse)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  count = 0, rc_segment = 0, counter = 0;
             segment++;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSZNL_VAL_LIMIT_OFF, RSZNL_VAL_LIMIT_LOWER),
            4, "Type");

    checkErr(RsCore_GetRepCapIdItemsCount(instrSession, "LimitSegment", &count));
    if (count == 1)
    {
        checkErr(rsznl_QueryLimitLineSegmentCount(instrSession, channel, &counter));

        if (counter == 0)
            count = 0;
    }

    rc_segment = count + 1;

    snprintf(repCap_segment, RS_REPCAP_BUF_SIZE, "LimitSeg%ld", rc_segment);

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", rc_segment);

    checkErr(RsCore_AddRepCap(instrSession, "LimitSegment", repCap_segment, repCap_cmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:DATA %ld,%.12lG,%.12lG,%.12lG,%.12lG",
            channel, type, startStimulus, stopStimulus, startResponse, stopResponse);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function edits existing segment of the limit line segments list.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) A segment must be created first to enable this function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR type/Selects the limit line type for a limit line segment.
/// HIPAR startStimulus/Change the start stimulus value (i.e. the smallest stimulus value) of
/// HIPAR startStimulus/a limit line segment. A segment must be created first to enable the
/// HIPAR startStimulus/command.
/// HIPAR stopStimulus/Changes the stop stimulus value (i.e. the largest stimulus value) of a
/// HIPAR stopStimulus/limit line segment. A segment must be created first to
/// HIPAR startResponse/Changes the start response value (i.e. the response value assigned to
/// HIPAR startResponse/the start s timulus value) of a limit line segment. A segment
/// HIPAR stopResponse/Change the stop response value (i.e. the response value assigned to
/// HIPAR stopResponse/the stop stimulus value) of a limit line segment. A segment
ViStatus _VI_FUNC rsznl_EditLimitLineSegment(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   segment,
                                             ViInt32   type,
                                             ViReal64  startStimulus,
                                             ViReal64  stopStimulus,
                                             ViReal64  startResponse,
                                             ViReal64  stopResponse)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_TYPE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_TYPE,
            "Segment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_TYPE, type),
            4, "Type");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_START_STIMULUS, startStimulus),
            5, "Start Stimulus");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_STOP_STIMULUS, stopStimulus),
            6, "Stop Stimulus");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_START_RESPONSE, startResponse),
            7, "Start Response");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_STOP_RESPONSE, stopResponse),
            8, "Stop Response");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the number of limit line segments, including
/// HIFN  enabled and disabled segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segmentCount/Returns the number of limit line segments, including enabled and
/// HIPAR segmentCount/disabled segments.
ViStatus _VI_FUNC rsznl_QueryLimitLineSegmentCount(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32*  segmentCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_COUNT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_COUNT, segmentCount),
            3, "Segment Count");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns entire limit line segment list. The limit line
/// HIFN  segment is calculated as a straight line connecting the two points
/// HIFN  (<Start Stimulus>, <Start Response>) and (<Stop Stimulus>, <Stop
/// HIFN  Response>).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR listSize/Pass the maximum number of segments (segments list size) to be taken
/// HIPAR listSize/out of the segments list.
/// HIPAR segmentsCount/Returns the number of received list segments.
/// HIPAR type/Type indicates whether the segment belongs to an Upper or a Lower
/// HIPAR type/limit line, or if the limit check at the segment is switched Off.
/// HIPAR startStimulus/Start Stimulus is the stimulus (x-axis) value of the first point of
/// HIPAR startStimulus/the segment (not necessarily smaller than Stop Stimulus).
/// HIPAR stopStimulus/Stop Stimulus is the stimulus (x-axis) value of the last point of the
/// HIPAR stopStimulus/segment (not necessarily larger than Start Stimulus).
/// HIPAR startResponse/Start Response is the response (y-axis) value of the first point of
/// HIPAR startResponse/the segment.
/// HIPAR stopResponse/Stop Response is the response (y-axis) value of the last point of the
/// HIPAR stopResponse/segment.
ViStatus _VI_FUNC rsznl_ReadLimitLineSegmentList(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   listSize,
                                                 ViInt32*  segmentsCount,
                                                 ViInt32   type[],
                                                 ViReal64  startStimulus[],
                                                 ViReal64  stopStimulus[],
                                                 ViReal64  startResponse[],
                                                 ViReal64  stopResponse[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar*  prd_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i, count, j;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:DATA?", channel);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &prd_buf));

    *segmentsCount = 0;

    p2buf = prd_buf;
    do {
        p2buf = strchr(p2buf, ',');
        (*segmentsCount)++;
        if (p2buf)
            p2buf++;
    } while (p2buf);

    *segmentsCount /= 5;

    count = (listSize < *segmentsCount) ? listSize : *segmentsCount;

    p2buf = prd_buf;
    for (i = 0; i < count; i++)
    {
        (void)sscanf(p2buf, "%ld,%le,%le,%le,%le", &type[i],
            &startStimulus[i],
            &stopStimulus[i],
            &startResponse[i],
            &stopResponse[i]);
        for (j = 0; j < 5; j++)
        {
            p2buf = strchr(p2buf, ',');
            if (p2buf)
                p2buf++;
        }
    }

Error:
    if (prd_buf)
        free(prd_buf);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the stimulus values of the limit line and/or
/// HIFN  creates new limit line segments. It also defines the response (y-axis)
/// HIFN  values of the lower (upper) limit line.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function use a fixed numbering scheme for limit line
/// HIFN  segments: Upper limit line segments are assigned odd numbers (1, 3,
/// HIFN  5,...), lower limit line segments are assigned even numbers (2, 4,
/// HIFN  6,...).
/// HIFN
/// HIFN     (2) Rules for creating segments:
/// HIFN     The following rules apply to an active trace with n existing upper and
/// HIFN  n existing lower limit line segments:
/// HIFN
/// HIFN     (3) An odd number of values is rejected; an error message
/// HIFN  -109,"Missing parameter..." is generated.
/// HIFN
/// HIFN     (4) An even number of 2*k values updates or generates k lower limit
/// HIFN  line segments.
/// HIFN
/// HIFN     (5) For n > k the response values of all existing lower limit line
/// HIFN  segments no. 2, 4, ...,2*k are updated, the existing upper and lower
/// HIFN  limit line segments no. 2*k+1, ..., 2*n are deleted. The existing upper
/// HIFN  limit line segments no. 1, 3, 2*k-1 are not affected.
/// HIFN
/// HIFN     (6) For n < k the response values of the lower limit line segments no.
/// HIFN  2, 4 to 2*n are updated, the lower limit line segments 2*n+2,
/// HIFN  2*n+4,..., 2*k are generated with default stimulus values (see
/// HIFN  CALCulate<Chn>:LIMit:CONTrol[:DATA] . In addition, the missing upper
/// HIFN  limit line segments 2*n+1, 2*n+3,..., 2*k-1 are generated with default
/// HIFN  stimulus and response values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR listSize/Pass the number of segments (segments list size).
/// HIPAR type/Selects the limit line type.
/// HIPAR startStimulus/Start Stimulus is the stimulus (x-axis) value of the first point of
/// HIPAR startStimulus/the segment(s) (not necessarily smaller than Stop Stimulus).
/// HIPAR stopStimulus/Stop Stimulus is the stimulus (x-axis) value of the last point of the
/// HIPAR stopStimulus/segment(s) (not necessarily larger than Start Stimulus).
/// HIPAR startResponse/Start Response is the response (y-axis) value of the first point of
/// HIPAR startResponse/the segment(s).
/// HIPAR stopResponse/Stop Response is the response (y-axis) value of the last point of the
/// HIPAR stopResponse/segment(s).
ViStatus _VI_FUNC rsznl_WriteLimitLineSegmentList(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   listSize,
                                                  ViInt32   type,
                                                  ViReal64  startStimulus[],
                                                  ViReal64  stopStimulus[],
                                                  ViReal64  startResponse[],
                                                  ViReal64  stopResponse[])
{
    ViStatus  error = VI_SUCCESS;
    ViChar*   pbuffer = NULL;
    ViChar*   p2buf;
    ViInt32   i = 0,
    index     = 0;
    ViReal64* tempArr = NULL;

    checkErr(RsCore_LockSession(instrSession));

    /*

    Upper limit line segments are assigned odd numbers (1, 3, 5,...).
    Lower limit line segments are assigned even numbers (2, 4, 6,...).

    */

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, listSize, 1), 3, "Size of list must be greater than 0");
    checkAlloc(pbuffer = (ViChar*)malloc(RS_MAX_MESSAGE_BUF_SIZE + listSize * 8 * 4));
    checkAlloc(tempArr = malloc(listSize * 4 * sizeof(ViReal64)));  // NOLINT(bugprone-implicit-widening-of-multiplication-result)

    // --- Response data ---

    p2buf = pbuffer + sprintf(pbuffer, "CALC%ld:LIM:%sDATA ", channel, gsc_limitCheckArr[type]);

    for (i = 0; i < listSize; i++)
        p2buf += sprintf(p2buf, "%.12lG,%.12lG,", startResponse[i], stopResponse[i]);

    *--p2buf = '\0';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, pbuffer, 0));

    // --- Stimulus data ---

    checkErr(rsznl_getViReal64ArrayWindow(instrSession,
        "CALC%ld:LIM:CONT?",
        channel,
        tempArr,
        listSize * 4,
        VI_ERROR_PARAMETER4));

    p2buf = pbuffer + sprintf(pbuffer, "CALC%ld:LIM:CONT ", channel);

    index = 0;

    for (i = 0; i < listSize; i++)
    {
        if (type == RSZNL_VAL_LIMIT_LOWER)
        {
            p2buf += sprintf(p2buf, "%.12lG,%.12lG,%.12lG,%.12lG,", tempArr[index + 0], tempArr[index + 1], startStimulus[i], stopStimulus[i]);
        }
        else
        {
            p2buf += sprintf(p2buf, "%.12lG,%.12lG,%.12lG,%.12lG,", startStimulus[i], stopStimulus[i], tempArr[index + 2], tempArr[index + 3]);
        }

        index += 4;
    }

    *--p2buf = '\0';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, pbuffer, 0));

Error:
    if (pbuffer)
        free(pbuffer);
    if (tempArr)
        free(tempArr);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes all limit line segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_DeleteLimitLineSegments(ViSession instrSession,
                                                ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DELETE_LIMIT_LINE_SEGMENTS, NULL));

    checkErr(RsCore_ResetRepCapID(instrSession, "LimitSegment", rsznl_RsCoreRepCapTable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function loads a limit line definition from a specified file and
/// HIFN  assigns it to a trace with a specified name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Name of an existing trace in the active setup (string parameter). The
/// HIPAR traceName/imported limit line is assigned to this trace, irrespective of the
/// HIPAR traceName/trace information in the limit line file.
/// HIPAR fileName/String parameter to specify the name and directory of the limit line
/// HIPAR fileName/file to be loaded. The default extension (manual control) for limit
/// HIPAR fileName/line files is *.limit, although other extensions are allowed. If no
/// HIPAR fileName/path is specified the analyzer searches the current directory, to be
/// HIPAR fileName/queried with MMEMory:CDIRectory?.
/// HIPAR sParameter/This control selects an S-parameter from a Touchstone file.
/// HIPAR xOffset/This control sets the stimulus offset for limit lines loaded from a
/// HIPAR xOffset/Touchstone file. A 1 GHz offset shifts the limit line by 1 GHz in
/// HIPAR xOffset/(positive) horizontal direction.
/// HIPAR yOffset/This control sets the response offset for limit lines loaded from a
/// HIPAR yOffset/Touchstone file. A 1 dB offset shifts the limit line by 1 dB in
/// HIPAR yOffset/(positive) vertical direction.
/// HIPAR type/Selects the limit line type for a limit line segment.
ViStatus _VI_FUNC rsznl_RecallLimitLine(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViString  sParameter,
                                        ViReal64  xOffset,
                                        ViReal64  yOffset,
                                        ViInt32   type)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, RSZNL_VAL_LIMIT_OFF, RSZNL_VAL_LIMIT_LOWER),
            7, "Type");

    if (strncmp(sParameter, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:LIM '%s','%s'", traceName, fileName);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:LIM '%s','%s','%s',%.12lG,%.12lG,%s", traceName, fileName, sParameter, xOffset, yOffset,
            RsZnl_rngLimitLineType.entries[type].cmdString);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function saves the limit lines associated to a specified trace to
/// HIFN  a limit line file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Name of an existing trace in the active setup (string parameter) for
/// HIPAR traceName/which a limit line definition exists.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/limit line file. The default extension (manual control) for limit line
/// HIPAR fileName/files is *.limit, although other extensions are allowed. If no path is
/// HIPAR fileName/specified the analyzer uses the current directory, to be queried with
/// HIPAR fileName/MMEMory:CDIRectory?.
ViStatus _VI_FUNC rsznl_SaveLimitLine(ViSession instrSession,
                                      ViString  traceName,
                                      ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:LIM '%s','%s'", traceName, fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function generates an lower (upper) limit line using the stimulus
/// HIFN  values of a data or memory trace and specified offset values.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace. This trace provides
/// HIPAR channel/the stimulus data for the limit line unless another trace <trace_name>
/// HIPAR channel/is specified.
/// HIPAR limitLineType/Select limit line type.
/// HIPAR stimulusOffset/Stimulus offset value, used to shift all imported limit line segments
/// HIPAR stimulusOffset/in horizontal direction.
/// HIPAR responseOffset/Response offset value, used to shift all imported limit line segments
/// HIPAR responseOffset/in vertical direction.
/// HIPAR traceName/Name of the selected trace as used e.g. in
/// HIPAR traceName/CALCulate<Ch>:PARameter:SDEFine. If no trace name is specified the
/// HIPAR traceName/analyzer uses the active trace no. <Ch/Tr>.
ViStatus _VI_FUNC rsznl_ImportTraceAsLimitLine(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   limitLineType,
                                               ViReal64  stimulusOffset,
                                               ViReal64  responseOffset,
                                               ViString  traceName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, limitLineType, RSZNL_VAL_LIMIT_UPPER, RSZNL_VAL_LIMIT_LOWER),
            3, "limitLineType");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, stimulusOffset, -1000.0e9, 1000.0e9), 4, "Stimulus Offset");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, responseOffset, -10.0e12, 10.0e12), 5, "Response Offset");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:%s:FEED %.12lG,%.12lG,'%s'", channel,
        RsZnl_rngLimitLineSegmentType.entries[limitLineType].cmdString,
        stimulusOffset,
        responseOffset,
        traceName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a custom formula for limit line segment <Seg> of the related
/// HIFN  trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR enabled/Defines whether a custom formula is used for limit line segment <Seg>
/// HIPAR enabled/of the related trace.
/// HIPAR formula/Defines a custom formula for limit line segment <Seg> of the related
/// HIPAR formula/trace.
ViStatus _VI_FUNC rsznl_ConfigureLimitLineFormula(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   segment,
                                                  ViBoolean enabled,
                                                  ViString  formula)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA_ENABLED,
            "LimitSegment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA_ENABLED, enabled),
            4, "Enabled");

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA, formula),
            5, "Formula");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Interpolation determines whether the limit line segment is
/// HIFN  interpolated linearly or logarithmically. The latter may be more
/// HIFN  suitable for logarithmic sweeps.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR interpolation/Interpolation determines whether the limit line segment is
/// HIPAR interpolation/interpolated linearly or logarithmically. The latter may be more
/// HIPAR interpolation/suitable for logarithmic sweeps.
ViStatus _VI_FUNC rsznl_ConfigureLimitLineInterpolation(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   segment,
                                                        ViInt32   interpolation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_INTERPOLATION,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_SEGMENT_INTERPOLATION,
            "LimitSegment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_SEGMENT_INTERPOLATION, interpolation),
            4, "Interpolation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the TTL pass/fail signals on or off. The
/// HIFN  signals are applied to the USER CONTROL connector as long as the active
/// HIFN  trace <Chn> is within limits, including the ripple limits.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR outputNo/Select TTL output.
/// HIPAR ttlOutput/Sets TTL output signal on or off.
ViStatus _VI_FUNC rsznl_ConfigureLimitLineTTLPass(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   outputNo,
                                                  ViBoolean ttlOutput)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_output[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, outputNo, 1, 2),
            3, "Output No");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_TTL_PASS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_LIMIT_LINE_TTL_PASS,
            "OutputNumber", outputNo - 1, RS_REPCAP_BUF_SIZE, repCap_output),
            3, "Output No");

    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_output, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_LIMIT_LINE_TTL_PASS, ttlOutput),
            4, "TTL Output");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function displays or hides all ripple limit lines (including all
/// HIFN  ranges) associated to the active trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showRippleLimits/Switches the display line on or off.
ViStatus _VI_FUNC rsznl_ShowRippleLimits(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean showRippleLimits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SHOW_RIPPLE_LIMITS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SHOW_RIPPLE_LIMITS, showRippleLimits),
            3, "Show Ripple Limits");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the global ripple limit check on or off. This
/// HIFN  check covers all traces in the active setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR rippleCheck/Switches the limit check on or off.
/// HIPAR horizontalPosition/Selects the horizontal position of the info field.
/// HIPAR verticalPosition/Selects the vertical position of the info field.
ViStatus _VI_FUNC rsznl_ConfigureRippleCheck(ViSession instrSession,
                                             ViInt32   channel,
                                             ViBoolean rippleCheck,
                                             ViInt32   horizontalPosition,
                                             ViInt32   verticalPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, horizontalPosition, RSZNL_VAL_HORIZONTAL_LEFT, RSZNL_VAL_HORIZONTAL_RIGHT),
            4, "Horizontal Position");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, verticalPosition, RSZNL_VAL_VERTICAL_TOP, RSZNL_VAL_VERTICAL_BOTTOM),
            5, "Vertical Position");

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_CHECK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_CHECK, rippleCheck),
            3, "Ripple Check");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:RIPP:STAT:AREA %s,%s", channel,
        RsZnl_rngHorizontalPosition.entries[horizontalPosition].cmdString,
        RsZnl_rngVerticalPosition.entries[verticalPosition].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a 0 or 1, to indicate whether or not the global
/// HIFN  ripple limit check has failed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR rippleLimitCheckResult/Returns a 0 or 1, to indicate whether or not the global ripple limit
/// HIPAR rippleLimitCheckResult/check has failed.
ViStatus _VI_FUNC rsznl_QueryRippleLimitGlobalCheckResult(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32*  rippleLimitCheckResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_CHECK_RESULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_CHECK_RESULT, rippleLimitCheckResult),
            3, "Ripple Limit Check Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Clear the ripple limit check.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_ClearRippleLimitGlobalCheckResult(ViSession instrSession,
                                                          ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_CHECK_CLEAR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_CHECK_CLEAR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function enables or disables the limit check in the ripple limit
/// HIFN  range no. <Seg>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR limitCheck/Switches the limit check on or off.
ViStatus _VI_FUNC rsznl_ConfigureRippleLimitRangeSegmentCheck(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   segment,
                            ViBoolean limitCheck)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK,
            "RippleSegment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK, limitCheck),
            4, "Limit Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the result of the ripple limit check in the
/// HIFN  previously defined limit range no. <Seg>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR fail/Returns a 0 or 1, to indicate whether the LIMit test has failed or
/// HIPAR fail/not.
/// HIPAR limitCheckResult/Measured ripple in the limit range. A result is returned even if the
/// HIPAR limitCheckResult/limit check in the range no. <Seg> is disabled.
ViStatus _VI_FUNC rsznl_QueryRippleLimitCheckSegmentResult(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   segment,
                                                           ViInt32*  fail,
                                                           ViReal64* limitCheckResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];
    ViChar   rd_buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViUInt32 values_returned = 0;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:RIPP:SEGM%ld:RES?", channel, segment);
    checkErr(rsznl_QueryViString(instrSession, cmd, RS_MAX_MESSAGE_BUF_SIZE, rd_buffer, &values_returned));

    values_returned = strncmp(rd_buffer, "", 1);

    if (values_returned != 0)
    {
        p2buf = strtok(rd_buffer, ",");

        (void)sscanf(p2buf, "%ld", fail);

        p2buf = strtok(NULL, ",");

        (void)sscanf(p2buf, "%le", limitCheckResult);
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function adds and enables/disables an arbitrary number of ripple
/// HIFN  limit ranges, assigning the stimulus values and the ripple limits.
/// HIFN
/// HIFN     Note(s):
/// HIFN
/// HIFN     (1) This function does not overwrite existing ripple limit ranges. The
/// HIFN  defined ranges are appended to the range list as new ranges.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR noofValues/Set number of values for controls Type, Start Stimulus, Stop Stimulus,
/// HIPAR noofValues/Limit.
/// HIPAR type/Identifier for the type of the ripple limit range.
/// HIPAR startStimulus/Start Stimulus is the stimulus (x-axis) value of the first point of
/// HIPAR startStimulus/the segment (not necessarily smaller than Stop Stimulus).
/// HIPAR stopStimulus/Stop Stimulus is the stimulus (x-axis) value of the last point of the
/// HIPAR stopStimulus/segment (not necessarily larger than Start Stimulus).
/// HIPAR limit/Limit value, to be defined in accordance with the selected format
/// HIPAR limit/(CALCulate<Chn>:RIPPle:RDOMain:FORMat).
ViStatus _VI_FUNC rsznl_AddRippleLimitLineRangesSegment(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   noofValues,
                                                        ViInt32   type[],
                                                        ViReal64  startStimulus[],
                                                        ViReal64  stopStimulus[],
                                                        ViReal64  limit[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  count = 0, rc_segment = 0, counter = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetRepCapIdItemsCount(instrSession, "RippleSegment", &count));

    if (count == 1)
    {
        checkErr(rsznl_QueryRippleLimitRangesCount(instrSession, channel, &counter));

        if (counter == 0)
            count = 0;
    }

    rc_segment = count + 1;

    snprintf(repCap_segment, RS_REPCAP_BUF_SIZE, "RippleSeg%ld", rc_segment);

    snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", rc_segment);

    checkErr(RsCore_AddRepCap(instrSession, "RippleSegment", repCap_segment, repCap_cmd));

    p2buf = cmd + snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:RIPP:DATA ", channel);

    for (i = 0; i < noofValues; i++)
    {
        p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%ld,%.12lG,%.12lG,%.12lG,",
            type[i],
            startStimulus[i],
            stopStimulus[i],
            limit[i]);
    }

    *p2buf = '\0';

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function edits existing segment of the ripple limit line segments
/// HIFN  list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR segment/Segment number.
/// HIPAR startStimulus/Changes the start stimulus value (i.e. the smallest stimulus value) of
/// HIPAR startStimulus/a ripple limit range. A range must be created first to enable this
/// HIPAR startStimulus/command.
/// HIPAR stopStimulus/Changes the stop stimulus value (i.e. the largest stimulus values) of
/// HIPAR stopStimulus/a ripple limit range. A range must be created first to enable this
/// HIPAR stopStimulus/command.
/// HIPAR limit/Defines the ripple limit for ripple limit range no. <Seg>. A range
/// HIPAR limit/must be created first to enable.
ViStatus _VI_FUNC rsznl_EditRippleLimitLineSegment(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   segment,
                                                   ViReal64  startStimulus,
                                                   ViReal64  stopStimulus,
                                                   ViReal64  limit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_segment[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));
    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK,
            "RippleSegment", segment - 1, RS_REPCAP_BUF_SIZE, repCap_segment));
    RsCore_StrcatMaxLen(repCap, RS_REPCAP_BUF_SIZE, ",", repCap_segment, NULL);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_START_STIMULUS, startStimulus),
            4, "Start Stimulus");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_STOP_STIMULUS, stopStimulus),
            5, "Stop Stimulus");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_LIMIT, limit),
            6, "Limit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the number of ripple limit ranges.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR rippleLimitRangesCount/Returns 0 | 1 | ... - number of (enabled or disabled)) ripple limit
/// HIPAR rippleLimitRangesCount/ranges.
ViStatus _VI_FUNC rsznl_QueryRippleLimitRangesCount(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  rippleLimitRangesCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_COUNT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_COUNT, rippleLimitRangesCount),
            3, "Ripple Limit RangesCount");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function deletes all ripple limit ranges.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_DeleteAllRippleLimitRanges(ViSession instrSession,
                                                   ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", channel);

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_DELETE_ALL_RANGES, NULL));

    checkErr(RsCore_ResetRepCapID(instrSession, "RippleSegment", rsznl_RsCoreRepCapTable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function saves or recalls the ripple limits associated with a
/// HIFN  specified trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR operationtobePerformed/This control selects the type of operation to be performed.
/// HIPAR traceName/Name of an existing trace in the active setup (string parameter) for
/// HIPAR traceName/which a ripple limit definition exists.
/// HIPAR fileName/String parameter to specify the name and directory of the created
/// HIPAR fileName/ripple limit file.
ViStatus _VI_FUNC rsznl_SaveRecallRippleLimit(ViSession instrSession,
                                              ViInt32   operationtobePerformed,
                                              ViString  traceName,
                                              ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    switch (operationtobePerformed)
    {
    case RSZNL_VAL_SAVE:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:RIPP '%s','%s'", traceName, fileName);
        break;

    case RSZNL_VAL_RECALL:
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:RIPP '%s','%s'", traceName, fileName);
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, operationtobePerformed), 2, "Operation to be Performed");
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a 0 or 1 to indicate whether or not the global ripple limit
/// HIFN  check has failed for at least one channel in the referenced channel
/// HIFN  setup. 0 represents pass and 1 represents fail.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR setup/Name of a VNA channel setup.
/// HIPAR result/Returns a 0 or 1 to indicate whether or not the limit line check has
/// HIPAR result/failed for at least one channel in the referenced channel setup. 0
/// HIPAR result/represents pass and 1 represents fail.
ViStatus _VI_FUNC rsznl_QueryRippleLimitCheckResultChannel(ViSession instrSession,
                                                           ViString  setup,
                                                           ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (strncmp(setup, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:RIPP:FAIL:ALL?");
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:RIPP:FAIL:ALL? '%s'", setup);
    }

    checkErr(rsznl_QueryViInt32(instrSession, cmd, result));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIFN  generated each time the analyzer detects an exceeded ripple limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR failBeep/Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIPAR failBeep/generated each time the analyzer detects an exceeded ripple limit.
ViStatus _VI_FUNC rsznl_ConfigureRippleLimitLineFailBeep(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean failBeep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_LINE_FAIL_BEEP,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_LINE_FAIL_BEEP, failBeep),
            3, "Fail Beep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the display of ripple check info fields for the active
/// HIFN  channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR showResultsAllTraces/Configures the display of ripple check info fields for the active
/// HIPAR showResultsAllTraces/channel setup.
ViStatus _VI_FUNC rsznl_ConfigureRippleLimitLineShowResultsAllTraces(
                            ViSession instrSession,
                            ViBoolean showResultsAllTraces)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_RIPPLE_LIMIT_LINE_SHOW_RESULTS_ALL_TRACES, showResultsAllTraces),
            2, "Show Results All Traces");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the existing ripple limit ranges and (re-)defines the physical
/// HIFN  units of the stimulus values of the ripple limit lines. The unit of the
/// HIFN  ripple limit is defined via RSZNL_ATTR_RIPPLE_LIMIT_RESPONSE_UNIT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR unit/Deletes the existing ripple limit ranges and (re-)defines the physical
/// HIPAR unit/units of the stimulus values of the ripple limit lines. The unit of the
/// HIPAR unit/ripple limit is defined via RSZNL_ATTR_RIPPLE_LIMIT_RESPONSE_UNIT.
ViStatus _VI_FUNC rsznl_ConfigureRippleLimitStimulusUnit(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   unit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_STIMULUS_UNIT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_STIMULUS_UNIT, unit),
            3, "Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the existing ripple limit ranges and (re-)defines the physical
/// HIFN  unit of the ripple limit. The units of the stimulus values are defined
/// HIFN  via RSZNL_ATTR_RIPPLE_LIMIT_STIMULUS_UNIT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR unit/Deletes the existing ripple limit ranges and (re-)defines the physical
/// HIPAR unit/unit of the ripple limit. The units of the stimulus values are defined
/// HIPAR unit/via RSZNL_ATTR_RIPPLE_LIMIT_STIMULUS_UNIT.
ViStatus _VI_FUNC rsznl_ConfigureRippleLimitResponseUnit(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   unit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_RIPPLE_LIMIT_RESPONSE_UNIT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_RIPPLE_LIMIT_RESPONSE_UNIT, unit),
            3, "Unit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function displays or hides the circle limit line associated to
/// HIFN  the active trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showCircleLimitLine/Switches the display line on or off.
ViStatus _VI_FUNC rsznl_ShowCircleLimits(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean showCircleLimitLine)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_SHOW_CIRCLE_LIMITS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_SHOW_CIRCLE_LIMITS, showCircleLimitLine),
            3, "Show Circle Limit Line");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the circle limit check on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR rippleCheck/Switches the limit check on or off.
ViStatus _VI_FUNC rsznl_ConfigureCircleLimitCheck(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViBoolean circleLimitCheck)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel, 1), 2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CIRCLE_LIMIT_CHECK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CIRCLE_LIMIT_CHECK, circleLimitCheck),
            3, "Ripple Check");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines a circle limit lines by its center coordinates
/// HIFN  and its radius.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR centerX/Defines the limit circle by its center on the x-axis.
/// HIPAR centerY/Defines the limit circle by its center on the y-axis.
/// HIPAR radius/Defines the limit circle by its radius.
ViStatus _VI_FUNC rsznl_ConfigureCircleLimitLine(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  centerX,
                                                 ViReal64  centerY,
                                                 ViReal64  radius)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel, 1), 2, "Channel");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:CIRC:DATA %.12lG,%.12lG,%.12lG", channel, centerX, centerY, radius);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns a 0 or 1, to indicate whether or not the circle
/// HIFN  limit check has failed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR circleLimitCheckResult/Returns a 0 or 1, to indicate whether or not the circle limit check
/// HIPAR circleLimitCheckResult/has failed.
ViStatus _VI_FUNC rsznl_QueryCircleLimitCheckResult(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  circleLimitCheckResult)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, channel, 1), 2, "Channel");
    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CIRCLE_LIMIT_CHECK_RESULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_CIRCLE_LIMIT_CHECK_RESULT, circleLimitCheckResult),
            3, "Circle Limit Check Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Clear the circle limit lines.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_ClearCircleLimitCheckResult(ViSession instrSession,
                                                    ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CIRCLE_LIMIT_CHECK_CLEAR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_CIRCLE_LIMIT_CHECK_CLEAR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a 0 or 1 to indicate whether or not the circle limit check has
/// HIFN  failed for at least one channel in the referenced channel setup. 0
/// HIFN  represents pass and 1 represents fail.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR setup/Name of a VNA channel setup.
/// HIPAR result/Returns a 0 or 1 to indicate whether or not the limit line check has
/// HIPAR result/failed for at least one channel in the referenced channel setup. 0
/// HIPAR result/represents pass and 1 represents fail.
ViStatus _VI_FUNC rsznl_QueryCircleLimitCheckResultChannel(ViSession instrSession,
                                                           ViString  setup,
                                                           ViInt32*  result)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (strncmp(setup, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM:CIRC:FAIL:ALL?");
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:LIM:CIRC:FAIL:ALL? '%s'", setup);
    }

    checkErr(rsznl_QueryViInt32(instrSession, cmd, result));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIFN  generated each time the analyzer detects an exceeded circle limit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR circleFailBeep/Switches the acoustic signal (fail beep) on or off. The fail beep is
/// HIPAR circleFailBeep/generated each time the analyzer detects an exceeded circle limit.
ViStatus _VI_FUNC rsznl_ConfigureCircleFailBeep(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean circleFailBeep)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_CIRCLE_FAIL_BEEP,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_CIRCLE_FAIL_BEEP, circleFailBeep),
            3, "Circle Fail Beep");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets/queries the visibility of the display circle for the active trace
/// HIFN  of channel <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR showBorder/Sets/queries the visibility of the display circle for the active trace
/// HIPAR showBorder/of channel <Chn>.
ViStatus _VI_FUNC rsznl_ConfigureDisplayCircleShowBorder(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean showBorder)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_CIRCLE_SHOW_BORDER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DISPLAY_CIRCLE_SHOW_BORDER, showBorder),
            3, "Show Border");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets/queries the state of the display circle for the active trace of
/// HIFN  channel <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR limitToCircle/Sets/queries the state of the display circle for the active trace of
/// HIPAR limitToCircle/channel <Chn>.
ViStatus _VI_FUNC rsznl_ConfigureDisplayCircleLimitToCircle(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean limitToCircle)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_CIRCLE_LIMIT_TO_CIRCLE_ON_OFF,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_DISPLAY_CIRCLE_LIMIT_TO_CIRCLE_ON_OFF, limitToCircle),
            3, "Limit To Circle");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the display circle for the active trace of channel <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
/// HIPAR centerX/Defines the limit circle by its center on the x-axis.
/// HIPAR centerY/Defines the limit circle by its center on the y-axis.
/// HIPAR radius/Defines the limit circle by its radius.
ViStatus _VI_FUNC rsznl_ConfigureDisplayCircle(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  centerX,
                                               ViReal64  centerY,
                                               ViReal64  radius)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC%ld:LIM:DCIR:DATA %.12lG,%.12lG,,%.12lG", channel, centerX, centerY, radius);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the display circle to its default configuration (unit circle;
/// HIFN  show border: off; limit to circle: off).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number used to identify the active trace.
ViStatus _VI_FUNC rsznl_DisplayCircleClear(ViSession instrSession,
                                           ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_DISPLAY_CIRCLE_CLEAR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap),
            2, "Channel");

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_DISPLAY_CIRCLE_CLEAR, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the default storage device used by all file system commands.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selectedStorageDevice/Selects the default storage device used by all file system commands.
ViStatus _VI_FUNC rsznl_ConfigureDataSelectedStorageDevice(ViSession instrSession,
                                                           ViString  selectedStorageDevice)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_SELECTED_STORAGE_DEVICE, selectedStorageDevice),
            2, "Selected Storage Device");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selectedDirectory/Changes the current directory.
ViStatus _VI_FUNC rsznl_ConfigureDataSelectedDirectory(ViSession instrSession,
                                                       ViString  selectedDirectory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_SELECTED_DIRECTORY, selectedDirectory),
            2, "Selected Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a new directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Creates a new directory.
ViStatus _VI_FUNC rsznl_DataCreateDirectory(ViSession instrSession,
                                            ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_CREATE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of a particular directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/String containing the path and directory
/// HIPAR arraySize/Defines the memory size allocated for Content.
/// HIPAR contents/Returns the contents of a particular directory.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryDataDirectoryContents(ViSession instrSession,
                                                   ViString  directory,
                                                   ViUInt32  arraySize,
                                                   ViChar    contents[],
                                                   ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CAT? '%s'", directory);
    checkErr(rsznl_QueryViString(instrSession, cmd, arraySize, contents, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the contents of a particular directory with additional
/// HIFN  information about the files.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/String containing the path and directory
/// HIPAR arraySize/Defines the memory size allocated for Content.
/// HIPAR contents/Returns the contents of a particular directory.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryDataDirectoryAdditionalContents(ViSession instrSession,
                                                             ViString  directory,
                                                             ViUInt32  arraySize,
                                                             ViChar    contents[],
                                                             ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CAT:LONG? '%s'", directory);
    checkErr(rsznl_QueryViString(instrSession, cmd, arraySize, contents, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the indicated directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Deletes the indicated directory.
ViStatus _VI_FUNC rsznl_DataDeleteDirectory(ViSession instrSession,
                                            ViString  directory)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_DELETE_DIRECTORY, directory),
            2, "Directory");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Has several purposes, depending on the context it is used in.
/// HIFN     It creates a new and empty file. It defines the file name for
/// HIFN  screenshots taken with RSZNL_ATTR_HCOPY_PRINT. Note that you have to
/// HIFN  route the printer output to a file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dataFileName/Has several purposes, depending on the context it is used in.
ViStatus _VI_FUNC rsznl_ConfigureDataFileName(ViSession instrSession,
                                              ViString  dataFileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_FILE_NAME, dataFileName),
            2, "Data File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a comment for the stored settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR comment/Defines a comment for the stored settings.
ViStatus _VI_FUNC rsznl_ConfigureDataFileNameComment(ViSession instrSession,
                                                     ViString  comment)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_FILE_NAME_COMMENT, comment),
            2, "Comment");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the decimal separator for data exported in ASCII format.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR decimalSeparator/Selects the decimal separator for data exported in ASCII format.
ViStatus _VI_FUNC rsznl_ConfigureDataDecimalSeparator(ViSession instrSession,
                                                      ViInt32   decimalSeparator)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_DATA_DECIMAL_SEPARATOR, decimalSeparator),
            2, "Decimal Separator");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This method copies one or more files to another directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sourceFile/String containing the path and file name of the source file.
/// HIPAR destinationFile/String containing the path and name of the target file.
ViStatus _VI_FUNC rsznl_DataCopyFile(ViSession instrSession,
                                     ViString  sourceFile,
                                     ViString  destinationFile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:COPY '%s','%s'", sourceFile, destinationFile);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This method moves a file to another directory.
/// HIFN
/// HIFN     This method also renames the file if you define a new name in the
/// HIFN  target directory.
/// HIFN
/// HIFN     If you do not include a path for <NewFileName>, the method just
/// HIFN  renames the file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR sourceFile/String containing the path and file name of the source file.
/// HIPAR newFileName/String containing the path and name of the target file.
ViStatus _VI_FUNC rsznl_DataMoveFile(ViSession instrSession,
                                     ViString  sourceFile,
                                     ViString  newFileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:MOVE '%s','%s'", sourceFile, newFileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes a file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Deletes a file.
ViStatus _VI_FUNC rsznl_DataDeleteFile(ViSession instrSession,
                                       ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_DELETE, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Maps a drive to a server or server directory of the network.
/// HIFN     Note that you have to allow sharing for a server or folder in
/// HIFN  Microsoft networks first.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR drive/String containing the drive name or path of the directory you want to
/// HIPAR drive/map.
/// HIPAR hostname/String containing the host name of the computer or the IP address and
/// HIPAR hostname/the share name of the drive.
/// HIPAR username/String containing a user name in the network.
/// HIPAR password/String containing the password corresponding to the <UserName>.
/// HIPAR reconnect/Reconnects at logon with the same user name.
ViStatus _VI_FUNC rsznl_DataNetworkMapDrive(ViSession instrSession,
                                            ViString  drive,
                                            ViString  hostname,
                                            ViString  username,
                                            ViString  password,
                                            ViBoolean reconnect)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:NETW:MAP '%s','%s','%s','%s',%s", drive,
        hostname,
        username,
        password,
        reconnect ? "ON" : "OFF");
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Disconnects a network drive.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR drive/String containing the drive name.
/// HIPAR force/Determines whether disconnection is forced or not.
ViStatus _VI_FUNC rsznl_DataNetworkDisconnectDrive(ViSession instrSession,
                                                   ViString  drive,
                                                   ViBoolean force)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:NETW:DISC '%s',%s", drive,
        force ? "ON" : "OFF");
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a list of unused network drives.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Unused Drives.
/// HIPAR unusedDrives/Returns a list of unused network drives.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryDataNetworkUnusedDrives(ViSession instrSession,
                                                     ViUInt32  arraySize,
                                                     ViChar    unusedDrives[],
                                                     ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_NETWORK_UNUSED_DRIVES,
            arraySize, unusedDrives),
            3, "Unused Drives");

    *returnedValues = (ViUInt32)strlen(unusedDrives);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns a list of all network drives in use.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Used Drives.
/// HIPAR usedDrives/Returns a list of all network drives in use.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryDataNetworkUsedDrives(ViSession instrSession,
                                                   ViUInt32  arraySize,
                                                   ViChar    usedDrives[],
                                                   ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_NETWORK_USED_DRIVES,
            arraySize, usedDrives),
            3, "Used Drives");

    *returnedValues = (ViUInt32)strlen(usedDrives);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines whether the data from the entire instrument or only from the
/// HIFN  current channel setup is stored with the subsequent instrument settings
/// HIFN  methods and attributes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR settingsMode/Defines whether the data from the entire instrument or only from the
/// HIPAR settingsMode/current channel setup is stored with the subsequent instrument settings
/// HIPAR settingsMode/methods and controls.
ViStatus _VI_FUNC rsznl_ConfigureDataInstrumentSettingsMode(ViSession instrSession,
                                                            ViInt32   settingsMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_MODE, settingsMode),
            2, "Settings Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes all instrument configuration files in the current directory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsDeleteAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_DELETE_ALL, NULL),
            2, "Data Instrument Settings Delete All");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes an instrument configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/String containing the path and name of the file to delete. The string
/// HIPAR fileName/may or may not contain the file's extension.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsDelete(ViSession instrSession,
                                                     ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:CLE:STAT 1,'%s'", fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Restores an instrument configuration and defines that configuration as
/// HIFN  the default state.
/// HIFN     The default state is restored after a preset or after you turn on the
/// HIFN  instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/String containing the path and name of the configuration file.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsStartupRecall(ViSession instrSession,
                                                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:AUTO 1,'%s'", fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines whether the channel setups that will be loaded
/// HIFN  with the subsequent MMEM:LOAD:STAT command will replace the current
/// HIFN  channel setup or activate a new channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR recallMode/Defines whether the channel setups that will be loaded
/// HIPAR recallMode/with the subsequent MMEM:LOAD:STAT command will replace the current
/// HIPAR recallMode/channel setup or activate a new channel setup.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsRecallMode(ViSession instrSession,
                                                         ViInt32   recallMode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_RECALL_MODE, recallMode),
            2, "Recall Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Restores and activates the instrument configuration stored in a *.dfl
/// HIFN  file.
/// HIFN     Note that files with other formats cannot be loaded with this method.
/// HIFN     The contents that are reloaded from the file are defined by the last
/// HIFN  selection made either in the Save/Recall dialogs (manual operation) or
/// HIFN  through the Items To Store attributes (remote operation; the settings
/// HIFN  are identical in both cases).
/// HIFN     By default, the selection is limited to the HW Settings. The selection
/// HIFN  is not reset by Preset or *RST.
/// HIFN     As a consequence, the results of a SCPI script using the Recall method
/// HIFN  without a previous Items To Store attribute may vary, depending on
/// HIFN  previous actions in the GUI or in previous scripts, even if the script
/// HIFN  starts with the *RST command.
/// HIFN     It is therefore recommended that you use the appropriate Items To
/// HIFN  Store attribute before using this method.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/String containing the path and name of the file to load. The string
/// HIPAR fileName/may or may not include the file's extension.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsRecall(ViSession instrSession,
                                                     ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:LOAD:STAT 1,'%s'", fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));
    checkErr(rsznl_SynchronizeDynamicRepeatedCapability(instrSession, RSZNL_VAL_ALL_REP_CAPS));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current instrument configuration in a *.dfl file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/String containing the path and name of the target file. The file
/// HIPAR fileName/extension is .dfl.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsSave(ViSession instrSession,
                                                   ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:STOR:STAT 1,'%s'", fileName);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the current instrument configuration in a *.dfl file.
/// HIFN     The file name depends on the one you have set with Save method. Adds a
/// HIFN  consecutive number to the file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_DataInstrumentSettingsSaveNext(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_SAVE_NEXT, NULL),
            2, "Data Instrument Settings Save Next");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the current settings as the only item to store to and load
/// HIFN  from a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentDefault(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_DEFAULT, NULL),
            2, "Items To Store Instrument Default");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Includes all items when storing or loading a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_ALL, NULL),
            2, "Items To Store Instrument All");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Does not include any of the following items when storing or loading a
/// HIFN  configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentNone(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_NONE, NULL),
            2, "Items To Store Instrument None");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures which information shall be part of stored configuration
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hwSettingsEnabled/Includes or excludes measurement (hardware) settings when storing or
/// HIPAR hwSettingsEnabled/loading a configuration file.
/// HIPAR limitLinesEnabled/Includes or excludes all limit lines (active and inactive) when
/// HIPAR limitLinesEnabled/storing or loading a configuration file.
/// HIPAR spectrogramDataEnabled/Includes or excludes spectrogram data when storing or loading a
/// HIPAR spectrogramDataEnabled/configuration file.
/// HIPAR traceDataEnabled/Includes or excludes trace data when storing or loading a
/// HIPAR traceDataEnabled/configuration file.
/// HIPAR transducerFactorsEnabled/Includes or excludes transducer factors when storing or loading a
/// HIPAR transducerFactorsEnabled/configuration file.
ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreInstrument(ViSession instrSession,
                                                        ViBoolean hwSettingsEnabled,
                                                        ViBoolean limitLinesEnabled,
                                                        ViBoolean spectrogramDataEnabled,
                                                        ViBoolean traceDataEnabled,
                                                        ViBoolean transducerFactorsEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_HW_SETTINGS_ENABLED, hwSettingsEnabled),
            2, "HW Settings Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_LIMIT_LINES_ENABLED, limitLinesEnabled),
            3, "Limit Lines Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_SPECTROGRAM_DATA_ENABLED, spectrogramDataEnabled),
            4, "Spectrogram Data Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_TRACE_DATA_ENABLED, traceDataEnabled),
            5, "Trace Data Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_TRANSDUCER_FACTORS_ENABLED, transducerFactorsEnabled),
            6, "Transducer Factors Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the current settings as the only item to store to and load
/// HIFN  from a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreChannelDefault(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_DEFAULT, NULL),
            2, "Items To Store Channel Default");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Includes all items when storing or loading a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreChannelAll(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_ALL, NULL),
            2, "Items To Store Channel All");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Does not include any of the following items when storing or loading a
/// HIFN  configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ItemsToStoreChannelNone(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_NONE, NULL),
            2, "Items To Store Channel None");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures which information shall be part of stored configuration
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hwSettingsEnabled/Includes or excludes measurement (hardware) settings when storing or
/// HIPAR hwSettingsEnabled/loading a configuration file.
/// HIPAR limitLinesEnabled/Includes or excludes all limit lines (active and inactive) when
/// HIPAR limitLinesEnabled/storing or loading a configuration file.
/// HIPAR spectrogramDataEnabled/Includes or excludes spectrogram data when storing or loading a
/// HIPAR spectrogramDataEnabled/configuration file.
/// HIPAR traceDataEnabled/Includes or excludes trace data when storing or loading a
/// HIPAR traceDataEnabled/configuration file.
/// HIPAR transducerFactorsEnabled/Includes or excludes transducer factors when storing or loading a
/// HIPAR transducerFactorsEnabled/configuration file.
ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreChannel(ViSession instrSession,
                                                     ViBoolean hwSettingsEnabled,
                                                     ViBoolean limitLinesEnabled,
                                                     ViBoolean spectrogramDataEnabled,
                                                     ViBoolean traceDataEnabled,
                                                     ViBoolean transducerFactorsEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_HW_SETTINGS_ENABLED, hwSettingsEnabled),
            2, "HW Settings Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_LIMIT_LINES_ENABLED, limitLinesEnabled),
            3, "Limit Lines Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_SPECTROGRAM_DATA_ENABLED, spectrogramDataEnabled),
            4, "Spectrogram Data Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_TRACE_DATA_ENABLED, traceDataEnabled),
            5, "Trace Data Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_TRANSDUCER_FACTORS_ENABLED, transducerFactorsEnabled),
            6, "Transducer Factors Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Aborts a running hardcopy output.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_HcopyAbort(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_ABORT, NULL),
            2, "Hcopy Abort");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates a print job.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_HcopyPrint(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT, NULL),
            2, "Hcopy Print");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates a print job. Adds a consecutive number to the file name.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_HcopyPrintNext(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_NEXT, NULL),
            2, "Hcopy Print Next");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Determines the content included in the printout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR contentType/Determines the type of content included in the printout.
/// HIPAR comment/Defines an optional comment to be included in the printout of the
/// HIPAR comment/display. Maximum 120 characters are allowed. Up to 60 characters fit in
/// HIPAR comment/one line. In the first line, a manual line-feed can be forced at any
/// HIPAR comment/point by entering @.
/// HIPAR logoEnabled/Activates/deactivates the printout of the Rohde & Schwarz company logo
/// HIPAR logoEnabled/at the top of each page.
/// HIPAR pageCountEnabled/Includes or excludes the page number for printouts consisting of
/// HIPAR pageCountEnabled/multiple pages.
/// HIPAR dateAndTimeEnabled/Includes or excludes the time and date in the printout.
ViStatus _VI_FUNC rsznl_ConfigureHcopyContent(ViSession instrSession,
                                              ViInt32   contentType,
                                              ViString  comment,
                                              ViBoolean logoEnabled,
                                              ViBoolean pageCountEnabled,
                                              ViBoolean dateAndTimeEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_CONTENT_TYPE, contentType),
            2, "Content Type");

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_COMMENT, comment),
            3, "Comment");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_LOGO_ENABLED, logoEnabled),
            4, "Logo Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_COUNT_ENABLED, pageCountEnabled),
            5, "Page Count Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_DATE_AND_TIME_ENABLED, dateAndTimeEnabled),
            6, "Date And Time Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the windows to be included in the printout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelName/String containing the name of the channel setup.
/// HIPAR windowName/String containing the name of the existing window.
/// HIPAR windowEnabled/Defines whether window is included in printout.
ViStatus _VI_FUNC rsznl_ConfigureHcopyWindowPrintout(ViSession instrSession,
                                                     ViString  channelName,
                                                     ViString  windowName,
                                                     ViBoolean windowEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "HCOP:PAGE:WIND1:STAT '%s','%s',%s", channelName, windowName, windowEnabled ? "ON" : "OFF");
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects all windows of the specified channel setup to be included in
/// HIFN  the printout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channelName/String containing the name of the channel setup.
/// HIPAR channelEnabled/Defines whether window is included in printout.
ViStatus _VI_FUNC rsznl_ConfigureHcopyChannelPrintout(ViSession instrSession,
                                                      ViString  channelName,
                                                      ViBoolean channelEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "HCOP:PAGE:WIND1:CHAN:STAT '%s',%s", channelName, channelEnabled ? "ON" : "OFF");
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the complete screen contents to be printed, including the logo, time,
/// HIFN  and the marker list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintAllHeaders(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_ALL_HEADERS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the screen contents to be printed, the logo
/// HIFN  (RSZNL_ATTR_HCOPY_PRINT_LOGO), time (RSZNL_ATTR_HCOPY_PRINT_TIME), and
/// HIFN  the marker list (RSZNL_ATTR_HCOPY_PRINT_MARKER_LIST).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR logoEnabled/Activates/deactivates the printout of the Rohde & Schwarz company
/// HIPAR logoEnabled/logo at the top of each page.
/// HIPAR markerListEnabled/Activates/deactivates the printout of the marker list.
/// HIPAR timeEnabled/Activates/deactivates the printout of the time.
ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintHeaders(ViSession instrSession,
                                                   ViBoolean logoEnabled,
                                                   ViBoolean markerListEnabled,
                                                   ViBoolean timeEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_LOGO, logoEnabled),
            2, "Logo Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_MARKER_LIST, markerListEnabled),
            3, "Marker List Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_TIME, timeEnabled),
            4, "Time Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines how the diagrams shall be printed
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR printDiagramArea/Defines how the diagrams shall be printed
ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintDiagramArea(ViSession instrSession,
                                                       ViInt32   printDiagramArea)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_PRINT_DIAGRAM_AREA, printDiagramArea),
            2, "Print Diagram Area");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the destination of a print job.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR destination/Selects the destination of a print job.
ViStatus _VI_FUNC rsznl_ConfigureHcopyDestination(ViSession instrSession,
                                                  ViInt32   destination)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_DESTINATION, destination),
            2, "Destination");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the printer that processes jobs sent by the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selectedPrinter/Selects the printer that processes jobs sent by the instrument.
ViStatus _VI_FUNC rsznl_ConfigureHcopySelectedPrinter(ViSession instrSession,
                                                      ViString  selectedPrinter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_SELECTED_PRINTER, selectedPrinter),
            2, "Selected Printer");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the file format for a print job.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hcopyFileFormat/Selects the file format for a print job.
ViStatus _VI_FUNC rsznl_HcopyFileFormat(ViSession instrSession,
                                        ViInt32   hcopyFileFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_FILE_FORMAT, hcopyFileFormat),
            2, "HCopy File Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the name of the first available printer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for First Printer.
/// HIPAR firstPrinter/Queries the name of the first available printer.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryHcopyFirstPrinter(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    firstPrinter[],
                                               ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_FIRST_PRINTER,
            arraySize, firstPrinter),
            2, "First Printer");
    *returnedValues = (ViUInt32)strlen(firstPrinter);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the name of available printers.
/// HIFN     You have to use RSZNL_ATTR_HCOPY_FIRST_PRINTER/FirstPrinter for this
/// HIFN  attribute to work properly.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Next Printer.
/// HIPAR nextPrinter/Queries the name of available printers.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryHcopyNextPrinter(ViSession instrSession,
                                              ViUInt32  arraySize,
                                              ViChar    nextPrinter[],
                                              ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_HCOPY_NEXT_PRINTER,
            arraySize, nextPrinter),
            2, "Next Printer");
    *returnedValues = (ViUInt32)strlen(nextPrinter);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the page orientation of the printout.
/// HIFN     The attribute is only available if the output device is a printer or a
/// HIFN  PDF file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR pageOrientation/Selects the page orientation of the printout.
ViStatus _VI_FUNC rsznl_ConfigureHcopyPageOrientation(ViSession instrSession,
                                                      ViInt32   pageOrientation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_ORIENTATION, pageOrientation),
            2, "Page Orientation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how many windows are displayed on a single page of the
/// HIFN  printout for Windows content type.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR windowsPerPage/Defines how many windows are displayed on a single page of the
/// HIPAR windowsPerPage/printout for Windows content type.
ViStatus _VI_FUNC rsznl_ConfigureHcopyWindowsPerPage(ViSession instrSession,
                                                     ViInt32   windowsPerPage)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_WINDOWS_PER_PAGE, windowsPerPage),
            2, "Windows Per Page");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Determines the scaling of the windows in the printout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR scaleToFitEnabled/Determines the scaling of the windows in the printout.
ViStatus _VI_FUNC rsznl_ConfigureHcopyPageScaleToFitEnabled(ViSession instrSession,
                                                            ViBoolean scaleToFitEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_SCALE_TO_FIT_ENABLED, scaleToFitEnabled),
            2, "Scale To Fit Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the page margin.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR unit/Defines the unit in which the margins for the printout page are
/// HIPAR unit/configured.
/// HIPAR bottom/Defines the margin at the bottom of the printout page on which no
/// HIPAR bottom/elements are printed. The margins are defined according to
/// HIPAR bottom/RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT.
/// HIPAR left/Defines the margin at the left side of the printout page on which no
/// HIPAR left/elements are printed. The margins are defined according to
/// HIPAR left/RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT.
/// HIPAR right/Defines the margin at the right side of the printout page on which no
/// HIPAR right/elements are printed. The margins are defined according to
/// HIPAR right/RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT.
/// HIPAR top/Defines the margin at the top of the printout page on which no
/// HIPAR top/elements are printed. The margins are defined according to
/// HIPAR top/RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT.
ViStatus _VI_FUNC rsznl_ConfigureHcopyPageMargin(ViSession instrSession,
                                                 ViInt32   unit,
                                                 ViReal64  bottom,
                                                 ViReal64  left,
                                                 ViReal64  right,
                                                 ViReal64  top)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT, unit),
            2, "Unit");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_MARGIN_BOTTOM, bottom),
            3, "Bottom");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_MARGIN_LEFT, left),
            4, "Left");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_MARGIN_RIGHT, right),
            5, "Right");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_HCOPY_PAGE_MARGIN_TOP, top),
            6, "Top");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Turns color printing on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR colorPrintingEnabled/Turns color printing on and off.
ViStatus _VI_FUNC rsznl_ConfigureHcopyColorPrinting(ViSession instrSession,
                                                    ViBoolean colorPrintingEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_HCOPY_COLOR_PRINTING_ENABLED, colorPrintingEnabled),
            2, "Color Printing Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the color scheme for print jobs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR color/Selects the color.
ViStatus _VI_FUNC rsznl_ResetHcopyColorScheme(ViSession instrSession,
                                              ViInt32   displayItem,
                                              ViInt32   color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, color, 1, 4),
            3, "Color");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DISP:CMAP%ld:DEF%ld", displayItem, color);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the color for various screen elements in print jobs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR tint/Tint
/// HIPAR saturation/Saturation
/// HIPAR brightness/Brightness
ViStatus _VI_FUNC rsznl_SelectHcopyColor(ViSession instrSession,
                                         ViInt32   displayItem,
                                         ViReal64  tint,
                                         ViReal64  saturation,
                                         ViReal64  brightness)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, tint, 0.0, 1.0), 3, "Tint");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, saturation, 0.0, 1.0), 4, "Saturation");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, brightness, 0.0, 1.0), 5, "Brightness");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "HCOP:CMAP%ld:HSL %.12lG,%.12lG,%.12lG", displayItem, tint,
        saturation, brightness);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects a predefined color for various screen elements in print jobs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayItem/Selects the item for which the color scheme is to be defined.
/// HIPAR color/Selects the color.
ViStatus _VI_FUNC rsznl_SelectHcopyPredefinedColor(ViSession instrSession,
                                                   ViInt32   displayItem,
                                                   ViInt32   color)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, displayItem, RSZNL_VAL_CMAP1, RSZNL_VAL_CMAP41),
            2, "Display Item");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, color, RSZNL_VAL_COLOR_BLACK, RSZNL_VAL_COLOR_LMAGENTA),
            3, "Color");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "HCOP:CMAP%ld:PDEF %s", displayItem, RsZnl_rngPredefinedColor.entries[color].cmdString);
    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates a calibration (self-alignment) routine and queries if
/// HIFN  calibration was successful. During the acquisition of correction data
/// HIFN  the instrument does not accept any remote control commands. In order to
/// HIFN  recognize when the acquisition of correction data is completed, the MAV
/// HIFN  bit in the status byte can be used. If the associated bit is set in the
/// HIFN  Service Request Enable (SRE) register, the instrument generates a
/// HIFN  service request after the acquisition of correction data has been
/// HIFN  completed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrate/Calibration query
ViStatus _VI_FUNC rsznl_Calibrate(ViSession instrSession,
                                  ViInt32*  calibrate)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_INITIATE_CALIBRATION, calibrate),
            2, "Calibrate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This command returns the results collected during calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Self Test Results.
/// HIPAR calibrationResult/This command returns the results collected during calibration.
/// HIPAR returnedValues/Number of returned values.
ViStatus _VI_FUNC rsznl_QueryCalibrationResult(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    calibrationResult[],
                                               ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_RESULTS,
            arraySize, calibrationResult),
            3, "Calibration Result");

    *returnedValues = (ViUInt32)strlen(calibrationResult);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the frequency of the calibration signal.
/// HIFN     Possible frequencies of the calibration signal are fix.
/// HIFN     If you define a frequency that is not available, the instrument uses
/// HIFN  the next available frequency. Example: a frequency of 20 MHz is rounded
/// HIFN  up to the next available frequency (25 MHz).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationSignalFrequency/Defines the frequency of the calibration signal.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationSignalFrequency(ViSession instrSession,
                                                            ViReal64  calibrationSignalFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_CALIBRATION_SIGNAL_FREQUENCY, calibrationSignalFrequency),
            2, "Calibration Signal Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates or deactivates the use of an internal calibration signal as
/// HIFN  input for the R&S ZNL/ZNLE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationInputSource/Activates or deactivates the use of an internal calibration signal as
/// HIPAR calibrationInputSource/input for the R&S ZNL/ZNLE.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationInputSource(ViSession instrSession,
                                                        ViInt32   calibrationInputSource)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_CALIBRATION_INPUT_SOURCE, calibrationInputSource),
            2, "Calibration Input Source");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This attribute queries the current frontend temperature of the
/// HIFN  instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR frontendTemperature/This control queries the current frontend temperature of the
/// HIPAR frontendTemperature/instrument.
ViStatus _VI_FUNC rsznl_QueryFrontendTemperature(ViSession instrSession,
                                                 ViReal64* frontendTemperature)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_FRONTEND_TEMPERATURE, frontendTemperature),
            2, "Frontend Temperature");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This attribute reads the results of the selftest out of the
/// HIFN  instrument. The lines of the result table are output as string data
/// HIFN  separated by commas.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Self Test Results.
/// HIPAR selfTestResults/This control reads the results of the selftest out of the instrument.
/// HIPAR selfTestResults/The lines of the result table are output as string data separated by
/// HIPAR selfTestResults/commas.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QuerySelfTestResults(ViSession instrSession,
                                             ViUInt32  arraySize,
                                             ViChar    selfTestResults[],
                                             ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_QueryViString(instrSession, "DIAG:SERV:STES:RES?", arraySize, selfTestResults, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the days on which a self-alignment is scheduled for
/// HIFN  CalibrationDueSchedule. Up to 7 different days can be scheduled.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CALibration:DUE:DAYS
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Sets the number of elements to be used with 'Calibration Due Days'.
/// HIPAR calibrationDueDays/Defines the days on which a self-alignment is scheduled for
/// HIPAR calibrationDueDays/CalibrationDueSchedule. Up to 7 different days can be scheduled.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueDays(ViSession instrSession,
                                                    ViInt32   arraySize,
                                                    ViInt32   calibrationDueDays[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   parameters[RS_MAX_MESSAGE_LEN] = "";
    ViChar*  p2param;
    ViPChar  paramDays;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    p2param = parameters;

    for (i = 0; i < arraySize; i++)
    {
        if (i > 0)
        {
            p2param += snprintf(p2param, RS_MAX_MESSAGE_LEN, ",");
        }

        viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
            &RsZnl_rngCalibrationDueDays,
            calibrationDueDays[i], &paramDays),
            3, "Calibration Due Days");

        p2param += snprintf(p2param, RS_MAX_MESSAGE_LEN, "%s", paramDays);
    }

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_HIDDEN_CALIBRATION_DUE_DAYS, parameters),
            3, "Calibraiton Due Days");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, a self-alignment is performed regularly at specific days
/// HIFN  and time. Specify the date and time using the CaibrationDueDays and
/// HIFN  CalibrationDueTime attributes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR schedule/If enabled, a self-alignment is performed regularly at specific days
/// HIPAR schedule/and time. Specify the date and time using the CaibrationDueDays and
/// HIPAR schedule/CalibrationDueTime controls.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueSchedule(ViSession instrSession,
                                                        ViBoolean schedule)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_DUE_SCHEDULE, schedule),
            2, "Schedule");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If activated, the R&S ZNL/ZNLE is automatically shut down after
/// HIFN  self-alignment is completed. Note that the instrument cannot be
/// HIFN  restarted via remote control.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR shutdown/If activated, the R&S ZNL/ZNLE is automatically shut down after
/// HIPAR shutdown/self-alignment is completed. Note that the instrument cannot be
/// HIPAR shutdown/restarted via remote control.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueShutdown(ViSession instrSession,
                                                        ViBoolean shutdown)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_DUE_SHUTDOWN, shutdown),
            2, "Shutdown");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the time at which a self-alignment is scheduled for the days
/// HIFN  specified by CalibrationDueDays, if CalibrationDueSchedule is ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR time/Defines the time at which a self-alignment is scheduled for the days
/// HIPAR time/specified by CalibrationDueDays, if CalibrationDueSchedule is ON.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueTime(ViSession instrSession,
                                                    ViString  time)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_DUE_TIME, time),
            2, "Time");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, self-alignment is started automatically after the warmup
/// HIFN  operation has completed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR warmup/If enabled, self-alignment is started automatically after the warmup
/// HIPAR warmup/operation has completed.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueWarmup(ViSession instrSession,
                                                      ViBoolean warmup)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_DUE_WARMUP, warmup),
            2, "Warmup");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Starts a service function.
/// HIFN     The service functions are available after you have entered the level 1
/// HIFN  or level 2 system password.
/// HIFN     The ID of the service function is made up out of five numbers,
/// HIFN  separated by a point.
/// HIFN     - function group number
/// HIFN     - board number
/// HIFN     - function number
/// HIFN     - parameter 1 (see the Service Manual)
/// HIFN     - parameter 2 (see the Service Manual)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR serviceFunction/Starts a service function.
ViStatus _VI_FUNC rsznl_StartServiceFunction(ViSession instrSession,
                                             ViString  serviceFunction)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SERVICE_FUNCTION, serviceFunction),
            2, "Service Function");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the results of the most recent service function you have used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for Last Result.
/// HIPAR lastResult/Queries the results of the most recent service function you have used.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryServiceFunctionLastResult(ViSession instrSession,
                                                       ViUInt32  arraySize,
                                                       ViChar    lastResult[],
                                                       ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SERVICE_FUNCTION_LAST_RESULT,
            arraySize, lastResult),
            3, "Last Results");

    *returnedValues = (ViUInt32)strlen(lastResult);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes the results of the most recent service function you have used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ServiceFunctionDeleteLastResult(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SERVICE_FUNCTION_DELETE_LAST_RESULT, NULL),
            2, "Service Function Delete Last Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves the results of the most recent service function you have used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Saves the results of the most recent service function you have used.
ViStatus _VI_FUNC rsznl_SaveServiceFunctionResult(ViSession instrSession,
                                                  ViString  fileName)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SERVICE_FUNCTION_RESULT_FILE_NAME, fileName),
            2, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Creates a *.zip file with important support information. The *.zip
/// HIFN  file contains the system configuration information ('device
/// HIFN  footprint'), the current eeprom data and a screenshot of the screen
/// HIFN  display (if available).
/// HIFN     As a result of this command, the created file name (including the
/// HIFN  drive and path) is returned.
/// HIFN     If you contact the Rohde&Schwarz support to get help for a certain
/// HIFN  problem, send this file to the support in order to identify and solve
/// HIFN  the problem faster.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for File Path.
/// HIPAR filePath/Creates a *.zip file with important support information. The *.zip
/// HIPAR filePath/file contains the system configuration information ('device
/// HIPAR filePath/footprint'), the current eeprom data and a screenshot of the screen
/// HIPAR filePath/display (if available).
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryServiceSystemInformationFilePath(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViChar    filePath[],
                            ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SERVICE_SYSTEM_INFORMATION_FILE_PATH,
            arraySize, filePath),
            3, "File Path");

    *returnedValues = (ViUInt32)strlen(filePath);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the joint charge state of the internal batteries (with
/// HIFN  internal battery pack option R&SFPL1-B31).
/// HIFN
/// HIFN     Internal Li-Ion Batteries are not available for R&SZNLE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR batteryLevel/Queries the joint charge state of the internal batteries (with
/// HIPAR batteryLevel/internal battery pack option R&SFPL1-B31).
ViStatus _VI_FUNC rsznl_QueryServiceFunctionBatteryLevel(ViSession instrSession,
                                                         ViInt32*  batteryLevel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_SERVICE_FUNCTION_BATTERY_LEVEL, batteryLevel),
            2, "Battery Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the reference oscillator.
/// HIFN     If you want to select the external reference, it must be connected to
/// HIFN  the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceOscillatorSource/Selects the reference oscillator.
/// HIPAR externalFrequency/Defines the frequency of the external reference oscillator. If the
/// HIPAR externalFrequency/external reference oscillator is selected, the reference signal must be
/// HIPAR externalFrequency/connected to the rear panel of the instrument.
ViStatus _VI_FUNC rsznl_ConfigureReferenceOscillator(ViSession instrSession,
                                                     ViInt32   referenceOscillatorSource,
                                                     ViReal64  externalFrequency)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_REFERENCE_OSCILLATOR_SOURCE, referenceOscillatorSource),
            2, "Reference Oscillator Source");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_GENERAL_EXTERNAL_REFERENCE_OSCILLATOR_FREQUENCY, externalFrequency),
            3, "External Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the current reference type in case you have activated an
/// HIFN  automatic switch to the internal reference if the external reference is
/// HIFN  missing.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceType/Queries the current reference type in case you have activated an
/// HIPAR referenceType/automatic switch to the internal reference if the external reference is
/// HIPAR referenceType/missing.
ViStatus _VI_FUNC rsznl_QueryCurrentReferenceType(ViSession instrSession,
                                                  ViInt32*  referenceType)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_REFERENCE_OSCILLATOR_SOURCE, referenceType),
            2, "Reference Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables automatic power reduction at all test ports while
/// HIFN  an automatic calibration using the calibration unit R&S ZV-Zxx is
/// HIFN  active.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoPowerReduction/Enables or disables automatic power reduction at all test ports while
/// HIPAR autoPowerReduction/an automatic calibration using the calibration unit R&S ZV-Zxx is
/// HIPAR autoPowerReduction/active.
ViStatus _VI_FUNC rsznl_ConfigureAutoPowerReductionForCalUnit(
                            ViSession instrSession,
                            ViBoolean autoPowerReduction)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_AUTO_POWER_REDUCTION_FOR_CAL_UNIT, autoPowerReduction),
            2, "Auto Power Reduction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function selects the averaging during calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR avaraging/This control selects the averaging during calibration.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationAutoAveraging(ViSession instrSession,
                                                          ViInt32   averaging)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_CALIBRATION_AUTO_AVERAGING, averaging),
            2, "Averaging");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the 'Search Path for Additional Cal Kits and Connector
/// HIFN  Types'. All cal kit files in the specified directory will be
/// HIFN  (re-)loaded automatically as predefined kits (i.e. readonly kits which
/// HIFN  cannot be modified) every time the VNA application is started.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Specifies the 'Search Path for Additional Cal Kits and Connector
/// HIPAR path/Types'. All cal kit files in the specified directory will be
/// HIPAR path/(re-)loaded automatically as predefined kits (i.e. readonly kits which
/// HIPAR path/cannot be modified) every time the VNA application is started.
ViStatus _VI_FUNC rsznl_ConfigureSearchPathForAdditionalCalKitsAndConnectorTypes(
                            ViSession instrSession,
                            ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_SEARCH_PATH_FOR_ADDITIONAL_CAL_KITS_AND_CONNECTOR_TYPES, path),
            2, "Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how bandfilter searches calculate the center frequency of the
/// HIFN  passband or stopband.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bandfilterCenterCalculation/Defines how bandfilter searches calculate the center frequency of the
/// HIPAR bandfilterCenterCalculation/passband or stopband.
ViStatus _VI_FUNC rsznl_ConfigureCalculationOfBandfilterCenter(
                            ViSession instrSession,
                            ViBoolean bandfilterCenterCalculation)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_GEOMETRIC_CALCULATION_OF_BANDFILTER_CENTER, bandfilterCenterCalculation),
            2, "Bandfilter Center Calculation");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures whitespace insertion during Touchstone file export.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR positiveNumberPrefix/Defines how positive numbers are prefixed during Touchstone file
/// HIPAR positiveNumberPrefix/export: by a leading space, a plus sign or not at all.
/// HIPAR skipSeparatorLines/efines whitespace insertion during Touchstone file export. If set to
/// HIPAR skipSeparatorLines/ON, separator lines are skipped, i.e. the content parts are no longer
/// HIPAR skipSeparatorLines/separated by blank lines.
/// HIPAR useTAB/Defines whitespace insertion during Touchstone file export. If set to
/// HIPAR useTAB/ON, columns are separated by tabs rather than spaces.
/// HIPAR trimLeadingWhitespace/Defines whitespace insertion during Touchstone file export. If set to
/// HIPAR trimLeadingWhitespace/ON, whitespace at the beginning of each line is removed.
ViStatus _VI_FUNC rsznl_ConfigureTouchstoneExport(ViSession instrSession,
                                                  ViInt32   positiveNumberPrefix,
                                                  ViBoolean skipSeparatorLines,
                                                  ViBoolean useTAB,
                                                  ViBoolean trimLeadingWhitespace)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_POSITIVE_NUMBER_PREFIX, positiveNumberPrefix),
            2, "Positive Number Prefix");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_SKIP_SEPARATOR_LINES, skipSeparatorLines),
            3, "Skip Separator Lines");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_USE_TAB, useTAB),
            4, "Use TAB");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_TRIM_LEADING_WHITESPACE, trimLeadingWhitespace),
            5, "Trim Leading Whitespace");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures how the VNA sets the output power between sweeps. This
/// HIFN  applies to all sweep modes but is particularly useful in single sweep
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerModeAtSweepEnd/Selects the power mode at sweep end.
/// HIPAR settlingDelay/If sweep end mode REDuce or KEEP is active
/// HIPAR settlingDelay/(RSZNL_ATTR_GENERAL_POWER_MODE_AT_SWEEP_END) this defines the settling
/// HIPAR settlingDelay/delay at subsequent sweep starts, i.e. the time between power reset and
/// HIPAR settlingDelay/sweep start when a new sweep is requested.
ViStatus _VI_FUNC rsznl_ConfigurePowerAtSweepEnd(ViSession instrSession,
                                                 ViInt32   powerModeAtSweepEnd,
                                                 ViReal64  settlingDelay)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_POWER_MODE_AT_SWEEP_END, powerModeAtSweepEnd),
            2, "Power Mode At Sweep End");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_GENERAL_SWEEP_END_SETTLING_DELAY, settlingDelay),
            3, "Settling Delay");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Turns logging of remote commands on and off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR remoteLoggingEnabled/Turns logging of remote commands on and off.
ViStatus _VI_FUNC rsznl_ConfigureRemoteLoggingEnabled(ViSession instrSession,
                                                      ViBoolean remoteLoggingEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_REMOTE_LOGGING_ENABLED, remoteLoggingEnabled),
            2, "Remote Logging Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures display of instrument in remote control mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayUpdateEnabled/Turns the display during remote operation on and off.
/// HIPAR displayErrorEnabled/The error display during remote operation on and off.
ViStatus _VI_FUNC rsznl_ConfigureRemoteDisplay(ViSession instrSession,
                                               ViBoolean displayUpdateEnabled,
                                               ViBoolean displayErrorEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_DISPLAY_UPDATE_ENABLED, displayUpdateEnabled),
            2, "Display Update Enabled");

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_DISPLAY_ERROR_ENABLED, displayErrorEnabled),
            2, "Display Error Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes all contents of the 'Remote Errors' table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ClearRemoteErrors(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_CLEAR_REMOTE_ERRORS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes all contents of the 'System Messages' table.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ClearSystemMessages(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_CLEAR_SYSTEM_MESSAGES, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates the local lockout (remote control) or returns to the local
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR generalLocalLockoutEnabled/Activates the local lockout (remote control) or returns to the local
/// HIPAR generalLocalLockoutEnabled/mode.
ViStatus _VI_FUNC rsznl_ConfigureLocalLockout(ViSession instrSession,
                                              ViBoolean generalLocalLockoutEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_LOCAL_LOCKOUT_ENABLED, generalLocalLockoutEnabled),
            2, "General Local Lockout Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  The instrument switches between manual and remote operation.
/// HIFN
/// HIFN     False = The instrument switches from remote to manual operation. You
/// HIFN  can operate the instrument locally.
/// HIFN
/// HIFN     True = The instrument switches from manual to remote operation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR remoteControl/The instrument switches between manual and remote operation.
ViStatus _VI_FUNC rsznl_ConfigureRemoteControl(ViSession instrSession,
                                               ViBoolean remoteControl)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_REMOTE_CONTROL, remoteControl),
            2, "Remote Control");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the language of the software-defined interface elements (such
/// HIFN  as softkeys, dialog boxes, diagram texts etc.).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR displayLanguage/Defines the language of the software-defined interface elements (such
/// HIPAR displayLanguage/as softkeys, dialog boxes, diagram texts etc.).
ViStatus _VI_FUNC rsznl_ConfigureDisplayLanguage(ViSession instrSession,
                                                 ViInt32   displayLanguage)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_DISPLAY_LANGUAGE, displayLanguage),
            2, "Display Language");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the remote control command set.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR language/Sets the remote control command set.
ViStatus _VI_FUNC rsznl_ConfigureRemoteLanguage(ViSession instrSession,
                                                ViString  language)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_REMOTE_CONTROL_COMMAND_SET, language),
            2, "Language");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the response to the REV? query for the revision number to the
/// HIFN  factory default.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ResetRevisionToFactoryDefault(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_RESET_REVISION_TO_FACTORY_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the query to *IDN? to its default value.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ResetIDNQueryToFactoryDefault(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_RESET_IDN_QUERY_TO_FACTORY_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the response to *IDN?.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR idnQueryString/Defines the response to *IDN?.
ViStatus _VI_FUNC rsznl_ConfigureIDNQueryString(ViSession instrSession,
                                                ViString  idnQueryString)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_IDN_QUERY_STRING, idnQueryString),
            2, "IDN Query String");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the response format to the *IDN? query.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR idnFormat/Selects the response format to the *IDN? query.
ViStatus _VI_FUNC rsznl_ConfigureIDNFormat(ViSession instrSession,
                                           ViInt32   idnFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_IDN_FORMAT, idnFormat),
            2, "IDN Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Starts a firmware update using the *.msi files in the selected
/// HIFN  directory. The default path is D:\FW_UPDATE. The path is changed via
/// HIFN  RSZNL_ATTR_DATA_SELECTED_DIRECTORY. To store the update files the
/// HIFN  RSZNL_FUNC_WRITE_FROM_FILE_TO_INSTRUMENT is used.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR path/Selects the directory. The default path is D:\FW_UPDATE. The path is
/// HIPAR path/changed via RSZNL_ATTR_DATA_SELECTED_DIRECTORY. To store the update
/// HIPAR path/files the RSZNL_FUNC_WRITE_FROM_FILE_TO_INSTRUMENT is used.
ViStatus _VI_FUNC rsznl_ConfigureFirmwareUpdate(ViSession instrSession,
                                                ViString  path)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_FIRMWARE_UPDATE, path),
            2, "Path");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the LXI settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for LXI Info.
/// HIPAR lxiInfo/Queries the LXI settings.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QueryLXIInfo(ViSession instrSession,
                                     ViUInt32  arraySize,
                                     ViChar    lxiInfo[],
                                     ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_LXI_INFO,
            arraySize, lxiInfo),
            3, "LXI Info");

    *returnedValues = (ViUInt32)strlen(lxiInfo);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the LAN configuration as required by the LXI standard. The
/// HIFN  command also resets the LXI password and instrument description.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_LXILANReset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_LXI_LAN_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the LXI instrument description.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lxiInstrumentDescription/Defines the LXI instrument description.
ViStatus _VI_FUNC rsznl_ConfigureLXIInstrumentDescription(ViSession instrSession,
                                                          ViString  lxiInstrumentDescription)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_LXI_INSTRUMENT_DESCRIPTION, lxiInstrumentDescription),
            2, "LXI Instrument Description");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the LXI password.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR lxiPassword/Defines the LXI password.
ViStatus _VI_FUNC rsznl_ConfigureLXIPassword(ViSession instrSession,
                                             ViString  lxiPassword)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_LXI_PASSWORD, lxiPassword),
            2, "LXI Password");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Changes the presentation of 'capacitance C in parallel with
/// HIFN  resistance R' circuit blocks in lumped de/embedding networks.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR conductanceInEmbed.Networks/Changes the presentation of 'capacitance C in parallel with
/// HIPAR conductanceInEmbed.Networks/resistance R' circuit blocks in lumped de/embedding networks.
ViStatus _VI_FUNC rsznl_ConfigureConductanceInEmbeddingNetworks(
                            ViSession instrSession,
                            ViBoolean conductanceInEmbedNetworks)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_GENERAL_CONDUCTANCE_IN_EMBEDDING_NETWORKS_ENABLED, conductanceInEmbedNetworks),
            2, "Conductance in Embedding Networks");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates an immediate update of the channel or trace settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_UpdateSettings(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_UPDATE_SETTINGS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets or gets the host name of the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR hostname/Sets or gets the host name of the instrument.
ViStatus _VI_FUNC rsznl_ConfigureInstrumentHostname(ViSession instrSession,
                                                    ViString  hostname)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_INSTRUMENT_HOSTNAME, hostname),
            2, "Hostname");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function presets all parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_Preset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_PRESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function restores the default instrument settings in the current
/// HIFN  channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_PresetChannel(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_PRESET_CHANNEL, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function defines the operating mode that is activated when you
/// HIFN  switch on the R&S ZNL/ZNLE or press the PRESET key.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Defines the operating mode that is activated when you switch on the
/// HIPAR mode/R&S ZNL/ZNLE or press the PRESET key.
ViStatus _VI_FUNC rsznl_PresetMode(ViSession instrSession,
                                   ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_PRESET_MODE, mode),
            2, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function runs the instrument's self test routine and returns the
/// HIFN  test result(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR selfTestResult/This control contains the value returned from the instrument self
/// HIPAR selfTestResult/test.  Zero means success.  For any other code, see the device's
/// HIPAR selfTestResult/operator's manual.
/// HIPAR selfTestMessage/Returns the self-test response string from the instrument. See the
/// HIPAR selfTestMessage/device's operation manual for an explanation of the string's contents.
ViStatus _VI_FUNC rsznl_self_test(ViSession instrSession,
                                  ViInt16*  selfTestResult,
                                  ViChar    selfTestMessage[])
{
    ViStatus error = VI_SUCCESS;
    ViInt32  result = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, selfTestResult), 2, "Null address for Test Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, selfTestMessage), 3, "Null address for Test Message");

    checkErr(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_GENERAL_SELF_TEST, &result));
    if (*selfTestResult == 0)
        strcpy(selfTestMessage, "Self-Test Passed.");
    else
        strcpy(selfTestMessage, "Self-Test Failed.");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the BIOS version of the CPU board.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for System BIOS Info.
/// HIPAR systemBIOSInfo/Queries the BIOS version of the CPU board.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QuerySystemBIOSInfo(ViSession instrSession,
                                            ViUInt32  arraySize,
                                            ViChar    systemBIOSInfo[],
                                            ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_BIOS_INFO,
            arraySize, systemBIOSInfo),
            3, "System BIOS Info");

    *returnedValues = (ViUInt32)strlen(systemBIOSInfo);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries information about the hardware and software components.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for System Version Info.
/// HIPAR systemVersionInfo/Queries information about the hardware and software components.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QuerySystemVersionInfo(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    systemVersionInfo[],
                                               ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_VERSION_INFO,
            arraySize, systemVersionInfo),
            3, "System Version Info");

    *returnedValues = (ViUInt32)strlen(systemVersionInfo);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries hardware information.
/// HIFN
/// HIFN     String containing the following information for every hardware
/// HIFN  component.
/// HIFN     component: name of the hardware component
/// HIFN     serial#: serial number of the component
/// HIFN     order#: order number of the component
/// HIFN     model: model of the component
/// HIFN     code: code of the component
/// HIFN     revision: revision of the component
/// HIFN     subrevision>: subrevision of the component
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR arraySize/Defines the memory size allocated for System HW Info.
/// HIPAR systemHWInfo/Queries hardware information.
/// HIPAR returnedValues/Returns number of returned values.
ViStatus _VI_FUNC rsznl_QuerySystemHWInfo(ViSession instrSession,
                                          ViUInt32  arraySize,
                                          ViChar    systemHWInfo[],
                                          ViUInt32* returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_HW_INFO,
            arraySize, systemHWInfo),
            3, "System HW Info");

    *returnedValues = (ViUInt32)strlen(systemHWInfo);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Reboots the instrument, including the operating system.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SystemReboot(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_REBOOT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function switches the instrument to standby state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SystemShutdown(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_SHUTDOWN, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Determines the level of detail and hence the size of the dump files
/// HIFN  created in case of firmware exceptions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR dumpFileSize/Determines the level of detail and hence the size of the dump files
/// HIPAR dumpFileSize/created in case of firmware exceptions.
ViStatus _VI_FUNC rsznl_DumpFileSize(ViSession instrSession,
                                     ViInt32   dumpFileSize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_DUMP_FILE_SIZE, dumpFileSize),
            2, "Dump File Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries how many switching cycles the individual relays
/// HIFN  have performed since they were installed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR relay/Selects the relay.
/// HIPAR cyclesCount/Returns how many switching cycles the individual relays have performed
/// HIPAR cyclesCount/since they were installed.
ViStatus _VI_FUNC rsznl_RelaySwitchingCyclesCount(ViSession instrSession,
                                                  ViInt32   relay,
                                                  ViInt32*  cyclesCount)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, relay, RSZNL_VAL_RELAY_ACDC, RSZNL_VAL_RELAY_PREAMP),
            2, "Relay");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "DIAG:INFO:CCO? %s", RsZnl_rngRelay.entries[relay].cmdString);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, cyclesCount));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opcTimeout/This control sets the timeout value.
ViStatus _VI_FUNC rsznl_SetTimeout(ViSession instrSession,
                                   ViUInt32  opcTimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetOPCTimeout(instrSession, opcTimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control returns the timeout value.
ViStatus _VI_FUNC rsznl_GetTimeout(ViSession instrSession,
                                   ViUInt32* timeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_GetOPCTimeout(instrSession, (ViInt32*)timeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function resets the instrument to a known state and sends
/// HIFN  initialization commands to the instrument.  The initialization commands
/// HIFN  set instrument settings such as Headers Off, Short Command form, and
/// HIFN  Data Transfer Binary to the state necessary for the operation of the
/// HIFN  instrument driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR directory/Specifies the directory of the file to be executed.
/// HIPAR fileToExecute/Name of an application program to be executed or of a file to be
/// HIPAR fileToExecute/opened. Blanks in the file name are not allowed.
/// HIPAR fileParameters/Command name in the selected application.
/// HIPAR waitToFinish/Locks command execution and manual control of the analyzer while a
/// HIPAR waitToFinish/program is running. The analyzer does not execute any further commands
/// HIPAR waitToFinish/or queries until the program is stopped or paused.
ViStatus _VI_FUNC rsznl_ExecuteProgram(ViSession instrSession,
                                       ViString  directory,
                                       ViString  fileToExecute,
                                       ViString  fileParameters,
                                       ViBoolean waitToFinish)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViInt32(instrSession, "", RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_SELECT_APPLICATION, RSZNL_VAL_SELECT_APPL_PROG));

    viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_DATA_SELECTED_DIRECTORY, directory),
            2, "Directory");

    if (strncmp(fileParameters, "", 1) == 0)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "%s", fileToExecute);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "%s %s", fileToExecute, fileParameters);
    }

    viCheckParm(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_START, cmd),
            3, "File To Execute");

    if (waitToFinish == VI_TRUE)
    {
        checkErr(rsznl_SetAttributeViString(instrSession, "", RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_WAIT_TO_FINISH, NULL));
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function queries the return value of an application or process
/// HIFN  started via PROGram[:SELected]:EXECute (see function
/// HIFN  rsznl_ExecuteProgram).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR returnValue/This control queries the return value of an application or started
/// HIPAR returnValue/process.
ViStatus _VI_FUNC rsznl_QueryProgramReturnValue(ViSession instrSession,
                                                ViInt32*  returnValue)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_RETURN_VALUE, returnValue),
            2, "Return Value");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIFN Note that the actual timeout used may be higher than the one
/// HIFN requested.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR VISATimeout/Specifies the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
/// HIPAR VISATimeout/Note that the actual timeout used may be higher than the one
/// HIPAR VISATimeout/requested.
ViStatus _VI_FUNC rsznl_SetIOTimeout(ViSession instrSession,
                                     ViUInt32  VISATimeout)
{
    return RsCore_SetVisaTimeout(instrSession, VISATimeout);
}

/// HIFN This function queries the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a
/// HIPAR instrSession/particular instrument session.
/// HIPAR VISATimeout/Queries the minimum timeout value to use (in milliseconds)
/// HIPAR VISATimeout/when accessing the device associated with the given session.
ViStatus _VI_FUNC rsznl_GetIOTimeout(ViSession instrSession,
                                     ViUInt32* VISATimeout)
{
    return RsCore_GetVisaTimeout(instrSession, VISATimeout);
}

/*****************************************************************************
 * Function: rsznl_WriteInstrData
 * Purpose:  This function writes a user-specified string to the instrument.
 *****************************************************************************/

ViStatus _VI_FUNC rsznl_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_Write(instrSession, writeBuffer));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function sets the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsznl_SetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32   attributeValue)
{
    return RsCore_SetAttributeViInt32(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function sets the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsznl_SetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt64   attributeValue)
{
    return RsCore_SetAttributeViInt64(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function sets the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsznl_SetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64  attributeValue)
{
    return RsCore_SetAttributeViReal64(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function sets the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsznl_SetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViString  attributeValue)
{
    return RsCore_SetAttributeViStringOrRawString(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function sets the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to set the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Pass the value to which you want to set the attribute.
ViStatus _VI_FUNC rsznl_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeID,
                                              ViBoolean attributeValue)
{
    return RsCore_SetAttributeViBoolean(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function queries the value of a ViInt32 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt32 variable.
ViStatus _VI_FUNC rsznl_GetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32*  attributeValue)
{
    return RsCore_GetAttributeViInt32(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function queries the value of a ViInt64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViInt64 variable.
ViStatus _VI_FUNC rsznl_GetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt64*  attributeValue)
{
    return RsCore_GetAttributeViInt64(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function queries the value of a ViReal64 attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViReal64 variable.
ViStatus _VI_FUNC rsznl_GetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64* attributeValue)
{
    return RsCore_GetAttributeViReal64(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function queries the value of a ViString attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR bufSize/Pass the number of bytes in the ViChar array you specify for the
/// HIPAR bufSize/Attribute Value parameter.
/// HIPAR value/The buffer in which the function returns the current value of the
/// HIPAR value/attribute.  The buffer must be of type ViChar and have at least as many
/// HIPAR value/bytes as indicated in the Buffer Size parameter.
ViStatus _VI_FUNC rsznl_GetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[])
{
    return RsCore_GetAttributeViStringOrRawString(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL,
        bufferSize, attributeValue);
}

/// HIFN  This function queries the value of a ViBoolean attribute.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR channelName/If the attribute is channel-based, this parameter specifies the name
/// HIPAR channelName/of the channel on which to obtain the value of the attribute. If the
/// HIPAR channelName/attribute is not channel-based, then pass NULL or an empty string.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR value/Returns the current value of the attribute.  Pass the address of a
/// HIPAR value/ViBoolean variable.
ViStatus _VI_FUNC rsznl_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   channelName,
                                              ViAttr     attributeID,
                                              ViBoolean* attributeValue)
{
    return RsCore_GetAttributeViBoolean(instrSession, channelName, attributeID, RS_VAL_DIRECT_USER_CALL, attributeValue);
}

/// HIFN  This function synchronizes the selected repeated capability with
/// HIFN  the current instrument's state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR repeatedCapability/Selects the repeated capability.
ViStatus _VI_FUNC rsznl_SynchronizeDynamicRepeatedCapability(ViSession instrSession,
                                                             ViInt32   repeatedCapability)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  repCap_list[1024];
    ViInt32  repCap_value = 0;
    ViInt32  i = 0;
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_cmd[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, repeatedCapability, RSZNL_VAL_ALL_REP_CAPS, RSZNL_VAL_RIPPLE_SEGMENT),
            2, "Repeated Capability");

    // Channel repeated capability
    if ((repeatedCapability == RSZNL_VAL_CHANNEL || repeatedCapability == RSZNL_VAL_ALL_REP_CAPS))
    {
        memset((void*)repCap_list, 0, 1024);
        repCap_value = 0;
        i = 0;
        buffer[0] = '\0';
        repCap[0] = '\0';
        repCap_cmd[0] = '\0';

        // reset 'Channel' rep cap
        checkErr(RsCore_ResetRepCapID(instrSession, "Channel", rsznl_RsCoreRepCapTable));

        // get all active channels
        checkErr(rsznl_ChannelList(instrSession, RS_MAX_MESSAGE_BUF_SIZE, buffer));

        //parse buffer - '1,Ch1,2,New_Channel'.
        p2buf = strtok(buffer, ",");

        while (p2buf != NULL)
        {
            repCap_list[i++] = atoi(p2buf);
            (void)strtok(NULL, ",");
            p2buf = strtok(NULL, ",");
        }

        // enter active channel numbers as 'Channel' rep caps
        while (repCap_value < i)
        {
            snprintf(repCap, RS_REPCAP_BUF_SIZE, "Channel%ld", repCap_list[repCap_value]);
            snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", repCap_list[repCap_value]);
            checkErr(RsCore_AddRepCap(instrSession, "Channel", repCap, repCap_cmd));

            repCap_value++;
        }
    }

    // Window repeated capability
    if ((repeatedCapability == RSZNL_VAL_WINDOW || repeatedCapability == RSZNL_VAL_ALL_REP_CAPS))
    {
        memset((void*)repCap_list, 0, 1024);
        repCap_value = 0;
        i = 0;
        buffer[0] = '\0';
        repCap[0] = '\0';
        repCap_cmd[0] = '\0';

        // reset 'Window' rep cap
        checkErr(RsCore_ResetRepCapID(instrSession, "Window", rsznl_RsCoreRepCapTable));

        // get all active Windows
        checkErr(rsznl_DiagramAreaCatalog(instrSession, buffer, RS_MAX_MESSAGE_BUF_SIZE));

        //parse buffer - '1,Window 1,2,Another Window'.
        p2buf = strtok(buffer, ",");

        while (p2buf != NULL)
        {
            repCap_list[i++] = atoi(p2buf);
            (void)strtok(NULL, ",");
            p2buf = strtok(NULL, ",");
        }

        // enter active window numbers as 'Window' rep caps
        while (repCap_value < i)
        {
            snprintf(repCap, RS_REPCAP_BUF_SIZE, "Win%ld", repCap_list[repCap_value]);
            snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", repCap_list[repCap_value]);
            checkErr(RsCore_AddRepCap(instrSession, "Window", repCap, repCap_cmd));

            repCap_value++;
        }
    }

    // Segment repeated capability
    if ((repeatedCapability == RSZNL_VAL_SEGMENT || repeatedCapability == RSZNL_VAL_ALL_REP_CAPS))
    {
        ViInt32 channel = 0;
        ViInt32 segment = 0;
        ViInt32 max_segment = 0;

        memset((void*)repCap_list, 0, 1024);
        repCap_value = 0;
        i = 0;
        buffer[0] = '\0';
        repCap[0] = '\0';
        repCap_cmd[0] = '\0';

        // reset 'Segment' rep cap
        checkErr(RsCore_ResetRepCapID(instrSession, "Segment", rsznl_RsCoreRepCapTable));

        // get all active channels
        checkErr(rsznl_ChannelList(instrSession, RS_MAX_MESSAGE_BUF_SIZE, buffer));

        //parse buffer - '1,Ch1,2,New_Channel'.
        p2buf = strtok(buffer, ",");

        while (p2buf != NULL)
        {
            repCap_list[i++] = atoi(p2buf);
            (void)strtok(NULL, ",");
            p2buf = strtok(NULL, ",");
        }

        for (channel = 0; channel < i; channel++)
        {
            // get all active Segment for each active channel
            checkErr(rsznl_QuerySweepSegmentNumber(instrSession, channel + 1, &segment));
            // store the highest segment number
            if (segment > max_segment) max_segment = segment;
        }

        // enter active window numbers as 'Segment' rep caps
        while (repCap_value < max_segment)
        {
            repCap_value++;

            snprintf(repCap, RS_REPCAP_BUF_SIZE, "Seg%ld", repCap_value);
            snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", repCap_value);
            checkErr(RsCore_AddRepCap(instrSession, "Segment", repCap, repCap_cmd));
        }
    }

    // Limit Segment repeated capability
    if ((repeatedCapability == RSZNL_VAL_LIMIT_SEGMENT || repeatedCapability == RSZNL_VAL_ALL_REP_CAPS))
    {
        ViInt32 channel = 0;
        ViInt32 segment = 0;
        ViInt32 max_segment = 0;

        memset((void*)repCap_list, 0, 1024);
        repCap_value = 0;
        i = 0;
        buffer[0] = '\0';
        repCap[0] = '\0';
        repCap_cmd[0] = '\0';

        // reset 'Limit Segment' rep cap
        checkErr(RsCore_ResetRepCapID(instrSession, "LimitSegment", rsznl_RsCoreRepCapTable));

        // get all active channels
        checkErr(rsznl_ChannelList(instrSession, RS_MAX_MESSAGE_BUF_SIZE, buffer));

        //parse buffer - '1,Ch1,2,New_Channel'.
        p2buf = strtok(buffer, ",");

        while (p2buf != NULL)
        {
            repCap_list[i++] = atoi(p2buf);
            (void)strtok(NULL, ",");
            p2buf = strtok(NULL, ",");
        }

        for (channel = 0; channel < i; channel++)
        {
            // get all active Limit Segment for each active channel
            checkErr(rsznl_QueryLimitLineSegmentCount(instrSession, channel + 1, &segment));
            // store the highest limit segment number
            if (segment > max_segment) max_segment = segment;
        }

        // enter active limit segment numbers as 'Limit Segment' rep caps
        while (repCap_value < max_segment)
        {
            repCap_value++;

            snprintf(repCap, RS_REPCAP_BUF_SIZE, "LimitSeg%ld", repCap_value);
            snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", repCap_value);
            checkErr(RsCore_AddRepCap(instrSession, "LimitSegment", repCap, repCap_cmd));
        }
    }

    // Ripple Segment repeated capability
    if ((repeatedCapability == RSZNL_VAL_RIPPLE_SEGMENT || repeatedCapability == RSZNL_VAL_ALL_REP_CAPS))
    {
        ViInt32 channel = 0;
        ViInt32 segment = 0;
        ViInt32 max_segment = 0;

        memset((void*)repCap_list, 0, 1024);
        repCap_value = 0;
        i = 0;
        buffer[0] = '\0';
        repCap[0] = '\0';
        repCap_cmd[0] = '\0';

        // reset 'Ripple Segment' rep cap
        checkErr(RsCore_ResetRepCapID(instrSession, "RippleSegment", rsznl_RsCoreRepCapTable));

        // get all active channels
        checkErr(rsznl_ChannelList(instrSession, RS_MAX_MESSAGE_BUF_SIZE, buffer));

        //parse buffer - '1,Ch1,2,New_Channel'.
        p2buf = strtok(buffer, ",");

        while (p2buf != NULL)
        {
            repCap_list[i++] = atoi(p2buf);
            (void)strtok(NULL, ",");
            p2buf = strtok(NULL, ",");
        }

        for (channel = 0; channel < i; channel++)
        {
            // get all active Ripple Segment for each active channel
            checkErr(rsznl_QueryRippleLimitRangesCount(instrSession, channel + 1, &segment));
            // store the highest Ripple segment number
            if (segment > max_segment) max_segment = segment;
        }

        // enter active limit segment numbers as 'Ripple Segment' rep caps
        while (repCap_value < max_segment)
        {
            repCap_value++;

            snprintf(repCap, RS_REPCAP_BUF_SIZE, "RippleSeg%ld", repCap_value);
            snprintf(repCap_cmd, RS_REPCAP_BUF_SIZE, "%ld", repCap_value);
            checkErr(RsCore_AddRepCap(instrSession, "RippleSegment", repCap, repCap_cmd));
        }
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the repeated capability id(s) that belongs
/// HIFN to the attribute you specify. More then one id is listed in
/// HIFN comma separated string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR attributeID/Pass the ID of an attribute.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id(s) parameter.
/// HIPAR repeatedCapabilityIds/The buffer in which the function returns the repeated capability id(s) belonging to the attribute.
ViStatus _VI_FUNC rsznl_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViUInt32  attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeID, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/// HIFN This function returns the repeated capability name(s) that
/// HIFN belongs to the attribute and single repeated capability id you
/// HIFN may specify. More then one name is listed in comma separated
/// HIFN string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR attributeID/Pass the ID of an attribute.
/// HIPAR repeatedCapabilityId/If the attribute applies to a repeated capability such as a trace, this parameter defines the Id of the repeated capability on which to query repeated capability id name(s).
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Repeated Capability Id Name(s) parameter.
/// HIPAR repeatedCapabilityIdNames/The buffer in which the function returns the repeated capability id name(s) belonging to the attribute.
ViStatus _VI_FUNC rsznl_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeID,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}

/// HIFN  This function resets the edge detectors and ENABle parts of all
/// HIFN  registers to a defined value. All PTRansition parts are set to FFFFh,
/// HIFN  i.e. all transitions from 0 to 1 are detected. All NTRansition parts
/// HIFN  are set to 0, i.e. a transition from 1 to 0 in a CONDition bit is not
/// HIFN  detected. The ENABle part of the STATus:OPERation and
/// HIFN  STATus:QUEStionable registers are set to 0, i.e. all events in these
/// HIFN  registers are not passed on.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
ViStatus _VI_FUNC rsznl_PresetStatusRegister(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_STATUS_PRESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function sets the Enable, NTransition, and PTransition bits of
/// HIFN  the status questionable and operating registers.
/// HIFN
/// HIFN     Note:
/// HIFN
/// HIFN     - For detailed description of Status Reporting System see also
/// HIFN  operating manual.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR enable/This control sets the enable bits of the status register.
/// HIPAR ptransition/This control sets the PTransition bits (edge detectors) of the status
/// HIPAR ptransition/register.
/// HIPAR ntransition/This control sets the NTransition bits (edge detectors) of the status
/// HIPAR ntransition/register.
ViStatus _VI_FUNC rsznl_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViUInt16  enable,
                                          ViUInt16  ptransition,
                                          ViUInt16  ntransition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (registerOperation == RSZNL_VAL_STAT_REG_OPERATION)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:ENAB %hu;PTR %hu;NTR %hu", enable, ptransition, ntransition);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES%s:ENAB %hu;PTR %hu;NTR %hu", gsc_statusRegister[questionableRegister], enable, ptransition, ntransition);
    }

    checkErr(rsznl_WriteCommandWithOPCSync(instrSession, cmd, 0));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  This function contains the commands for the querying status reporting
/// HIFN  system.
/// HIFN
/// HIFN     Note:
/// HIFN
/// HIFN     For detailed description of Status Reporting System see also operating
/// HIFN  manual.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR registerOperation/Specifies the operation to perform.
/// HIPAR questionableRegister/This control selects the registers that will be configured.
/// HIPAR registerPart/Sets the register part.
/// HIPAR registerValue/Returns content of selected register.
ViStatus _VI_FUNC rsznl_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   registerPart,
                                          ViInt32*  registerValue)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    if (registerOperation == RSZNL_VAL_STAT_REG_OPERATION)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:OPER:%s?", RsZnl_rngStatusRegisterQuery.entries[registerPart].cmdString);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, ":STAT:QUES%s:%s?", gsc_statusRegister[questionableRegister],
            RsZnl_rngStatusRegisterQuery.entries[registerPart].cmdString);
    }

    checkErr(rsznl_QueryViInt32(instrSession, cmd, registerValue));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function is used to read data from the instrument and write it to
/// HIFN  a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument to
/// HIPAR source/control computer.
/// HIPAR destination/This control defines destination file to which the data transfer from
/// HIPAR destination/instrument to control computer applies.
ViStatus _VI_FUNC rsznl_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  source,
                                                 ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, source),
        2, "Source");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, destination),
        3, "Destination");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEMory:DATA? '%s'", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function is used to read data from the host computer and
/// HIFN  write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
ViStatus _VI_FUNC rsznl_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, source),
        2, "Source");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, destination),
        3, "Destination");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function resets the instrument to a known state and sends initialization commands to the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
ViStatus _VI_FUNC rsznl_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_ClearStatus(instrSession));
    checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

    checkErr(RsCore_ResetRepCapTable(instrSession, rsznl_RsCoreRepCapTable, rsznl_RsCoreRepCapTableCount));
    checkErr(rsznl_DefaultInstrSetup(instrSession));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/// HIFN This function returns the driver and instrument revisions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR driverRev/Returns the instrument driver software revision numbers in the form of a string.
/// HIPAR instrRev/Returns the instrument firmware revision numbers in the form of a string.
ViStatus _VI_FUNC rsznl_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SPECIFIC_DRIVER_REVISION,
        0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, "", RSZNL_ATTR_INSTRUMENT_FIRMWARE_REVISION,
        0, 256, firmwareRevision));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function reads an error code and a message from the
/// HIFN instrument's error queue.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR errCode/Returns the error code read from the instrument's error queue.
/// HIPAR errMessage/Returns the error message string read from the instrument's error message queue.
ViStatus _VI_FUNC rsznl_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function converts a status code returned by an instrument driver function into a user-readable string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR errorCode/Pass the Status parameter that is returned from any of the instrument driver functions.
/// HIPAR errorMessage/Returns the user-readable message string that corresponds to the status code you specify.
ViStatus _VI_FUNC rsznl_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[])
{
    return rsznl_utility_error_message(instrSession, errorCode, errorMessage);
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rsznl_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of IDQueryResponse buffer
/// HIPAR idQueryResponse/Returns the ID Query response string. The array should consist of at
/// HIPAR idQueryResponse/least 256 elements.
ViStatus _VI_FUNC rsznl_IDQueryResponse(ViSession instrSession,
                                        ViUInt32  bufferSize,
                                        ViChar    IDQueryResponse[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession))
    {
        strncpy(IDQueryResponse, RSZNL_SIMULATION_ID_QUERY, bufferSize);
        IDQueryResponse[bufferSize - 1] = 0;
        goto Error;
    }

    checkErr(rsznl_QueryViString(instrSession, "*IDN?", bufferSize, IDQueryResponse, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before *WAI
/// HIFN  have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_Write(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opc/Queries the OPC.
ViStatus _VI_FUNC rsznl_QueryOPC(ViSession instrSession,
                                 ViInt32*  opc)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", opc));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Clears any previously provided password and returns to the most
/// HIFN  restrictive service level.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_PasswordReset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_PASSWORD_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Provides a password for subsequent service functions.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR systemPassword/Provides a password for subsequent service functions.
ViStatus _VI_FUNC rsznl_ConfigureSystemPassword(ViSession instrSession,
                                                ViString  systemPassword)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_PASSWORD, systemPassword),
            2, "System Password");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rsvna_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsvna_init or
/// HIPAR instrSession/rsvna_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rsznl_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for writes.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for writes.
ViStatus _VI_FUNC rsznl_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrWrites = enable;

Error:
    return error;
}

/// HIFN  Switches OPC-synchronization ON/OFF for queries.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enable/Switches OPC-synchronization ON/OFF for queries.
ViStatus _VI_FUNC rsznl_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable)
{  
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->opcSyncAttrQueries = enable;

Error:
    return error;
}

/// HIFN  Sets the mechanism which is used for OPC-synchronised queries (valid
/// HIFN  for read attributes and all OPC-synchronised queries):
/// HIFN     Default value: 'useEsb' = true, 'clsBefore' = true, 'useMav' = false
/// HIFN
/// HIFN     Scenario A: useEsb = true:
/// HIFN     The query command is appended by the ';*OPC', and the wait loop ends
/// HIFN  if the ESB bit signals that the command was completed, or the ERRQ (bit
/// HIFN  2) signals an error.
/// HIFN         - clsBefore has no effect and is always set to true.
/// HIFN         - set the 'useMav' to true, to enable the opc-wait loop
/// HIFN  sucessfully finish if the MAV bit signals, that the response is
/// HIFN  available, even if the ESB bit is still 0.
/// HIFN
/// HIFN     Scenario B: useEsb = false:
/// HIFN     The query command is not appended by the ';*OPC', and the wait loop
/// HIFN  ends if the MAV bit signals that the message is available, or the ERRQ
/// HIFN  (bit 2) signals an error.
/// HIFN         - clsBefore causes sending query *STB? before sending the command
/// HIFN  to clear the error queue and output buffers.
/// HIFN         - useMav has no effect, and is always set to true.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsmxo_init or
/// HIPAR instrSession/rsmxo_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR useESB/Switches queries OPC-synchronization to use the Event Status Bit.
/// HIPAR clsBefore/Switches queries OPC-synchronization to use call the Clear Before
/// HIPAR clsBefore/Read procedure before sending the query.
/// HIPAR useMAV/Switches queries OPC-synchronization to react on Message Available bit (MAV)
ViStatus _VI_FUNC rsznl_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                 ViBoolean useEsb,
                                                 ViBoolean clsBefore,
                                                 ViBoolean useMav)
{
    return RsCore_SetOpcSyncQueryMechanism(instrSession, useEsb, clsBefore, useMav);
}

/// HIFN This function retrieves and then clears the error information
/// HIFN for the session or the current execution thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
/// HIPAR errorCode/Returns the error code for the session or execution thread.
/// HIPAR bufferSize/Pass the number of bytes in the ViChar array you specify for the Description parameter.
/// HIPAR description/Returns the error description for the session or execution thread. If there is no description, the function returns an empty string.
ViStatus _VI_FUNC rsznl_GetError(ViSession instrSession,
                                 ViStatus* errorCode,
                                 ViInt32   bufferSize,
                                 ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rsznl_utility_error_message, errorCode, bufferSize, description)
    );

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function clears the error code and error description for
/// HIFN the session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
ViStatus _VI_FUNC rsznl_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}

/*****************************************************************************
 * Function: Query ViBoolean
 * Purpose:  This function queries the ViBoolean value.
 *****************************************************************************/
ViStatus _VI_FUNC rsznl_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(command), 1, 10000000), 2, "Command(null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViBoolean(instrSession, command, value));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rsznl_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(command), 1, 10000000), 2, "Command(null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViInt32(instrSession, command, value));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rsznl_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(command), 1, 10000000), 2, "Command(null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViReal64(instrSession, command, value));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rsznl_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViUInt32  bufferSize,
                                      ViChar    value[],
                                      ViUInt32* returnCount)
{
    ViStatus error = VI_SUCCESS;
    ViStatus warning = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, (ViInt32)strlen(command), 1, 10000000), 2, "Command(null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, command, bufferSize, value, (ViInt32*)returnCount));
    checkErrKeepWarn(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sends a command to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for an instrument operation that can
/// HIFN take a long time to complete, e.g. self-alignment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
ViStatus _VI_FUNC rsznl_WriteCommandWithOPCSync(ViSession instrSession,
                                                ViString  writeBuffer,
                                                ViUInt32  timeout)
{
    return RsCore_WriteWithOpc(instrSession, writeBuffer, (ViInt32)timeout);
}

/// HIFN Sends a query to the instrument synchronised with OPC-polling.
/// HIFN Use this function to wait for a response that can take a long
/// HIFN time to complete e.g. self-alignment, calibration or self-test.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR writeBuffer/Pass the string to be written to the instrument.
/// HIPAR timeout/This control sets the timeout value.
/// HIPAR bufferSize/Pass the maximum number of bytes to read from the instruments.
/// HIPAR readBuffer/After this function executes, this parameter contains the data
/// HIPAR readBuffer/that was read from the instrument.
/// HIPAR numBytesRead/Returns the number of bytes actually read from the instrument
/// HIPAR numBytesRead/and stored in the Read Buffer.
ViStatus _VI_FUNC rsznl_QueryWithOPCSync(ViSession instrSession,
                                         ViString  writeBuffer,
                                         ViUInt32  timeout,
                                         ViUInt32  bufferSize,
                                         ViChar    readBuffer[],
                                         ViUInt32* numBytesRead)
{
    return RsCore_QueryViStringUnknownLengthToUserBufferWithOpc(instrSession, writeBuffer, (ViInt32)timeout, (ViInt32)bufferSize, readBuffer, (ViInt32*)numBytesRead);
}

/// HIFN  Adds trace <TraceName> to a previously initialized shared memory
/// HIFN  buffer.
/// HIFN
/// HIFN     Traces can only be added after the SYSTem:DATA:MEMory:INITalize and
/// HIFN  before the corresponding SYSTem:DATA:MEMory:COMMit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR traceName/Identifies the trace within the active channel setup.
/// HIPAR dataFormat/The data format of the stored trace values.
/// HIPAR numberOfPoints/Number of trace values to be stored.
ViStatus _VI_FUNC rsznl_SystemMemoryAdd(ViSession instrSession,
                                        ViString  traceName,
                                        ViInt32   dataFormat,
                                        ViInt32   numberOfPoints)
{
    ViStatus error = VI_SUCCESS;
    ViChar   param[RS_PARAM_BUF_SIZE];
    ViPChar  dataParam;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession,
        &RsZnl_rngMemoryDataFormat,
        dataFormat, &dataParam),
        3, "Data Format");

    snprintf(param, RS_PARAM_BUF_SIZE, "'%s',%s,%ld", traceName, dataParam, numberOfPoints);

    checkErr(RsCore_SetAttributeViString(instrSession, NULL,
        RSZNL_ATTR_HIDDEN_SYSTEM_MEMORY_ADD,
        RS_VAL_DIRECT_USER_CALL,
        param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the names of the shared memory buffers initialized using
/// HIFN  SYSTem:DATA:MEMory:INITalize.
/// HIFN
/// HIFN     Before the SYSTem:DATA:MEMory:COMMit, an initialized shared memory
/// HIFN  buffer has the temporary name NewMemory.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR catalog/Queries the names of the shared memory buffers initialized using
/// HIPAR catalog/SYSTem:DATA:MEMory:INITalize.
ViStatus _VI_FUNC rsznl_QuerySystemMemoryCatalog(ViSession instrSession,
                                                 ViInt32   bufferSize,
                                                 ViChar    catalog[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_CATALOG,
            bufferSize, catalog),
            3, "Catalog");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Completes the setup of a named shared memory buffer that was
/// HIFN  initialized using SYSTem:DATA:MEMory:INITalize an configured using one
/// HIFN  or more SYSTem:DATA:MEMory:ADD. The buffer is then available in
/// HIFN  Windows.
/// HIFN
/// HIFN     Before the next COMMit, the size of the created buffer can be queried
/// HIFN  using SYSTem:DATA:MEMory:SIZE?.
/// HIFN
/// HIFN     To delete the buffer and free its memory, use
/// HIFN  SYSTem:DATA:MEMory:DELete <ShMemName>, or SYSTem:DATA:MEMory:RESet.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memoryCommit/Completes the setup of a named shared memory buffer that was
/// HIPAR memoryCommit/initialized using SYSTem:DATA:MEMory:INITalize an configured using one
/// HIPAR memoryCommit/or more SYSTem:DATA:MEMory:ADD. The buffer is then available in
/// HIPAR memoryCommit/Windows.
ViStatus _VI_FUNC rsznl_ConfigureSystemMemoryCommit(ViSession instrSession,
                                                    ViString  memoryCommit)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_COMMIT, memoryCommit),
            2, "Memory Commit");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes a shared memory buffer <ShMemName> initialized using
/// HIFN  SYSTem:DATA:MEMory:INITalize.
/// HIFN
/// HIFN     Before the SYSTem:DATA:MEMory:COMMit, an initialized shared memory
/// HIFN  buffer has the temporary name NewMemory. Do not delete it.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memoryDelete/Deletes a shared memory buffer <ShMemName> initialized using
/// HIPAR memoryDelete/SYSTem:DATA:MEMory:INITalize.
ViStatus _VI_FUNC rsznl_ConfigureSystemMemoryDelete(ViSession instrSession,
                                                    ViString  memoryDelete)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_DELETE, memoryDelete),
            2, "Memory Delete");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initializes a new shared memory buffer.
/// HIFN
/// HIFN     Use SYSTem:DATA:MEMory:ADD to add traces to it.Finally, use
/// HIFN  SYSTem:DATA:MEMory:COMMit to complete the setup and create the named
/// HIFN  shared memory buffer in Windows.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SystemMemoryInit(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_INIT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the offset in bytes of the last added trace data block,
/// HIFN  relative to the start of the shared memory buffer (see
/// HIFN  SYSTem:DATA:MEMory:ADD).
/// HIFN
/// HIFN     The offset is required by processes that want to read the trace data
/// HIFN  from the buffer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR offset/Queries the offset in bytes of the last added trace data block,
/// HIPAR offset/relative to the start of the shared memory buffer (see
/// HIPAR offset/SYSTem:DATA:MEMory:ADD).
ViStatus _VI_FUNC rsznl_QuerySystemMemoryOffset(ViSession instrSession,
                                                ViReal64* offset)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_OFFSET, offset),
            2, "Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Define the start and stop powers for a power sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR sweepStart/Define the start powers for a power sweep.
/// HIPAR sweepStop/These commands define the stop powers for a power sweep
ViStatus _VI_FUNC rsznl_ConfigureStimulusPowerSweepStart(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   port,
                                                         ViReal64  sweepStart,
                                                         ViReal64  sweepStop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_POWER_SWEEP_START,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_POWER_SWEEP_START,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_POWER_SWEEP_START, sweepStart),
            4, "Sweep Start");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_POWER_SWEP_STOP, sweepStop),
            5, "Sweep Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a linear factor to modify the internal source power at port
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR linearFactor/Defines a linear factor to modify the internal source power at port
/// HIPAR linearFactor/<PhyPt> as a function of the stimulus frequency.
ViStatus _VI_FUNC rsznl_ConfigureStimulusSourcePowerLinearFactor(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  linearFactor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_SOURCE_POWER_LINEAR_FACTOR,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_SOURCE_POWER_LINEAR_FACTOR,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STIMULUS_SOURCE_POWER_LINEAR_FACTOR, linearFactor),
            4, "Linear Factor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Turns the RF source power at a specified test port on or off.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR rfSourceEnabled/Turns the RF source power at a specified test port on or off.
ViStatus _VI_FUNC rsznl_ConfigureStimulusRFSourceEnabled(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   port,
                                                         ViBoolean rfSourceEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_RF_SOURCE_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STIMULUS_RF_SOURCE_ENABLED,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STIMULUS_RF_SOURCE_ENABLED, rfSourceEnabled),
            4, "RF Source Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Allows you to link the time gates of different (time domain) traces,
/// HIFN  i.e. to align the time gate settings across linked coupled traces.
/// HIFN     Use the empty string to unlink the active trace of channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR timeGateLink/Allows you to link the time gates of different (time domain) traces,
/// HIPAR timeGateLink/i.e. to align the time gate settings across linked coupled traces.
ViStatus _VI_FUNC rsznl_ConfigureTimeGateLink(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  timeGateLink)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_TIME_GATE_LINK,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_TIME_GATE_LINK, timeGateLink),
            3, "Time Gate Link");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Displays or hides the compression point result in the diagram area
/// HIFN  channel <Chn>'s active trace..
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR pointState/Displays or hides the compression point result in the diagram area
/// HIPAR pointState/channel <Chn>'s active trace..
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionPointState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean pointState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_POINT_STATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_POINT_STATE, pointState),
            3, "Point State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the compression value x for the compression point measurement
/// HIFN  for dB formatted traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR compressionLevel/Defines the compression value x for the compression point measurement
/// HIPAR compressionLevel/for dB formatted traces.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionLevel(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  compressionLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_LEVEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_LEVEL, compressionLevel),
            3, "Compression Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the compression value x for the compression point measurement
/// HIFN  for phase formatted traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR compressionPhase/Defines the compression value x for the compression point measurement
/// HIPAR compressionPhase/for phase formatted traces.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionPhase(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  compressionPhase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_PHASE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_PHASE, compressionPhase),
            3, "Compression Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the compression point of an S-parameter or ratio measured in a
/// HIFN  power sweep.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR compressionPointIn/Returns the compression point of an S-parameter or ratio measured in a
/// HIPAR compressionPointIn/power sweep.
/// HIPAR compressionPointOut/Returns the compression point of an S-parameter or ratio measured in a
/// HIPAR compressionPointOut/power sweep.
ViStatus _VI_FUNC rsznl_QueryStatisticsCompressionResult(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64* compressionPointIn,
                                                         ViReal64* compressionPointOut)
{
    ViStatus  error = VI_SUCCESS;
    ViChar    repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar    response[RS_REPCAP_BUF_SIZE] = "";
    ViReal64* double_array = NULL;
    ViInt32   arr_size;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_GetAttributeViString(instrSession, repCap,
        RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT, 2, response));

    checkErr(RsCore_Convert_String_To_ViReal64Array(instrSession, response, &double_array, &arr_size));
    if (arr_size == 2) {
        *compressionPointIn = double_array[0];
        *compressionPointOut = double_array[1];
    }
    else{
        *compressionPointIn = RS_VAL_NAN_VI_REAL64;
        *compressionPointOut = RS_VAL_NAN_VI_REAL64;
    }

Error:
    if (double_array)
        free(double_array);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how the reference value for the compression point calculation
/// HIFN  is calculated
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR reference/Defines how the reference value for the compression point calculation
/// HIPAR reference/is calculated
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReference(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   reference)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE, reference),
            3, "Reference");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Allows you to select the marker whose value shall be used as the
/// HIFN  reference (small signal value) for the compression point calculation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceMarker/Allows you to select the marker whose value shall be used as the
/// HIPAR referenceMarker/reference (small signal value) for the compression point calculation.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceMarker(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referenceMarker)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_MARKER,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_MARKER, referenceMarker),
            3, "Reference Marker");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects one of the 10 channel-specific user defined ranges as the
/// HIFN  reference range for compression point calculation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceRange/Selects one of the 10 channel-specific user defined ranges as the
/// HIPAR referenceRange/reference range for compression point calculation.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceRange(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referenceRange)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_RANGE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_RANGE, referenceRange),
            3, "Reference Range");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the start and stop value of the range.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR rangeStart/Defines the start value of the range.
/// HIPAR rangeStop/Defines the stop value of the range.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionRangeStartStop(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  rangeStart,
                            ViReal64  rangeStop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_RANGE_START,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_RANGE_START, rangeStart),
            3, "Range Start");

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_RANGE_STOP, rangeStop),
            4, "Range Stop");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Displays or hides range limit lines for the reference range
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR showRangeEnabled/Displays or hides range limit lines for the reference range
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionShowRangeEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean showRangeEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_SHOW_RANGE_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_SHOW_RANGE_ENABLED, showRangeEnabled),
            3, "Show Range Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Manually defines the reference level for compression point calculation
/// HIFN  on dB formatted traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR referenceLevel/Manually defines the reference level for compression point calculation
/// HIPAR referenceLevel/on dB formatted traces.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceLevel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  referenceLevel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_LEVEL,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_LEVEL, referenceLevel),
            3, "Reference Level");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Manually defines the reference phase for compression point calculation
/// HIFN  on phase formatted traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR referencePhase/Manually defines the reference phase for compression point calculation
/// HIPAR referencePhase/on phase formatted traces.
ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferencePhase(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referencePhase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_PHASE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_PHASE, referencePhase),
            3, "Reference Phase");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures an external power meter and adds it to the list of
/// HIFN  available power meters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerMeterNumber/This control sets the number of the configured power meter. Power
/// HIPAR powerMeterNumber/meters must be numbered in ascending order, starting with 1. If a
/// HIPAR powerMeterNumber/number is re-used, the previous generator configuration is overwritten.
/// HIPAR powerMeterNumber/
/// HIPAR powerMeterName/Name of the external power meter (string parameter). An empty string
/// HIPAR powerMeterName/means that no particular name is assigned to the power meter
/// HIPAR driver/The power meter type is identical with the name of the power meter
/// HIPAR driver/driver file (*.pwm) stored in the resources\extdev subdirectory of the
/// HIPAR driver/analyzer's program directory. Can also contain the power meter driver
/// HIPAR driver/file name with its complete path.
/// HIPAR interfaceType/Interface type (string parameter): 'VXI-11', 'socket', 'GPIB0', ...,
/// HIPAR interfaceType/'GPIB9', 'other'
/// HIPAR interfaceAddress/Interface address (string parameter), depending on the interface type
/// HIPAR sensorId/This optional string parameter is used for power meters that can
/// HIPAR sensorId/control several power sensors. By specifying the suitable <SensorId>
/// HIPAR sensorId/you can address the related power sensor. For example, you have four
/// HIPAR sensorId/power sensor connectors, Sensor A to Sensor D. By specifying 'A', 'B',
/// HIPAR sensorId/'C' or 'D', you can take control over the power sensor that is attached
/// HIPAR sensorId/to this connector. Pass empty string to ignore this parameter.
ViStatus _VI_FUNC rsznl_DefinePowerMeter(ViSession instrSession,
                                         ViInt32   powerMeterNumber,
                                         ViString  powerMeterName,
                                         ViString  driver,
                                         ViString  interfaceType,
                                         ViString  interfaceAddress,
                                         ViString  sensorId)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    if (strlen(sensorId) == 0)
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYSTem:COMMunicate:RDEVice:PMETer%ld:DEFine  '%s','%s','%s','%s'", powerMeterNumber,powerMeterName, driver, interfaceType, interfaceAddress);
    else
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SYSTem:COMMunicate:RDEVice:PMETer%ld:DEFine  '%s','%s','%s','%s','%s'",
                powerMeterNumber, powerMeterName, driver, interfaceType, interfaceAddress, sensorId);
        checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Clears the configuration table for external power meters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_DeletePowerMeter(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_POWER_METER_DELETE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables auto-configuration of R&S NRPxxS/SN power sensors.
/// HIFN  If the function is enabled, the analyzer automatically configures all
/// HIFN  power sensors detected at any of the USB ports as Pmtr 1, Pmtr 2,
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoConfigure/Enables or disables auto-configuration of R&S NRPxxS/SN power sensors.
/// HIPAR autoConfigure/If the function is enabled, the analyzer automatically configures all
/// HIPAR autoConfigure/power sensors detected at any of the USB ports as Pmtr 1, Pmtr 2,
ViStatus _VI_FUNC rsznl_ConfigurePowerMeterAutoConfigure(ViSession instrSession,
                                                         ViBoolean autoConfigure)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_POWER_METER_AUTO_CONFIGURE, autoConfigure),
            2, "Auto Configure");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects an external power meter for the scalar source power
/// HIFN  calibration (flatness calibration).
/// HIFN     Cannot be used unless a power meter is connected via GPIB bus, USB or
/// HIFN  LAN interface and configured.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR powerMeter/Selects an external power meter for the scalar source power
/// HIPAR powerMeter/calibration (flatness calibration).
ViStatus _VI_FUNC rsznl_SelectPowerMeter(ViSession instrSession,
                                         ViInt32   powerMeter)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_SELECT_POWER_METER, powerMeter),
            2, "Select Power Meter");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the wave quantity and the source for the receiver power
/// HIFN  calibration, starts the calibration sweep, and applies the receiver
/// HIFN  power correction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR wave/Selects the Bwawes
/// HIPAR calPort/Calibrated port number
/// HIPAR sourceType/Internal source at port <CalPort>
/// HIPAR sourcePort/Number of the port for the internal source
/// HIPAR calOnlyPortFreq/Relevant for frequency conversion measurements only.
ViStatus _VI_FUNC rsznl_PowerCalibrationReceiver(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   wave,
                                                 ViInt32   calPort,
                                                 ViInt32   sourceType,
                                                 ViInt32   sourcePort,
                                                 ViBoolean calOnlyPortFreq)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  waveCmd;
    ViPChar  sourceTypeCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerCalibrationReceiverWave, wave, &waveCmd));
    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerCalibrationReceiver, sourceType, &sourceTypeCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENSe%ld:CORRection:POWer:ACQuire %s,%ld,%s,%ld,%s", channel, waveCmd, calPort, sourceTypeCmd, sourcePort, (calOnlyPortFreq ==VI_TRUE) ? "ON" : "OFF");
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Gets the power calibration label of the active trace in channel <Chn>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR bufferSize/Size of output array.
/// HIPAR label/Gets the power calibration label of the active trace in channel <Chn>.
ViStatus _VI_FUNC rsznl_QueryPowerCalibrationLabel(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_GetAttributeViString(instrSession, repCap,
        RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT, bufferSize, label));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Writes receiver power correction data sets.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR calibratedWave/Identifier for the calibrated wave:
/// HIPAR numberOfValues/This control sets the number of power correction values.
/// HIPAR powerCorrectionValues/This control sets the power correction values.
ViStatus _VI_FUNC rsznl_WriteCalibrationPowerDataSet(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  calibratedWave,
                                                     ViInt32   numberOfValues,
                                                     ViReal64  powerCorrectionValues[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENSe%ld:CORRection:POWer:DATA '%s',", channel, calibratedWave);
    checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, powerCorrectionValues, numberOfValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Reads receiver power correction data sets.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR arraySize/This control specifies the passed array size.
/// HIPAR calibratedWave/Identifier for the calibrated wave:
/// HIPAR numberOfValues/This control returns the number of power correction values.
/// HIPAR powerCorrectionValues/This control returns the power correction values.
ViStatus _VI_FUNC rsznl_ReadCalibrationPowerDataSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   arraySize,
                                                    ViString  calibratedWave,
                                                    ViInt32*  numberOfValues,
                                                    ViReal64  powerCorrectionValues[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENSe%ld:CORRection:POWer:DATA? '%s'", channel, calibratedWave);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, arraySize, powerCorrectionValues,
        numberOfValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Activates all power calibrations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_ActivatePowerCalibration(ViSession instrSession,
                                                 ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_ACTIVATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_ACTIVATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deactivates all power calibrations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DeactivatePowerCalibration(ViSession instrSession,
                                                   ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_DEACTIVATE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_DEACTIVATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the trace format for the limit check
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR limitCheckFormat/Selects the trace format for the limit check
ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationLimitCheckFormat(
                            ViSession instrSession,
                            ViInt32   limitCheckFormat)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT, limitCheckFormat),
            2, "Limit Check Format");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Disables/enables averaging for cal validation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR averageState/Disables/enables averaging for cal validation.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationAverageState(
                            ViSession instrSession,
                            ViBoolean averageState)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_CALIBRATION_VALIDATION_AVERAGE_STATE, averageState),
            2, "Average State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Runs the cal validation with its configured settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_RunCalibrationValidation(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_ACTIVATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Displays the result (PASS/FAIL) of the preceding cal validation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Size of output array.
/// HIPAR result/Displays the result (PASS/FAIL) of the preceding cal validation.
ViStatus _VI_FUNC rsznl_QueryCalibrationValidationResult(ViSession instrSession,
                                                         ViInt32   bufferSize,
                                                         ViChar    result[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViString(instrSession, NULL, RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT,
            bufferSize, result),
            3, "Result");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the magnitude cal validation limits for the MLINear trace
/// HIFN  format (see RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR lower/Magnitude lower limit value.
/// HIPAR upper/Magnitude upper limit value.
ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsMagnitude(ViSession instrSession,
                                                             ViInt32   port,
                                                             ViReal64  lower,
                                                             ViReal64  upper)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmdl[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   cmdu[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmdl, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:MAGNitude:LOWer %ld,%.12lG",port, lower);
    snprintf(cmdu, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:MAGNitude:UPPer %ld,%.12lG",port, upper);

    checkErr(rsznl_WriteInstrData(instrSession, cmdl));
    checkErr(rsznl_WriteInstrData(instrSession, cmdu));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the phase cal validation limits for the MLINear trace format
/// HIFN  (see RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR port/Physical analyzer port number.
/// HIPAR lower/Phase lower limit value.
/// HIPAR upper/Phase upper limit value.
ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsPhase(ViSession instrSession,
                                                         ViInt32   port,
                                                         ViReal64  lower,
                                                         ViReal64  upper)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmdl[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   cmdu[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmdl, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:PHASe:LOWer %ld,%.12lG", port, lower);
    snprintf(cmdu, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:PHASe:UPPer %ld,%.12lG", port, upper);

    checkErr(rsznl_WriteInstrData(instrSession, cmdl));
    checkErr(rsznl_WriteInstrData(instrSession, cmdu));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the upper and lower cal validation limits for the REAL trace
/// HIFN  format (see RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR port/Physical analyzer port number.
/// HIPAR lower/Real lower limit value.
/// HIPAR upper/Real upper limit value.
ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsReal(ViSession instrSession,
                                                        ViInt32   port,
                                                        ViReal64  lower,
                                                        ViReal64  upper)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmdl[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   cmdu[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmdl, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:REAL:LOWer %ld,%.12lG", port, lower);
    snprintf(cmdu, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:REAL:UPPer %ld,%.12lG", port, upper);

    checkErr(rsznl_WriteInstrData(instrSession, cmdl));
    checkErr(rsznl_WriteInstrData(instrSession, cmdu));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the upper and lower cal validation limits for the REAL trace
/// HIFN  format (see RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR port/Physical analyzer port number.
/// HIPAR lower/Imaginary lower limit value.
/// HIPAR upper/Imaginary upper limit value.
ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsImaginary(ViSession instrSession,
                                                             ViInt32   port,
                                                             ViReal64  lower,
                                                             ViReal64  upper)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmdl[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   cmdu[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmdl, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:IMAGinary:LOWer %ld,%.12lG", port, lower);
    snprintf(cmdu, RS_MAX_MESSAGE_BUF_SIZE, "CALCulate:CALValidate:RESPonse:IMAGinary:UPPer %ld,%.12lG", port, upper);

    checkErr(rsznl_WriteInstrData(instrSession, cmdl));
    checkErr(rsznl_WriteInstrData(instrSession, cmdu));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Resets the cal validation limits.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_RestoreDefaultCalibrationValidationLimits(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_VALIDATION_LIMITS_RESTORE_DEFAULT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the CalU characterization to be used for the cal validation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR characterization/Selects the CalU characterization to be used for the cal validation.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationCharacterization(
                            ViSession instrSession,
                            ViString  characterization)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_CALIBRATION_VALIDATION_CHARACTERIZATION, characterization),
            2, "Characterization");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the CalU standard to be used for cal validation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR standard/Selects the CalU standard to be used for cal validation.
ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationStandard(
                            ViSession instrSession,
                            ViInt32   standard)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_CALIBRATION_VALIDATION_STANDARD, standard),
            2, "Standard");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines how to define the source power that is used to perform the
/// HIFN  first calibration sweep of the source power calibration (Reference
/// HIFN  Receiver Cal Power).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceReciever/Defines how to define the source power that is used to perform the
/// HIPAR referenceReciever/first calibration sweep of the source power calibration (Reference
/// HIPAR referenceReciever/Receiver Cal Power).
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigReferenceReciever(
                            ViSession instrSession,
                            ViInt32   referenceReciever)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_REFERENCE_RECIEVER, referenceReciever),
            2, "Reference Reciever");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the source power taht is used to perform the first calibration
/// HIFN  sweep of the source power calibration (Reference Receiver Cal Power).
/// HIFN  This predefined power value is ignored if the device is set to use the
/// HIFN  calculated port power result
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR referenceRecieverPower/Defines the source power taht is used to perform the first calibration
/// HIPAR referenceRecieverPower/sweep of the source power calibration (Reference Receiver Cal Power).
/// HIPAR referenceRecieverPower/This predefined power value is ignored if the device is set to use the
/// HIPAR referenceRecieverPower/calculated port power result
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigReferenceRecieverPower(
                            ViSession instrSession,
                            ViReal64  referenceRecieverPower)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_REFERENCE_RECIEVER_POWER, referenceRecieverPower),
            2, "Reference Reciever Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines a port-specific source power or a power offset relative to the
/// HIFN  channel power.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR offset/Port-specific power offset
/// HIPAR offsetType/Offset type
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigPortPowerOffset(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  offset,
                            ViInt32   offsetType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  offsetTypeCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerCalibrationConfigOfsetType, offsetType, &offsetTypeCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce%ld:POWer%ld:LEVel:IMMediate:OFFSet %.12lG,%s", channel, port, offset, offsetTypeCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies a gain (positive values) or an attenuation (negative values)
/// HIFN  in the signal path between the source port and the calibrated reference
/// HIFN  plane. The value has no impact on the source power.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR calPowerOffset/Specifies a gain (positive values) or an attenuation (negative values)
/// HIPAR calPowerOffset/in the signal path between the source port and the calibrated reference
/// HIPAR calPowerOffset/plane. The value has no impact on the source power.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigCalPowerOffset(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  calPowerOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET, calPowerOffset),
            4, "Cal Power Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the use of two-port transmission coefficients for
/// HIFN  power correction.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR enabled/Enables (ON) or disables (OFF) the two-port transmission coefficients
/// HIPAR position/Determines the two-port the command refers to
ViStatus _VI_FUNC rsznl_ConfigurePowerTransmissionCoefficientTwoPortEnabled(
                            ViSession instrSession,
                            ViBoolean enabled,
                            ViInt32   deEmbeddingPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbeddingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbeddingPosition, &deEmbeddingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce:POWer:CORRection:TCOefficient:STATe  %s,%s", (enabled == VI_TRUE) ? "ON" : "OFF", deEmbeddingPositionCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the number of entries in the transmission coefficient list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR deEmbedingPosition/Determines the two-port the command refers to
/// HIPAR count/Number of entries in the transmission coefficient list.
ViStatus _VI_FUNC rsznl_QueryPowerTransmissionCoeficientTwoPortCount(
                            ViSession instrSession,
                            ViInt32   deEmbedingPosition,
                            ViInt32*  count)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbedingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbedingPosition, &deEmbedingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce:POWer:CORRection:TCOefficient:COUNt? %s", deEmbedingPositionCmd);
    checkErr(rsznl_QueryViInt32(instrSession, cmd, count));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Inserts a new frequency and transmission coefficient at position no.
/// HIFN  <ListNo> in the transmission coefficient list. The following points are
/// HIFN  shifted down in the list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR listNumber/Selects List Number.
/// HIPAR frequency/Stimulus frequency value. If several points with identical frequencies
/// HIPAR frequency/are added, the analyzer automatically ensures a frequency spacing of 1
/// HIPAR frequency/Hz
/// HIPAR transmissionCoefficient/Transmission coefficient
/// HIPAR position/Determines the two-port the command refers to
ViStatus _VI_FUNC rsznl_InsertPowerTransmissionCoefficientTwoPort(
                            ViSession instrSession,
                            ViInt32   listNumber,
                            ViReal64  frequency,
                            ViReal64  transmissionCoefficient,
                            ViInt32   deEmbedingPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbedingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbedingPosition, &deEmbedingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce:POWer:CORRection:TCOefficient:INSert%ld  %.12lG,%.12lG,%s", listNumber, frequency, transmissionCoefficient, deEmbedingPositionCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Adds a new frequency and transmission coefficient to the end of the
/// HIFN  transmission coefficient list. The query returns the frequency and
/// HIFN  transmission coefficient no. <ListNo>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR listNumber/Selects List Number.
/// HIPAR frequency/Stimulus frequency value. If several points with identical frequencies
/// HIPAR frequency/are added, the analyzer automatically ensures a frequency spacing of 1
/// HIPAR frequency/Hz
/// HIPAR transmissionCoefficient/Transmission coefficient
/// HIPAR position/Determines the two-port the command refers to
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_DefinePowerTransmissionCoefficientTwoPort(
                            ViSession instrSession,
                            ViInt32   listNumber,
                            ViReal64  frequency,
                            ViReal64  transmissionCoefficient,
                            ViInt32   deEmbeddingPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbedingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbeddingPosition, &deEmbedingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce:POWer:CORRection:TCOefficient:DEF%ld  %.12lG,%.12lG,%s", listNumber, frequency, transmissionCoefficient, deEmbedingPositionCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Deletes entry <ListNo> from the transmission coefficient list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deEmbeddingPosition/Deletes entry <ListNo> from the transmission coefficient list.
ViStatus _VI_FUNC rsznl_DeletePowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   deEmbeddingPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_DELETE, deEmbeddingPosition),
            2, "De Embedding Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Clears the transmission coefficient list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR deEmbedingPosition/Clears the transmission coefficient list.
ViStatus _VI_FUNC rsznl_DeleteAllPowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   deEmbedingPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_DELETE_ALL, deEmbedingPosition),
            2, "De Embedding Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Copies the active trace of channel <Chn>.
/// HIFN
/// HIFN     Attribute(s):
/// HIFN     -
/// HIFN
/// HIFN     Remote-control command(s):
/// HIFN     CALCulate<Chn>:PARameter:COPY
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR targetTraceName/Name of the new trace (i.e. the copy).
/// HIPAR toNewDiagram/Assign to new diagram or assigned to the diagram area of the copied
/// HIPAR toNewDiagram/trace
ViStatus _VI_FUNC rsznl_TraceCopy(ViSession instrSession,
                                  ViInt32   channel,
                                  ViString  targetTraceName,
                                  ViBoolean toNewDiagram)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_LEN] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_LEN, "CALC%ld:PARameter:COPY %s,%s", channel, targetTraceName, (toNewDiagram == VI_TRUE) ? "ON" : "OFF");

    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects a trace which provides the points for the transmission
/// HIFN  coefficient list.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR trace/String parameter for the trace name, e.g. 'Trc1'. The trace must exist
/// HIPAR trace/in the active channel setup
/// HIPAR deEmbeddingPosition/Determines the two-port the command refers to
ViStatus _VI_FUNC rsznl_SelectPowerTransmissionCoeficientTwoPortTrace(
                            ViSession instrSession,
                            ViString  trace,
                            ViInt32   deEmbeddingPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbedingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbeddingPosition, &deEmbedingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce:POWer:CORRection:TCOefficient:FEED '%s',%s", trace, deEmbedingPositionCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Saves two-port transmission coefficients of channel <Ch> to a power
/// HIFN  meter correction list file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR fileName/Saves two-port transmission coefficients of channel <Ch> to a power
/// HIPAR fileName/meter correction list file.
/// HIPAR channel/Channel number.
ViStatus _VI_FUNC rsznl_StorePowerTransmissionCoeficientTwoPortCoefficient(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  fileName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_STORE_COEFFICIENT,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViString(instrSession, repCap, RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_STORE_COEFFICIENT, fileName),
            3, "File Name");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Loads trace data from a specified power meter correction file or trace
/// HIFN  file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR traceFile/Specifies the name and directory of the loaded power meter correction
/// HIPAR traceFile/list file. If no path is specified the analyzer searches the current
/// HIPAR traceFile/directory. The file extensions *.s<n>p, *csv, and *.pmcl for
/// HIPAR traceFile/Touchstone, ASCII, and power meter correction list files are mandatory.
/// HIPAR trace/Specifies optional string parameter: For imported Touchstone files for
/// HIPAR trace/more than one port (*.s2p, *.s3p, *.s4p), the parameter denotes the
/// HIPAR trace/imported S-parameter ('S11', 'S12', ...). For ASCII (*.csv) files, the
/// HIPAR trace/parameter references a trace name in the file (case sensitive). If the
/// HIPAR trace/parameter is omitted, the first trace in the specified file is
/// HIPAR trace/imported. The parameter is not used for power meter correction list
/// HIPAR trace/files (*.pmcl).
/// HIPAR deEmbeddingPosition/Determines the two-port the command refers to
ViStatus _VI_FUNC rsznl_LoadPowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  traceFile,
                            ViString  trace,
                            ViInt32   deEmbeddingPosition)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  deEmbedingPositionCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition, deEmbeddingPosition, &deEmbedingPositionCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEMory:LOAD:CORRection:TCOefficient%ld  '%s','%s',%s", channel, traceFile, trace, deEmbedingPositionCmd);
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the position of the additional two-port in the test setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR additionalTwoPortPosition/Selects the position of the additional two-port in the test setup.
ViStatus _VI_FUNC rsznl_ConfigurePowerTransmissionCoeficientAdditionalTwoPortPosition(
                            ViSession instrSession,
                            ViBoolean additionalTwoPortPosition)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_ADDITIONAL_TWO_PORT_POSITION, additionalTwoPortPosition),
            2, "Additional Two Port Position");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets a limit for the number of calibration sweeps in the source power
/// HIFN  flatness cal. It's valid for all channels and ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR maxItterations/Sets a limit for the number of calibration sweeps in the source power
/// HIPAR maxItterations/flatness cal. It's valid for all channels and ports.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationMaxItterations(
                            ViSession instrSession,
                            ViInt32   maxItterations)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_MAX_ITTERATIONS, maxItterations),
            2, "Max Itterations");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the maximum deviation of the measured power from the target
/// HIFN  power of the calibration. It's valid for all channels and calibrated
/// HIFN  ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR tolerance/Specifies the maximum deviation of the measured power from the target
/// HIPAR tolerance/power of the calibration. It's valid for all channels and calibrated
/// HIPAR tolerance/ports.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationTolerance(ViSession instrSession,
                                                           ViReal64  tolerance)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_TOLERANCE, tolerance),
            2, "Tolerance");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the convergence factor for a source power calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR convergence/Specifies the convergence factor for a source power calibration.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConvergence(ViSession instrSession,
                                                             ViReal64  convergence)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_CONVERGENCE, convergence),
            2, "Convergence");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the source power calibration method.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR method/Selects the source power calibration method.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationMethod(ViSession instrSession,
                                                        ViInt32   method)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_METHOD, method),
            2, "Method");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Initiates a source power calibration for the source port <PhyPt> using
/// HIFN  an external power meter no. 1 or 2. To initiate a source power
/// HIFN  calibration for arbitrary power meters, use the alternative commands
/// HIFN  listed in the program example below.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR initiateCalibration/Initiates a source power calibration for the source port <PhyPt> using
/// HIPAR initiateCalibration/an external power meter no. 1 or 2. To initiate a source power
/// HIPAR initiateCalibration/calibration for arbitrary power meters, use the alternative commands
/// HIPAR initiateCalibration/listed in the program example below.
ViStatus _VI_FUNC rsznl_InitiatePowerCalibration(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   port,
                                                 ViInt32   initiateCalibration)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

   strcat(repCap, ",");
   strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_INITIATE_CALIBRATION, initiateCalibration),
            4, "Initiate Calibration");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Writes scalar source power correction data sets. A power correction
/// HIFN  data set contains n real values where:
/// HIFN     - Each value corresponds to the ratio of the actual power at the
/// HIFN  reference plane (value provided by the used source) to the uncalibrated
/// HIFN  power in dB.
/// HIFN     - The number n is equal to the number of sweep points.
/// HIFN     Increasing (decreasing) the values in the correction data sets
/// HIFN  increases (decreases) the power at the reference plane. Writing
/// HIFN  correction data (the setting command) fails if the number of
/// HIFN  transferred values is not equal to the number of sweep points.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR source/Identifier for the calibrated wave:
/// HIPAR numberOfValues/This control sets the number of power correction values.
/// HIPAR powerCorrectionValues/This control sets the power correction values.
ViStatus _VI_FUNC rsznl_WritePowerCalibrationDataSet(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  source,
                                                     ViInt32   numberOfValues,
                                                     ViReal64  powerCorrectionValues[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce%ld:POWer:CORRection:DATA '%s',", channel, source);
    checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, powerCorrectionValues, numberOfValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Reads scalar source power correction data sets. A power correction
/// HIFN  data set contains n real values where:
/// HIFN     - Each value corresponds to the ratio of the actual power at the
/// HIFN  reference plane (value provided by the used source) to the uncalibrated
/// HIFN  power in dB.
/// HIFN     - The number n is equal to the number of sweep points.
/// HIFN     Increasing (decreasing) the values in the correction data sets
/// HIFN  increases (decreases) the power at the reference plane
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR arraySize/This control specifies the passed array size.
/// HIPAR source/Identifier for the calibrated wave:
/// HIPAR numberOfValues/This control returns the number of power correction values.
/// HIPAR powerCorrectionValues/This control returns the power correction values.
ViStatus _VI_FUNC rsznl_ReadPowerCalibrationDataSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   arraySize,
                                                    ViString  source,
                                                    ViInt32*  numberOfValues,
                                                    ViReal64  powerCorrectionValues[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce%ld:POWer:CORRection:DATA? '%s'", channel, source);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, arraySize, powerCorrectionValues,
        numberOfValues));

    checkErr(rsznl_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Switches off all other sources during the calibration sweep for
/// HIFN  channel <Ch>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR otherSourcesEnabled/Switches off all other sources during the calibration sweep for
/// HIPAR otherSourcesEnabled/channel <Ch>.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationOtherSourcesEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean otherSourcesEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_OTHER_SOURCES_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_OTHER_SOURCES_ENABLED, otherSourcesEnabled),
            3, "Other Sources Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the source power calibration. Valid for all
/// HIFN  channels and ports.
/// HIFN     It is not possible to disable flatness calibration and the reference
/// HIFN  receiver calibration simultaneously
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR flatnessEnabled/Enables or disables the source power calibration. Valid for all
/// HIPAR flatnessEnabled/channels and ports.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationFlatnessEnabled(
                            ViSession instrSession,
                            ViBoolean flatnessEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_FLATNESS_ENABLED, flatnessEnabled),
            2, "Flatness Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables calibration of the reference receiver together
/// HIFN  with the source power calibration.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR receiverEnabled/Enables or disables calibration of the reference receiver together
/// HIPAR receiverEnabled/with the source power calibration.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReferenceReceiverEnabled(
                            ViSession instrSession,
                            ViBoolean receiverEnabled)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_RECEIVER_ENABLED, receiverEnabled),
            2, "Receiver Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Gets the number of available power calibrations (both source power and
/// HIFN  measurement receiver).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR availablePowerCalibrations/Gets the number of available power calibrations (both source power and
/// HIPAR availablePowerCalibrations/measurement receiver).
ViStatus _VI_FUNC rsznl_QueryPowerCalibrationAvailablePowerCalibrations(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  availablePowerCalibrations)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_AVAILABLE_POWER_CALIBRATIONS,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    viCheckParm(rsznl_GetAttributeViInt32(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_AVAILABLE_POWER_CALIBRATIONS, availablePowerCalibrations),
            3, "Available Power Calibrations");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects the source for the source power calibration, starts and
/// HIFN  applies the source power calibration.
/// HIFN     Note: The command cannot be used unless a power meter is connected via
/// HIFN  GPIB bus, USB or LAN interface and configured in the 'External Power
/// HIFN  Meters' dialog
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR sourceType/Port Number
/// HIPAR sourcePort/Analyzer port number, if PORT is the first parameter.
/// HIPAR calOnlyPortFreq/Relevant for frequency conversion measurements only.
ViStatus _VI_FUNC rsznl_SelectPowerCalibrationSource(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   sourceType,
                                                     ViInt32   sourcePort,
                                                     ViBoolean calOnlyPortFreq)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  sourceTypeCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &RsZnl_rngPowerCalibrationSelectSource, sourceType, &sourceTypeCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce%ld:POWer:CORRection:ACQuire  %s,%ld,%s'", channel, sourceTypeCmd, sourcePort, (calOnlyPortFreq == VI_TRUE) ? "ON" : "OFF");
    checkErr(rsznl_WriteInstrData(instrSession, cmd));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns the source power calibration data parameters.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR powerCalibration/Number of the power calibration
/// HIPAR settingsType/Selects the settings type
/// HIPAR araySize/
/// HIPAR result/
/// HIPAR numberOfValues/This control returns the number of result values.
ViStatus _VI_FUNC rsznl_QureyPowerCalibrationSettings(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   powerCalibration,
                                                      ViInt32   settingsType,
                                                      ViInt32   araySize,
                                                      ViChar    result[],
                                                      ViInt32*  numberOfValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViPChar  settingsTypeCmd;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rsznl_rngSourcePowerCalibrationData, settingsType, &settingsTypeCmd));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOURce%ld:POWer:CORRection:DATA:PARameter%ld?  %s", channel, powerCalibration, settingsTypeCmd);
    checkErr(rsznl_QueryViString(instrSession, cmd, araySize, result, (ViUInt32*)numberOfValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  If set to ON (1), only the active channel is measured. All other
/// HIFN  channels are switched off temporarily, i.e. until
/// HIFN  CONFigure:CHANnel:MEASure:ACTive is set to OFF.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationActiveChannel/If set to ON (1), only the active channel is measured. All other
/// HIPAR calibrationActiveChannel/channels are switched off temporarily, i.e. until
/// HIPAR calibrationActiveChannel/CONFigure:CHANnel:MEASure:ACTive is set to OFF.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationActiveChannelEnabled(
                            ViSession instrSession,
                            ViBoolean calibrationActiveChannel)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_ACTIVE_CHANNEL, calibrationActiveChannel),
            2, "Calibration Active Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Returns (and deletes) the result of the last verification sweep. The
/// HIFN  response contains three values:
/// HIFN     - Channel - calibrated channel, e.g. Ch 1 for channel no. 1.
/// HIFN     - Boolean -  1 for 'calibration passed' (the maximumr offset is below
/// HIFN  the tolerance), 0 for 'calibration failed'.
/// HIFN     - MaxOffset -  maximum power offset between the measured power at the
/// HIFN  reference plane and the 'Cal Power' during the verification sweep in
/// HIFN  dB.
/// HIFN     If no verfication sweep is available, or if the result has been
/// HIFN  queried already, the response is 0.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Calibrated channel, e.g. Ch 1 for channel no. 1.
/// HIPAR calibration/1 for "calibration passed" (the maximum offset is below the
/// HIPAR calibration/tolerance), 0 for "calibration failed".
/// HIPAR maxOffset/Maximum power offset between the measured power at the reference plane
/// HIPAR maxOffset/and the "Cal Power" during the verification sweep in dB.
ViStatus _VI_FUNC rsznl_QueryPowerCalibrationVerificationSweepResult(
                            ViSession  instrSession,
                            ViInt32*   channel,
                            ViBoolean* calibration,
                            ViReal64*  maxOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   res[RS_PARAM_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_GetAttributeViString(instrSession, NULL,
        RSZNL_ATTR_POWER_CALIBRATION_VERIFICATION_SWEEP_RESULT, RS_PARAM_BUF_SIZE, res));

    if (sscanf(res, "%*[^0-9]%ld%*[^0-9]%hu,%lf", channel, calibration, maxOffset)!=3)
    {
        *channel = RS_VAL_NAN_VI_INT32;
        *calibration = VI_FALSE;
        *maxOffset = RS_VAL_NAN_VI_REAL64;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables the source power calibration for channel <Ch> and
/// HIFN  for port number <PhyPt>. The setting command is disabled unless a
/// HIFN  source power calibration for the analyzer port has been performed
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR sourceEnabled/Enables or disables the source power calibration for channel <Ch> and
/// HIPAR sourceEnabled/for port number <PhyPt>. The setting command is disabled unless a
/// HIPAR sourceEnabled/source power calibration for the analyzer port has been performed
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationSourceEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean sourceEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_SOURCE_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_SOURCE_ENABLED,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

        strcat(repCap, ",");
        strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_SOURCE_ENABLED, sourceEnabled),
            4, "Source Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the receiver power calibration for channel <Ch>
/// HIFN  and for the reference waves an. The setting command is disabled unless
/// HIFN  the reference waves have been power calibrated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR referenceWaveEnable/Enables or disables the receiver power calibration for channel <Ch>
/// HIPAR referenceWaveEnable/and for the reference waves an. The setting command is disabled unless
/// HIPAR referenceWaveEnable/the reference waves have been power calibrated.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReferenceWaveEnable(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean referenceWaveEnable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_WAVE_ENABLE,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_WAVE_ENABLE,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_WAVE_ENABLE, referenceWaveEnable),
            4, "Reference Wave Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables or disables the receiver power calibration for channel <Ch>
/// HIFN  and for the received waves b<PhyPt>. The setting command is disabled
/// HIFN  unless the received waves have been power calibrated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR channel/Channel number.
/// HIPAR port/Port numbers of the analyzer.
/// HIPAR receivedWaveEnabled/Enables or disables the receiver power calibration for channel <Ch>
/// HIPAR receivedWaveEnabled/and for the received waves b<PhyPt>. The setting command is disabled
/// HIPAR receivedWaveEnabled/unless the received waves have been power calibrated.
ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReceivedWaveEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean receivedWaveEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap_port[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_RECEIVED_WAVE_ENABLED,
            "Channel", channel - 1, RS_REPCAP_BUF_SIZE, repCap));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, RSZNL_ATTR_POWER_CALIBRATION_RECEIVED_WAVE_ENABLED,
            "Port", port - 1, RS_REPCAP_BUF_SIZE, repCap_port));

    strcat(repCap, ",");
    strcat(repCap, repCap_port);

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, repCap, RSZNL_ATTR_POWER_CALIBRATION_RECEIVED_WAVE_ENABLED, receivedWaveEnabled),
            4, "Received Wave Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Includes or excludes source calibration data for an optional internal
/// HIFN  generator when storing or loading a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationData/Includes or excludes source calibration data for an optional internal
/// HIPAR calibrationData/generator when storing or loading a configuration file.
ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreInstrumentCalibrationData(
                            ViSession instrSession,
                            ViBoolean calibrationData)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViInt32(instrSession, NULL, RSZNL_ATTR_POWER_CALIBRATION_INITIATE_CALIBRATION, calibrationData),
            2, "Calibration Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Includes or excludes source calibration data for an optional internal
/// HIFN  generator when storing or loading a configuration file.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR calibrationData/Includes or excludes source calibration data for an optional internal
/// HIPAR calibrationData/generator when storing or loading a configuration file.
ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreChannelCalibrationData(
                            ViSession instrSession,
                            ViBoolean calibrationData)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViBoolean(instrSession, NULL, RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_CALIBRATION_DATA_ENABLED, calibrationData),
            2, "Calibration Data");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines a comment to be added to (the comment section of) exported
/// HIFN  trace files.
/// HIFN     This is a global setting, i.e. the comment string is used for each
/// HIFN  trace export in every open channel setup.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR exportComment/Defines a comment to be added to (the comment section of) exported
/// HIPAR exportComment/trace files.
ViStatus _VI_FUNC rsznl_ConfigureGeneralTouchstoneExportComment(
                            ViSession instrSession,
                            ViString  exportComment)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_COMMENT, exportComment),
            2, "Export Comment");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Deletes all shared memory buffers initialized using
/// HIFN  SYSTem:DATA:MEMory:INITalize.
/// HIFN
/// HIFN     For background information, see Memory-Mapped Trace Data Transfer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rsznl_SystemMemoryReset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rsznl_SetAttributeViString(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_RESET, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the size of the shared memory buffer that was last created
/// HIFN  using SYSTem:DATA:MEMory:COMMit.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR memorySize/Queries the size of the shared memory buffer that was last created
/// HIPAR memorySize/using SYSTem:DATA:MEMory:COMMit.
ViStatus _VI_FUNC rsznl_QuerySystemMemorySize(ViSession instrSession,
                                              ViReal64* memorySize)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rsznl_GetAttributeViReal64(instrSession, NULL, RSZNL_ATTR_SYSTEM_MEMORY_SIZE, memorySize),
            2, "Memory Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function closes the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsznl_init or
/// HIPAR instrSession/rsznl_InitWithOptions function.
ViStatus _VI_FUNC rsznl_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));  

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);

    return error;
}


/*****************************************************************************
 *------------------- End Instrument Driver Source Code ---------------------*
 *****************************************************************************/
