/****************************************************************************
 *
 *  Rohde & Schwarz Vector Network Analyzer instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSZNL_HEADER
#define __RSZNL_HEADER

#include "rscore.h"
#include "rsznl_attributes.h"
#include "rsznl_utility.h"

#include <float.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/
#define RSZNL_SIMULATION_ID_QUERY      "Rohde-Schwarz,ZNL3-2Port,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSZNL_VALID_ID_RESPONSE_STRING "Rohde-Schwarz,ZNL"      /* Valid response for identification query */
#define RSZNL_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSZNL_OPC_TIMEOUT              30000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSZNL_CLASS_DRIVER_DESCRIPTION           ""
#define RSZNL_CLASS_DRIVER_PREFIX                ""
#define RSZNL_CLASS_DRIVER_VENDOR                ""
#define RSZNL_CLASS_DRIVER_REVISION              ""
#define RSZNL_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSZNL_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSZNL_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSZNL_SPECIFIC_DRIVER_PREFIX             "RSZNL"
#define RSZNL_SPECIFIC_DRIVER_LOCATOR            ""
#define RSZNL_SPECIFIC_DRIVER_VENDOR             ""
#define RSZNL_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define RSZNL_MINOR_VERSION                      70L   /* Instrument driver minor version          */
#define RSZNL_MINOR_MINOR_VERSION                1L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSZNL_SUPPORTED_INSTRUMENT_MODELS        "ZNL,ZNLE"    /* Instrument driver supported model(s)     */
#define RSZNL_GROUP_CAPABILITIES                 ""
#define RSZNL_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSZNL_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSZNL_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSZNL_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSZNL_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSZNL_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSZNL_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSZNL_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSZNL_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSZNL_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSZNL_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSZNL_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSZNL_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSZNL_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSZNL_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSZNL_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSZNL_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSZNL_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSZNL_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSZNL_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSZNL_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSZNL_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSZNL_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSZNL_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSZNL_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSZNL_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSZNL_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME

/* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSZNL_ATTR_VECTOR_NETWORK_ANALYZER_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356994
#define RSZNL_ATTR_OPERATING_MODE_MULTIVIEW_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358191
#define RSZNL_ATTR_NUMBER_OF_TEST_PORTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357764
#define RSZNL_ATTR_CHANNEL_SETUP_DUPLICATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358192
#define RSZNL_ATTR_CHANNEL_SETUP_DELETE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358195
#define RSZNL_ATTR_OPERATING_MODE_LIST_OF_CHANNEL_SETUPS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358196
#define RSZNL_ATTR_CHANNEL_SETUP_ACTIVE_CHANNEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357763
#define RSZNL_ATTR_SEQUENCER_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358200
#define RSZNL_ATTR_SEQUENCER_INIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358201
#define RSZNL_ATTR_SEQUENCER_ABORT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358202
#define RSZNL_ATTR_SEQUENCER_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358203
#define RSZNL_ATTR_MARKER_COUPLING_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358407
#define RSZNL_ATTR_STIMULUS_FREQUENCY_START                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356995
#define RSZNL_ATTR_STIMULUS_FREQUENCY_STOP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356996
#define RSZNL_ATTR_STIMULUS_FREQUENCY_CENTER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356997
#define RSZNL_ATTR_STIMULUS_FREQUENCY_SPAN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356998
#define RSZNL_ATTR_STIMULUS_INTERNAL_SOURCE_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356999
#define RSZNL_ATTR_STIMULUS_FREQUENCY_CW                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357000
#define RSZNL_ATTR_STIMULUS_FREQUENCY_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357001
#define RSZNL_ATTR_STIMULUS_FREQUENCY_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357002
#define RSZNL_ATTR_STIMULUS_SOURCE_PORT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357003
#define RSZNL_ATTR_STIMULUS_RF_CHANNEL_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357005
#define RSZNL_ATTR_STIMULUS_TIME_DOMAIN_START_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357006
#define RSZNL_ATTR_STIMULUS_TIME_DOMAIN_STOP_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357007
#define RSZNL_ATTR_STIMULUS_TIME_DOMAIN_CENTER_TIME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357008
#define RSZNL_ATTR_STIMULUS_TIME_DOMAIN_TIME_SPAN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357009
#define RSZNL_ATTR_STIMULUS_TIME_DOMAIN_X_AXIS_SCALING                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357010
#define RSZNL_ATTR_STIMULUS_POWER_SWEEP_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358496
#define RSZNL_ATTR_STIMULUS_POWER_SWEP_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358497
#define RSZNL_ATTR_STIMULUS_SOURCE_POWER_LINEAR_FACTOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358498
#define RSZNL_ATTR_STIMULUS_RF_SOURCE_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358499
#define RSZNL_ATTR_STIMULUS_ATTENUATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358408
#define RSZNL_ATTR_RESOLUTION_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357011
#define RSZNL_ATTR_FILTER_SELECTIVITY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357012
#define RSZNL_ATTR_SWEEP_AVERAGE_FACTOR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357013
#define RSZNL_ATTR_SWEEP_AVERAGE_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357014
#define RSZNL_ATTR_SWEEP_AVERAGE_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357015
#define RSZNL_ATTR_SWEEP_AVERAGE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357016
#define RSZNL_ATTR_SWEEP_NUMBER_OF_POINTS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357017
#define RSZNL_ATTR_SWEEP_FREQUENCY_STEP_SIZE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357018
#define RSZNL_ATTR_SWEEP_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357019
#define RSZNL_ATTR_SWEEP_TIME_AUTO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357020
#define RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357021
#define RSZNL_ATTR_SWEEP_MEASUREMENT_DELAY_INSERTION_POINT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357022
#define RSZNL_ATTR_SWEEP_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357023
#define RSZNL_ATTR_SWEEP_MODE_CONTINUOUS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357024
#define RSZNL_ATTR_SWEEP_MODE_CONTINUOUS_ALL_CHANNELS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357025
#define RSZNL_ATTR_SWEEP_START                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357026
#define RSZNL_ATTR_SWEEP_START_SYNCHRONIZED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358405
#define RSZNL_ATTR_SWEEP_START_ALL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357027
#define RSZNL_ATTR_SWEEP_START_ALL_SYNCHRONIZED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358406
#define RSZNL_ATTR_SWEEP_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357028
#define RSZNL_ATTR_SWEEP_COUNT_ALL_CHANNELS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357029
#define RSZNL_ATTR_SWEEP_IN_SINGLE_CHANNEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357030
#define RSZNL_ATTR_SWEEP_IN_ALL_CHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357031
#define RSZNL_ATTR_SWEEP_SCOPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357032
#define RSZNL_ATTR_SWEEP_DETECTOR_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357033
#define RSZNL_ATTR_SWEEP_SEGMENT_X_AXIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357034
#define RSZNL_ATTR_SWEEP_SEGMENT_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357035
#define RSZNL_ATTR_SWEEP_SEGMENT_DELETE_ALL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357036
#define RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_POWER_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357037
#define RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_MEAS_BANDWIDTH_STATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357038
#define RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_SELECTIVITY_STATE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357039
#define RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_MEAS_DELAY_STATE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357040
#define RSZNL_ATTR_SWEEP_SEGMENT_INDEPENDENT_SEGMENT_TIME_STATE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357041
#define RSZNL_ATTR_SWEEP_SEGMENT_SUM_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357042
#define RSZNL_ATTR_SWEEP_SEGMENT_ADD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357043
#define RSZNL_ATTR_SWEEP_SEGMENT_INSERT_TIME_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357045
#define RSZNL_ATTR_SWEEP_SEGMENT_REDEFINE_TIME_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357047
#define RSZNL_ATTR_SWEEP_SEGMENT_DELETE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357048
#define RSZNL_ATTR_SWEEP_SEGMENT_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357049
#define RSZNL_ATTR_SWEEP_SEGMENT_FREQUENCY_CENTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357050
#define RSZNL_ATTR_SWEEP_SEGMENT_FREQUENCY_SPAN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357051
#define RSZNL_ATTR_AUX_PORT_CHANNEL_BITS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357052
#define RSZNL_ATTR_TRIGGER_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357055
#define RSZNL_ATTR_INIT_SOFTWARE_TRIGGER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357056
#define RSZNL_ATTR_TRIGGER_MEASUREMENT_SEQUENCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357057
#define RSZNL_ATTR_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357058
#define RSZNL_ATTR_TRIGGER_SLOPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357059
#define RSZNL_ATTR_TRACE_SELECT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357068
#define RSZNL_ATTR_TRACE_DIAGRAM_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357083
#define RSZNL_ATTR_TRACE_ASSIGN_DIAGRAM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357084
#define RSZNL_ATTR_TRACE_DELETE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357069
#define RSZNL_ATTR_TRACE_DELETE_ALL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357070
#define RSZNL_ATTR_TRACE_DELETE_ALL_CHANNELS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357071
#define RSZNL_ATTR_TRACE_CHANNEL_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357072
#define RSZNL_ATTR_TRACE_CHANNEL_CATALOG_BALANCED_PORTS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357073
#define RSZNL_ATTR_TRACE_CHANNEL_RENAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357075
#define RSZNL_ATTR_TRACE_CATALOG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357076
#define RSZNL_ATTR_TRACE_NAME_CATALOG                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357077
#define RSZNL_ATTR_MEM_TRACE_COPY_TO_MEMORY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357085
#define RSZNL_ATTR_MEM_TRACE_MATH_EXPRESSION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357088
#define RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_EXPRESSION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358409
#define RSZNL_ATTR_MEM_TRACE_MATH_MODE_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357089
#define RSZNL_ATTR_MEM_TRACE_MATH_FUNCTIONS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357090
#define RSZNL_ATTR_MEM_TRACE_MATH_WAVE_QUANTITY_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357091
#define RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358410
#define RSZNL_ATTR_MEM_TRACE_MATH_FORMATTED_FUNCTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358411
#define RSZNL_ATTR_MEM_TRACE_DELETE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357092
#define RSZNL_ATTR_MEM_TRACE_DELETE_ALL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357093
#define RSZNL_ATTR_MEM_TRACE_DELETE_ALL_CHANNELS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357094
#define RSZNL_ATTR_TIME_DOMAIN_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357095
#define RSZNL_ATTR_TIME_DOMAIN_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357096
#define RSZNL_ATTR_TIME_DOMAIN_STIMULUS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357097
#define RSZNL_ATTR_TIME_DOMAIN_IMPULSE_RESPONSE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357098
#define RSZNL_ATTR_TIME_DOMAIN_SIDE_LOBE_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357099
#define RSZNL_ATTR_TIME_DOMAIN_RESOLUTION_ENHANCEMENT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357100
#define RSZNL_ATTR_TIME_DOMAIN_GRID_HARMONIC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357101
#define RSZNL_ATTR_TIME_DOMAIN_HARMONIC_GRID_AND_KEEP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357102
#define RSZNL_ATTR_TIME_DOMAIN_AUTOMATIC_HARMONIC_GRID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357103
#define RSZNL_ATTR_TIME_DOMAIN_DC_VALUE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357104
#define RSZNL_ATTR_TIME_DOMAIN_CONTINUOUS_EXTRAPOLATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357105
#define RSZNL_ATTR_TIME_DOMAIN_EXTRAPOLATE_DC_VALUE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357106
#define RSZNL_ATTR_TIME_DOMAIN_CALCULATE_HARMONIC_GRID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357107
#define RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_TIME_DELAY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357557
#define RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_ELECTRICAL_LENGTH              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357558
#define RSZNL_ATTR_TIME_DOMAIN_DUT_EXPECTED_MAXIMUM_MECHANICAL_LENGTH              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357559
#define RSZNL_ATTR_TIME_DOMAIN_DUT_RELATIVE_PERMITTIVITY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357560
#define RSZNL_ATTR_TIME_DOMAIN_DUT_MINIMUM_RISE_TIME                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357561
#define RSZNL_ATTR_TIME_DOMAIN_DUT_RISE_TIME_THRESHOLD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357562
#define RSZNL_ATTR_TIME_DOMAIN_DUT_VELOCITY_FACTOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357563
#define RSZNL_ATTR_TIME_GATE_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357108
#define RSZNL_ATTR_TIME_GATE_CENTER_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357109
#define RSZNL_ATTR_TIME_GATE_SPAN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357110
#define RSZNL_ATTR_TIME_GATE_START_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357111
#define RSZNL_ATTR_TIME_GATE_STOP_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357112
#define RSZNL_ATTR_TIME_GATE_SHOW_RANGE_LINES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357113
#define RSZNL_ATTR_TIME_GATE_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357114
#define RSZNL_ATTR_TIME_GATE_FILTER_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357115
#define RSZNL_ATTR_TIME_GATE_SIDE_LOBE_LEVEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357116
#define RSZNL_ATTR_TIME_GATE_OFFSET_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357117
#define RSZNL_ATTR_TIME_GATE_LINK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358500
#define RSZNL_ATTR_DISTANCE_TO_FAULT_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357118
#define RSZNL_ATTR_DISTANCE_TO_FAULT_START_DISTANCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357119
#define RSZNL_ATTR_DISTANCE_TO_FAULT_STOP_DISTANCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357120
#define RSZNL_ATTR_DISTANCE_TO_FAULT_CENTER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357121
#define RSZNL_ATTR_DISTANCE_TO_FAULT_SPAN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357122
#define RSZNL_ATTR_DISTANCE_TO_FAULT_AUTO_NUMBER_OF_POINTS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357123
#define RSZNL_ATTR_DISTANCE_TO_FAULT_SELECT_CABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357124
#define RSZNL_ATTR_DISTANCE_TO_FAULT_DELETE_USER_DEFINED_CABLE_TYPE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357126
#define RSZNL_ATTR_DISTANCE_TO_FAULT_EXPORT_CABLE_TYPES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357127
#define RSZNL_ATTR_DISTANCE_TO_FAULT_IMPORT_CABLE_TYPES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357128
#define RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357129
#define RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_CHECK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357130
#define RSZNL_ATTR_DISTANCE_TO_FAULT_LIMIT_VIOLATIONS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357131
#define RSZNL_ATTR_STATISTICS_DISPLAY_ALL_RESULTS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357133
#define RSZNL_ATTR_STATISTICS_DISPLAY_MIN_MAX_PEAK_PEAK_RESULTS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357134
#define RSZNL_ATTR_STATISTICS_DISPLAY_MEAN_STD_DEV_RESULTS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357135
#define RSZNL_ATTR_STATISTICS_DISPLAY_PHASE_ELECTRICAL_LENGTH_RESULTS              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357136
#define RSZNL_ATTR_STATISTICS_DISPLAY_RMS_RESULTS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357137
#define RSZNL_ATTR_STATISTICS_DISPLAY_FLATNES_GAIN_SLOPE_RESULTS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357138
#define RSZNL_ATTR_STATISTICS_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357140
#define RSZNL_ATTR_STATISTICS_EVALUATION_RANGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357142
#define RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357143
#define RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_STOP                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357144
#define RSZNL_ATTR_STATISTICS_EVALUATION_RANGE_SHOW_LIMIT_LINES                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357145
#define RSZNL_ATTR_STATISTICS_COMPRESSION_POINT_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358501
#define RSZNL_ATTR_STATISTICS_COMPRESSION_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358502
#define RSZNL_ATTR_STATISTICS_COMPRESSION_PHASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358503
#define RSZNL_ATTR_STATISTICS_COMPRESSION_RESULT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358504
#define RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358505
#define RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_MARKER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358506
#define RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_RANGE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358507
#define RSZNL_ATTR_STATISTICS_COMPRESSION_RANGE_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358508
#define RSZNL_ATTR_STATISTICS_COMPRESSION_RANGE_STOP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358509
#define RSZNL_ATTR_STATISTICS_COMPRESSION_SHOW_RANGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358510
#define RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_LEVEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358511
#define RSZNL_ATTR_STATISTICS_COMPRESSION_REFERENCE_PHASE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358512
#define RSZNL_ATTR_TRACE_SMOOTHING_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357146
#define RSZNL_ATTR_TRACE_SMOOTHING_APERTURE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357147
#define RSZNL_ATTR_TRACE_HOLD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357148
#define RSZNL_ATTR_TRACE_IMPORT_DATA_AUTO_DISTRIBUTE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357152
#define RSZNL_ATTR_TRACE_RESPONSE_S_DATA_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357161
#define RSZNL_ATTR_TRACE_RESPONSE_SINGLE_SWEEP_DATA_COUNT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357162
#define RSZNL_ATTR_REGRID_MEMORY_TRACES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357758
#define RSZNL_ATTR_SHOW_LIMIT_LINE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357415
#define RSZNL_ATTR_LIMIT_CHECK                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357416
#define RSZNL_ATTR_LOWER_LIMIT_CHECK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357417
#define RSZNL_ATTR_UPPER_LIMIT_CHECK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357418
#define RSZNL_ATTR_LIMIT_CHECK_RESULT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357419
#define RSZNL_ATTR_GLOBAL_LIMIT_CHECK_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357420
#define RSZNL_ATTR_LIMIT_LINE_FAIL_BEEP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357423
#define RSZNL_ATTR_LIMIT_CHECK_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357424
#define RSZNL_ATTR_LIMIT_LINE_TTL_PASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357425
#define RSZNL_ATTR_LIMIT_LINE_HORIZONTAL_SHIFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357426
#define RSZNL_ATTR_LIMIT_LINE_UPPER_SHIFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357427
#define RSZNL_ATTR_LIMIT_LINE_LOWER_SHIFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357428
#define RSZNL_ATTR_DELETE_LIMIT_LINE_SEGMENTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357438
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357429
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357430
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_START_RESPONSE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357431
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_STOP_RESPONSE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357432
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_START_STIMULUS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357433
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_STOP_STIMULUS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357434
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358416
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_FORMULA_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358417
#define RSZNL_ATTR_LIMIT_LINE_SEGMENT_INTERPOLATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358418
#define RSZNL_ATTR_SHOW_RIPPLE_LIMITS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357442
#define RSZNL_ATTR_RIPPLE_LIMIT_CHECK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357443
#define RSZNL_ATTR_RIPPLE_LIMIT_CHECK_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357444
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_FAIL_BEEP                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357447
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_SHOW_RESULTS_ALL_TRACES                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357448
#define RSZNL_ATTR_RIPPLE_LIMIT_CHECK_CLEAR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357449
#define RSZNL_ATTR_RIPPLE_LIMIT_DELETE_ALL_RANGES                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357459
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357450
#define RSZNL_ATTR_RIPPLE_LIMIT_RANGE_SEGMENT_CHECK                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357451
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_START_STIMULUS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357452
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_STOP_STIMULUS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357453
#define RSZNL_ATTR_RIPPLE_LIMIT_LINE_SEGMENT_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357454
#define RSZNL_ATTR_RIPPLE_LIMIT_STIMULUS_UNIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357456
#define RSZNL_ATTR_RIPPLE_LIMIT_RESPONSE_UNIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357457
#define RSZNL_ATTR_SHOW_CIRCLE_LIMITS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357462
#define RSZNL_ATTR_CIRCLE_LIMIT_CHECK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357463
#define RSZNL_ATTR_CIRCLE_LIMIT_CHECK_RESULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357464
#define RSZNL_ATTR_CIRCLE_FAIL_BEEP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357466
#define RSZNL_ATTR_CIRCLE_LIMIT_CHECK_CLEAR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357467
#define RSZNL_ATTR_DISPLAY_CIRCLE_SHOW_BORDER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357469
#define RSZNL_ATTR_DISPLAY_CIRCLE_LIMIT_TO_CIRCLE_ON_OFF                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357470
#define RSZNL_ATTR_DISPLAY_CIRCLE_CLEAR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357471
#define RSZNL_ATTR_HORIZONTAL_LINE_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357473
#define RSZNL_ATTR_HORIZONTAL_LINE_RESPONSE_VALUE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357474
#define RSZNL_ATTR_PARAMETER_CONVERSION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357168
#define RSZNL_ATTR_VSWR_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358419
#define RSZNL_ATTR_DELETE_S_PARAMETER_GROUP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357621
#define RSZNL_ATTR_WAVE_QUANTITIES_UNIT_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357179
#define RSZNL_ATTR_POWER_SENSOR_AUTO_ZERO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357189
#define RSZNL_ATTR_POWER_METER_NUMBERS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357646
#define RSZNL_ATTR_POWER_METER_COUNT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357648
#define RSZNL_ATTR_POWER_METER_S_PARAMETER_CORRECTION_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357650
#define RSZNL_ATTR_POWER_METER_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358513
#define RSZNL_ATTR_POWER_METER_AUTO_CONFIGURE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358514
#define RSZNL_ATTR_SELECT_POWER_METER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358540
#define RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_USE_DEFAULT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357194
#define RSZNL_ATTR_BALANCED_PORT_REFERENCE_IMPEDANCE_RENORMALIZATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357195
#define RSZNL_ATTR_TRACE_FORMAT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357196
#define RSZNL_ATTR_GROUP_DELAY_APERTURE_POINTS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357197
#define RSZNL_ATTR_DEFAULT_MARKER_FORMAT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357198
#define RSZNL_ATTR_MARKER_STATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357199
#define RSZNL_ATTR_MARKER_STIMULUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357200
#define RSZNL_ATTR_MARKER_RESPONSE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357201
#define RSZNL_ATTR_MARKER_DISABLE_ALL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357202
#define RSZNL_ATTR_DELTA_MARKER_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357203
#define RSZNL_ATTR_MARKER_COUPLING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357205
#define RSZNL_ATTR_MARKER_NAME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357206
#define RSZNL_ATTR_MARKER_FORMAT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357207
#define RSZNL_ATTR_MARKER_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357208
#define RSZNL_ATTR_MARKER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357209
#define RSZNL_ATTR_MARKER_EXPORT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357210
#define RSZNL_ATTR_REFERENCE_MARKER_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357211
#define RSZNL_ATTR_REFERENCE_MARKER_STIMULUS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357212
#define RSZNL_ATTR_REFERENCE_MARKER_RESPONSE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357213
#define RSZNL_ATTR_REFERENCE_MARKER_NAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357214
#define RSZNL_ATTR_REFERENCE_MARKER_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357215
#define RSZNL_ATTR_REFERENCE_MARKER_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357216
#define RSZNL_ATTR_REFERENCE_MARKER_FORMAT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358420
#define RSZNL_ATTR_REFERENCE_MARKER_EXCURSION_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358460
#define RSZNL_ATTR_REFERENCE_MARKER_EXCURSION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358461
#define RSZNL_ATTR_REFERENCE_CENTER_SWEEP_RANGE_TO_MARKER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358462
#define RSZNL_ATTR_REFERENCE_START_SWEEP_RANGE_TO_MARKER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358463
#define RSZNL_ATTR_REFERENCE_STOP_SWEEP_RANGE_TO_MARKER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358464
#define RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358465
#define RSZNL_ATTR_REFERENCE_MARKER_THRESHOLD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358466
#define RSZNL_ATTR_CENTER_SWEEP_RANGE_TO_MARKER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357217
#define RSZNL_ATTR_SPAN_SWEEP_RANGE_TO_MARKER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357218
#define RSZNL_ATTR_START_SWEEP_RANGE_TO_MARKER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357219
#define RSZNL_ATTR_STOP_SWEEP_RANGE_TO_MARKER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357220
#define RSZNL_ATTR_MARKER_EXCURSION_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358421
#define RSZNL_ATTR_MARKER_EXCURSION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358422
#define RSZNL_ATTR_MARKER_THRESHOLD_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358423
#define RSZNL_ATTR_MARKER_THRESHOLD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358424
#define RSZNL_ATTR_MARKER_SEARCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357221
#define RSZNL_ATTR_MARKER_TRACKING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357224
#define RSZNL_ATTR_MARKER_SEARCH_RANGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357225
#define RSZNL_ATTR_MARKER_SEARCH_RANGE_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357226
#define RSZNL_ATTR_MARKER_SEARCH_RANGE_STOP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357227
#define RSZNL_ATTR_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357228
#define RSZNL_ATTR_MARKER_TARGET_VALUE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357229
#define RSZNL_ATTR_MARKER_TARGET_FORMAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357230
#define RSZNL_ATTR_REFERENCE_MARKER_SEARCH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358467
#define RSZNL_ATTR_REFERENCE_MARKER_TRACKING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358468
#define RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358469
#define RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_START                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358470
#define RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_STOP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358471
#define RSZNL_ATTR_REFERENCE_MARKER_SEARCH_RANGE_SHOW_LIMIT_LINES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358472
#define RSZNL_ATTR_REFERENCE_MARKER_TARGET_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358473
#define RSZNL_ATTR_REFERENCE_MARKER_TARGET_FORMAT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358474
#define RSZNL_ATTR_MARKER_BANDWIDTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357231
#define RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357233
#define RSZNL_ATTR_MARKER_BANDFILTER_SEARCH_RESULT_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357235
#define RSZNL_ATTR_MARKER_MULTIPLE_PEAK_EXCURSION_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358425
#define RSZNL_ATTR_MARKER_MULTIPLE_PEAK_EXCURSION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358426
#define RSZNL_ATTR_MARKER_MULTIPLE_PEAK_THRESHOLD_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358427
#define RSZNL_ATTR_MARKER_MULTIPLE_PEAK_THRESHOLD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358428
#define RSZNL_ATTR_CALIBRATION_UNIT_LIST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357236
#define RSZNL_ATTR_CALIBRATION_UNIT_SUBMODULE_LIST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358475
#define RSZNL_ATTR_SELECT_CALIBRATION_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357237
#define RSZNL_ATTR_CALIBRATION_UNIT_CHARACTERIZATIONS_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357238
#define RSZNL_ATTR_CALIBRATION_UNIT_CHARACTERIZATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358476
#define RSZNL_ATTR_CALIBRATION_UNIT_WARMUP_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357244
#define RSZNL_ATTR_CALIBRATION_ALL_CHANNELS_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357247
#define RSZNL_ATTR_CALIBRATION_DETECT_PORT_ASSIGNMENT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357248
#define RSZNL_ATTR_REPEAT_CALIBRATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358477
#define RSZNL_ATTR_CALIBRATION_TEMPERATURE_COMPENSATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358478
#define RSZNL_ATTR_EXPORT_FACTORY_CALIBRATION_DATA_TO_TOUCHSTONE_FILE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357251
#define RSZNL_ATTR_CORRECTION_DELETE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358431
#define RSZNL_ATTR_CORRECTION_METHOD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358434
#define RSZNL_ATTR_CALIBRATION_AUTOMATIC_MEMORY_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357254
#define RSZNL_ATTR_POWER_CALIBRATION_ACTIVATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358515
#define RSZNL_ATTR_POWER_CALIBRATION_DEACTIVATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358516
#define RSZNL_ATTR_CALIBRATION_CONNECTOR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357256
#define RSZNL_ATTR_CALIBRATION_CONNECTOR_TYPE_CATALOG                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357259
#define RSZNL_ATTR_CALIBRATION_DELETE_USER_CONNECTOR_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357260
#define RSZNL_ATTR_CALIBRATION_SAME_CONNECTOR_AT_ALL_PORTS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357261
#define RSZNL_ATTR_CALIBRATION_SAME_GENDER_AT_ALL_PORTS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357262
#define RSZNL_ATTR_SAVE_CALIBRATION_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357265
#define RSZNL_ATTR_GENERATE_DEFAULT_CALIBRATION_DATA                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357266
#define RSZNL_ATTR_DELETE_CALIBRATION_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357267
#define RSZNL_ATTR_DELETE_ALL_CALIBRATION_DATA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357268
#define RSZNL_ATTR_ACTIVE_CALIBRATION_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357859
#define RSZNL_ATTR_CALIBRATION_DATE_AND_TIME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357270
#define RSZNL_ATTR_CALIBRATION_STATUS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357271
#define RSZNL_ATTR_DELETE_CALIBRATION_KIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357278
#define RSZNL_ATTR_IMPORT_KIT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357279
#define RSZNL_ATTR_LOAD_ZVR_CALIBRATION_KIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357890
#define RSZNL_ATTR_CALIBRATION_KIT_PASSWORD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357284
#define RSZNL_ATTR_GENERATE_CALIBRATION_KIT_FILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357286
#define RSZNL_ATTR_DELETE_CALIBRATION_GROUP_FILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357289
#define RSZNL_ATTR_USER_DEFINED_PRESET_CAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357290
#define RSZNL_ATTR_MULTIPLE_CALIBRATION_TYPES_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357847
#define RSZNL_ATTR_SAVE_POWER_METER_CORRECTION_LIST                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357773
#define RSZNL_ATTR_CORRECTION_DISCARD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358430
#define RSZNL_ATTR_WAVE_CORRECTION_LOGIC_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358432
#define RSZNL_ATTR_CORRECTION_CALCULATE_AFTER_DE_EMBED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358433
#define RSZNL_ATTR_SYSTEM_ERROR_CORRECTION_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357287
#define RSZNL_ATTR_POWER_CALIBRATION_LABEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358517
#define RSZNL_ATTR_CALIBRATION_VALIDATION_LIMIT_CHECK_FORMAT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358518
#define RSZNL_ATTR_CALIBRATION_VALIDATION_AVERAGE_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358519
#define RSZNL_ATTR_CALIBRATION_VALIDATION_RUN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358520
#define RSZNL_ATTR_CALIBRATION_VALIDATION_RESULT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358521
#define RSZNL_ATTR_CALIBRATION_VALIDATION_LIMITS_RESTORE_DEFAULT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358522
#define RSZNL_ATTR_CALIBRATION_VALIDATION_CHARACTERIZATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358523
#define RSZNL_ATTR_CALIBRATION_VALIDATION_STANDARD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358524
#define RSZNL_ATTR_POWER_CALIBRATION_CONFIG_REFERENCE_RECIEVER                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358525
#define RSZNL_ATTR_POWER_CALIBRATION_CONFIG_REFERENCE_RECIEVER_POWER               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358526
#define RSZNL_ATTR_POWER_CALIBRATION_CONFIG_CAL_POWER_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358527
#define RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_DELETE_ALL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358529
#define RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_STORE_COEFFICIENT        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358530
#define RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_ADDITIONAL_TWO_PORT_POSITION      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358531
#define RSZNL_ATTR_POWER_TRANSMISSION_COEFICIENT_TWO_PORT_DELETE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358532
#define RSZNL_ATTR_POWER_CALIBRATION_MAX_ITTERATIONS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358533
#define RSZNL_ATTR_POWER_CALIBRATION_TOLERANCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358534
#define RSZNL_ATTR_POWER_CALIBRATION_CONVERGENCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358535
#define RSZNL_ATTR_POWER_CALIBRATION_METHOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358536
#define RSZNL_ATTR_POWER_CALIBRATION_OTHER_SOURCES_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358537
#define RSZNL_ATTR_POWER_CALIBRATION_FLATNESS_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358538
#define RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_RECEIVER_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358539
#define RSZNL_ATTR_POWER_CALIBRATION_AVAILABLE_POWER_CALIBRATIONS                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358541
#define RSZNL_ATTR_POWER_CALIBRATION_ACTIVE_CHANNEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358542
#define RSZNL_ATTR_POWER_CALIBRATION_VERIFICATION_SWEEP_RESULT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358546
#define RSZNL_ATTR_POWER_CALIBRATION_SOURCE_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358543
#define RSZNL_ATTR_POWER_CALIBRATION_REFERENCE_WAVE_ENABLE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358544
#define RSZNL_ATTR_POWER_CALIBRATION_RECEIVED_WAVE_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358545
#define RSZNL_ATTR_POWER_CALIBRATION_INITIATE_CALIBRATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358547
#define RSZNL_ATTR_CHANNEL_STATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357294
#define RSZNL_ATTR_CHANNEL_NAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357295
#define RSZNL_ATTR_CHANNEL_LIST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357297
#define RSZNL_ATTR_CHANNEL_FIXTURE_SIMULATOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357298
#define RSZNL_ATTR_DRIVING_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357299
#define RSZNL_ATTR_IMAGE_SUPPRESSION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357300
#define RSZNL_ATTR_USER_PORT_CHANNEL_BITS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357301
#define RSZNL_ATTR_USER_PORT_PINS_USAGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357302
#define RSZNL_ATTR_DELETE_ALL_PORT_GROUPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358018
#define RSZNL_ATTR_CHANNEL_SEGMENT_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358435
#define RSZNL_ATTR_CHANNEL_SEGMENT_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358436
#define RSZNL_ATTR_OFFSET_COMPENSATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357303
#define RSZNL_ATTR_RESET_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357304
#define RSZNL_ATTR_OFFSET_DELAY_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357305
#define RSZNL_ATTR_EFFSET_ELECTRICAL_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357306
#define RSZNL_ATTR_OFFSET_MECHANICAL_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357307
#define RSZNL_ATTR_OFFSET_PERMITTIVITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357308
#define RSZNL_ATTR_ADJUST_TIME_GATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357309
#define RSZNL_ATTR_AUTO_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357310
#define RSZNL_ATTR_ONE_WAY_LOSS_AT_DC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357311
#define RSZNL_ATTR_ONE_WAY_LOSS_AT_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357312
#define RSZNL_ATTR_ONE_WAY_LOSS_AT_SECOND_FREQUENCY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358437
#define RSZNL_ATTR_ONE_WAY_LOSS_FREQUENCY_FOR_LOSS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357313
#define RSZNL_ATTR_ONE_WAY_LOSS_SECOND_FREQUENCY_FOR_LOSS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358438
#define RSZNL_ATTR_ONE_WAY_LOSS_SECOND_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358439
#define RSZNL_ATTR_AUTO_LENGTH_AND_LOSS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357314
#define RSZNL_ATTR_FIXTURE_COMPENSATION_AUTO_LENGTH_AND_LOSS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357315
#define RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPENSATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357316
#define RSZNL_ATTR_FIXTURE_COMPENSATION_DIRECT_COMPANSATION_STATUS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357317
#define RSZNL_ATTR_FIXTURE_COMPENSATION_RESET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357318
#define RSZNL_ATTR_FIXTURE_COMPENSATION_APPLY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357320
#define RSZNL_ATTR_EMBEDDING_SINGLE_ENDED_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357323
#define RSZNL_ATTR_EMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357324
#define RSZNL_ATTR_EMBEDDING_PORT_SETS_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357331
#define RSZNL_ATTR_EMBEDDING_PORT_SETS_CIRCUIT_MODEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357332
#define RSZNL_ATTR_EMBEDDING_PORT_SETS_DELETE_ALL_PORT_SETS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357335
#define RSZNL_ATTR_EMBEDDING_BALANCED_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357341
#define RSZNL_ATTR_EMBEDDING_BALANCED_CIRCUIT_MODEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357342
#define RSZNL_ATTR_EMBEDDING_GROUND_LOOP_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357349
#define RSZNL_ATTR_EMBEDDING_GROUND_LOOP_CIRCUIT_MODEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357350
#define RSZNL_ATTR_EMBEDDING_GROUND_LOOP_LOAD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357355
#define RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357356
#define RSZNL_ATTR_EMBEDDING_DIFFERENTIAL_MATCH_CIRCUIT_MODEL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357357
#define RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358153
#define RSZNL_ATTR_DEEMBEDDING_SINGLE_ENDED_CIRCUIT_MODEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358154
#define RSZNL_ATTR_DEEMBEDDING_PORT_SETS_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358161
#define RSZNL_ATTR_DEEMBEDDING_PORT_SETS_CIRCUIT_MODEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358162
#define RSZNL_ATTR_DEEMBEDDING_PORT_SETS_DELETE_ALL_PORT_SETS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358163
#define RSZNL_ATTR_DEEMBEDDING_BALANCED_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358170
#define RSZNL_ATTR_DEEMBEDDING_BALANCED_CIRCUIT_MODEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358171
#define RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358178
#define RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_CIRCUIT_MODEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358179
#define RSZNL_ATTR_DEEMBEDDING_GROUND_LOOP_LOAD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358184
#define RSZNL_ATTR_INFINITE_AVERAGE_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358440
#define RSZNL_ATTR_INFINITE_AVERAGE_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358441
#define RSZNL_ATTR_ADD_TRACE_AND_DIAGRAM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357397
#define RSZNL_ATTR_DELETE_DIAGRAM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357398
#define RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_MAXIMIZE_ALL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357399
#define RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_TITLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357400
#define RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_NAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357401
#define RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_SHOW_TITLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357402
#define RSZNL_ATTR_DISPLAY_DIAGRAM_AREA_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357403
#define RSZNL_ATTR_DISPLAY_TRACE_DIAGRAM_AREA_CATALOG                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357404
#define RSZNL_ATTR_ZOOM_OVERVIEW                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357486
#define RSZNL_ATTR_DISPLAY_SPLIT_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357405
#define RSZNL_ATTR_SELECT_DISPLAY_LAYOUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357407
#define RSZNL_ATTR_LAYOUT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357409
#define RSZNL_ATTR_LAYOUT_CATALOG                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358443
#define RSZNL_ATTR_LAYOUT_OVERLAY_ALL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358480
#define RSZNL_ATTR_LAYOUT_SPLIT_ALL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358481
#define RSZNL_ATTR_DISPLAY_FREQUENCY_INFO_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357411
#define RSZNL_ATTR_DISPLAY_CHANNEL_INFO_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357412
#define RSZNL_ATTR_DISPLAY_TRACE_INFO_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357413
#define RSZNL_ATTR_DISPLAY_FONT_SIZE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357414
#define RSZNL_ATTR_DISPLAY_LOCK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358444
#define RSZNL_ATTR_DISPLAY_INFO_WINDOW_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358412
#define RSZNL_ATTR_DISPLAY_BACKGROUND_LIGHTING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358219
#define RSZNL_ATTR_DISPLAY_STATUS_BAR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358220
#define RSZNL_ATTR_DISPLAY_SOFTKEY_BAR_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358221
#define RSZNL_ATTR_DISPLAY_TOOLBAR_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358222
#define RSZNL_ATTR_DISPLAY_TOUCH_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358223
#define RSZNL_ATTR_DISPLAY_FRONT_PANEL_KEYS_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358224
#define RSZNL_ATTR_DISPLAY_DATE_AND_TIME_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358225
#define RSZNL_ATTR_DISPLAY_DATE_AND_TIME_FORMAT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358226
#define RSZNL_ATTR_DISPLAY_CHANNEL_BAR_INFORMATION_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358227
#define RSZNL_ATTR_DISPLAY_X_AXIS_LABEL_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358228
#define RSZNL_ATTR_COLORS_AND_THEMES_CATALOG                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358229
#define RSZNL_ATTR_COLORS_AND_THEMES_SELECTED_THEME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358230
#define RSZNL_ATTR_SERVICE_FUNCTION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358234
#define RSZNL_ATTR_SERVICE_FUNCTION_LAST_RESULT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358235
#define RSZNL_ATTR_SERVICE_FUNCTION_DELETE_LAST_RESULT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358236
#define RSZNL_ATTR_SERVICE_FUNCTION_RESULT_FILE_NAME                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358237
#define RSZNL_ATTR_SERVICE_SYSTEM_INFORMATION_FILE_PATH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358238
#define RSZNL_ATTR_SERVICE_FUNCTION_BATTERY_LEVEL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358445
#define RSZNL_ATTR_SERVICE_FUNCTION_INPUT_PULSED_FREQUENCY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358446
#define RSZNL_ATTR_INITIATE_CALIBRATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350148
#define RSZNL_ATTR_CALIBRATION_RESULTS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358240
#define RSZNL_ATTR_CALIBRATION_DUE_SCHEDULE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358484
#define RSZNL_ATTR_CALIBRATION_DUE_SHUTDOWN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358485
#define RSZNL_ATTR_CALIBRATION_DUE_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358486
#define RSZNL_ATTR_CALIBRATION_DUE_WARMUP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358487
#define RSZNL_ATTR_CALIBRATION_INPUT_SOURCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358241
#define RSZNL_ATTR_CALIBRATION_SIGNAL_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358242
#define RSZNL_ATTR_FRONTEND_TEMPERATURE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358244
#define RSZNL_ATTR_SELF_TEST_RESULTS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358245
#define RSZNL_ATTR_DATA_FILE_NAME_COMMENT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358246
#define RSZNL_ATTR_DATA_FILE_NAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358247
#define RSZNL_ATTR_DATA_DECIMAL_SEPARATOR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358248
#define RSZNL_ATTR_DATA_SELECTED_STORAGE_DEVICE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358249
#define RSZNL_ATTR_DATA_SELECTED_DIRECTORY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358250
#define RSZNL_ATTR_DATA_DELETE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358256
#define RSZNL_ATTR_DATA_CREATE_DIRECTORY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358258
#define RSZNL_ATTR_DATA_DELETE_DIRECTORY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358260
#define RSZNL_ATTR_DATA_NETWORK_UNUSED_DRIVES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358263
#define RSZNL_ATTR_DATA_NETWORK_USED_DRIVES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358264
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_DEFAULT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358265
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_ALL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358266
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_NONE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358267
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_HW_SETTINGS_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358268
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_LIMIT_LINES_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358269
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_SPECTROGRAM_DATA_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358270
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_TRACE_DATA_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358271
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_TRANSDUCER_FACTORS_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358272
#define RSZNL_ATTR_ITEMS_TO_STORE_INSTRUMENT_CALIBRATION_DATA_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358548
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_DEFAULT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358273
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_ALL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358274
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_NONE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358275
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_HW_SETTINGS_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358276
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_LIMIT_LINES_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358277
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_SPECTROGRAM_DATA_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358278
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_TRACE_DATA_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358279
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_TRANSDUCER_FACTORS_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358280
#define RSZNL_ATTR_ITEMS_TO_STORE_CHANNEL_CALIBRATION_DATA_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358549
#define RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358281
#define RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_DELETE_ALL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358282
#define RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_RECALL_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358447
#define RSZNL_ATTR_DATA_INSTRUMENT_SETTINGS_SAVE_NEXT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358287
#define RSZNL_ATTR_HCOPY_ABORT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358288
#define RSZNL_ATTR_HCOPY_PRINT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358289
#define RSZNL_ATTR_HCOPY_PRINT_NEXT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358290
#define RSZNL_ATTR_HCOPY_CONTENT_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358291
#define RSZNL_ATTR_HCOPY_COMMENT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358292
#define RSZNL_ATTR_HCOPY_LOGO_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358293
#define RSZNL_ATTR_HCOPY_PAGE_COUNT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358294
#define RSZNL_ATTR_HCOPY_DATE_AND_TIME_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358295
#define RSZNL_ATTR_HCOPY_PRINT_ALL_HEADERS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358488
#define RSZNL_ATTR_HCOPY_PRINT_LOGO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358489
#define RSZNL_ATTR_HCOPY_PRINT_MARKER_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358490
#define RSZNL_ATTR_HCOPY_PRINT_TIME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358491
#define RSZNL_ATTR_HCOPY_PRINT_DIAGRAM_AREA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358492
#define RSZNL_ATTR_HCOPY_DESTINATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358298
#define RSZNL_ATTR_HCOPY_SELECTED_PRINTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358299
#define RSZNL_ATTR_HCOPY_FILE_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358300
#define RSZNL_ATTR_HCOPY_FIRST_PRINTER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358301
#define RSZNL_ATTR_HCOPY_NEXT_PRINTER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358302
#define RSZNL_ATTR_HCOPY_PAGE_ORIENTATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358303
#define RSZNL_ATTR_HCOPY_WINDOWS_PER_PAGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358304
#define RSZNL_ATTR_HCOPY_PAGE_SCALE_TO_FIT_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358305
#define RSZNL_ATTR_HCOPY_PAGE_MARGIN_UNIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358306
#define RSZNL_ATTR_HCOPY_PAGE_MARGIN_BOTTOM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358307
#define RSZNL_ATTR_HCOPY_PAGE_MARGIN_LEFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358308
#define RSZNL_ATTR_HCOPY_PAGE_MARGIN_RIGHT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358309
#define RSZNL_ATTR_HCOPY_PAGE_MARGIN_TOP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358310
#define RSZNL_ATTR_HCOPY_COLOR_PRINTING_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358311
#define RSZNL_ATTR_GENERAL_REFERENCE_OSCILLATOR_SOURCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358315
#define RSZNL_ATTR_GENERAL_EXTERNAL_REFERENCE_OSCILLATOR_FREQUENCY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358316
#define RSZNL_ATTR_GENERAL_AUTO_POWER_REDUCTION_FOR_CAL_UNIT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358101
#define RSZNL_ATTR_GENERAL_CALIBRATION_AUTO_AVERAGING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358098
#define RSZNL_ATTR_GENERAL_SEARCH_PATH_FOR_ADDITIONAL_CAL_KITS_AND_CONNECTOR_TYPES RS_SPECIFIC_PUBLIC_ATTR_BASE + 358318
#define RSZNL_ATTR_GENERAL_GEOMETRIC_CALCULATION_OF_BANDFILTER_CENTER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358097
#define RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_POSITIVE_NUMBER_PREFIX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358319
#define RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_SKIP_SEPARATOR_LINES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358320
#define RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_USE_TAB                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358321
#define RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_TRIM_LEADING_WHITESPACE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358322
#define RSZNL_ATTR_GENERAL_TOUCHSTONE_EXPORT_COMMENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358550
#define RSZNL_ATTR_GENERAL_POWER_MODE_AT_SWEEP_END                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358053
#define RSZNL_ATTR_GENERAL_SWEEP_END_SETTLING_DELAY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358100
#define RSZNL_ATTR_GENERAL_SELF_TEST                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358323
#define RSZNL_ATTR_GENERAL_REMOTE_LOGGING_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358324
#define RSZNL_ATTR_GENERAL_DISPLAY_LANGUAGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358325
#define RSZNL_ATTR_GENERAL_RESET_REVISION_TO_FACTORY_DEFAULT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358326
#define RSZNL_ATTR_GENERAL_RESET_IDN_QUERY_TO_FACTORY_DEFAULT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358327
#define RSZNL_ATTR_GENERAL_IDN_QUERY_STRING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358328
#define RSZNL_ATTR_GENERAL_IDN_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358329
#define RSZNL_ATTR_GENERAL_FIRMWARE_UPDATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358330
#define RSZNL_ATTR_GENERAL_LOCAL_LOCKOUT_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358332
#define RSZNL_ATTR_GENERAL_REMOTE_CONTROL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358493
#define RSZNL_ATTR_GENERAL_LXI_INFO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358333
#define RSZNL_ATTR_GENERAL_LXI_LAN_RESET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358334
#define RSZNL_ATTR_GENERAL_LXI_INSTRUMENT_DESCRIPTION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358335
#define RSZNL_ATTR_GENERAL_LXI_PASSWORD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358336
#define RSZNL_ATTR_GENERAL_DISPLAY_UPDATE_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358337
#define RSZNL_ATTR_GENERAL_DISPLAY_ERROR_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358338
#define RSZNL_ATTR_SYST_ERR                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358339
#define RSZNL_ATTR_GENERAL_CLEAR_SYSTEM_MESSAGES                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358341
#define RSZNL_ATTR_GENERAL_CLEAR_REMOTE_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358342
#define RSZNL_ATTR_GENERAL_REMOTE_CONTROL_COMMAND_SET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358106
#define RSZNL_ATTR_GENERAL_CONDUCTANCE_IN_EMBEDDING_NETWORKS_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358104
#define RSZNL_ATTR_GENERAL_UPDATE_SETTINGS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358107
#define RSZNL_ATTR_GENERAL_INSTRUMENT_HOSTNAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358096
#define RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_SELECT_APPLICATION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357793
#define RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357790
#define RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_WAIT_TO_FINISH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357795
#define RSZNL_ATTR_EXTERNAL_APPLICATION_CONTROL_RETURN_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357794
#define RSZNL_ATTR_SYSTEM_BIOS_INFO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358346
#define RSZNL_ATTR_SYSTEM_HW_INFO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358347
#define RSZNL_ATTR_SYSTEM_VERSION_INFO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358348
#define RSZNL_ATTR_DUMP_FILE_SIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358349
#define RSZNL_ATTR_STATUS_PRESET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358368
#define RSZNL_ATTR_ID_QUERY_RESPONSE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358372
#define RSZNL_ATTR_SYSTEM_PRESET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358374
#define RSZNL_ATTR_PRESET_CHANNEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358375
#define RSZNL_ATTR_PRESET_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358376
#define RSZNL_ATTR_GENERAL_REBOOT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358377
#define RSZNL_ATTR_GENERAL_SHUTDOWN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358378
#define RSZNL_ATTR_PASSWORD_RESET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358448
#define RSZNL_ATTR_SYSTEM_PASSWORD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358449
#define RSZNL_ATTR_SYSTEM_MEMORY_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358451
#define RSZNL_ATTR_SYSTEM_MEMORY_COMMIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358452
#define RSZNL_ATTR_SYSTEM_MEMORY_DELETE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358453
#define RSZNL_ATTR_SYSTEM_MEMORY_INIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358454
#define RSZNL_ATTR_SYSTEM_MEMORY_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358455
#define RSZNL_ATTR_SYSTEM_MEMORY_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358456
#define RSZNL_ATTR_SYSTEM_MEMORY_SIZE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358457

// RsZnl_rngTraceFormat
#define RSZNL_VAL_DB_MAG                                                    0
#define RSZNL_VAL_PHASE                                                     1
#define RSZNL_VAL_SMITH                                                     2
#define RSZNL_VAL_POLAR                                                     3
#define RSZNL_VAL_DELAY                                                     4
#define RSZNL_VAL_SWR                                                       5
#define RSZNL_VAL_LIN_MAG                                                   6
#define RSZNL_VAL_REAL                                                      7
#define RSZNL_VAL_IMAG                                                      8
#define RSZNL_VAL_ISMITH                                                    9
#define RSZNL_VAL_UPHASE                                                    10
#define RSZNL_VAL_DB_COMP                                                   11
#define RSZNL_VAL_DB_MAGN                                                   12
#define RSZNL_VAL_DB_LOG                                                    13

// RsZnl_rngWaveQuantityUnitType
#define RSZNL_VAL_WAVE_UNIT_TYPE_POWER                                      0
#define RSZNL_VAL_WAVE_UNIT_TYPE_VOLTAGE                                    1

// RsZnl_rngPeakHoldMode
#define RSZNL_VAL_HOLD_OFF                                                  0
#define RSZNL_VAL_HOLD_MIN                                                  1
#define RSZNL_VAL_HOLD_MAX                                                  2

// RsZnl_rngPortSetsCircuitModel
#define RSZNL_VAL_BALANCED_CIRCUIT_FIMP                                     0
#define RSZNL_VAL_BALANCED_CIRCUIT_STSL                                     1
#define RSZNL_VAL_BALANCED_CIRCUIT_STSC                                     2
#define RSZNL_VAL_BALANCED_CIRCUIT_SLST                                     3
#define RSZNL_VAL_BALANCED_CIRCUIT_SCST                                     4
#define RSZNL_VAL_BALANCED_CIRCUIT_CSSL                                     5
#define RSZNL_VAL_BALANCED_CIRCUIT_LSSC                                     6
#define RSZNL_VAL_BALANCED_CIRCUIT_CSSC                                     7
#define RSZNL_VAL_BALANCED_CIRCUIT_LSSL                                     8
#define RSZNL_VAL_BALANCED_CIRCUIT_SLCS                                     9
#define RSZNL_VAL_BALANCED_CIRCUIT_SCLS                                     10
#define RSZNL_VAL_BALANCED_CIRCUIT_SCCS                                     11
#define RSZNL_VAL_BALANCED_CIRCUIT_SLLS                                     12
#define RSZNL_VAL_BALANCED_CIRCUIT_STSG                                     13
#define RSZNL_VAL_BALANCED_CIRCUIT_SGST                                     14
#define RSZNL_VAL_BALANCED_CIRCUIT_GSSL                                     15
#define RSZNL_VAL_BALANCED_CIRCUIT_LSSG                                     16
#define RSZNL_VAL_BALANCED_CIRCUIT_GSSG                                     17
#define RSZNL_VAL_BALANCED_CIRCUIT_SLGS                                     18
#define RSZNL_VAL_BALANCED_CIRCUIT_SGLS                                     19
#define RSZNL_VAL_BALANCED_CIRCUIT_SGGS                                     20

// RsZnl_rngDifferentialMatchCircuitModel
#define RSZNL_VAL_CIRCUIT_FIMP                                              0
#define RSZNL_VAL_CIRCUIT_SHLC                                              1

// RsZnl_rngGroundLoopCircuitModel
#define RSZNL_VAL_GLOOP_CIRCUIT_FIMP                                        0
#define RSZNL_VAL_GLOOP_CIRCUIT_SL                                          1
#define RSZNL_VAL_GLOOP_CIRCUIT_SC                                          2
#define RSZNL_VAL_GLOOP_CIRCUIT_SG                                          3

// RsZnl_rngPortInterchange
#define RSZNL_VAL_PORT_NUMBERS_NOT_INTERCHANGED                             0
#define RSZNL_VAL_PORT_NUMBERS_INTERCHANGED                                 1
#define RSZNL_VAL_PORT_NUMBERS_SWAPED_GATES                                 2
#define RSZNL_VAL_PORT_NUMBERS_SWAPED_INCREASING_PORT                       3

// RsZnl_rngRiseThreshold
#define RSZNL_VAL_RISE_THRESHOLD_10_90                                      0
#define RSZNL_VAL_RISE_THRESHOLD_20_80                                      1

// RsZnl_rngStimulusUnit
#define RSZNL_VAL_LIMIT_DOM_FLIN                                            0
#define RSZNL_VAL_LIMIT_DOM_FLOG                                            1
#define RSZNL_VAL_LIMIT_DOM_FSEG                                            2
#define RSZNL_VAL_LIMIT_DOM_FSIN                                            3
#define RSZNL_VAL_LIMIT_DOM_TLIN                                            4
#define RSZNL_VAL_LIMIT_DOM_TLOG                                            5
#define RSZNL_VAL_LIMIT_DOM_PLIN                                            6
#define RSZNL_VAL_LIMIT_DOM_PLOG                                            7
#define RSZNL_VAL_LIMIT_DOM_PSIN                                            8

// RsZnl_rngResponseUnit
#define RSZNL_VAL_LIMIT_RESPONSE_COMPLEX                                    0
#define RSZNL_VAL_LIMIT_RESPONSE_MAGNITUDE                                  1
#define RSZNL_VAL_LIMIT_RESPONSE_PHASE                                      2
#define RSZNL_VAL_LIMIT_RESPONSE_REAL                                       3
#define RSZNL_VAL_LIMIT_RESPONSE_IMAGINARY                                  4
#define RSZNL_VAL_LIMIT_RESPONSE_SWR                                        5
#define RSZNL_VAL_LIMIT_RESPONSE_GDELAY                                     6
#define RSZNL_VAL_LIMIT_RESPONSE_L                                          7
#define RSZNL_VAL_LIMIT_RESPONSE_C                                          8

// RsZnl_rngLimitLineType
#define RSZNL_VAL_LIMIT_OFF                                                 0
#define RSZNL_VAL_LIMIT_UPPER                                               1
#define RSZNL_VAL_LIMIT_LOWER                                               2

// RsZnl_rngMarkerFormat
#define RSZNL_VAL_MARKER_FORMAT_DB_MAG                                      0
#define RSZNL_VAL_MARKER_FORMAT_LIN_MAG                                     1
#define RSZNL_VAL_MARKER_FORMAT_PHASE                                       2
#define RSZNL_VAL_MARKER_FORMAT_REAL                                        3
#define RSZNL_VAL_MARKER_FORMAT_IMAG                                        4
#define RSZNL_VAL_MARKER_FORMAT_SWR                                         5
#define RSZNL_VAL_MARKER_FORMAT_DELAY                                       6
#define RSZNL_VAL_MARKER_FORMAT_DB_MAG_PHASE                                7
#define RSZNL_VAL_MARKER_FORMAT_LIN_MAG_PHASE                               8
#define RSZNL_VAL_MARKER_FORMAT_REAL_IMAG                                   9
#define RSZNL_VAL_MARKER_FORMAT_DEFAULT                                     10
#define RSZNL_VAL_MARKER_FORMAT_R_JX                                        11
#define RSZNL_VAL_MARKER_FORMAT_G_JB                                        12
#define RSZNL_VAL_MARKER_FORMAT_MIMP                                        13
#define RSZNL_VAL_MARKER_FORMAT_MDB                                         14
#define RSZNL_VAL_MARKER_FORMAT_ML_PHASE                                    15
#define RSZNL_VAL_MARKER_FORMAT_MD_PHASE                                    16
#define RSZNL_VAL_MARKER_FORMAT_COMPLEX                                     17
#define RSZNL_VAL_MARKER_FORMAT_PIMP                                        18
#define RSZNL_VAL_MARKER_FORMAT_PADM                                        19
#define RSZNL_VAL_MARKER_FORMAT_MADM                                        20
#define RSZNL_VAL_MARKER_FORMAT_MPIM                                        21
#define RSZNL_VAL_MARKER_FORMAT_MPAD                                        22
#define RSZNL_VAL_MARKER_FORMAT_INDX                                        23

// RsZnl_rngBandFilterSearchModes
#define RSZNL_VAL_BWID_MODE_NONE                                            -1
#define RSZNL_VAL_BWID_MODE_BPAS                                            0
#define RSZNL_VAL_BWID_MODE_BST                                             1
#define RSZNL_VAL_BWID_MODE_BPRM                                            2
#define RSZNL_VAL_BWID_MODE_BSRM                                            3
#define RSZNL_VAL_BWID_MODE_BPAB                                            4
#define RSZNL_VAL_BWID_MODE_BSAB                                            5

// RsZnl_rngMarkerSearch
#define RSZNL_VAL_MARKER_MAX                                                0
#define RSZNL_VAL_MARKER_MIN                                                1
#define RSZNL_VAL_MARKER_NEXT                                               2
#define RSZNL_VAL_MARKER_RPEAK                                              3
#define RSZNL_VAL_MARKER_LPEAK                                              4
#define RSZNL_VAL_MARKER_TARGET                                             5
#define RSZNL_VAL_MARKER_RTARGET                                            6
#define RSZNL_VAL_MARKER_LTARGET                                            7
#define RSZNL_VAL_MARKER_BFILTER                                            8
#define RSZNL_VAL_MARKER_MMAXIMUM                                           9
#define RSZNL_VAL_MARKER_MMINIMUM                                           10
#define RSZNL_VAL_MARKER_SPROGRESS                                          11

// RsZnl_rngMarkerMode
#define RSZNL_VAL_CONTINUOUS                                                0
#define RSZNL_VAL_DISCRETE                                                  1

// RsZnl_rngMarkerType
#define RSZNL_VAL_NORMAL                                                    0
#define RSZNL_VAL_FIXED                                                     1
#define RSZNL_VAL_ARBITRARY                                                 2

// RsZnl_rngTargetFormat
#define RSZNL_VAL_TARGET_FORMAT_MLIN                                        0
#define RSZNL_VAL_TARGET_FORMAT_MLOG                                        1
#define RSZNL_VAL_TARGET_FORMAT_PHASE                                       2
#define RSZNL_VAL_TARGET_FORMAT_UPHASE                                      3
#define RSZNL_VAL_TARGET_FORMAT_REAL                                        4
#define RSZNL_VAL_TARGET_FORMAT_IMAG                                        5
#define RSZNL_VAL_TARGET_FORMAT_SWR                                         6
#define RSZNL_VAL_TARGET_FORMAT_DEF                                         7

// RsZnl_rngMathFunctions
#define RSZNL_VAL_MATH_FUNC_NORMAL                                          0
#define RSZNL_VAL_MATH_FUNC_ADD                                             1
#define RSZNL_VAL_MATH_FUNC_SUBTRACT                                        2
#define RSZNL_VAL_MATH_FUNC_MULTIPLY                                        3
#define RSZNL_VAL_MATH_FUNC_DIVIDE                                          4

// RsZnl_rngStatisticsFormat
#define RSZNL_VAL_STATISTICS_FORMAT_ZVAB                                    0
#define RSZNL_VAL_STATISTICS_FORMAT_IMPEDANCE                               1
#define RSZNL_VAL_STATISTICS_FORMAT_ADMITTANCE                              2

// RsZnl_rngHorizontalPosition
#define RSZNL_VAL_HORIZONTAL_LEFT                                           0
#define RSZNL_VAL_HORIZONTAL_MID                                            1
#define RSZNL_VAL_HORIZONTAL_RIGHT                                          2

// RsZnl_rngVerticalPosition
#define RSZNL_VAL_VERTICAL_TOP                                              0
#define RSZNL_VAL_VERTICAL_MID                                              1
#define RSZNL_VAL_VERTICAL_BOTTOM                                           2

// RsZnl_rngTimeGateType
#define RSZNL_VAL_TGATE_TYPE_BPASS                                          0
#define RSZNL_VAL_TGATE_TYPE_NOTCH                                          1

// RsZnl_rngTimeDomainImpulseResponse
#define RSZNL_VAL_FILTER_RECTANGLE                                          0
#define RSZNL_VAL_FILTER_HANNING                                            1
#define RSZNL_VAL_FILTER_HAMMING                                            2
#define RSZNL_VAL_FILTER_BOHMAN                                             3
#define RSZNL_VAL_FILTER_DCHEBYSHEV                                         4

// RsZnl_rngParameterConversion
#define RSZNL_VAL_CONV_S                                                    0
#define RSZNL_VAL_CONV_Y                                                    1
#define RSZNL_VAL_CONV_Z                                                    2

// RsZnl_rngImpedanceRenormalization
#define RSZNL_VAL_RENORMALIZATION_TWAV                                      0
#define RSZNL_VAL_RENORMALIZATION_PWAV                                      1

// RsZnl_rngTimeDomainHarmonicGrid
#define RSZNL_VAL_GRID_KFST                                                 0
#define RSZNL_VAL_GRID_KDFR                                                 1
#define RSZNL_VAL_GRID_KSDF                                                 2

// RsZnl_rngTimeDomainStimulus
#define RSZNL_VAL_STIMULUS_IMPULSE                                          0
#define RSZNL_VAL_STIMULUS_STEP                                             1

// RsZnl_rngTimeDomainType
#define RSZNL_VAL_TYPE_BAND_PASS                                            0
#define RSZNL_VAL_TYPE_LOW_PASS                                             1

// RsZnl_rngStimulusTimeDomainXAxisScaling
#define RSZNL_VAL_TIME                                                      0
#define RSZNL_VAL_DISTANCE                                                  1

// RsZnl_rngCalUnitStandard
#define RSZNL_VAL_CALUNIT_STD_THR                                           0
#define RSZNL_VAL_CALUNIT_STD_OPEN                                          1
#define RSZNL_VAL_CALUNIT_STD_SHOR                                          2
#define RSZNL_VAL_CALUNIT_STD_MATC                                          3

// RsZnl_rngCalStandard
#define RSZNL_VAL_CALSTD_MMTH                                               0
#define RSZNL_VAL_CALSTD_FFTH                                               1
#define RSZNL_VAL_CALSTD_MFTH                                               2
#define RSZNL_VAL_CALSTD_MMLI                                               3
#define RSZNL_VAL_CALSTD_FFLI                                               4
#define RSZNL_VAL_CALSTD_MFLI                                               5
#define RSZNL_VAL_CALSTD_MMLI_2                                             6
#define RSZNL_VAL_CALSTD_FFLI_2                                             7
#define RSZNL_VAL_CALSTD_MFLI_2                                             8
#define RSZNL_VAL_CALSTD_MMLI_3                                             9
#define RSZNL_VAL_CALSTD_FFLI_3                                             10
#define RSZNL_VAL_CALSTD_MFLI_3                                             11
#define RSZNL_VAL_CALSTD_MOSH                                               12
#define RSZNL_VAL_CALSTD_FOSH                                               13
#define RSZNL_VAL_CALSTD_MOSH_2                                             14
#define RSZNL_VAL_CALSTD_FOSH_2                                             15
#define RSZNL_VAL_CALSTD_MOSH_3                                             16
#define RSZNL_VAL_CALSTD_FOSH_3                                             17
#define RSZNL_VAL_CALSTD_MMAT                                               18
#define RSZNL_VAL_CALSTD_FFAT                                               19
#define RSZNL_VAL_CALSTD_MFAT                                               20
#define RSZNL_VAL_CALSTD_MMSN                                               21
#define RSZNL_VAL_CALSTD_FFSN                                               22
#define RSZNL_VAL_CALSTD_MFSN                                               23
#define RSZNL_VAL_CALSTD_MOP                                                24
#define RSZNL_VAL_CALSTD_FOP                                                25
#define RSZNL_VAL_CALSTD_MSH                                                26
#define RSZNL_VAL_CALSTD_FSH                                                27
#define RSZNL_VAL_CALSTD_MREF                                               28
#define RSZNL_VAL_CALSTD_FREF                                               29
#define RSZNL_VAL_CALSTD_MMTC                                               30
#define RSZNL_VAL_CALSTD_FMTC                                               31
#define RSZNL_VAL_CALSTD_MSM                                                32
#define RSZNL_VAL_CALSTD_FSM                                                33
#define RSZNL_VAL_CALSTD_OSH                                                34
#define RSZNL_VAL_CALSTD_OSH_2                                              35
#define RSZNL_VAL_CALSTD_OSH_3                                              36

// RsZnl_rngSParameter
#define RSZNL_VAL_S11                                                       0
#define RSZNL_VAL_S12                                                       1
#define RSZNL_VAL_S21                                                       2
#define RSZNL_VAL_S22                                                       3

// RsZnl_rngDumpSize
#define RSZNL_VAL_DUMP_SIZE_NONE                                            0
#define RSZNL_VAL_DUMP_SIZE_MINI                                            1
#define RSZNL_VAL_DUMP_SIZE_NORMAL                                          2
#define RSZNL_VAL_DUMP_SIZE_LARGE                                           3
#define RSZNL_VAL_DUMP_SIZE_FULL                                            4

// RsZnl_rngDisplaySplitType
#define RSZNL_VAL_SPLIT_TYPE_LINEUP                                         0
#define RSZNL_VAL_SPLIT_TYPE_STACK                                          1
#define RSZNL_VAL_SPLIT_TYPE_HORIZONTAL                                     2
#define RSZNL_VAL_SPLIT_TYPE_VERTICAL                                       3
#define RSZNL_VAL_SPLIT_TYPE_GRID                                           4

// RsZnl_rngLayoutFormatMode
#define RSZNL_VAL_LAYOUT_FORMAT_HORIZONTAL                                  0
#define RSZNL_VAL_LAYOUT_FORMAT_VERTICAL                                    1

// RsZnl_rngDataFormat
#define RSZNL_VAL_UNFORMATTED                                               0
#define RSZNL_VAL_FORMATTED                                                 1
#define RSZNL_VAL_UNFORMATTED_MATH                                          2
#define RSZNL_VAL_FACTORY_CALIBRATED                                        4
#define RSZNL_VAL_UNCALIBRATED                                              5

// RsZnl_rngFSData
#define RSZNL_VAL_FSI                                                       1

// RsZnl_rngCalibrationSameConnectorGender
#define RSZNL_VAL_CONNECTOR_TYPE_SINGLE                                     0
#define RSZNL_VAL_CONNECTOR_TYPE_ALL                                        1

// RsZnl_rngAveragingMode
#define RSZNL_VAL_AVERAGING_AUTO                                            0
#define RSZNL_VAL_AVERAGING_FLATTEN                                         1
#define RSZNL_VAL_AVERAGING_REDUCE                                          2
#define RSZNL_VAL_AVERAGING_MOVING                                          3

// RsZnl_rngFilterSelectivity
#define RSZNL_VAL_FILTER_SELECTIVITY_NORMAL                                 0
#define RSZNL_VAL_FILTER_SELECTIVITY_MEDIUM                                 1
#define RSZNL_VAL_FILTER_SELECTIVITY_HIGH                                   2

// RsZnl_rngDrivingMode
#define RSZNL_VAL_DRIVING_MODE_AUTO                                         0
#define RSZNL_VAL_DRIVING_MODE_ALTERNATE                                    1
#define RSZNL_VAL_DRIVING_MODE_CHOPPED                                      2

// RsZnl_rngSegmentedAxisType
#define RSZNL_VAL_SEG_X_AXIS_POINT                                          0
#define RSZNL_VAL_SEG_X_AXIS_FREQUENCY                                      1

// RsZnl_rngSweepMeasurementDelayInsertionPoint
#define RSZNL_VAL_INSERT_BEFORE_ALL                                         0
#define RSZNL_VAL_INSERT_BEFORE_FIRST                                       1

// RsZnl_rngSweepType
#define RSZNL_VAL_SWEEP_LINEAR                                              0
#define RSZNL_VAL_SWEEP_LOGARITHMIC                                         1
#define RSZNL_VAL_SWEEP_POWER                                               2
#define RSZNL_VAL_SWEEP_CW                                                  3
#define RSZNL_VAL_SWEEP_TIME                                                4
#define RSZNL_VAL_SWEEP_SEGMENT                                             5

// RsZnl_rngDelayMode
#define RSZNL_VAL_AGILENT                                                   0
#define RSZNL_VAL_ZVR                                                       1

// RsZnl_rngSweepEndModes
#define RSZNL_VAL_SWEEP_END_MODE_AUTO                                       0
#define RSZNL_VAL_SWEEP_END_MODE_REDUCE                                     1
#define RSZNL_VAL_SWEEP_END_MODE_KEEP                                       2

// RsZnl_rngCalibrationAutoAveraging
#define RSZNL_VAL_AVERAGING_MAN                                             1

// RsZnl_rngMemoryTraceNames
#define RSZNL_VAL_MDATA_1                                                   1
#define RSZNL_VAL_MDATA_2                                                   2
#define RSZNL_VAL_MDATA_3                                                   3
#define RSZNL_VAL_MDATA_4                                                   4
#define RSZNL_VAL_MDATA_5                                                   5
#define RSZNL_VAL_MDATA_6                                                   6
#define RSZNL_VAL_MDATA_7                                                   7
#define RSZNL_VAL_MDATA_8                                                   8

// RsZnl_rngTriggerMultipleSource
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_IMMEDIATE                         0
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_EXT_1                             1
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_EXT_2                             2
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_EXT_1_AND_2                       3
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_EXT_1_OR_2                        4
#define RSZNL_VAL_MULTIPLE_TRIGGER_SOURCE_MANUAL                            5

// RsZnl_rngTriggerSlope
#define RSZNL_VAL_TRIGGER_SLOPE_POSITIVE                                    0
#define RSZNL_VAL_TRIGGER_SLOPE_NEGATIVE                                    1
#define RSZNL_VAL_TRIGGER_SLOPE_HIGH                                        2
#define RSZNL_VAL_TRIGGER_SLOPE_LOW                                         3

// RsZnl_rngTriggerSource
#define RSZNL_VAL_TRIGGER_SOURCE_IMMEDIATE                                  0
#define RSZNL_VAL_TRIGGER_SOURCE_EXTERNAL                                   1
#define RSZNL_VAL_TRIGGER_SOURCE_MANUAL                                     2
#define RSZNL_VAL_TRIGGER_SOURCE_MULTIPLE                                   3

// RsZnl_rngEmbedSingleEndedLoadPort
#define RSZNL_VAL_VNET_PARAM_PMAIN                                          0
#define RSZNL_VAL_VNET_PARAM_PSECOND                                        1

// RsZnl_rngOutputFormat
#define RSZNL_VAL_COMPLEX                                                   0
#define RSZNL_VAL_LIN_PHASE                                                 1
#define RSZNL_VAL_LOG_PHASE                                                 2

// RsZnl_rngDecimalSeparator
#define RSZNL_VAL_POINT                                                     0
#define RSZNL_VAL_COMMA                                                     1

// RsZnl_rngFieldSeparator
#define RSZNL_VAL_SEMICOLON                                                 0
#define RSZNL_VAL_TABULATOR                                                 2
#define RSZNL_VAL_SPACE                                                     3

// RsZnl_rngCalibrationStandard
#define RSZNL_VAL_CAL_STD_THR                                               0
#define RSZNL_VAL_CAL_STD_OPEN                                              1
#define RSZNL_VAL_CAL_STD_SHORT                                             2
#define RSZNL_VAL_CAL_STD_MATCH                                             3
#define RSZNL_VAL_CAL_STD_NET                                               4
#define RSZNL_VAL_CAL_STD_ATT                                               5
#define RSZNL_VAL_CAL_STD_REFL                                              6
#define RSZNL_VAL_CAL_STD_SLID                                              7
#define RSZNL_VAL_CAL_STD_OSH                                               8
#define RSZNL_VAL_CAL_STD_OSH_2                                             9
#define RSZNL_VAL_CAL_STD_OSH_3                                             10
#define RSZNL_VAL_CAL_STD_ISOLATION                                         11
#define RSZNL_VAL_CAL_STD_UTHR                                              12
#define RSZNL_VAL_CAL_STD_OSH1                                              13

// RsZnl_rngCalibrationType
#define RSZNL_VAL_CALTYPE_TOSM                                              0
#define RSZNL_VAL_CALTYPE_FOP                                               1
#define RSZNL_VAL_CALTYPE_OPTP                                              2
#define RSZNL_VAL_CALTYPE_FRTR                                              3
#define RSZNL_VAL_CALTYPE_FTR                                               4
#define RSZNL_VAL_CALTYPE_RTR                                               5
#define RSZNL_VAL_CALTYPE_UOSM                                              6
#define RSZNL_VAL_CALTYPE_REFL                                              7
#define RSZNL_VAL_CALTYPE_RSH                                               8
#define RSZNL_VAL_CALTYPE_FNP                                               9
#define RSZNL_VAL_CALTYPE_UTR                                               10

// RsZnl_rngKitGender
#define RSZNL_VAL_GENDER_NGENDER                                            0
#define RSZNL_VAL_GENDER_MALE                                               1
#define RSZNL_VAL_GENDER_FEMALE                                             2

// RsZnl_rngCalibrationConnector
#define RSZNL_VAL_CONNECTOR_N50FEMALE                                       0
#define RSZNL_VAL_CONNECTOR_N50MALE                                         1
#define RSZNL_VAL_CONNECTOR_N75FEMALE                                       2
#define RSZNL_VAL_CONNECTOR_N75MALE                                         3
#define RSZNL_VAL_CONNECTOR_PC7                                             4
#define RSZNL_VAL_CONNECTOR_PC35FEMALE                                      5
#define RSZNL_VAL_CONNECTOR_PC35MALE                                        6
#define RSZNL_VAL_CONNECTOR_PC292FEMALE                                     7
#define RSZNL_VAL_CONNECTOR_PC292MALE                                       8
#define RSZNL_VAL_CONNECTOR_UFEMALE1                                        9
#define RSZNL_VAL_CONNECTOR_UMALE1                                          10
#define RSZNL_VAL_CONNECTOR_UFEMALE2                                        11
#define RSZNL_VAL_CONNECTOR_UMALE2                                          12
#define RSZNL_VAL_CONNECTOR_SMAFEMALE                                       13
#define RSZNL_VAL_CONNECTOR_SMAMALE                                         14
#define RSZNL_VAL_CONNECTOR_BNC50FEMALE                                     15
#define RSZNL_VAL_CONNECTOR_BNC50MALE                                       16
#define RSZNL_VAL_CONNECTOR_BNC75FEMALE                                     17
#define RSZNL_VAL_CONNECTOR_BNC75MALE                                       18
#define RSZNL_VAL_CONNECTOR_PC24FEMALE                                      19
#define RSZNL_VAL_CONNECTOR_PC24MALE                                        20
#define RSZNL_VAL_CONNECTOR_PC185FEMALE                                     21
#define RSZNL_VAL_CONNECTOR_PC185MALE                                       22
#define RSZNL_VAL_CONNECTOR_S7_16FEMALE                                     23
#define RSZNL_VAL_CONNECTOR_S7_16MALE                                       24

// RsZnl_rngFixtureStandardType
#define RSZNL_VAL_FIXTURE_OPEN                                              0
#define RSZNL_VAL_FIXTURE_SHORT                                             1

// RsZnl_rngConnectorGender
#define RSZNL_VAL_CONNECTOR_GENDER_MALE                                     0
#define RSZNL_VAL_CONNECTOR_GENDER_FEMALE                                   1

// RsZnl_rngPropagationMode
#define RSZNL_VAL_CONNECTION_MODE_TEM                                       0
#define RSZNL_VAL_CONNECTION_MODE_WGUIDE                                    1

// RsZnl_rngConnectorType
#define RSZNL_VAL_CONNECTION_CONNECTOR_GENDER                               0
#define RSZNL_VAL_CONNECTION_CONNECTOR_NGENDER                              1

// RsZnl_rngCalibrationParameter
#define RSZNL_VAL_CAL_PARAM_ACAL                                            0
#define RSZNL_VAL_CAL_PARAM_START                                           1
#define RSZNL_VAL_CAL_PARAM_STOP                                            2
#define RSZNL_VAL_CAL_PARAM_POINTS                                          3
#define RSZNL_VAL_CAL_PARAM_POWER                                           4
#define RSZNL_VAL_CAL_PARAM_SWEEP_TYPE                                      5
#define RSZNL_VAL_CAL_PARAM_BANDWIDTH                                       6
#define RSZNL_VAL_CAL_PARAM_POINT_DELAY                                     7
#define RSZNL_VAL_CAL_PARAM_ATTENUATION                                     8
#define RSZNL_VAL_CAL_PARAM_CAL_TYPE                                        9
#define RSZNL_VAL_CAL_PARAM_PORTS                                           10
#define RSZNL_VAL_CAL_PARAM_THROUGH                                         11
#define RSZNL_VAL_CAL_PARAM_TIMESTAMP                                       12
#define RSZNL_VAL_CAL_PARAM_LOCAL_TIMESTAMP                                 13
#define RSZNL_VAL_CAL_PARAM_CKIT                                            14

// RsZnl_rngTimeMode
#define RSZNL_VAL_TIME_MODE_SEGMENT_TIME                                    0
#define RSZNL_VAL_TIME_MODE_MEAS_DELAY                                      1

// RsZnl_rngSideBand
#define RSZNL_VAL_SIDE_BAND_NEGATIVE                                        0
#define RSZNL_VAL_SIDE_BAND_POSITIVE                                        1
#define RSZNL_VAL_SIDE_BAND_AUTO                                            2

// RsZnl_rngFreqSweepMode
#define RSZNL_VAL_FREQ_SWEEP_MODE_STEPPED                                   0

// RsZnl_rngTriggerMeasurementSequence
#define RSZNL_VAL_TRIGGER_SEQUENCE_SWEEP                                    0
#define RSZNL_VAL_TRIGGER_SEQUENCE_SEGMENT                                  1
#define RSZNL_VAL_TRIGGER_SEQUENCE_POINT                                    2
#define RSZNL_VAL_TRIGGER_SEQUENCE_PARTIAL_MEAS                             3

// RsZnl_rngShowTraceType
#define RSZNL_VAL_DISP_TRAC_DATA                                            0
#define RSZNL_VAL_DISP_TRAC_MEM                                             1
#define RSZNL_VAL_DISP_TRAC_SING                                            2

// RsZnl_rngStatisticsResults
#define RSZNL_VAL_STATISTICS_RESULTS_ALL                                    0
#define RSZNL_VAL_STATISTICS_RESULTS_MEAN                                   1
#define RSZNL_VAL_STATISTICS_RESULTS_STD_DEV                                2
#define RSZNL_VAL_STATISTICS_RESULTS_MAX                                    3
#define RSZNL_VAL_STATISTICS_RESULTS_MIN                                    4
#define RSZNL_VAL_STATISTICS_RESULTS_RMS                                    5
#define RSZNL_VAL_STATISTICS_RESULTS_PEAK_TO_PEAK                           6
#define RSZNL_VAL_STATISTICS_RESULTS_ELECTRICAL_LENGTH                      7
#define RSZNL_VAL_STATISTICS_RESULTS_PHASE_DELAY                            8
#define RSZNL_VAL_STATISTICS_RESULTS_GAIN                                   9
#define RSZNL_VAL_STATISTICS_RESULTS_SLOPE                                  10
#define RSZNL_VAL_STATISTICS_RESULTS_FLATNESS                               11

// RsZnl_rngStatisticsEvaluationRange
#define RSZNL_VAL_FULL_SPAN                                                 0
#define RSZNL_VAL_RANGE_1                                                   1
#define RSZNL_VAL_RANGE_2                                                   2
#define RSZNL_VAL_RANGE_3                                                   3
#define RSZNL_VAL_RANGE_4                                                   4
#define RSZNL_VAL_RANGE_5                                                   5
#define RSZNL_VAL_RANGE_6                                                   6
#define RSZNL_VAL_RANGE_7                                                   7
#define RSZNL_VAL_RANGE_8                                                   8
#define RSZNL_VAL_RANGE_9                                                   9
#define RSZNL_VAL_RANGE_10                                                  10

// RsZnl_rngImpedanceMode
#define RSZNL_VAL_COMMON_IMPEDANCE                                          0
#define RSZNL_VAL_PORT_IMPEDANCE                                            1

// RsZnl_rngChannelSelection
#define RSZNL_VAL_CHANNEL_TRACE_SINGLE                                      0
#define RSZNL_VAL_CHANNEL_TRACE_ALL                                         1

// RsZnl_rngInOutMode
#define RSZNL_VAL_SINGLE_ENDED                                              0
#define RSZNL_VAL_DIFFERENTIAL                                              1
#define RSZNL_VAL_COMMON                                                    2

// RsZnl_rngInOutRawMode
#define RSZNL_VAL_SINGLE_ENDED_RAW                                          3

// RsZnl_rngRatios
#define RSZNL_VAL_RATIO_B1_A1_SRC_PORT_1                                    0
#define RSZNL_VAL_RATIO_B2_A1_SRC_PORT_1                                    1
#define RSZNL_VAL_RATIO_B2_A2_SRC_PORT_2                                    2
#define RSZNL_VAL_RATIO_B1_A2_SRC_PORT_2                                    3

// RsZnl_rngNumerator
#define RSZNL_VAL_A                                                         0
#define RSZNL_VAL_B                                                         1

// RsZnl_rngDetector
#define RSZNL_VAL_DET_RMS                                                   0
#define RSZNL_VAL_DET_PEAK                                                  1
#define RSZNL_VAL_DET_AVG                                                   2

// RsZnl_rngWaveQuantities
#define RSZNL_VAL_WQUANTITY_A1_SRC_PORT_1                                   0
#define RSZNL_VAL_WQUANTITY_B1_SRC_PORT_1                                   1
#define RSZNL_VAL_WQUANTITY_B2_SRC_PORT_1                                   2
#define RSZNL_VAL_WQUANTITY_A2_SRC_PORT_2                                   3
#define RSZNL_VAL_WQUANTITY_B1_SRC_PORT_2                                   4
#define RSZNL_VAL_WQUANTITY_B2_SRC_PORT_2                                   5

// RsZnl_rngStabilityFactor
#define RSZNL_VAL_SFACTOR_K                                                 0
#define RSZNL_VAL_SFACTOR_U1                                                1
#define RSZNL_VAL_SFACTOR_U2                                                2

// RsZnl_rngPowerSensorSource
#define RSZNL_VAL_PMET_EXT_GEN                                              0
#define RSZNL_VAL_PMET_ANALYZER                                             1

// RsZnl_rngDeleteBalancedPort
#define RSZNL_VAL_SINGLE                                                    0
#define RSZNL_VAL_ALL                                                       1

// RsZnl_rngLimitState
#define RSZNL_VAL_LIMIT_ON                                                  1

// RsZnl_rngSweepScope
#define RSZNL_VAL_SWEEP_ALL_CHAN                                            0
#define RSZNL_VAL_SWEEP_SINGLE_CHAN                                         1

// RsZnl_rngCalibrationStatus
#define RSZNL_VAL_CALSTATE_CAL                                              0
#define RSZNL_VAL_CALSTATE_CAI                                              1
#define RSZNL_VAL_CALSTATE_CA                                               2
#define RSZNL_VAL_CALSTATE_CAV                                              3
#define RSZNL_VAL_CALSTATE_CALOFF                                           4
#define RSZNL_VAL_CALSTATE_NONE                                             5

// RsZnl_rngConnectorKit
#define RSZNL_VAL_CONNECTOR_KIT_N50                                         0
#define RSZNL_VAL_CONNECTOR_KIT_N75                                         1
#define RSZNL_VAL_CONNECTOR_KIT_PC7                                         2
#define RSZNL_VAL_CONNECTOR_KIT_PC35                                        3
#define RSZNL_VAL_CONNECTOR_KIT_PC292                                       4
#define RSZNL_VAL_CONNECTOR_KIT_USER1                                       5
#define RSZNL_VAL_CONNECTOR_KIT_USER2                                       6
#define RSZNL_VAL_CONNECTOR_KIT_SMA                                         7

// RsZnl_rngApproximationModelling
#define RSZNL_VAL_OPEN                                                      0
#define RSZNL_VAL_SHORT                                                     1
#define RSZNL_VAL_MATCH                                                     2
#define RSZNL_VAL_RESISTANCE                                                3

// RsZnl_rngCalManagerOperation
#define RSZNL_VAL_CORR_MAN_COPY                                             0
#define RSZNL_VAL_CORR_MAN_APPLY                                            1
#define RSZNL_VAL_CORR_MAN_RESOLVE                                          2
#define RSZNL_VAL_CORR_MAN_MERGE                                            3
#define RSZNL_VAL_CORR_MAN_DELETE                                           4

// RsZnl_rngCircuitModel
#define RSZNL_VAL_SENDED_CIRCUIT_FIMP                                       0
#define RSZNL_VAL_SENDED_CIRCUIT_CSL                                        1
#define RSZNL_VAL_SENDED_CIRCUIT_LSC                                        2
#define RSZNL_VAL_SENDED_CIRCUIT_CSC                                        3
#define RSZNL_VAL_SENDED_CIRCUIT_LSL                                        4
#define RSZNL_VAL_SENDED_CIRCUIT_SLC                                        5
#define RSZNL_VAL_SENDED_CIRCUIT_SCL                                        6
#define RSZNL_VAL_SENDED_CIRCUIT_SCC                                        7
#define RSZNL_VAL_SENDED_CIRCUIT_SLL                                        8
#define RSZNL_VAL_SENDED_CIRCUIT_SHLC                                       9
#define RSZNL_VAL_SENDED_CIRCUIT_GSL                                        10
#define RSZNL_VAL_SENDED_CIRCUIT_LSG                                        11
#define RSZNL_VAL_SENDED_CIRCUIT_GSG                                        12
#define RSZNL_VAL_SENDED_CIRCUIT_SGL                                        13
#define RSZNL_VAL_SENDED_CIRCUIT_SLG                                        14
#define RSZNL_VAL_SENDED_CIRCUIT_SGG                                        15

// RsZnl_rngReferenceOscillatorSource
#define RSZNL_VAL_INT                                                       0
#define RSZNL_VAL_EXT                                                       1

// RsZnl_rngErrorTerm
#define RSZNL_VAL_CAL_DATA_DIRECTIVITY                                      0
#define RSZNL_VAL_CAL_DATA_SRCMATCH                                         1
#define RSZNL_VAL_CAL_DATA_REFLTRACK                                        2
#define RSZNL_VAL_CAL_DATA_LOADMATCH                                        3
#define RSZNL_VAL_CAL_DATA_TRANSTRACK                                       4

// RsZnl_rngPortSelector
#define RSZNL_VAL_ALL_PORTS                                                 0
#define RSZNL_VAL_SELECTED_PORTS                                            1

// RsZnl_rngDetail
#define RSZNL_VAL_CONNECTOR                                                 0
#define RSZNL_VAL_LABEL                                                     1
#define RSZNL_VAL_NAME                                                      2
#define RSZNL_VAL_GENDER                                                    3

// RsZnl_rngRelay
#define RSZNL_VAL_RELAY_ACDC                                                0
#define RSZNL_VAL_RELAY_ATT_5                                               1
#define RSZNL_VAL_RELAY_ATT_10                                              2
#define RSZNL_VAL_RELAY_ATT_20                                              3
#define RSZNL_VAL_RELAY_ATT_40                                              4
#define RSZNL_VAL_RELAY_CAL                                                 5
#define RSZNL_VAL_RELAY_EATT                                                6
#define RSZNL_VAL_RELAY_PREAMP                                              7

// RsZnl_rngCalibrationInputSource
#define RSZNL_VAL_INPUT_RF                                                  0
#define RSZNL_VAL_INPUT_CAL                                                 1

// RsZnl_rngChannelType
#define RSZNL_VAL_CHAN_TYPE_VNA                                             0
#define RSZNL_VAL_CHAN_TYPE_SANALYZER                                       1
#define RSZNL_VAL_CHAN_TYPE_ADEM                                            2
#define RSZNL_VAL_CHAN_TYPE_IQ                                              3
#define RSZNL_VAL_CHAN_TYPE_NOISE                                           4

// RsZnl_rngSequencerMode
#define RSZNL_VAL_SEQUENCER_MODE_SINGLE                                     0
#define RSZNL_VAL_SEQUENCER_MODE_CONTINUOUS                                 1
#define RSZNL_VAL_SEQUENCER_MODE_CDEFINED                                   2

// RsZnl_rngDisplayItem
#define RSZNL_VAL_CMAP1                                                     1
#define RSZNL_VAL_CMAP2                                                     2
#define RSZNL_VAL_CMAP3                                                     3
#define RSZNL_VAL_CMAP4                                                     4
#define RSZNL_VAL_CMAP5                                                     5
#define RSZNL_VAL_CMAP6                                                     6
#define RSZNL_VAL_CMAP7                                                     7
#define RSZNL_VAL_CMAP8                                                     8
#define RSZNL_VAL_CMAP9                                                     9
#define RSZNL_VAL_CMAP10                                                    10
#define RSZNL_VAL_CMAP11                                                    11
#define RSZNL_VAL_CMAP12                                                    12
#define RSZNL_VAL_CMAP13                                                    13
#define RSZNL_VAL_CMAP14                                                    14
#define RSZNL_VAL_CMAP15                                                    15
#define RSZNL_VAL_CMAP16                                                    16
#define RSZNL_VAL_CMAP17                                                    17
#define RSZNL_VAL_CMAP18                                                    18
#define RSZNL_VAL_CMAP19                                                    19
#define RSZNL_VAL_CMAP20                                                    20
#define RSZNL_VAL_CMAP21                                                    21
#define RSZNL_VAL_CMAP22                                                    22
#define RSZNL_VAL_CMAP23                                                    23
#define RSZNL_VAL_CMAP24                                                    24
#define RSZNL_VAL_CMAP25                                                    25
#define RSZNL_VAL_CMAP26                                                    26
#define RSZNL_VAL_CMAP27                                                    27
#define RSZNL_VAL_CMAP28                                                    28
#define RSZNL_VAL_CMAP29                                                    29
#define RSZNL_VAL_CMAP30                                                    30
#define RSZNL_VAL_CMAP31                                                    31
#define RSZNL_VAL_CMAP32                                                    32
#define RSZNL_VAL_CMAP33                                                    33
#define RSZNL_VAL_CMAP34                                                    34
#define RSZNL_VAL_CMAP35                                                    35
#define RSZNL_VAL_CMAP36                                                    36
#define RSZNL_VAL_CMAP37                                                    37
#define RSZNL_VAL_CMAP38                                                    38
#define RSZNL_VAL_CMAP39                                                    39
#define RSZNL_VAL_CMAP40                                                    40
#define RSZNL_VAL_CMAP41                                                    41

// RsZnl_rngPredefinedColor
#define RSZNL_VAL_COLOR_BLACK                                               0
#define RSZNL_VAL_COLOR_BLUE                                                1
#define RSZNL_VAL_COLOR_BROWN                                               2
#define RSZNL_VAL_COLOR_GREEN                                               3
#define RSZNL_VAL_COLOR_CYAN                                                4
#define RSZNL_VAL_COLOR_RED                                                 5
#define RSZNL_VAL_COLOR_MAGENTA                                             6
#define RSZNL_VAL_COLOR_YELLOW                                              7
#define RSZNL_VAL_COLOR_WHITE                                               8
#define RSZNL_VAL_COLOR_DGRAY                                               9
#define RSZNL_VAL_COLOR_LGRAY                                               10
#define RSZNL_VAL_COLOR_LBLUE                                               11
#define RSZNL_VAL_COLOR_LGREEN                                              12
#define RSZNL_VAL_COLOR_LCYAN                                               13
#define RSZNL_VAL_COLOR_LRED                                                14
#define RSZNL_VAL_COLOR_LMAGENTA                                            15

// RsZnl_rngDateTimeFormat
#define RSZNL_VAL_DATE_TIME_US                                              0
#define RSZNL_VAL_DATE_TIME_DE                                              1
#define RSZNL_VAL_DATE_TIME_ISO                                             2

// RsZnl_rngDisplayTouchEnabled
#define RSZNL_VAL_TOUCH_OFF                                                 0
#define RSZNL_VAL_TOUCH_ON                                                  1
#define RSZNL_VAL_TOUCH_FRAME                                               2

// RsZnl_rngStatusRegisterOperation
#define RSZNL_VAL_STAT_REG_QUESTIONABLE                                     1
#define RSZNL_VAL_STAT_REG_OPERATION                                        2

// RsZnl_rngStatusRegister
#define RSZNL_VAL_STAT_REG_MAIN                                             0
#define RSZNL_VAL_STAT_REG_LIMIT                                            1
#define RSZNL_VAL_STAT_REG_LIMIT_2                                          2
#define RSZNL_VAL_STAT_REG_INTEGRITY                                        3
#define RSZNL_VAL_STAT_REG_INTEGRITY_HW                                     4

// RsZnl_rngStatusRegisterQuery
#define RSZNL_VAL_STAT_REG_QUERY_COND                                       0
#define RSZNL_VAL_STAT_REG_QUERY_EVENT                                      1
#define RSZNL_VAL_STAT_REG_QUERY_ENABLE                                     2
#define RSZNL_VAL_STAT_REG_QUERY_PTRANSITION                                3
#define RSZNL_VAL_STAT_REG_QUERY_NTRANSITION                                4

// RsZnl_rngInstrumentSettingsMode
#define RSZNL_VAL_SETTINGS_INSTRUMENT                                       0
#define RSZNL_VAL_SETTINGS_CHANNEL                                          1

// RsZnl_rngHcopyContent
#define RSZNL_VAL_HCOPY_WINDOWS                                             0
#define RSZNL_VAL_HCOPY_HCOPY                                               1

// RsZnl_rngHcopyDevice
#define RSZNL_VAL_HCOPY_DEVICE_MEM                                          0
#define RSZNL_VAL_HCOPY_DEVICE_PRN                                          1
#define RSZNL_VAL_HCOPY_DEVICE_CLP                                          2

// RsZnl_rngHcopyFileFormat
#define RSZNL_VAL_HCOPY_FORMAT_GDI                                          0
#define RSZNL_VAL_HCOPY_FORMAT_BMP                                          1
#define RSZNL_VAL_HCOPY_FORMAT_PNG                                          2
#define RSZNL_VAL_HCOPY_FORMAT_JPEG                                         3
#define RSZNL_VAL_HCOPY_FORMAT_JPG                                          4
#define RSZNL_VAL_HCOPY_FORMAT_DOC                                          5
#define RSZNL_VAL_HCOPY_FORMAT_PDF                                          6
#define RSZNL_VAL_HCOPY_FORMAT_SVG                                          7
#define RSZNL_VAL_HCOPY_FORMAT_RTF                                          8

// RsZnl_rngPageOrientation
#define RSZNL_VAL_PAGE_ORIENTATION_LANDSCAPE                                0
#define RSZNL_VAL_PAGE_ORIENTATION_PORTRAIT                                 1

// RsZnl_rngPageMarginUnit
#define RSZNL_VAL_PAGE_MARGIN_MM                                            0
#define RSZNL_VAL_PAGE_MARGIN_IN                                            1

// RsZnl_rngROSCSource
#define RSZNL_VAL_ROSC_INTERNAL                                             0
#define RSZNL_VAL_ROSC_EXTERNAL                                             1

// RsZnl_rngGeneralDisplayLanguage
#define RSZNL_VAL_DISPLAY_LANGUAGE_EN                                       0
#define RSZNL_VAL_DISPLAY_LANGUAGE_ZH_CH                                    1
#define RSZNL_VAL_DISPLAY_LANGUAGE_ZH_TW                                    2
#define RSZNL_VAL_DISPLAY_LANGUAGE_JA                                       3
#define RSZNL_VAL_DISPLAY_LANGUAGE_KO                                       4
#define RSZNL_VAL_DISPLAY_LANGUAGE_RU                                       5

// RsZnl_rngPresetMode
#define RSZNL_VAL_PRESET_VNA                                                0
#define RSZNL_VAL_PRESET_SAN                                                1

// RsZnl_rngGeneralIDNFormat
#define RSZNL_VAL_IDN_FORMAT_LEGACY                                         0
#define RSZNL_VAL_IDN_FORMAT_NEW                                            1
#define RSZNL_VAL_IDN_FORMAT_FSL                                            2

// RsZnl_rngMessageType
#define RSZNL_VAL_MESSAGE_TYPE_SYSTEM_MSG                                   0
#define RSZNL_VAL_MESSAGE_TYPE_REMOTE_ERR                                   1

// RsZnl_rngExternalApplicationControlSelectApplication
#define RSZNL_VAL_SELECT_APPL_PROG                                          0

// RsZnl_rngGeneralTouchstoneExportPositiveNumberPrefix
#define RSZNL_VAL_PREFIX_SPACE                                              0
#define RSZNL_VAL_PREFIX_PLUS                                               1
#define RSZNL_VAL_PREFIX_VOID                                               2

// RsZnl_rngCorrectionMethod
#define RSZNL_VAL_CORRECTION_METHOD_FRTRANS                                 0
#define RSZNL_VAL_CORRECTION_METHOD_PFRTRANS                                1
#define RSZNL_VAL_CORRECTION_METHOD_FTRANS                                  2
#define RSZNL_VAL_CORRECTION_METHOD_PFTRANS                                 3
#define RSZNL_VAL_CORRECTION_METHOD_RTRANS                                  4
#define RSZNL_VAL_CORRECTION_METHOD_PRTRANS                                 5
#define RSZNL_VAL_CORRECTION_METHOD_TOM                                     6
#define RSZNL_VAL_CORRECTION_METHOD_TSM                                     7
#define RSZNL_VAL_CORRECTION_METHOD_TRM                                     8
#define RSZNL_VAL_CORRECTION_METHOD_TRL                                     9
#define RSZNL_VAL_CORRECTION_METHOD_TNA                                     10
#define RSZNL_VAL_CORRECTION_METHOD_TOSM                                    11
#define RSZNL_VAL_CORRECTION_METHOD_ETOM                                    12
#define RSZNL_VAL_CORRECTION_METHOD_ETSM                                    13
#define RSZNL_VAL_CORRECTION_METHOD_FOPORT1                                 14
#define RSZNL_VAL_CORRECTION_METHOD_FOPORT2                                 15
#define RSZNL_VAL_CORRECTION_METHOD_FOPORT12                                16
#define RSZNL_VAL_CORRECTION_METHOD_FOPTPORT                                17
#define RSZNL_VAL_CORRECTION_METHOD_ROPTPORT                                18
#define RSZNL_VAL_CORRECTION_METHOD_REFL1                                   19
#define RSZNL_VAL_CORRECTION_METHOD_REFL2                                   20
#define RSZNL_VAL_CORRECTION_METHOD_REFL12                                  21
#define RSZNL_VAL_CORRECTION_METHOD_TPORT                                   22
#define RSZNL_VAL_CORRECTION_METHOD_UOSM                                    23

// RsZnl_rngMarkerCouplingType
#define RSZNL_VAL_MARKER_COUPLING_TYPE_ALL                                  0
#define RSZNL_VAL_MARKER_COUPLING_TYPE_CHANNEL                              1
#define RSZNL_VAL_MARKER_COUPLING_TYPE_DIAGRAM                              2

// RsZnl_rngInfiniteAverageMode
#define RSZNL_VAL_INFINITE_AVERAGE_MODE_MAGPHASE                            0
#define RSZNL_VAL_INFINITE_AVERAGE_MODE_REIMAG                              1

// RsZnl_rngLimitLineSegmentInterpolation
#define RSZNL_VAL_LIMIT_LINE_SEGMENT_INTERPOLATION_LOGARITHMIC              0
#define RSZNL_VAL_LIMIT_LINE_SEGMENT_INTERPOLATION_LINEAR                   1

// RsZnl_rngRecallMode
#define RSZNL_VAL_RECALL_MODE_NEW                                           0
#define RSZNL_VAL_RECALL_MODE_REPLACE                                       1

// RsZnl_rngMemoryDataFormat
#define RSZNL_VAL_MEMORY_DATA_FORMAT_COMPLEX                                0
#define RSZNL_VAL_MEMORY_DATA_FORMAT_REAL                                   1

// RsZnl_rngLimitFailType
#define RSZNL_VAL_LIMIT_FAIL_TYPE_LIMIT                                     0
#define RSZNL_VAL_LIMIT_FAIL_TYPE_RIPPLE                                    1
#define RSZNL_VAL_LIMIT_FAIL_TYPE_CIRCLE                                    2

// RsZnl_rngMathFormattedFunction
#define RSZNL_VAL_MATH_FORMATTED_FUNCTION_NORM                              0
#define RSZNL_VAL_MATH_FORMATTED_FUNCTION_ADD                               1
#define RSZNL_VAL_MATH_FORMATTED_FUNCTION_SUBTRACT                          2
#define RSZNL_VAL_MATH_FORMATTED_FUNCTION_MULT                              3
#define RSZNL_VAL_MATH_FORMATTED_FUNCTION_DIV                               4

// RsZnl_rngInfoWindowBandFilter
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_CENTER                            0
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_BAND                              1
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_UPP                               2
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_LOW                               3
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_LOSS                              4
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_QFAC                              5
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_QFA3                              6
#define RSZNL_VAL_INFO_WINDOW_BAND_FILTER_HEAD                              7

// RsZnl_rngStimulusAttenuation
#define RSZNL_VAL_STIMULUS_ATTENUATION_0                                    0
#define RSZNL_VAL_STIMULUS_ATTENUATION_10                                   1
#define RSZNL_VAL_STIMULUS_ATTENUATION_20                                   2
#define RSZNL_VAL_STIMULUS_ATTENUATION_30                                   3
#define RSZNL_VAL_STIMULUS_ATTENUATION_UP                                   4
#define RSZNL_VAL_STIMULUS_ATTENUATION_DOWN                                 5

// RsZnl_rngRepeatedCapability
#define RSZNL_VAL_ALL_REP_CAPS                                              0
#define RSZNL_VAL_CHANNEL                                                   1
#define RSZNL_VAL_WINDOW                                                    2
#define RSZNL_VAL_SEGMENT                                                   3
#define RSZNL_VAL_LIMIT_SEGMENT                                             4
#define RSZNL_VAL_RIPPLE_SEGMENT                                            5

// RsZnl_rngCalibrationDueDays
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_ALL                                  0
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_MONDAY                               1
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_TUESDAY                              2
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_WEDNESDAY                            3
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_THURSDAY                             4
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_FRIDAY                               5
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_SATURDAY                             6
#define RSZNL_VAL_CALIBRATION_DUE_DAYS_SUNDAY                               7

// RsZnl_rngHcopyPrintDiagramArea
#define RSZNL_VAL_PRINT_DIAGRAM_AREA_ALL                                    0
#define RSZNL_VAL_PRINT_DIAGRAM_AREA_SINGLE                                 1
#define RSZNL_VAL_PRINT_DIAGRAM_AREA_ACTIVE                                 2
#define RSZNL_VAL_PRINT_DIAGRAM_AREA_HARDCOPY                               3
#define RSZNL_VAL_PRINT_DIAGRAM_AREA_NONE                                   4

// RsZnl_rngCalLocation
#define RSZNL_VAL_CAL_LOCATION_CHANNEL                                      0
#define RSZNL_VAL_CAL_LOCATION_POOL                                         1

// RsZnl_rngCalibrationValidationLimitCheckFormat
#define RSZNL_VAL_LIMIT_CHECK_FORMAT_MLIN                                   0
#define RSZNL_VAL_LIMIT_CHECK_FORMAT_REAL                                   1

// RsZnl_rngCalibrationValidationStandard
#define RSZNL_VAL_CALIBRATION_VALIDATION_STANDARD_OPEN                      0
#define RSZNL_VAL_CALIBRATION_VALIDATION_STANDARD_SHORT                     1
#define RSZNL_VAL_CALIBRATION_VALIDATION_STANDARD_MATCH                     2

// RsZnl_rngStatisticsCompressionReference
#define RSZNL_VAL_STATISTICS_COMPRESSION_REFERENCE_FPO                      0
#define RSZNL_VAL_STATISTICS_COMPRESSION_REFERENCE_DVAL                     1
#define RSZNL_VAL_STATISTICS_COMPRESSION_REFERENCE_MARK                     2
#define RSZNL_VAL_STATISTICS_COMPRESSION_REFERENCE_RANG                     3

// RsZnl_rngPowerCalibrationConfigOfsetType
#define RSZNL_VAL_POWER_CALIBRATION_CONFIG_OFSET_TYPE_ONLY                  0
#define RSZNL_VAL_POWER_CALIBRATION_CONFIG_OFSET_TYPE_CPAD                  1

// RsZnl_rngPowerCalibrationReferenceReciever
#define RSZNL_VAL_POWER_CALIBRATION_REFERENCE_RECIEVER_CPOW                 0
#define RSZNL_VAL_POWER_CALIBRATION_REFERENCE_RECIEVER_PPOW                 1

// RsZnl_rngPowerTransmimissionCoefficientDeEmbeddingPosition
#define RSZNL_VAL_POWER_TRANSMIMISSION_COEFFICIENT_DE_EMBEDDING_POSITION_DUT 0
#define RSZNL_VAL_POWER_TRANSMIMISSION_COEFFICIENT_DE_EMBEDDING_POSITION_PM 1
#define RSZNL_VAL_POWER_TRANSMIMISSION_COEFFICIENT_DE_EMBEDDING_POSITION_BOTH 2

// RsZnl_rngPowerCalibrationMethod
#define RSZNL_VAL_POWER_CALIBRATION_METHOD_PMON                             0
#define RSZNL_VAL_POWER_CALIBRATION_METHOD_RRAF                             1
#define RSZNL_VAL_POWER_CALIBRATION_METHOD_RRON                             2

// RsZnl_rngPowerCalibrationReceiverWave
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_AWAV                      0
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_BWAV                      1
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_B1                        2
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_B2                        3
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_B3                        4
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_WAVE_B4                        5

// RsZnl_rngPowerCalibrationReceiver
#define RSZNL_VAL_POWER_CALIBRATION_RECEIVER_PORT                           0

// RsZnl_rngPowerCalibrationInitiateCalibration
#define RSZNL_VAL_POWER_CALIBRATION_INITIATE_CALIBRATION_ASEN               0
#define RSZNL_VAL_POWER_CALIBRATION_INITIATE_CALIBRATION_BSEN               1

// RsZnl_rngPowerCalibrationSelectSource
#define RSZNL_VAL_POWER_CALIBRATION_SELECT_SOURCE_PORT                      0
#define RSZNL_VAL_POWER_CALIBRATION_SELECT_SOURCE_A1                        1
#define RSZNL_VAL_POWER_CALIBRATION_SELECT_SOURCE_A2                        2

// rsznl_rngSourcePowerCalibrationData
#define RSZNL_VAL_SETTING_TYPE_WAVE                                         0
#define RSZNL_VAL_SETTING_TYPE_START                                        1
#define RSZNL_VAL_SETTING_TYPE_STOP                                         2
#define RSZNL_VAL_SETTING_TYPE_POINTS                                       3
#define RSZNL_VAL_SETTING_TYPE_STYPE                                        4
#define RSZNL_VAL_SETTING_TYPE_ATTENUATION                                  5
#define RSZNL_VAL_SETTING_TYPE_CPOWER                                       6
#define RSZNL_VAL_SETTING_TYPE_CFREQUENCY                                   7
#define RSZNL_VAL_SETTING_TYPE_TIMESTAMP                                    8
#define RSZNL_VAL_SETTING_TYPE_TIMESTAMP_LOCAL                              9
#define RSZNL_VAL_SETTING_TYPE_SWEEP_MODE                                   10

//repcap Channel
#define RSZNL_REPCAP_CHANNEL_CHANNEL1                                       1
#define RSZNL_REPCAP_CHANNEL_CHANNEL2                                       2
#define RSZNL_REPCAP_CHANNEL_CHANNEL3                                       3
#define RSZNL_REPCAP_CHANNEL_CHANNEL4                                       4

//repcap Window
#define RSZNL_REPCAP_WINDOW_WIN1                                            1

//repcap PowMeter
#define RSZNL_REPCAP_POWMETER_PM1                                           1
#define RSZNL_REPCAP_POWMETER_PM2                                           2
#define RSZNL_REPCAP_POWMETER_PM3                                           3
#define RSZNL_REPCAP_POWMETER_PM4                                           4
#define RSZNL_REPCAP_POWMETER_PM5                                           5
#define RSZNL_REPCAP_POWMETER_PM6                                           6
#define RSZNL_REPCAP_POWMETER_PM7                                           7
#define RSZNL_REPCAP_POWMETER_PM8                                           8

//repcap LogicalPort
#define RSZNL_REPCAP_LOGICALPORT_LOGPORT1                                   1
#define RSZNL_REPCAP_LOGICALPORT_LOGPORT2                                   2
#define RSZNL_REPCAP_LOGICALPORT_LOGPORT3                                   3
#define RSZNL_REPCAP_LOGICALPORT_LOGPORT4                                   4

//repcap OutputNumber
#define RSZNL_REPCAP_OUTPUTNUMBER_TTL1                                      1
#define RSZNL_REPCAP_OUTPUTNUMBER_TTL2                                      2

//repcap Marker
#define RSZNL_REPCAP_MARKER_MK1                                             1
#define RSZNL_REPCAP_MARKER_MK2                                             2
#define RSZNL_REPCAP_MARKER_MK3                                             3
#define RSZNL_REPCAP_MARKER_MK4                                             4
#define RSZNL_REPCAP_MARKER_MK5                                             5
#define RSZNL_REPCAP_MARKER_MK6                                             6
#define RSZNL_REPCAP_MARKER_MK7                                             7
#define RSZNL_REPCAP_MARKER_MK8                                             8
#define RSZNL_REPCAP_MARKER_MK9                                             9
#define RSZNL_REPCAP_MARKER_MK10                                            10

//repcap Port
#define RSZNL_REPCAP_PORT_PT1                                               1
#define RSZNL_REPCAP_PORT_PT2                                               2

//repcap ListNo
#define RSZNL_REPCAP_LISTNO_LN1                                             1
#define RSZNL_REPCAP_LISTNO_LN2                                             2
#define RSZNL_REPCAP_LISTNO_LN3                                             3
#define RSZNL_REPCAP_LISTNO_LN4                                             4
#define RSZNL_REPCAP_LISTNO_LN5                                             5
#define RSZNL_REPCAP_LISTNO_LN6                                             6
#define RSZNL_REPCAP_LISTNO_LN7                                             7
#define RSZNL_REPCAP_LISTNO_LN8                                             8
#define RSZNL_REPCAP_LISTNO_LN9                                             9
#define RSZNL_REPCAP_LISTNO_LN10                                            10
#define RSZNL_REPCAP_LISTNO_LN11                                            11
#define RSZNL_REPCAP_LISTNO_LN12                                            12
#define RSZNL_REPCAP_LISTNO_LN13                                            13
#define RSZNL_REPCAP_LISTNO_LN14                                            14
#define RSZNL_REPCAP_LISTNO_LN15                                            15
#define RSZNL_REPCAP_LISTNO_LN16                                            16
#define RSZNL_REPCAP_LISTNO_LN17                                            17
#define RSZNL_REPCAP_LISTNO_LN18                                            18
#define RSZNL_REPCAP_LISTNO_LN19                                            19
#define RSZNL_REPCAP_LISTNO_LN20                                            20
#define RSZNL_REPCAP_LISTNO_LN21                                            21
#define RSZNL_REPCAP_LISTNO_LN22                                            22
#define RSZNL_REPCAP_LISTNO_LN23                                            23
#define RSZNL_REPCAP_LISTNO_LN24                                            24
#define RSZNL_REPCAP_LISTNO_LN25                                            25
#define RSZNL_REPCAP_LISTNO_LN26                                            26
#define RSZNL_REPCAP_LISTNO_LN27                                            27
#define RSZNL_REPCAP_LISTNO_LN28                                            28
#define RSZNL_REPCAP_LISTNO_LN29                                            29
#define RSZNL_REPCAP_LISTNO_LN30                                            30
#define RSZNL_REPCAP_LISTNO_LN31                                            31
#define RSZNL_REPCAP_LISTNO_LN32                                            32
#define RSZNL_REPCAP_LISTNO_LN33                                            33
#define RSZNL_REPCAP_LISTNO_LN34                                            34
#define RSZNL_REPCAP_LISTNO_LN35                                            35
#define RSZNL_REPCAP_LISTNO_LN36                                            36
#define RSZNL_REPCAP_LISTNO_LN37                                            37
#define RSZNL_REPCAP_LISTNO_LN38                                            38
#define RSZNL_REPCAP_LISTNO_LN39                                            39
#define RSZNL_REPCAP_LISTNO_LN40                                            40
#define RSZNL_REPCAP_LISTNO_LN41                                            41
#define RSZNL_REPCAP_LISTNO_LN42                                            42
#define RSZNL_REPCAP_LISTNO_LN43                                            43
#define RSZNL_REPCAP_LISTNO_LN44                                            44
#define RSZNL_REPCAP_LISTNO_LN45                                            45
#define RSZNL_REPCAP_LISTNO_LN46                                            46
#define RSZNL_REPCAP_LISTNO_LN47                                            47
#define RSZNL_REPCAP_LISTNO_LN48                                            48
#define RSZNL_REPCAP_LISTNO_LN49                                            49
#define RSZNL_REPCAP_LISTNO_LN50                                            50
#define RSZNL_REPCAP_LISTNO_LN51                                            51
#define RSZNL_REPCAP_LISTNO_LN52                                            52
#define RSZNL_REPCAP_LISTNO_LN53                                            53
#define RSZNL_REPCAP_LISTNO_LN54                                            54
#define RSZNL_REPCAP_LISTNO_LN55                                            55
#define RSZNL_REPCAP_LISTNO_LN56                                            56
#define RSZNL_REPCAP_LISTNO_LN57                                            57
#define RSZNL_REPCAP_LISTNO_LN58                                            58
#define RSZNL_REPCAP_LISTNO_LN59                                            59
#define RSZNL_REPCAP_LISTNO_LN60                                            60
#define RSZNL_REPCAP_LISTNO_LN61                                            61
#define RSZNL_REPCAP_LISTNO_LN62                                            62
#define RSZNL_REPCAP_LISTNO_LN63                                            63
#define RSZNL_REPCAP_LISTNO_LN64                                            64
#define RSZNL_REPCAP_LISTNO_LN65                                            65
#define RSZNL_REPCAP_LISTNO_LN66                                            66
#define RSZNL_REPCAP_LISTNO_LN67                                            67
#define RSZNL_REPCAP_LISTNO_LN68                                            68
#define RSZNL_REPCAP_LISTNO_LN69                                            69
#define RSZNL_REPCAP_LISTNO_LN70                                            70
#define RSZNL_REPCAP_LISTNO_LN71                                            71
#define RSZNL_REPCAP_LISTNO_LN72                                            72
#define RSZNL_REPCAP_LISTNO_LN73                                            73
#define RSZNL_REPCAP_LISTNO_LN74                                            74
#define RSZNL_REPCAP_LISTNO_LN75                                            75
#define RSZNL_REPCAP_LISTNO_LN76                                            76
#define RSZNL_REPCAP_LISTNO_LN77                                            77
#define RSZNL_REPCAP_LISTNO_LN78                                            78
#define RSZNL_REPCAP_LISTNO_LN79                                            79
#define RSZNL_REPCAP_LISTNO_LN80                                            80
#define RSZNL_REPCAP_LISTNO_LN81                                            81
#define RSZNL_REPCAP_LISTNO_LN82                                            82
#define RSZNL_REPCAP_LISTNO_LN83                                            83
#define RSZNL_REPCAP_LISTNO_LN84                                            84
#define RSZNL_REPCAP_LISTNO_LN85                                            85
#define RSZNL_REPCAP_LISTNO_LN86                                            86
#define RSZNL_REPCAP_LISTNO_LN87                                            87
#define RSZNL_REPCAP_LISTNO_LN88                                            88
#define RSZNL_REPCAP_LISTNO_LN89                                            89
#define RSZNL_REPCAP_LISTNO_LN90                                            90
#define RSZNL_REPCAP_LISTNO_LN91                                            91
#define RSZNL_REPCAP_LISTNO_LN92                                            92
#define RSZNL_REPCAP_LISTNO_LN93                                            93
#define RSZNL_REPCAP_LISTNO_LN94                                            94
#define RSZNL_REPCAP_LISTNO_LN95                                            95
#define RSZNL_REPCAP_LISTNO_LN96                                            96
#define RSZNL_REPCAP_LISTNO_LN97                                            97
#define RSZNL_REPCAP_LISTNO_LN98                                            98
#define RSZNL_REPCAP_LISTNO_LN99                                            99
#define RSZNL_REPCAP_LISTNO_LN100                                           100
#define RSZNL_REPCAP_LISTNO_LN101                                           101
#define RSZNL_REPCAP_LISTNO_LN102                                           102
#define RSZNL_REPCAP_LISTNO_LN103                                           103
#define RSZNL_REPCAP_LISTNO_LN104                                           104
#define RSZNL_REPCAP_LISTNO_LN105                                           105
#define RSZNL_REPCAP_LISTNO_LN106                                           106
#define RSZNL_REPCAP_LISTNO_LN107                                           107
#define RSZNL_REPCAP_LISTNO_LN108                                           108
#define RSZNL_REPCAP_LISTNO_LN109                                           109
#define RSZNL_REPCAP_LISTNO_LN110                                           110
#define RSZNL_REPCAP_LISTNO_LN111                                           111
#define RSZNL_REPCAP_LISTNO_LN112                                           112
#define RSZNL_REPCAP_LISTNO_LN113                                           113
#define RSZNL_REPCAP_LISTNO_LN114                                           114
#define RSZNL_REPCAP_LISTNO_LN115                                           115
#define RSZNL_REPCAP_LISTNO_LN116                                           116
#define RSZNL_REPCAP_LISTNO_LN117                                           117
#define RSZNL_REPCAP_LISTNO_LN118                                           118
#define RSZNL_REPCAP_LISTNO_LN119                                           119
#define RSZNL_REPCAP_LISTNO_LN120                                           120
#define RSZNL_REPCAP_LISTNO_LN121                                           121
#define RSZNL_REPCAP_LISTNO_LN122                                           122
#define RSZNL_REPCAP_LISTNO_LN123                                           123
#define RSZNL_REPCAP_LISTNO_LN124                                           124
#define RSZNL_REPCAP_LISTNO_LN125                                           125
#define RSZNL_REPCAP_LISTNO_LN126                                           126
#define RSZNL_REPCAP_LISTNO_LN127                                           127
#define RSZNL_REPCAP_LISTNO_LN128                                           128
#define RSZNL_REPCAP_LISTNO_LN129                                           129
#define RSZNL_REPCAP_LISTNO_LN130                                           130
#define RSZNL_REPCAP_LISTNO_LN131                                           131
#define RSZNL_REPCAP_LISTNO_LN132                                           132
#define RSZNL_REPCAP_LISTNO_LN133                                           133
#define RSZNL_REPCAP_LISTNO_LN134                                           134
#define RSZNL_REPCAP_LISTNO_LN135                                           135
#define RSZNL_REPCAP_LISTNO_LN136                                           136
#define RSZNL_REPCAP_LISTNO_LN137                                           137
#define RSZNL_REPCAP_LISTNO_LN138                                           138
#define RSZNL_REPCAP_LISTNO_LN139                                           139
#define RSZNL_REPCAP_LISTNO_LN140                                           140
#define RSZNL_REPCAP_LISTNO_LN141                                           141
#define RSZNL_REPCAP_LISTNO_LN142                                           142
#define RSZNL_REPCAP_LISTNO_LN143                                           143
#define RSZNL_REPCAP_LISTNO_LN144                                           144
#define RSZNL_REPCAP_LISTNO_LN145                                           145
#define RSZNL_REPCAP_LISTNO_LN146                                           146
#define RSZNL_REPCAP_LISTNO_LN147                                           147
#define RSZNL_REPCAP_LISTNO_LN148                                           148
#define RSZNL_REPCAP_LISTNO_LN149                                           149
#define RSZNL_REPCAP_LISTNO_LN150                                           150
#define RSZNL_REPCAP_LISTNO_LN151                                           151
#define RSZNL_REPCAP_LISTNO_LN152                                           152
#define RSZNL_REPCAP_LISTNO_LN153                                           153
#define RSZNL_REPCAP_LISTNO_LN154                                           154
#define RSZNL_REPCAP_LISTNO_LN155                                           155
#define RSZNL_REPCAP_LISTNO_LN156                                           156
#define RSZNL_REPCAP_LISTNO_LN157                                           157
#define RSZNL_REPCAP_LISTNO_LN158                                           158
#define RSZNL_REPCAP_LISTNO_LN159                                           159
#define RSZNL_REPCAP_LISTNO_LN160                                           160
#define RSZNL_REPCAP_LISTNO_LN161                                           161
#define RSZNL_REPCAP_LISTNO_LN162                                           162
#define RSZNL_REPCAP_LISTNO_LN163                                           163
#define RSZNL_REPCAP_LISTNO_LN164                                           164
#define RSZNL_REPCAP_LISTNO_LN165                                           165
#define RSZNL_REPCAP_LISTNO_LN166                                           166
#define RSZNL_REPCAP_LISTNO_LN167                                           167
#define RSZNL_REPCAP_LISTNO_LN168                                           168
#define RSZNL_REPCAP_LISTNO_LN169                                           169
#define RSZNL_REPCAP_LISTNO_LN170                                           170
#define RSZNL_REPCAP_LISTNO_LN171                                           171
#define RSZNL_REPCAP_LISTNO_LN172                                           172
#define RSZNL_REPCAP_LISTNO_LN173                                           173
#define RSZNL_REPCAP_LISTNO_LN174                                           174
#define RSZNL_REPCAP_LISTNO_LN175                                           175
#define RSZNL_REPCAP_LISTNO_LN176                                           176
#define RSZNL_REPCAP_LISTNO_LN177                                           177
#define RSZNL_REPCAP_LISTNO_LN178                                           178
#define RSZNL_REPCAP_LISTNO_LN179                                           179
#define RSZNL_REPCAP_LISTNO_LN180                                           180
#define RSZNL_REPCAP_LISTNO_LN181                                           181
#define RSZNL_REPCAP_LISTNO_LN182                                           182
#define RSZNL_REPCAP_LISTNO_LN183                                           183
#define RSZNL_REPCAP_LISTNO_LN184                                           184
#define RSZNL_REPCAP_LISTNO_LN185                                           185
#define RSZNL_REPCAP_LISTNO_LN186                                           186
#define RSZNL_REPCAP_LISTNO_LN187                                           187
#define RSZNL_REPCAP_LISTNO_LN188                                           188
#define RSZNL_REPCAP_LISTNO_LN189                                           189
#define RSZNL_REPCAP_LISTNO_LN190                                           190
#define RSZNL_REPCAP_LISTNO_LN191                                           191
#define RSZNL_REPCAP_LISTNO_LN192                                           192
#define RSZNL_REPCAP_LISTNO_LN193                                           193
#define RSZNL_REPCAP_LISTNO_LN194                                           194
#define RSZNL_REPCAP_LISTNO_LN195                                           195
#define RSZNL_REPCAP_LISTNO_LN196                                           196
#define RSZNL_REPCAP_LISTNO_LN197                                           197
#define RSZNL_REPCAP_LISTNO_LN198                                           198
#define RSZNL_REPCAP_LISTNO_LN199                                           199
#define RSZNL_REPCAP_LISTNO_LN200                                           200
#define RSZNL_REPCAP_LISTNO_LN201                                           201
#define RSZNL_REPCAP_LISTNO_LN202                                           202
#define RSZNL_REPCAP_LISTNO_LN203                                           203
#define RSZNL_REPCAP_LISTNO_LN204                                           204
#define RSZNL_REPCAP_LISTNO_LN205                                           205
#define RSZNL_REPCAP_LISTNO_LN206                                           206
#define RSZNL_REPCAP_LISTNO_LN207                                           207
#define RSZNL_REPCAP_LISTNO_LN208                                           208
#define RSZNL_REPCAP_LISTNO_LN209                                           209
#define RSZNL_REPCAP_LISTNO_LN210                                           210
#define RSZNL_REPCAP_LISTNO_LN211                                           211
#define RSZNL_REPCAP_LISTNO_LN212                                           212
#define RSZNL_REPCAP_LISTNO_LN213                                           213
#define RSZNL_REPCAP_LISTNO_LN214                                           214
#define RSZNL_REPCAP_LISTNO_LN215                                           215
#define RSZNL_REPCAP_LISTNO_LN216                                           216
#define RSZNL_REPCAP_LISTNO_LN217                                           217
#define RSZNL_REPCAP_LISTNO_LN218                                           218
#define RSZNL_REPCAP_LISTNO_LN219                                           219
#define RSZNL_REPCAP_LISTNO_LN220                                           220
#define RSZNL_REPCAP_LISTNO_LN221                                           221
#define RSZNL_REPCAP_LISTNO_LN222                                           222
#define RSZNL_REPCAP_LISTNO_LN223                                           223
#define RSZNL_REPCAP_LISTNO_LN224                                           224
#define RSZNL_REPCAP_LISTNO_LN225                                           225
#define RSZNL_REPCAP_LISTNO_LN226                                           226
#define RSZNL_REPCAP_LISTNO_LN227                                           227
#define RSZNL_REPCAP_LISTNO_LN228                                           228
#define RSZNL_REPCAP_LISTNO_LN229                                           229
#define RSZNL_REPCAP_LISTNO_LN230                                           230
#define RSZNL_REPCAP_LISTNO_LN231                                           231
#define RSZNL_REPCAP_LISTNO_LN232                                           232
#define RSZNL_REPCAP_LISTNO_LN233                                           233
#define RSZNL_REPCAP_LISTNO_LN234                                           234
#define RSZNL_REPCAP_LISTNO_LN235                                           235
#define RSZNL_REPCAP_LISTNO_LN236                                           236
#define RSZNL_REPCAP_LISTNO_LN237                                           237
#define RSZNL_REPCAP_LISTNO_LN238                                           238
#define RSZNL_REPCAP_LISTNO_LN239                                           239
#define RSZNL_REPCAP_LISTNO_LN240                                           240
#define RSZNL_REPCAP_LISTNO_LN241                                           241
#define RSZNL_REPCAP_LISTNO_LN242                                           242
#define RSZNL_REPCAP_LISTNO_LN243                                           243
#define RSZNL_REPCAP_LISTNO_LN244                                           244
#define RSZNL_REPCAP_LISTNO_LN245                                           245
#define RSZNL_REPCAP_LISTNO_LN246                                           246
#define RSZNL_REPCAP_LISTNO_LN247                                           247
#define RSZNL_REPCAP_LISTNO_LN248                                           248
#define RSZNL_REPCAP_LISTNO_LN249                                           249
#define RSZNL_REPCAP_LISTNO_LN250                                           250
#define RSZNL_REPCAP_LISTNO_LN251                                           251
#define RSZNL_REPCAP_LISTNO_LN252                                           252
#define RSZNL_REPCAP_LISTNO_LN253                                           253
#define RSZNL_REPCAP_LISTNO_LN254                                           254
#define RSZNL_REPCAP_LISTNO_LN255                                           255
#define RSZNL_REPCAP_LISTNO_LN256                                           256
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSZNL_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSZNL_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSZNL_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSZNL_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/

#define RSZNL_VAL_ALL_REP_CAPS   0
#define RSZNL_VAL_CHANNEL        1
#define RSZNL_VAL_WINDOW         2
#define RSZNL_VAL_SEGMENT        3
#define RSZNL_VAL_LIMIT_SEGMENT  4
#define RSZNL_VAL_RIPPLE_SEGMENT 5

#define RSZNL_VAL_FREQ_MIN       0
#define RSZNL_VAL_FREQ_MAX       1

#define RSZNL_VAL_LOCAL_OSCILLATOR_NEGATIVE 0
#define RSZNL_VAL_LOCAL_OSCILLATOR_POSITIVE 1
#define RSZNL_VAL_LOCAL_OSCILLATOR_AUTO     2

#define RSZNL_VAL_SAVE   0
#define RSZNL_VAL_RECALL 1

#define RSZNL_VAL_LIMIT_ALL   3

#define RSZNL_VAL_RESTORE  0
#define RSZNL_VAL_MAXIMIZE 1

#define RSZNL_VAL_VNET_FUNC_DEEMBED  0
#define RSZNL_VAL_VNET_FUNC_EMBED    1

#define RSZNL_VAL_VNET_PARAM_C  0
#define RSZNL_VAL_VNET_PARAM_L  1
#define RSZNL_VAL_VNET_PARAM_R  2
#define RSZNL_VAL_VNET_PARAM_G  3

#define RSZNL_VAL_OFFSET_COMPENSATION_AUTO_LENGTH      0
#define RSZNL_VAL_OFFSET_COMPENSATION_AUTO_LENGTH_LOSS 1
#define RSZNL_VAL_OFFSET_COMPENSATION_DIRECT           2

#define RSZNL_VAL_DRIVE_PORTS  0
#define RSZNL_VAL_CHANNEL_BITS 1

#define RSZNL_VAL_UTHR_AUTO 0
#define RSZNL_VAL_UTHR_MAN  1

#define RSZNL_VAL_SET_BY_MARKER_START  0
#define RSZNL_VAL_SET_BY_MARKER_STOP   1
#define RSZNL_VAL_SET_BY_MARKER_CENTER 2
#define RSZNL_VAL_SET_BY_MARKER_SPAN   3

#define RSZNL_VAL_MARKER           0
#define RSZNL_VAL_REFERENCE_MARKER 1

#define RSZNL_VAL_TYPE_BPAS_IMP  0
#define RSZNL_VAL_TYPE_LPAS_IMP  1
#define RSZNL_VAL_TYPE_LPAS_STEP 2

#define RSZNL_VAL_HEADERS_ALL         0
#define RSZNL_VAL_HEADERS_LOGO        1
#define RSZNL_VAL_HEADERS_MARKER_LIST 2
#define RSZNL_VAL_HEADERS_TIME        3

/****************************************************************************
*---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/

ViStatus _VI_FUNC rsznl_init(ViRsrc     resourceName,
                             ViBoolean  IDQuery,
                             ViBoolean  resetDevice,
                             ViSession* instrSession);

ViStatus _VI_FUNC rsznl_InitWithOptions(ViRsrc     resourceName,
                                        ViBoolean  IDQuery,
                                        ViBoolean  resetDevice,
                                        ViString   optionString,
                                        ViSession* instrSession);

ViStatus _VI_FUNC rsznl_VectorNetworkAnalyzerMode(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureOperatingModeMultiviewEnabled(
                            ViSession instrSession,
                            ViBoolean modeMultiviewEnabled);

ViStatus _VI_FUNC rsznl_QueryNumberOfTestPorts(ViSession instrSession,
                                               ViInt32*  numberOfTestPorts);

ViStatus _VI_FUNC rsznl_AddMeasurementChannel(ViSession instrSession,
                                              ViString  channelType,
                                              ViString  channelName);

ViStatus _VI_FUNC rsznl_SelectMeasurementChannelByType(ViSession instrSession,
                                                       ViInt32   type);

ViStatus _VI_FUNC rsznl_SelectMeasurementChannelByName(ViSession instrSession,
                                                       ViString  channelName);

ViStatus _VI_FUNC rsznl_DuplicateMeasurementChannel(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ReplaceMeasurementChannel(ViSession instrSession,
                                                  ViString  oldChannelName,
                                                  ViString  newChannelType,
                                                  ViString  newChannelName);

ViStatus _VI_FUNC rsznl_RenameMeasurementChannel(ViSession instrSession,
                                                 ViString  oldChannelName,
                                                 ViString  newChannelName);

ViStatus _VI_FUNC rsznl_DeleteMeasurementChannel(ViSession instrSession,
                                                 ViString  channelName);

ViStatus _VI_FUNC rsznl_OperatingModeListOfChannelSetups(ViSession instrSession,
                                                         ViUInt32  arraySize,
                                                         ViChar    channelCatalog[]);

ViStatus _VI_FUNC rsznl_SetupActiveMeasurementChannel(ViSession instrSession,
                                                      ViInt32   activeChannel);

ViStatus _VI_FUNC rsznl_ConfigureSequencerEnabled(ViSession instrSession,
                                                  ViBoolean sequencerEnabled);

ViStatus _VI_FUNC rsznl_ConfigureSequencerMode(ViSession instrSession,
                                               ViInt32   mode);

ViStatus _VI_FUNC rsznl_SequencerInit(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SequencerAbort(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureFrequencyStartStop(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  startFrequency,
                                                    ViReal64  stopFrequency);

ViStatus _VI_FUNC rsznl_ConfigureFrequencyCenterSpan(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  centerFrequency,
                                                     ViReal64  span);

ViStatus _VI_FUNC rsznl_ConfigurePower(ViSession instrSession,
                                       ViInt32   channel,
                                       ViReal64  power);

ViStatus _VI_FUNC rsznl_ConfigureCWFrequency(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  CWFrequency);

ViStatus _VI_FUNC rsznl_ConfigureSourcePort(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   sourcePort);

ViStatus _VI_FUNC rsznl_QueryFrequencyRange(ViSession instrSession,
                                            ViInt32   range,
                                            ViReal64* frequency);

ViStatus _VI_FUNC rsznl_ConfigureStimulusStepAttenuators(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   physicalPortNumber,
                                                         ViInt32   attenuationFactor);

ViStatus _VI_FUNC rsznl_ConfigureRFChannelState(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean RFState);

ViStatus _VI_FUNC rsznl_ConfigureStimulusAttenuation(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   attenuation);

ViStatus _VI_FUNC rsznl_ConfigureStimulusPowerSweepStart(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   port,
                                                         ViReal64  sweepStart,
                                                         ViReal64  sweepStop);

ViStatus _VI_FUNC rsznl_ConfigureStimulusSourcePowerLinearFactor(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  linearFactor);

ViStatus _VI_FUNC rsznl_ConfigureStimulusRFSourceEnabled(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   port,
                                                         ViBoolean RFSourceEnabled);

ViStatus _VI_FUNC rsznl_ConfigureTimeDomainStartStopTime(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  startTime,
                                                         ViReal64  stopTime);

ViStatus _VI_FUNC rsznl_ConfigureTimeDomainCenterSpanTime(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  centerTime,
                                                          ViReal64  timeSpan);

ViStatus _VI_FUNC rsznl_ConfigureTimeDomainXAxisScaling(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   xAxisScaling);

ViStatus _VI_FUNC rsznl_ConfigureBandwidth(ViSession instrSession,
                                           ViInt32   channel,
                                           ViReal64  bandwidth,
                                           ViInt32   filterSelectivity);

ViStatus _VI_FUNC rsznl_ConfigureAverageMode(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   averageMode);

ViStatus _VI_FUNC rsznl_ConfigureAverage(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean sweepAverageState,
                                         ViInt32   averageFactor);

ViStatus _VI_FUNC rsznl_RestartAverage(ViSession instrSession,
                                       ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureSweepNumberOfPoints(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   numberOfPoints);

ViStatus _VI_FUNC rsznl_ConfigureFrequencyStepSize(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  stepSize);

ViStatus _VI_FUNC rsznl_ConfigureSweepTime(ViSession instrSession,
                                           ViInt32   channel,
                                           ViBoolean autoSweepTime,
                                           ViReal64  sweepTime);

ViStatus _VI_FUNC rsznl_ConfigureSweepMeasDelay(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  measDelay);

ViStatus _VI_FUNC rsznl_ConfigureSweepMeasDelayInsertionPoint(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   insertionPoint);

ViStatus _VI_FUNC rsznl_ConfigureSweepType(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   sweepType);

ViStatus _VI_FUNC rsznl_ConfigureAcquisition(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   continuousSweepScope,
                                             ViBoolean sweepModeContinuous,
                                             ViInt32   sweepCount,
                                             ViInt32   sweepScope);

ViStatus _VI_FUNC rsznl_InitiateSweep(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   sweepScope);

ViStatus _VI_FUNC rsznl_InitiateSweepAndWait(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   sweepScope,
                                             ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_ConfigureMeasurementInChannel(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   channelScope,
                                                      ViBoolean enableSweep);

ViStatus _VI_FUNC rsznl_InsertNewSegment(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   segment,
                                         ViReal64  startFrequency,
                                         ViReal64  stopFrequency,
                                         ViInt32   numberOfPoints,
                                         ViReal64  power,
                                         ViInt32   sweepTimeSelect,
                                         ViReal64  timeOrDelay,
                                         ViReal64  measBandwidth,
                                         ViInt32   localOscillatorFrequency,
                                         ViInt32   selectivity,
                                         ViInt32   frequencySweepMode);

ViStatus _VI_FUNC rsznl_RedefineSegment(ViSession instrSession,
                                        ViInt32   channel,
                                        ViInt32   segment,
                                        ViReal64  startFrequency,
                                        ViReal64  stopFrequency,
                                        ViInt32   numberOfPoints,
                                        ViReal64  power,
                                        ViInt32   sweepTimeSelect,
                                        ViReal64  timeOrDelay,
                                        ViReal64  measBandwidth,
                                        ViInt32   localOscillatorFrequency,
                                        ViInt32   selectivity,
                                        ViInt32   frequencySweepMode);

ViStatus _VI_FUNC rsznl_AddNewSegment(ViSession instrSession,
                                      ViInt32   channel,
                                      ViInt32   segment);

ViStatus _VI_FUNC rsznl_QuerySweepSegmentNumber(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32*  numberOfSweepSegments);

ViStatus _VI_FUNC rsznl_DeleteSelectedSegment(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   segment);

ViStatus _VI_FUNC rsznl_DeleteAllSegments(ViSession instrSession,
                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentState(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   segment,
                                                   ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentXAxis(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   xAxis);

ViStatus _VI_FUNC rsznl_QuerySweepSegmentFrequencyCenterSpan(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   segment,
                                                             ViReal64* center,
                                                             ViReal64* span);

ViStatus _VI_FUNC rsznl_ConfigureSweepSegmentIndependentSettings(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean power,
                            ViBoolean bandwidth,
                            ViBoolean selectivity,
                            ViBoolean measDelay,
                            ViBoolean time);

ViStatus _VI_FUNC rsznl_QuerySweepSegmentSumTime(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64* sumTime);

ViStatus _VI_FUNC rsznl_ConfigureAUXPortChannelBits(ViSession instrSession,
                                                    ViInt32   AUXPortChannelBits);

ViStatus _VI_FUNC rsznl_SaveSegment(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  fileName);

ViStatus _VI_FUNC rsznl_LoadSegment(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  fileName);

ViStatus _VI_FUNC rsznl_ConfigureTriggerSource(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   triggerSource);

ViStatus _VI_FUNC rsznl_SendTrigger(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SendTriggerWaitOPC(ViSession instrSession,
                                           ViInt32   timeout);

ViStatus _VI_FUNC rsznl_ConfigureTriggerSettings(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   triggerMeasSequence,
                                                 ViReal64  triggerDelay,
                                                 ViInt32   slopeLevel);

ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerSource(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   triggerMeasSequence,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerSlope(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   triggerSignal,
                                                      ViInt32   triggerMeasSequence,
                                                      ViInt32   slopeLevel);

ViStatus _VI_FUNC rsznl_ConfigureMultipleTriggerDelay(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   triggerMeasSequence,
                                                      ViReal64  triggerDelay);

ViStatus _VI_FUNC rsznl_TraceAdd(ViSession instrSession,
                                 ViInt32   channel,
                                 ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceAddDiagramArea(ViSession instrSession,
                                            ViInt32   window,
                                            ViInt32   channel,
                                            ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceAssignDiagramArea(ViSession instrSession,
                                               ViInt32   window,
                                               ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceUnassignDiagramArea(ViSession instrSession,
                                                 ViInt32   window,
                                                 ViInt32   window_Trace);

ViStatus _VI_FUNC rsznl_ConfigureTraceDisplayState(ViSession instrSession,
                                                   ViInt32   traceType,
                                                   ViString  singleTraceName,
                                                   ViBoolean showTrace);

ViStatus _VI_FUNC rsznl_TraceSelect(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceDelete(ViSession instrSession,
                                    ViInt32   channel,
                                    ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceDeleteAll(ViSession instrSession,
                                       ViInt32   channel);

ViStatus _VI_FUNC rsznl_TraceDeleteAllChannels(ViSession instrSession);

ViStatus _VI_FUNC rsznl_TraceCopy(ViSession instrSession,
                                  ViInt32   channel,
                                  ViString  targetTraceName,
                                  ViBoolean toNewDiagram);

ViStatus _VI_FUNC rsznl_TraceList(ViSession instrSession,
                                  ViInt32   channel,
                                  ViChar    catalog[],
                                  ViInt32   bufferSize);

ViStatus _VI_FUNC rsznl_TraceListBalancedPorts(ViSession instrSession,
                                               ViInt32   channel,
                                               ViChar    catalog[],
                                               ViInt32   bufferSize);

ViStatus _VI_FUNC rsznl_TraceRename(ViSession instrSession,
                                    ViString  oldTraceName,
                                    ViString  newTraceName);

ViStatus _VI_FUNC rsznl_ChannelTraceRename(ViSession instrSession,
                                           ViInt32   channel,
                                           ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceListCatalog(ViSession instrSession,
                                         ViChar    catalog[],
                                         ViInt32   bufferSize);

ViStatus _VI_FUNC rsznl_TraceListChannelCatalog(ViSession instrSession,
                                                ViInt32   channel,
                                                ViChar    catalog[],
                                                ViInt32   bufferSize);

ViStatus _VI_FUNC rsznl_QueryTraceName(ViSession instrSession,
                                       ViInt32   traceNumber,
                                       ViChar    traceName[]);

ViStatus _VI_FUNC rsznl_QueryTraceNumber(ViSession instrSession,
                                         ViString  traceName,
                                         ViInt32*  traceNumber);

ViStatus _VI_FUNC rsznl_QueryTraceDiagramNumber(ViSession instrSession,
                                                ViString  traceName,
                                                ViInt32*  traceNumber,
                                                ViInt32*  diagramNumber);

ViStatus _VI_FUNC rsznl_QueryTraceChannelName(ViSession instrSession,
                                              ViString  traceName,
                                              ViChar    channelName[]);

ViStatus _VI_FUNC rsznl_QueryTraceChannelNumber(ViSession instrSession,
                                                ViString  traceName,
                                                ViInt32*  channelNumber);

ViStatus _VI_FUNC rsznl_TraceDataToMemory(ViSession instrSession,
                                          ViInt32   channel_Trace);

ViStatus _VI_FUNC rsznl_TraceDataToMemoryTrace(ViSession instrSession,
                                               ViString  memoryTrace,
                                               ViString  dataTrace);

ViStatus _VI_FUNC rsznl_TraceMathToMemoryTrace(ViSession instrSession,
                                               ViString  memoryTrace,
                                               ViString  dataTrace);

ViStatus _VI_FUNC rsznl_DeleteMemoryTrace(ViSession instrSession,
                                          ViInt32   memTraceDelete);

ViStatus _VI_FUNC rsznl_DeleteMemoryTraceAll(ViSession instrSession,
                                             ViInt32   channel);

ViStatus _VI_FUNC rsznl_DeleteMemoryTraceAllChannel(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureMemoryTraceMathFormatted(ViSession instrSession,
                                                          ViInt32   channel_Trace,
                                                          ViBoolean enabled,
                                                          ViString  expression,
                                                          ViInt32   function);

ViStatus _VI_FUNC rsznl_TraceUserDefinedMath(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViString  mathematicalExpression);

ViStatus _VI_FUNC rsznl_ConfigureTraceMathState(ViSession instrSession,
                                                ViInt32   channel_Trace,
                                                ViBoolean mathState);

ViStatus _VI_FUNC rsznl_ConfigureTraceMathFunction(ViSession instrSession,
                                                   ViInt32   channel_Trace,
                                                   ViInt32   mathematicalFunction);

ViStatus _VI_FUNC rsznl_ConfigureTraceMathWaveQuantityState(ViSession instrSession,
                                                            ViInt32   channel_Trace,
                                                            ViBoolean mathWaveQuantityState);

ViStatus _VI_FUNC rsznl_ConfigureTimeDomain(ViSession instrSession,
                                            ViInt32   channel,
                                            ViBoolean timeDomain,
                                            ViInt32   type,
                                            ViInt32   impulseResponse,
                                            ViReal64  sideLobeLevel,
                                            ViReal64  resolutionEnhancement);

ViStatus _VI_FUNC rsznl_ConfigureHarmonicGridAndKeep(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   calculationMethod);

ViStatus _VI_FUNC rsznl_ExtrapolateDCValue(ViSession instrSession,
                                           ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureDCValue(ViSession instrSession,
                                         ViInt32   channel,
                                         ViReal64  DCValue);

ViStatus _VI_FUNC rsznl_CalculateHarmonicGrid(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureAutomaticHarmonicGrid(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean automatic);

ViStatus _VI_FUNC rsznl_QueryHarmonicGrid(ViSession  instrSession,
                                          ViInt32    channel,
                                          ViBoolean* harmonicGrid);

ViStatus _VI_FUNC rsznl_ConfigureContinuousExtrapolation(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean continuousExtrapolation);

ViStatus _VI_FUNC rsznl_ConfigureHarmonicDUT(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  expectedMaxTimeDelay,
                                             ViReal64  expectedMaxElectricalLength,
                                             ViReal64  expectedMaxMechanicalLength,
                                             ViReal64  relativePermitivity,
                                             ViReal64  minimumRiseTime,
                                             ViInt32   riseTimeThreshold,
                                             ViReal64  velocityFactor);

ViStatus _VI_FUNC rsznl_ConfigureTimeGate(ViSession instrSession,
                                          ViInt32   channel,
                                          ViBoolean timeGate,
                                          ViInt32   timeGateType,
                                          ViBoolean rangeLines,
                                          ViInt32   filterType,
                                          ViReal64  sideLobeLevel);

ViStatus _VI_FUNC rsznl_ConfigureTimeGateStartStop(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  startTime,
                                                   ViReal64  stopTime);

ViStatus _VI_FUNC rsznl_ConfigureTimeGateCenterSpan(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  centerTime,
                                                    ViReal64  span);

ViStatus _VI_FUNC rsznl_ConfigureTimeGateOffsetActivation(ViSession instrSession,
                                                          ViBoolean adjustTimeGate);

ViStatus _VI_FUNC rsznl_ConfigureTimeGateLink(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  timeGateLink);

ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultState(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultStartStopDistance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  startDistance,
                            ViReal64  stopDistance);

ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultCenterSpan(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViReal64  center,
                                                           ViReal64  span);

ViStatus _VI_FUNC rsznl_DistanceToFaultAutoNumberOfPoints(ViSession instrSession,
                                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultCableType(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViString  cableType);

ViStatus _VI_FUNC rsznl_DistanceToFaultDefineUserDefinedCableType(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  name,
                            ViReal64  permittivity,
                            ViInt32   arraySize,
                            ViReal64  attenuation[],
                            ViReal64  frequency[]);

ViStatus _VI_FUNC rsznl_DistanceToFaultDeleteUserDefinedCableType(
                            ViSession instrSession,
                            ViString  name);

ViStatus _VI_FUNC rsznl_DistanceToFaultExportCableTypes(ViSession instrSession,
                                                        ViString  path);

ViStatus _VI_FUNC rsznl_DistanceToFaultImportCableTypes(ViSession instrSession,
                                                        ViString  path);

ViStatus _VI_FUNC rsznl_ConfigureDistanceToFaultLimitCheck(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViBoolean state,
                                                           ViReal64  limit);

ViStatus _VI_FUNC rsznl_QueryDistanceToFaultLimitViolationsCount(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  count);

ViStatus _VI_FUNC rsznl_DistanceToFaultLimitViolationsPeakData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   faultNumber,
                            ViReal64  distance[],
                            ViReal64  response[]);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsDisplayedResults(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean minMaxPeakPeak,
                                                            ViBoolean meanStdDev,
                                                            ViBoolean phaseElectricalLength,
                                                            ViBoolean RMS,
                                                            ViBoolean flatnesGainSlope);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsInfoField(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViBoolean infoField,
                                                     ViInt32   horizontalPosition,
                                                     ViInt32   verticalPosition);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsFormat(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   format);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsEvaluationRangeLimitLinesState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean showLimitLines);

ViStatus _VI_FUNC rsznl_ConfigureTraceEvaluationRange(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   evaluationRange,
                                                      ViReal64  start,
                                                      ViReal64  stop);

ViStatus _VI_FUNC rsznl_QueryTraceStatisticalParameter(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   statisticalParameter,
                                                       ViReal64* responseValue);

ViStatus _VI_FUNC rsznl_QueryTraceStatisticalAllParameters(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   bufferSize,
                                                           ViReal64  responseValues[]);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionPointState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean pointState);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionLevel(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  compressionLevel);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionPhase(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  compressionPhase);

ViStatus _VI_FUNC rsznl_QueryStatisticsCompressionResult(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64* compressionPointIn,
                                                         ViReal64* compressionPointOut);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReference(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   reference);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceMarker(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referenceMarker);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceRange(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referenceRange);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionRangeStartStop(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  rangeStart,
                            ViReal64  rangeStop);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionShowRangeEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean showRangeEnabled);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferenceLevel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  referenceLevel);

ViStatus _VI_FUNC rsznl_ConfigureStatisticsCompressionReferencePhase(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   referencePhase);

ViStatus _VI_FUNC rsznl_ConfigureTraceSmoothing(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean smoothing,
                                                ViReal64  aperture);

ViStatus _VI_FUNC rsznl_ConfigureTraceHold(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   traceHold);

ViStatus _VI_FUNC rsznl_TraceShiftStimulusValue(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   channel_Trace,
                                                ViReal64  shiftStimulusValue);

ViStatus _VI_FUNC rsznl_TraceShiftResponseValue(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   channel_Trace,
                                                ViReal64  magnitude,
                                                ViReal64  phase,
                                                ViReal64  real,
                                                ViReal64  imaginary);

ViStatus _VI_FUNC rsznl_TraceResponseData(ViSession instrSession,
                                          ViInt32   channel_Trace,
                                          ViInt32   arraySize,
                                          ViInt32   dataFormat,
                                          ViInt32*  noOfValues,
                                          ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseDataError(ViSession instrSession,
                                               ViInt32   channel_Trace,
                                               ViInt32   errorTerm,
                                               ViInt32   arraySize,
                                               ViInt32*  noOfValues,
                                               ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseDataAll(ViSession instrSession,
                                             ViInt32   arraySize,
                                             ViInt32   dataFormat,
                                             ViString  recallSet,
                                             ViInt32*  noOfValues,
                                             ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceChannelResponseDataAll(ViSession instrSession,
                                                    ViInt32   channel_Trace,
                                                    ViInt32   arraySize,
                                                    ViInt32   dataFormat,
                                                    ViInt32*  noOfValues,
                                                    ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseDataAllData(ViSession instrSession,
                                                 ViInt32   arraySize,
                                                 ViInt32   dataFormat,
                                                 ViInt32*  noOfValues,
                                                 ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceChannelResponseDataAllData(ViSession instrSession,
                                                        ViInt32   channel_Trace,
                                                        ViInt32   arraySize,
                                                        ViInt32   dataFormat,
                                                        ViInt32*  noOfValues,
                                                        ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseDataAllSData(ViSession instrSession,
                                                  ViInt32   channel_Trace,
                                                  ViInt32   arraySize,
                                                  ViInt32   dataFormat,
                                                  ViInt32*  noOfValues,
                                                  ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseSDataCatalog(ViSession instrSession,
                                                  ViInt32   channel_Trace,
                                                  ViInt32   bufferSize,
                                                  ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_TraceSParameterGroupResponseData(ViSession instrSession,
                                                         ViInt32   channel_Trace,
                                                         ViInt32   arraySize,
                                                         ViInt32   dataFormat,
                                                         ViInt32*  noOfValues,
                                                         ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepData(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   sweepNumber,
                                                     ViInt32   arraySize,
                                                     ViInt32*  noOfValues,
                                                     ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepDataCount(ViSession instrSession,
                                                          ViInt32   channel_Trace,
                                                          ViInt32*  sweepCount);

ViStatus _VI_FUNC rsznl_TraceResponseSingleSweepDataFirstLast(
                            ViSession instrSession,
                            ViInt32   channel_Trace,
                            ViInt32   firstSweep,
                            ViInt32   lastSweep,
                            ViInt32   arraySize,
                            ViInt32*  noOfValues,
                            ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_ArbitraryTraceResponseData(ViSession instrSession,
                                                   ViString  traceName,
                                                   ViInt32   arraySize,
                                                   ViInt32   dataFormat,
                                                   ViInt32*  noOfValues,
                                                   ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_TraceStimulusData(ViSession instrSession,
                                          ViInt32   channel_Trace,
                                          ViInt32   arraySize,
                                          ViInt32*  noOfValues,
                                          ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_WriteMemoryTraceData(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   dataFormat,
                                             ViInt32   noOfPoints,
                                             ViReal64  traceData[]);

ViStatus _VI_FUNC rsznl_RegridMemoryTraces(ViSession instrSession,
                                           ViInt32   channel_Trace);

ViStatus _VI_FUNC rsznl_TraceImportData(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViString  SParamOrTraceName);

ViStatus _VI_FUNC rsznl_TraceImportDataAutoDistribute(ViSession instrSession,
                                                      ViString  traceName);

ViStatus _VI_FUNC rsznl_TraceExportData(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViInt32   exportFormat,
                                        ViInt32   exportData,
                                        ViInt32   decimalSeparator,
                                        ViInt32   fieldSeparator);

ViStatus _VI_FUNC rsznl_TraceExportDataPorts(ViSession instrSession,
                                             ViInt32   channelNumber,
                                             ViString  fileName,
                                             ViInt32   exportData,
                                             ViInt32   impedanceMode,
                                             ViInt32   port1,
                                             ViInt32   port2,
                                             ViInt32   port3,
                                             ViInt32   port4);

ViStatus _VI_FUNC rsznl_TraceExportDataPortsVariable(ViSession instrSession,
                                                     ViInt32   channelNumber,
                                                     ViString  fileName,
                                                     ViInt32   exportData,
                                                     ViInt32   impedanceMode,
                                                     ViInt32   arraySize,
                                                     ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_ChannelTraceExportData(ViSession instrSession,
                                               ViInt32   selectChannel,
                                               ViInt32   channelNumber,
                                               ViString  fileName,
                                               ViInt32   exportFormat,
                                               ViInt32   exportData,
                                               ViInt32   decimalSeparator,
                                               ViInt32   fieldSeparator);

ViStatus _VI_FUNC rsznl_ConfigureParametersConversion(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   conversion);

ViStatus _VI_FUNC rsznl_ConfigureVSWREnabled(ViSession instrSession,
                                             ViBoolean enabled);

ViStatus _VI_FUNC rsznl_SelectSParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outPort,
                                          ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectMoreSParameters(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  traceName,
                                              ViInt32   outMode,
                                              ViInt32   outPort,
                                              ViInt32   inMode,
                                              ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectBalancedPortsSParameters(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViString  traceName,
                                                       ViInt32   outMode,
                                                       ViInt32   outPort,
                                                       ViInt32   inMode,
                                                       ViInt32   inPort);

ViStatus _VI_FUNC rsznl_CreateTraceSParametersGroup(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   numberOfLogicalPorts,
                                                    ViInt32   logicalPorts[]);

ViStatus _VI_FUNC rsznl_DeleteSParametersGroup(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsznl_SelectRatios(ViSession instrSession,
                                     ViInt32   channel,
                                     ViString  traceName,
                                     ViInt32   ratios);

ViStatus _VI_FUNC rsznl_SelectMoreRatios(ViSession instrSession,
                                         ViInt32   channel,
                                         ViString  traceName,
                                         ViInt32   sourcePort,
                                         ViInt32   numeratorType,
                                         ViInt32   numeratorPortNumber,
                                         ViInt32   denominatorType,
                                         ViInt32   denominatorPortNumber);

ViStatus _VI_FUNC rsznl_SelectMoreRatiosWithDetector(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  traceName,
                                                     ViInt32   sourcePort,
                                                     ViInt32   numeratorType,
                                                     ViInt32   numeratorPortNumber,
                                                     ViInt32   denominatorType,
                                                     ViInt32   denominatorPortNumber,
                                                     ViInt32   detector,
                                                     ViReal64  measurementTime);

ViStatus _VI_FUNC rsznl_SelectWaveQuantities(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  traceName,
                                             ViInt32   waveQuantities);

ViStatus _VI_FUNC rsznl_SelectMoreWaveQuantities(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViString  traceName,
                                                 ViInt32   waveQuantityType,
                                                 ViInt32   waveQuantityPortNumber,
                                                 ViInt32   sourcePort,
                                                 ViInt32   showAs);

ViStatus _VI_FUNC rsznl_SelectMoreWaveQuantitiesWithDetector(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViString  traceName,
                                                             ViInt32   waveQuantityType,
                                                             ViInt32   waveQuantityPortNumber,
                                                             ViInt32   sourcePort,
                                                             ViInt32   showAs,
                                                             ViInt32   detector,
                                                             ViReal64  measurementTime);

ViStatus _VI_FUNC rsznl_SelectImpedances(ViSession instrSession,
                                         ViInt32   channel,
                                         ViString  traceName,
                                         ViInt32   outPort,
                                         ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectMoreImpedances(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  traceName,
                                             ViInt32   outMode,
                                             ViInt32   outPort,
                                             ViInt32   inMode,
                                             ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectAdmittances(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outPort,
                                          ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectMoreAdmittances(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  traceName,
                                              ViInt32   outMode,
                                              ViInt32   outPort,
                                              ViInt32   inMode,
                                              ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectZParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outMode,
                                          ViInt32   outPort,
                                          ViInt32   inMode,
                                          ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectYParameters(ViSession instrSession,
                                          ViInt32   channel,
                                          ViString  traceName,
                                          ViInt32   outMode,
                                          ViInt32   outPort,
                                          ViInt32   inMode,
                                          ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectImbalance(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  traceName,
                                        ViInt32   outPort,
                                        ViInt32   inPort);

ViStatus _VI_FUNC rsznl_SelectStabilityFactors(ViSession instrSession,
                                               ViInt32   channel,
                                               ViString  traceName,
                                               ViInt32   DUTOut,
                                               ViInt32   DUTIn,
                                               ViInt32   stabilityFactor);

ViStatus _VI_FUNC rsznl_SelectPowerSensorMeasurement(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  traceName,
                                                     ViInt32   powerSensor,
                                                     ViInt32   source,
                                                     ViInt32   sourcePort);

ViStatus _VI_FUNC rsznl_PowerMeterAutoZero(ViSession instrSession,
                                           ViInt32   powerMeterNumber);

ViStatus _VI_FUNC rsznl_QueryPowerMeterNumbers(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    powerMeterNumbers[]);

ViStatus _VI_FUNC rsznl_QueryPowerMeterCount(ViSession instrSession,
                                             ViInt32*  powerMeterCount);

ViStatus _VI_FUNC rsznl_ConfigurePowerMeterSParameterCorrection(
                            ViSession instrSession,
                            ViInt32   powerMeterNumber,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_DefinePowerMeter(ViSession instrSession,
                                         ViInt32   powerMeterNumber,
                                         ViString  powerMeterName,
                                         ViString  driver,
                                         ViString  interfaceType,
                                         ViString  interfaceAddress,
                                         ViString  sensorId);

ViStatus _VI_FUNC rsznl_DeletePowerMeter(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigurePowerMeterAutoConfigure(ViSession instrSession,
                                                         ViBoolean autoConfigure);

ViStatus _VI_FUNC rsznl_SelectPowerMeter(ViSession instrSession,
                                         ViInt32   powerMeter);

ViStatus _VI_FUNC rsznl_DefineBalancedPort(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   logicalPort,
                                           ViInt32   physicalPort1,
                                           ViInt32   physicalPort2);

ViStatus _VI_FUNC rsznl_DeleteBalancedPort(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   logicalPort);

ViStatus _VI_FUNC rsznl_DeleteAllBalancedPorts(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceCommonMode(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViReal64  real,
                            ViReal64  imaginary);

ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceDifferentialMode(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViReal64  real,
                            ViReal64  imaginary);

ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceRenormalization(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   theory);

ViStatus _VI_FUNC rsznl_ConfigureLogicalPortReferenceImpedanceDefault(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   logicalPort,
                            ViBoolean useDefault);

ViStatus _VI_FUNC rsznl_ConfigurePhysicalPortReferenceImpedance(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   physicalPort,
                            ViReal64  real,
                            ViReal64  imaginary);

ViStatus _VI_FUNC rsznl_ConfigureTraceFormat(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   format,
                                             ViInt32   aperturePoints);

ViStatus _VI_FUNC rsznl_ConfigureDefaultMarkerFormat(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   format);

ViStatus _VI_FUNC rsznl_ConfigureMarkerState(ViSession instrSession,
                                             ViInt32   channel_Trace,
                                             ViInt32   marker,
                                             ViBoolean markerState);

ViStatus _VI_FUNC rsznl_ConfigureMarker(ViSession instrSession,
                                        ViInt32   channel_Trace,
                                        ViInt32   marker,
                                        ViBoolean markerState,
                                        ViReal64  markerStimulus);

ViStatus _VI_FUNC rsznl_QueryMarkerResponse(ViSession instrSession,
                                            ViInt32   channel_Trace,
                                            ViInt32   marker,
                                            ViReal64  markerResponse[]);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarker(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean referenceMarkerState,
                                                 ViReal64  referenceMarkerStimulus);

ViStatus _VI_FUNC rsznl_QueryReferenceMarkerResponse(ViSession instrSession,
                                                     ViInt32   channel_Trace,
                                                     ViInt32   marker,
                                                     ViReal64  referenceMarkerResponse[]);

ViStatus _VI_FUNC rsznl_ConfigureMarkerDeltaMode(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean deltaMarkerState);

ViStatus _VI_FUNC rsznl_ConfigureMarkerCoupling(ViSession instrSession,
                                                ViInt32   channel_Trace,
                                                ViInt32   marker,
                                                ViBoolean markerCoupling);

ViStatus _VI_FUNC rsznl_ConfigureMarkerFormat(ViSession instrSession,
                                              ViInt32   channel_Trace,
                                              ViInt32   marker,
                                              ViInt32   format);

ViStatus _VI_FUNC rsznl_SetAllMarkersOff(ViSession instrSession,
                                         ViInt32   channel_Trace);

ViStatus _VI_FUNC rsznl_MarkerExport(ViSession instrSession,
                                     ViString  fileName);

ViStatus _VI_FUNC rsznl_ConfigureMarkerInfoFieldPosition(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   horizontalPosition,
                                                         ViInt32   verticalPosition);

ViStatus _VI_FUNC rsznl_ConfigureMarkerProperties(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   marker,
                                                  ViInt32   markerType,
                                                  ViString  markerName,
                                                  ViInt32   discreteMode,
                                                  ViInt32   fixedMarker);

ViStatus _VI_FUNC rsznl_ConfigureMarkerCouplingType(ViSession instrSession,
                                                    ViInt32   couplingType);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerFormat(ViSession instrSession,
                                                       ViInt32   channel_Trace,
                                                       ViInt32   marker,
                                                       ViInt32   format);

ViStatus _VI_FUNC rsznl_ConfigureMarkerExcursion(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean enabled,
                                                 ViReal64  excursion);

ViStatus _VI_FUNC rsznl_ConfigureMarkerThreshold(ViSession instrSession,
                                                 ViInt32   channel_Trace,
                                                 ViInt32   marker,
                                                 ViBoolean enabled,
                                                 ViReal64  threshold);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerExcursion(ViSession instrSession,
                                                          ViInt32   channel_Trace,
                                                          ViInt32   marker,
                                                          ViBoolean enabled,
                                                          ViReal64  excursion);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerThreshold(ViSession instrSession,
                                                          ViInt32   channel_Trace,
                                                          ViInt32   marker,
                                                          ViBoolean enabled,
                                                          ViReal64  threshold);

ViStatus _VI_FUNC rsznl_MarkerSearch(ViSession instrSession,
                                     ViInt32   channel,
                                     ViInt32   marker,
                                     ViInt32   search);

ViStatus _VI_FUNC rsznl_ReferenceMarkerSearch(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   marker,
                                              ViInt32   search);

ViStatus _VI_FUNC rsznl_MarkerTargetSearch(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   marker,
                                           ViInt32   search);

ViStatus _VI_FUNC rsznl_ConfigureMarkerTargetValue(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   marker,
                                                   ViReal64  targetValue);

ViStatus _VI_FUNC rsznl_ConfigureMarkerTargetFormat(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   targetFormat);

ViStatus _VI_FUNC rsznl_ReferenceMarkerTargetSearch(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   search);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTargetValue(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   marker,
                                                            ViReal64  targetValue);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTargetFormat(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   marker,
                                                             ViInt32   targetFormat);

ViStatus _VI_FUNC rsznl_MarkerBandfilterSearch(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsznl_ReferenceMarkerBandfilterSearch(ViSession instrSession,
                                                        ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureMarkerBandfilterSearchMode(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   searchMode);

ViStatus _VI_FUNC rsznl_ConfigureMarkerxdBBandwidth(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  xDBBandwidth);

ViStatus _VI_FUNC rsznl_QueryMarkerBandfilterResults(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64* bandwidth,
                                                     ViReal64* centerStimulus,
                                                     ViReal64* qualityFactor,
                                                     ViReal64* loss,
                                                     ViReal64* lowerEdge,
                                                     ViReal64* upperEdge);

ViStatus _VI_FUNC rsznl_ConfigureMarkerBandfilterSearchResultState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean searchResults,
                            ViInt32   horizontalPosition,
                            ViInt32   verticalPosition);

ViStatus _VI_FUNC rsznl_ConfigureMarkerTracking(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   marker,
                                                ViBoolean markerTracking);

ViStatus _VI_FUNC rsznl_ConfigureMarkerSearchRange(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   marker,
                                                   ViInt32   searchRange,
                                                   ViReal64  start,
                                                   ViReal64  stop);

ViStatus _VI_FUNC rsznl_ConfigureMarkerSearchLimitLinesState(ViSession instrSession,
                                                             ViInt32   marker,
                                                             ViInt32   channel,
                                                             ViBoolean showLimitLines);

ViStatus _VI_FUNC rsznl_QueryMarkerSearchResults(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   marker,
                                                 ViInt32   bufferSize,
                                                 ViReal64  markerStimulus[],
                                                 ViReal64  markerResponse[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerTracking(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   marker,
                                                         ViBoolean markerTracking);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerSearchRange(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   marker,
                                                            ViInt32   searchRange,
                                                            ViReal64  start,
                                                            ViReal64  stop);

ViStatus _VI_FUNC rsznl_ConfigureReferenceMarkerSearchLimitLinesState(
                            ViSession instrSession,
                            ViInt32   marker,
                            ViInt32   channel,
                            ViBoolean showLimitLines);

ViStatus _VI_FUNC rsznl_QueryReferenceMarkerSearchResults(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   marker,
                                                          ViInt32   bufferSize,
                                                          ViReal64  markerStimulus[],
                                                          ViReal64  markerResponse[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureSweepRangeToMarker(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   marker,
                                                    ViInt32   setByMarker);

ViStatus _VI_FUNC rsznl_ConfigureSweepRangeToReferenceMarker(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   marker,
                                                             ViInt32   setByMarker);

ViStatus _VI_FUNC rsznl_ConfigureMarkerMultiplePeakExcursion(ViSession instrSession,
                                                             ViInt32   channel_Trace,
                                                             ViBoolean enabled,
                                                             ViReal64  excursion);

ViStatus _VI_FUNC rsznl_ConfigureMarkerMultiplePeakThreshold(ViSession instrSession,
                                                             ViInt32   channel_Trace,
                                                             ViBoolean enabled,
                                                             ViReal64  threshold);

ViStatus _VI_FUNC rsznl_AutoScaleTrace(ViSession instrSession,
                                       ViString  traceName);

ViStatus _VI_FUNC rsznl_ConfigureTrace(ViSession instrSession,
                                       ViString  traceName,
                                       ViReal64  scaleDivisions,
                                       ViReal64  referenceLevel,
                                       ViReal64  referencePosition);

ViStatus _VI_FUNC rsznl_ConfigureTraceMaxMin(ViSession instrSession,
                                             ViString  traceName,
                                             ViReal64  top,
                                             ViReal64  bottom);

ViStatus _VI_FUNC rsznl_ConfigureInfiniteAverage(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean enabled,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsznl_SelectCalibrationType(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  calibrationName,
                                              ViInt32   calibrationType,
                                              ViInt32   arraySize,
                                              ViInt32   ports[],
                                              ViString  adapterCalKit);

ViStatus _VI_FUNC rsznl_StartCalibration(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   standard,
                                         ViInt32   port1,
                                         ViInt32   port2,
                                         ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_StartCalibrationWithOptions(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   standard,
                                                    ViInt32   port1,
                                                    ViInt32   port2,
                                                    ViBoolean dispersion,
                                                    ViInt32   delayPhase,
                                                    ViReal64  delayPhaseValue,
                                                    ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_ConfigureSystemErrorCorrectionState(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean correctionState);

ViStatus _VI_FUNC rsznl_LoadCalibrationDataFromCalGroupFile(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViString  calPoolFile,
                                                            ViInt32   standard,
                                                            ViInt32   port1,
                                                            ViInt32   port2);

ViStatus _VI_FUNC rsznl_CalibrationManager(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   operationToBePerformed,
                                           ViString  fileName,
                                           ViString  secondFileName);

ViStatus _VI_FUNC rsznl_ConfigureUserDefinedPresetCalibration(
                            ViSession instrSession,
                            ViString  userDefinedPresetCalibration);

ViStatus _VI_FUNC rsznl_MultipleCalibrationTypesMode(ViSession instrSession,
                                                     ViBoolean mode);

ViStatus _VI_FUNC rsznl_CalibrationAuto(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  calibrationKitName,
                                        ViInt32   analyzerPort1,
                                        ViInt32   analyzerPort2,
                                        ViInt32   analyzerPort3,
                                        ViInt32   analyzerPort4,
                                        ViInt32   calUnitPort1,
                                        ViInt32   calUnitPort2,
                                        ViInt32   calUnitPort3,
                                        ViInt32   calUnitPort4,
                                        ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_CalibrationAutoSimplified(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  calibrationKitName,
                                                  ViInt32   analyzerPort1,
                                                  ViInt32   analyzerPort2,
                                                  ViInt32   analyzerPort3,
                                                  ViInt32   analyzerPort4,
                                                  ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_CalibrationAutoType(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   parameters,
                                            ViString  calibrationKitName,
                                            ViInt32   analyzerPort1,
                                            ViInt32   analyzerPort2,
                                            ViInt32   analyzerPort3,
                                            ViInt32   analyzerPort4,
                                            ViInt32   calUnitPort1,
                                            ViInt32   calUnitPort2,
                                            ViInt32   calUnitPort3,
                                            ViInt32   calUnitPort4,
                                            ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_CalibrationAutoTypeSimplified(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   parameters,
                                                      ViString  calibrationKitName,
                                                      ViInt32   analyzerPort1,
                                                      ViInt32   analyzerPort2,
                                                      ViInt32   analyzerPort3,
                                                      ViInt32   analyzerPort4,
                                                      ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_RepeatCalibration(ViSession instrSession,
                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationTemperatureCompensation(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean temperatureCompensation);

ViStatus _VI_FUNC rsznl_CalibrationUnknownThroughMeasurement(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   testPort1,
                                                             ViInt32   testPort2);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationAllChannelsState(ViSession instrSession,
                                                             ViBoolean state);

ViStatus _VI_FUNC rsznl_QueryCalibrationConnection(ViSession instrSession,
                                                   ViInt32*  analyzerPort1,
                                                   ViInt32*  analyzerPort2,
                                                   ViInt32*  analyzerPort3,
                                                   ViInt32*  analyzerPort4);

ViStatus _VI_FUNC rsznl_QueryCalibrationDate(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   bufferSize,
                                             ViChar    calibrationDate[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationState(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32*  calibrationState);

ViStatus _VI_FUNC rsznl_ConfigureActiveCalibrationUnit(ViSession instrSession,
                                                       ViString  calibrationUnit);

ViStatus _VI_FUNC rsznl_QueryAllCalibrationUnits(ViSession instrSession,
                                                 ViInt32   bufferSize,
                                                 ViChar    calibrationUnits[]);

ViStatus _VI_FUNC rsznl_QueryAllCalibrationSubmoduleUnits(ViSession instrSession,
                                                          ViInt32   bufferSize,
                                                          ViChar    calibrationSubmoduleUnits[]);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationUnitStandard(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   port1,
                                                         ViInt32   port2,
                                                         ViInt32   calKitID);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationAutomaticMemoryState(
                            ViSession instrSession,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationUnitCharacterization(
                            ViSession instrSession,
                            ViString  calUnitCharacterizations);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizations(
                            ViSession instrSession,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizations[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationsStandards(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizations[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationDate(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizationDate[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationFrequencyRange(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViReal64* startFrequency,
                            ViReal64* stopFrequency);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationPorts(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   bufferSize,
                            ViChar    calUnitCharacterizationPorts[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitCharacterizationData(
                            ViSession instrSession,
                            ViString  calUnitCharacterization,
                            ViInt32   standard,
                            ViInt32   sParameter,
                            ViInt32   firstPortNumber,
                            ViInt32   secondPortNumber,
                            ViInt32   bufferSize,
                            ViReal64  calibrationData[],
                            ViInt32*  noOfValues);

ViStatus _VI_FUNC rsznl_QueryCalibrationUnitWarmupState(ViSession  instrSession,
                                                        ViBoolean* warmupState);

ViStatus _VI_FUNC rsznl_ConfigureAutomaticCalibration(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   calibrationType,
                                                      ViString  characterization,
                                                      ViString  name);

ViStatus _VI_FUNC rsznl_CorrectionDiscard(ViSession instrSession,
                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_CorrectionDelete(ViSession instrSession,
                                         ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureWaveCorrectionLogicEnabled(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsznl_ConfigureCorrectionCalculateAfterDeEmbed(
                            ViSession instrSession,
                            ViBoolean calculateAfterDeEmbed);

ViStatus _VI_FUNC rsznl_ConfigureCorrectionMethod(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   method);

ViStatus _VI_FUNC rsznl_JoinCalibrations(ViSession instrSession,
                                         ViString  firstCal,
                                         ViInt32   locationFirstCal,
                                         ViString  secondCal,
                                         ViInt32   locationSecondCal,
                                         ViString  outputCal,
                                         ViInt32   locationOutputCal);

ViStatus _VI_FUNC rsznl_AreCalibrationsJoinable(ViSession  instrSession,
                                                ViString   firstCal,
                                                ViInt32    locationFirstCal,
                                                ViString   secondCal,
                                                ViInt32    locationSecondCal,
                                                ViBoolean* areCalibrationsJoinable);

ViStatus _VI_FUNC rsznl_PowerCalibrationReceiver(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   wave,
                                                 ViInt32   calPort,
                                                 ViInt32   sourceType,
                                                 ViInt32   sourcePort,
                                                 ViBoolean calOnlyPortFreq);

ViStatus _VI_FUNC rsznl_QueryPowerCalibrationLabel(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bufferSize,
                                                   ViChar    label[]);

ViStatus _VI_FUNC rsznl_WriteCalibrationPowerDataSet(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  calibratedWave,
                                                     ViInt32   numberOfValues,
                                                     ViReal64  powerCorrectionValues[]);

ViStatus _VI_FUNC rsznl_ReadCalibrationPowerDataSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   arraySize,
                                                    ViString  calibratedWave,
                                                    ViInt32*  numberOfValues,
                                                    ViReal64  powerCorrectionValues[]);

ViStatus _VI_FUNC rsznl_ActivatePowerCalibration(ViSession instrSession,
                                                 ViInt32   channel);

ViStatus _VI_FUNC rsznl_DeactivatePowerCalibration(ViSession instrSession,
                                                   ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureConnector(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   port,
                                           ViInt32   connector);

ViStatus _VI_FUNC rsznl_ConfigureUserConnectorType(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViString  connectorName,
                                                   ViInt32   propagationMode,
                                                   ViInt32   connectorType,
                                                   ViReal64  relativePermittivity,
                                                   ViReal64  impedance);

ViStatus _VI_FUNC rsznl_ConfigureUserConnector(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   port,
                                               ViString  connector,
                                               ViInt32   connectorGender);

ViStatus _VI_FUNC rsznl_DeleteUserConnectorType(ViSession instrSession,
                                                ViInt32   channel,
                                                ViString  connectorName);

ViStatus _VI_FUNC rsznl_ConfigurePortConnectorTypes(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   connectorType);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationSameGenderAtAllPorts(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   sameGenderAtAllPorts);

ViStatus _VI_FUNC rsznl_ConnectorTypesCatalog(ViSession instrSession,
                                              ViInt32   bufferSize,
                                              ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_SaveCalibrationData(ViSession instrSession,
                                            ViInt32   channel);

ViStatus _VI_FUNC rsznl_GenerateDefaultCalibrationData(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsznl_DeleteCalibrationData(ViSession instrSession,
                                              ViInt32   channel,
                                              ViString  calibrationName);

ViStatus _VI_FUNC rsznl_QueryAvailableCalibrationDataCatalog(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   catalog,
                                                             ViInt32   port1,
                                                             ViInt32   port2,
                                                             ViInt32   arraySize,
                                                             ViChar    availableBuffers[],
                                                             ViInt32*  numberOfValues);

ViStatus _VI_FUNC rsznl_ReadCalibrationData(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   errorTerm,
                                            ViInt32   sourcePort,
                                            ViInt32   loadPort,
                                            ViInt32   bufferSize,
                                            ViReal64  calibrationData[],
                                            ViInt32*  noOfValues);

ViStatus _VI_FUNC rsznl_WriteCalibrationData(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   errorTerm,
                                             ViInt32   sourcePort,
                                             ViInt32   loadPort,
                                             ViReal64  calibrationData[]);

ViStatus _VI_FUNC rsznl_QueryAvailableCalibrationDataCatalogPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   physicalPort,
                            ViInt32   catalog,
                            ViInt32   port1,
                            ViInt32   port2,
                            ViInt32   arraySize,
                            ViChar    availableBuffers[],
                            ViInt32*  numberOfValues);

ViStatus _VI_FUNC rsznl_ReadCalibrationDataPort(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   physicalPort,
                                                ViInt32   errorTermParameters,
                                                ViInt32   port1,
                                                ViInt32   port2,
                                                ViInt32   bufferSize,
                                                ViReal64  calibrationData[],
                                                ViInt32*  noOfValues);

ViStatus _VI_FUNC rsznl_WriteCalibrationDataPort(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   physicalPort,
                                                 ViInt32   errorTerm,
                                                 ViInt32   port1,
                                                 ViInt32   port2,
                                                 ViReal64  calibrationData[]);

ViStatus _VI_FUNC rsznl_ExportFactoryCalibrationDataToTouchstoneFile(
                            ViSession instrSession,
                            ViString  directory);

ViStatus _VI_FUNC rsznl_ExportUserDefinedCalibrationDataToTouchstoneFile(
                            ViSession instrSession,
                            ViString  directory,
                            ViString  calibrationKitName);

ViStatus _VI_FUNC rsznl_QueryCalibrationStimulusFrequencies(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   bufferSize,
                                                            ViReal64  stimulusFrequencies[],
                                                            ViInt32*  noOfValues);

ViStatus _VI_FUNC rsznl_QueryCalibrationDataParameters(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViReal64* frequencyStart,
                                                       ViReal64* frequencyStop,
                                                       ViInt32*  numberOfPoints,
                                                       ViReal64* internalSignalSourcePower,
                                                       ViInt32*  sweepType);

ViStatus _VI_FUNC rsznl_QueryCalibrationDataParametersSpecific(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   systemErrorCorrection,
                            ViInt32   index,
                            ViInt32   type,
                            ViInt32   bufferSize,
                            ViChar    info[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationDataParametersCount(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32*  parametersCount);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKit(ViSession instrSession,
                                                ViInt32   connector,
                                                ViString  calibrationKitName);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitAuto(ViSession instrSession,
                                                    ViString  calibrationKitName,
                                                    ViInt32   analyzerPort1,
                                                    ViInt32   analyzerPort2,
                                                    ViInt32   analyzerPort3,
                                                    ViInt32   analyzerPort4,
                                                    ViInt32   calUnitPort1,
                                                    ViInt32   calUnitPort2,
                                                    ViInt32   calUnitPort3,
                                                    ViInt32   calUnitPort4,
                                                    ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_AddCalibrationKitAuto(ViSession instrSession,
                                              ViString  characterization,
                                              ViInt32   analyzerPort1,
                                              ViInt32   analyzerPort2,
                                              ViInt32   analyzerPort3,
                                              ViInt32   analyzerPort4,
                                              ViInt32   calUnitPort1,
                                              ViInt32   calUnitPort2,
                                              ViInt32   calUnitPort3,
                                              ViInt32   calUnitPort4,
                                              ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitUserConnectorType(
                            ViSession instrSession,
                            ViString  connector,
                            ViString  calibrationKitName);

ViStatus _VI_FUNC rsznl_CalibrationKitCatalog(ViSession instrSession,
                                              ViString  connectorName,
                                              ViInt32   bufferSize,
                                              ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_DefineCalibrationStandard(ViSession instrSession,
                                                  ViInt32   standard,
                                                  ViString  connectorType,
                                                  ViString  calibrationKitName,
                                                  ViString  serialNumber,
                                                  ViReal64  minFrequency,
                                                  ViReal64  maxFrequency,
                                                  ViReal64  delayParam,
                                                  ViReal64  loss,
                                                  ViReal64  z0,
                                                  ViReal64  capacitances[],
                                                  ViReal64  residualInductances[],
                                                  ViInt32   approximation,
                                                  ViReal64  resistance,
                                                  ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_CalibrationStandardsCatalog(ViSession instrSession,
                                                    ViString  calibrationKitName,
                                                    ViInt32   bufferSize,
                                                    ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitLabel(ViSession instrSession,
                                                     ViString  calibrationKitName,
                                                     ViString  label);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitPassword(ViSession instrSession,
                                                        ViString  password);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDelayMode(ViSession instrSession,
                                                      ViString  connectorType,
                                                      ViString  calibrationKitName,
                                                      ViString  calibrationKitLabel,
                                                      ViInt32   delayMode);

ViStatus _VI_FUNC rsznl_SaveCalibrationKit(ViSession instrSession,
                                           ViString  fileName);

ViStatus _VI_FUNC rsznl_DeleteCalibrationKit(ViSession instrSession,
                                             ViString  calibrationKitName);

ViStatus _VI_FUNC rsznl_LoadCalibrationKit(ViSession instrSession,
                                           ViString  connectorType,
                                           ViString  calibrationKitName,
                                           ViInt32   standard,
                                           ViString  calibrationKitLabel,
                                           ViString  fileName,
                                           ViInt32   portNumber1,
                                           ViInt32   portNumber2);

ViStatus _VI_FUNC rsznl_LoadCalibrationKitByGenderFromFile(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViString  calibrationKitFile,
                                                           ViInt32   gender,
                                                           ViInt32   portSelector,
                                                           ViInt32   arraySize,
                                                           ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_LoadCalibrationKitByGenderFromPool(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViString  calibrationKitName,
                                                           ViString  label,
                                                           ViInt32   gender,
                                                           ViInt32   portSelector,
                                                           ViInt32   arraySize,
                                                           ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_QueryCalibrationKitData(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   port,
                                                ViInt32   detail,
                                                ViInt32   bufferSize,
                                                ViChar    result[]);

ViStatus _VI_FUNC rsznl_LoadZVRCalibrationKit(ViSession instrSession,
                                              ViString  file);

ViStatus _VI_FUNC rsznl_ImportKit(ViSession instrSession,
                                  ViString  fileName);

ViStatus _VI_FUNC rsznl_ExportKit(ViSession instrSession,
                                  ViString  kitName,
                                  ViString  fileName);

ViStatus _VI_FUNC rsznl_QueryCalibrationKitInfo(ViSession instrSession,
                                                ViString  calKitFile,
                                                ViInt32   bufferSize,
                                                ViChar    connectorType[],
                                                ViChar    calKitName[],
                                                ViChar    calKitLabel[],
                                                ViInt32*  calKitGender);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitWithLabel(ViSession instrSession,
                                                         ViInt32   connector,
                                                         ViString  calibrationKitName,
                                                         ViString  calibrationKitLabel);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitUserConnectorTypeWithLabel(
                            ViSession instrSession,
                            ViString  connector,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel);

ViStatus _VI_FUNC rsznl_CalibrationKitCatalogWithLabel(ViSession instrSession,
                                                       ViString  connectorName,
                                                       ViInt32   bufferSize,
                                                       ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationStandardWithLabel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  connectorType,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel,
                            ViString  serialNumber,
                            ViReal64  minFrequency,
                            ViReal64  maxFrequency,
                            ViReal64  delayParam,
                            ViReal64  loss,
                            ViReal64  z0,
                            ViReal64  capacitances[],
                            ViReal64  residualInductances[],
                            ViInt32   approximation,
                            ViReal64  resistance,
                            ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_CalibrationStandardsCatalogWithLabel(ViSession instrSession,
                                                             ViString  calibrationKitName,
                                                             ViString  calibrationKitLabel,
                                                             ViInt32   bufferSize,
                                                             ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationKitLabelWithLabel(
                            ViSession instrSession,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel,
                            ViString  newLabel);

ViStatus _VI_FUNC rsznl_DeleteCalibrationKitWithLabel(ViSession instrSession,
                                                      ViString  calibrationKitName,
                                                      ViString  calibrationKitLabel);

ViStatus _VI_FUNC rsznl_LoadCalibrationKitWithLabel(ViSession instrSession,
                                                    ViString  connectorName,
                                                    ViString  calibrationKitName,
                                                    ViString  calibrationKitLabel,
                                                    ViInt32   standard,
                                                    ViString  standardLabel,
                                                    ViString  fileName,
                                                    ViInt32   portNumber1,
                                                    ViInt32   portNumber2);

ViStatus _VI_FUNC rsznl_ReadCalibrationKitWithLabelSParameterData(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  connectorName,
                            ViString  calibrationKitName,
                            ViString  calibrationKitLabel,
                            ViInt32   sParameter,
                            ViInt32   portNumber1,
                            ViInt32   portNumber2,
                            ViInt32   arraySize,
                            ViReal64  traceData[],
                            ViInt32*  noOfValues);

ViStatus _VI_FUNC rsznl_ExportKitWithLabel(ViSession instrSession,
                                           ViString  kitName,
                                           ViString  calkitLabel,
                                           ViString  fileName);

ViStatus _VI_FUNC rsznl_PowerMeterSavePowerLossList(ViSession instrSession,
                                                    ViString  traceFile);

ViStatus _VI_FUNC rsznl_PowerMeterLoadPowerLossList(ViSession instrSession,
                                                    ViString  traceFile,
                                                    ViString  trace);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationLimitCheckFormat(
                            ViSession instrSession,
                            ViInt32   limitCheckFormat);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationAverageState(
                            ViSession instrSession,
                            ViBoolean averageState);

ViStatus _VI_FUNC rsznl_RunCalibrationValidation(ViSession instrSession);

ViStatus _VI_FUNC rsznl_QueryCalibrationValidationResult(ViSession instrSession,
                                                         ViInt32   bufferSize,
                                                         ViChar    result[]);

ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsMagnitude(ViSession instrSession,
                                                             ViInt32   port,
                                                             ViReal64  lower,
                                                             ViReal64  upper);

ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsPhase(ViSession instrSession,
                                                         ViInt32   port,
                                                         ViReal64  lower,
                                                         ViReal64  upper);

ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsReal(ViSession instrSession,
                                                        ViInt32   port,
                                                        ViReal64  lower,
                                                        ViReal64  upper);

ViStatus _VI_FUNC rsznl_CalibrationValidationLimitsImaginary(ViSession instrSession,
                                                             ViInt32   port,
                                                             ViReal64  lower,
                                                             ViReal64  upper);

ViStatus _VI_FUNC rsznl_RestoreDefaultCalibrationValidationLimits(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationCharacterization(
                            ViSession instrSession,
                            ViString  characterization);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationValidationStandard(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigReferenceReciever(
                            ViSession instrSession,
                            ViInt32   referenceReciever);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigReferenceRecieverPower(
                            ViSession instrSession,
                            ViReal64  referenceRecieverPower);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigPortPowerOffset(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  offset,
                            ViInt32   offsetType);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConfigCalPowerOffset(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViReal64  calPowerOffset);

ViStatus _VI_FUNC rsznl_ConfigurePowerTransmissionCoefficientTwoPortEnabled(
                            ViSession instrSession,
                            ViBoolean enabled,
                            ViInt32   deEmbeddingPosition);

ViStatus _VI_FUNC rsznl_QueryPowerTransmissionCoeficientTwoPortCount(
                            ViSession instrSession,
                            ViInt32   deEmbedingPosition,
                            ViInt32*  count);

ViStatus _VI_FUNC rsznl_InsertPowerTransmissionCoefficientTwoPort(
                            ViSession instrSession,
                            ViInt32   listNumber,
                            ViReal64  frequency,
                            ViReal64  transmissionCoefficient,
                            ViInt32   deEmbedingPosition);

ViStatus _VI_FUNC rsznl_DefinePowerTransmissionCoefficientTwoPort(
                            ViSession instrSession,
                            ViInt32   listNumber,
                            ViReal64  frequency,
                            ViReal64  transmissionCoefficient,
                            ViInt32   deEmbeddingPosition);

ViStatus _VI_FUNC rsznl_DeletePowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   deEmbeddingPosition);

ViStatus _VI_FUNC rsznl_DeleteAllPowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   deEmbedingPosition);

ViStatus _VI_FUNC rsznl_SelectPowerTransmissionCoeficientTwoPortTrace(
                            ViSession instrSession,
                            ViString  trace,
                            ViInt32   deEmbeddingPosition);

ViStatus _VI_FUNC rsznl_StorePowerTransmissionCoeficientTwoPortCoefficient(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsznl_LoadPowerTransmissionCoeficientTwoPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViString  traceFile,
                            ViString  trace,
                            ViInt32   deEmbeddingPosition);

ViStatus _VI_FUNC rsznl_ConfigurePowerTransmissionCoeficientAdditionalTwoPortPosition(
                            ViSession instrSession,
                            ViBoolean additionalTwoPortPosition);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationMaxItterations(
                            ViSession instrSession,
                            ViInt32   maxItterations);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationTolerance(ViSession instrSession,
                                                           ViReal64  tolerance);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationConvergence(ViSession instrSession,
                                                             ViReal64  convergence);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationMethod(ViSession instrSession,
                                                        ViInt32   method);

ViStatus _VI_FUNC rsznl_InitiatePowerCalibration(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   port,
                                                 ViInt32   initiateCalibration);

ViStatus _VI_FUNC rsznl_WritePowerCalibrationDataSet(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViString  source,
                                                     ViInt32   numberOfValues,
                                                     ViReal64  powerCorrectionValues[]);

ViStatus _VI_FUNC rsznl_ReadPowerCalibrationDataSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   arraySize,
                                                    ViString  source,
                                                    ViInt32*  numberOfValues,
                                                    ViReal64  powerCorrectionValues[]);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationOtherSourcesEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean otherSourcesEnabled);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationFlatnessEnabled(
                            ViSession instrSession,
                            ViBoolean flatnessEnabled);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReferenceReceiverEnabled(
                            ViSession instrSession,
                            ViBoolean receiverEnabled);

ViStatus _VI_FUNC rsznl_QueryPowerCalibrationAvailablePowerCalibrations(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32*  availablePowerCalibrations);

ViStatus _VI_FUNC rsznl_SelectPowerCalibrationSource(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   sourceType,
                                                     ViInt32   sourcePort,
                                                     ViBoolean calOnlyPortFreq);

ViStatus _VI_FUNC rsznl_QureyPowerCalibrationSettings(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   powerCalibration,
                                                      ViInt32   settingsType,
                                                      ViInt32   araySize,
                                                      ViChar    result[],
                                                      ViInt32*  numberOfValues);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationActiveChannelEnabled(
                            ViSession instrSession,
                            ViBoolean calibrationActiveChannel);

ViStatus _VI_FUNC rsznl_QueryPowerCalibrationVerificationSweepResult(
                            ViSession  instrSession,
                            ViInt32*   channel,
                            ViBoolean* calibration,
                            ViReal64*  maxOffset);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationSourceEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean sourceEnabled);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReferenceWaveEnable(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean referenceWaveEnable);

ViStatus _VI_FUNC rsznl_ConfigurePowerCalibrationReceivedWaveEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   port,
                            ViBoolean receivedWaveEnabled);

ViStatus _VI_FUNC rsznl_ChannelAdd(ViSession instrSession,
                                   ViInt32   channel,
                                   ViString  channelName);

ViStatus _VI_FUNC rsznl_ChannelAddTrace(ViSession instrSession,
                                        ViInt32   channel,
                                        ViString  channelName,
                                        ViString  traceName);

ViStatus _VI_FUNC rsznl_ChannelAddTraceDiagramArea(ViSession instrSession,
                                                   ViInt32   window,
                                                   ViInt32   channel,
                                                   ViString  channelName,
                                                   ViString  traceName);

ViStatus _VI_FUNC rsznl_ChannelDelete(ViSession instrSession,
                                      ViInt32   channel);

ViStatus _VI_FUNC rsznl_ChannelRename(ViSession instrSession,
                                      ViInt32   channel,
                                      ViString  channelName);

ViStatus _VI_FUNC rsznl_ChannelList(ViSession instrSession,
                                    ViInt32   bufferSize,
                                    ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_QueryChannelNumber(ViSession instrSession,
                                           ViString  channelName,
                                           ViInt32*  channelNumber);

ViStatus _VI_FUNC rsznl_ConfigureActiveChannel(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureChannelFixtureSimulator(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean fixtureSimulator);

ViStatus _VI_FUNC rsznl_ConfigureDrivingMode(ViSession instrSession,
                                             ViInt32   drivingMode);

ViStatus _VI_FUNC rsznl_ConfigureImageSuppression(ViSession instrSession,
                                                  ViInt32   imageSuppression);

ViStatus _VI_FUNC rsznl_ConfigureChannelBits(ViSession instrSession,
                                             ViInt32   channel,
                                             ViString  channelBits,
                                             ViInt32   pin1617);

ViStatus _VI_FUNC rsznl_ConfigureChannelSegment(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   segment,
                                                ViBoolean enabled,
                                                ViString  segmentValue);

ViStatus _VI_FUNC rsznl_DefinePortGroupContinuous(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   group,
                                                  ViInt32   arraySize,
                                                  ViInt32   logicalPorts[]);

ViStatus _VI_FUNC rsznl_DefinePortGroupArbitrary(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   group,
                                                 ViInt32   arraySize,
                                                 ViInt32   logicalPorts[]);

ViStatus _VI_FUNC rsznl_DeleteAllPortGroups(ViSession instrSession,
                                            ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureOffsetDelay(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   port,
                                             ViReal64  delay);

ViStatus _VI_FUNC rsznl_ConfigureOffsetElectricalLength(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   port,
                                                        ViReal64  electricalLength);

ViStatus _VI_FUNC rsznl_ConfigureOffsetMechanicalLength(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   port,
                                                        ViReal64  mechanicalLength);

ViStatus _VI_FUNC rsznl_ConfigureOffsetPermittivity(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   port,
                                                    ViReal64  permittivity);

ViStatus _VI_FUNC rsznl_ConfigureOneWayLoss(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   port,
                                            ViReal64  lossAtDC,
                                            ViReal64  lossAtFrequency,
                                            ViReal64  frequencyForLoss);

ViStatus _VI_FUNC rsznl_AutoLength(ViSession instrSession,
                                   ViInt32   channel);

ViStatus _VI_FUNC rsznl_AutoLengthAndLoss(ViSession instrSession,
                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureResetOffsets(ViSession instrSession,
                                              ViInt32   channel,
                                              ViBoolean resetOffset);

ViStatus _VI_FUNC rsznl_ConfigureOffsetCompensation(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   port,
                                                    ViBoolean compensation);

ViStatus _VI_FUNC rsznl_ConfigureTimeGateAdjust(ViSession instrSession,
                                                ViBoolean adjustTimeGate);

ViStatus _VI_FUNC rsznl_ConfigureOneWayLossAtSecondFrequency(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   port,
                                                             ViBoolean enabled,
                                                             ViReal64  secondFrequency,
                                                             ViReal64  frequencyForLoss);

ViStatus _VI_FUNC rsznl_ConfigureFixtureCompensationOffsetCorrection(
                            ViSession instrSession,
                            ViInt32   offsetCompensation);

ViStatus _VI_FUNC rsznl_ResetFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel);

ViStatus _VI_FUNC rsznl_StartFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   arraySize,
                                                 ViInt32   terminatedType,
                                                 ViInt32   portNumbers[]);

ViStatus _VI_FUNC rsznl_ApplyFixtureCompensation(ViSession instrSession,
                                                 ViInt32   channel);

ViStatus _VI_FUNC rsznl_ImportFixtureCompensation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  fixtureFile,
                                                  ViInt32   terminatedType,
                                                  ViInt32   arraySize,
                                                  ViInt32   portNumbers[]);

ViStatus _VI_FUNC rsznl_ExportFixtureCompensation(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  fixtureFile,
                                                  ViInt32   terminatedType,
                                                  ViInt32   arraySize,
                                                  ViInt32   portNumbers[]);

ViStatus _VI_FUNC rsznl_QueryFixtureCompensationDirectCompansationStatus(
                            ViSession  instrSession,
                            ViInt32    channel,
                            ViInt32    port,
                            ViBoolean* status);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedPort(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   parameterType,
                            ViInt32   parameterNumber,
                            ViInt32   circuitModel,
                            ViReal64  value);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   interchange,
                            ViString  touchstoneFile);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkSingleEndedCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   physicalPortNumber,
                            ViInt32   circuitModel);

ViStatus _VI_FUNC rsznl_LoadSingleEndedPortCircuitModelData(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   physicalPortNumber,
                                                            ViString  fileName,
                                                            ViBoolean interchangePortNumbers);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkABalancedState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedPort(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   logicalPortNumber,
                                                            ViInt32   parameterType,
                                                            ViInt32   parameterNumber,
                                                            ViInt32   circuitModel,
                                                            ViReal64  value);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedData(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   functionType,
                                                            ViInt32   logicalPortNumber,
                                                            ViInt32   portAssignment,
                                                            ViInt32   interchange,
                                                            ViString  touchstoneFile);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkBalancedCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   circuitModel);

ViStatus _VI_FUNC rsznl_LoadBalancedPortCircuitModelData(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   functionType,
                                                         ViInt32   logicalPortNumber,
                                                         ViString  fileName,
                                                         ViInt32   parameter,
                                                         ViBoolean interchangePortNumbers);

ViStatus _VI_FUNC rsznl_DefineVirtualNetworkPortSet(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32   functionType,
                                                    ViInt32   portSet,
                                                    ViInt32   arraySize,
                                                    ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_DefineVirtualNetworkPortPair(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType,
                                                     ViInt32   portPair,
                                                     ViInt32   arraySize,
                                                     ViInt32   ports[]);

ViStatus _VI_FUNC rsznl_DeleteVirtualNetworkPortPair(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPairState(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32   functionType,
                                                             ViInt32   portPair,
                                                             ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPair(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   functionType,
                                                        ViInt32   portPair,
                                                        ViInt32   parameterType,
                                                        ViInt32   parameterNumber,
                                                        ViInt32   circuitModel,
                                                        ViReal64  value);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkPortPairCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   portPair,
                            ViInt32   circuitModel);

ViStatus _VI_FUNC rsznl_LoadPortPairCircuitModelData(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   functionType,
                                                     ViInt32   portPair,
                                                     ViString  fileName,
                                                     ViInt32   parameter,
                                                     ViBoolean interchangePortNumbers);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoopState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoop(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   functionType,
                                                          ViInt32   parameterType,
                                                          ViInt32   circuitModel,
                                                          ViReal64  groundLoopValue);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkGroundLoopCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   circuitModel);

ViStatus _VI_FUNC rsznl_LoadGroundLoopCircuitModelData(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   functionType,
                                                       ViString  fileName);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchState(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatch(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   parameterType,
                            ViInt32   parameterNumber,
                            ViInt32   circuitModel,
                            ViReal64  value);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   interchange,
                            ViString  touchstoneFile);

ViStatus _VI_FUNC rsznl_ConfigureVirtualNetworkDifferentialMatchCircuitModel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViInt32   circuitModel);

ViStatus _VI_FUNC rsznl_LoadDifferentialMatchCircuitModelData(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   functionType,
                            ViInt32   logicalPortNumber,
                            ViString  fileName,
                            ViBoolean interchangePortNumbers);

ViStatus _VI_FUNC rsznl_DiagramAreaAdd(ViSession instrSession,
                                       ViInt32   window);

ViStatus _VI_FUNC rsznl_DiagramAreaDelete(ViSession instrSession,
                                          ViInt32   window);

ViStatus _VI_FUNC rsznl_DiagramAreaMaximize(ViSession instrSession,
                                            ViInt32   window,
                                            ViInt32   diagramArea);

ViStatus _VI_FUNC rsznl_DiagramAreaTitle(ViSession instrSession,
                                         ViInt32   window,
                                         ViBoolean title,
                                         ViString  titleString);

ViStatus _VI_FUNC rsznl_DiagramAreaName(ViSession instrSession,
                                        ViInt32   window,
                                        ViString  areaName);

ViStatus _VI_FUNC rsznl_DiagramAreaCatalog(ViSession instrSession,
                                           ViChar    catalog[],
                                           ViInt32   bufferSize);

ViStatus _VI_FUNC rsznl_TraceDiagramAreaCatalog(ViSession instrSession,
                                                ViInt32   window,
                                                ViInt32   bufferSize,
                                                ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_DisplayTraceLabel(ViSession instrSession,
                                          ViString  traceName,
                                          ViBoolean enabled);

ViStatus _VI_FUNC rsznl_ConfigureTraceZoom(ViSession instrSession,
                                           ViInt32   window,
                                           ViInt32   window_Trace,
                                           ViBoolean zoomState,
                                           ViReal64  topEdge,
                                           ViReal64  bottomEdge,
                                           ViReal64  leftEdge,
                                           ViReal64  rightEdge);

ViStatus _VI_FUNC rsznl_ConfigureZoomOverview(ViSession instrSession,
                                              ViInt32   window,
                                              ViBoolean zoomOverviewState);

ViStatus _VI_FUNC rsznl_ConfigureSplitType(ViSession instrSession,
                                           ViInt32   layoutMode);

ViStatus _VI_FUNC rsznl_ConfigureSplitGrid(ViSession instrSession,
                                           ViInt32   rows,
                                           ViInt32   columns);

ViStatus _VI_FUNC rsznl_ConfigureLayoutSimplified(ViSession instrSession,
                                                  ViInt32   layoutID,
                                                  ViInt32   layoutFormatMode,
                                                  ViString  layoutData);

ViStatus _VI_FUNC rsznl_ConfigureLayout(ViSession instrSession,
                                        ViString  layoutData);

ViStatus _VI_FUNC rsznl_JoinLayouts(ViSession instrSession,
                                    ViInt32   mainLayoutID,
                                    ViInt32   diagramNumber,
                                    ViInt32   subLayoutID);

ViStatus _VI_FUNC rsznl_QueryLayoutCatalog(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_LayoutOverlayAll(ViSession instrSession);

ViStatus _VI_FUNC rsznl_LayoutSplitAll(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureDisplayFrequencyInfoState(ViSession instrSession,
                                                           ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureDisplayChannelInfoState(ViSession instrSession,
                                                         ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureDisplayTraceInfoState(ViSession instrSession,
                                                       ViBoolean state);

ViStatus _VI_FUNC rsznl_ConfigureDisplayFontSize(ViSession instrSession,
                                                 ViReal64  fontSize);

ViStatus _VI_FUNC rsznl_ConfigureDisplayLock(ViSession instrSession,
                                             ViBoolean displayLock);

ViStatus _VI_FUNC rsznl_ConfigureTraceInfoWindowEnabled(ViSession instrSession,
                                                        ViBoolean enabled);

ViStatus _VI_FUNC rsznl_TraceInfoWindowContentSelection(ViSession instrSession,
                                                        ViBoolean enabled,
                                                        ViString  traceName,
                                                        ViInt32   bandFilterItem);

ViStatus _VI_FUNC rsznl_MarkerInfoWindowEnabled(ViSession instrSession,
                                                ViInt32   marker,
                                                ViBoolean enabled,
                                                ViString  traceName);

ViStatus _VI_FUNC rsznl_ConfigureDisplay(ViSession instrSession,
                                         ViBoolean statusBarEnabled,
                                         ViBoolean softkeyBarEnabled,
                                         ViBoolean toolbarEnabled,
                                         ViInt32   touchEnabled,
                                         ViBoolean channelInformationEnabled,
                                         ViBoolean xAxisLabelEnabled,
                                         ViBoolean dateAndTimeEnabled,
                                         ViBoolean frontPanelKeysEnabled);

ViStatus _VI_FUNC rsznl_ConfigureDisplayBrightness(ViSession instrSession,
                                                   ViInt32   displayBrightness);

ViStatus _VI_FUNC rsznl_ConfigureDisplayDateAndTimeFormat(ViSession instrSession,
                                                          ViInt32   dateAndTimeFormat);

ViStatus _VI_FUNC rsznl_QueryColorsAndThemesCatalog(ViSession instrSession,
                                                    ViUInt32  arraySize,
                                                    ViChar    catalog[],
                                                    ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureColorsAndThemesSelectedTheme(
                            ViSession instrSession,
                            ViString  selectedTheme);

ViStatus _VI_FUNC rsznl_ResetColorScheme(ViSession instrSession,
                                         ViInt32   displayItem,
                                         ViInt32   color);

ViStatus _VI_FUNC rsznl_SelectColor(ViSession instrSession,
                                    ViInt32   displayItem,
                                    ViReal64  tint,
                                    ViReal64  saturation,
                                    ViReal64  brightness);

ViStatus _VI_FUNC rsznl_SelectPredefinedColor(ViSession instrSession,
                                              ViInt32   displayItem,
                                              ViInt32   color);

ViStatus _VI_FUNC rsznl_ShowLimitLine(ViSession instrSession,
                                      ViInt32   channel,
                                      ViBoolean showLimitLine);

ViStatus _VI_FUNC rsznl_ConfigureLimitCheck(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   limitLine,
                                            ViBoolean limitCheck,
                                            ViInt32   horizontalPosition,
                                            ViInt32   verticalPosition);

ViStatus _VI_FUNC rsznl_QueryLimitCheckResult(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32*  limitCheckResult);

ViStatus _VI_FUNC rsznl_QueryGlobalLimitCheckResult(ViSession instrSession,
                                                    ViInt32*  globalLimitCheck);

ViStatus _VI_FUNC rsznl_ClearLimitCheckResults(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsznl_QueryLimitEffectivePoints(ViSession instrSession,
                                                  ViInt32   type,
                                                  ViString  traceName,
                                                  ViInt32   arraySize,
                                                  ViReal64  points[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureHorizontalLine(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean displayLine,
                                                ViReal64  responseValue);

ViStatus _VI_FUNC rsznl_QueryLimitCheckResultChannel(ViSession instrSession,
                                                     ViString  setup,
                                                     ViInt32*  result);

ViStatus _VI_FUNC rsznl_ConfigureLimitLineFailBeep(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean failBeep);

ViStatus _VI_FUNC rsznl_ConfigureLimitLineShift(ViSession instrSession,
                                                ViInt32   channel,
                                                ViReal64  horizontalShift,
                                                ViReal64  upperShift,
                                                ViReal64  lowerShift);

ViStatus _VI_FUNC rsznl_ConfigureLimitLineTTLPass(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   outputNo,
                                                  ViBoolean TTLOutput);

ViStatus _VI_FUNC rsznl_QueryLimitFailSweepPoints(ViSession instrSession,
                                                  ViString  traceName,
                                                  ViInt32   limitFailType,
                                                  ViInt32   bufferSize,
                                                  ViChar    limitFailSweepPoints[]);

ViStatus _VI_FUNC rsznl_AddLimitLineSegment(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   segment,
                                            ViInt32   type,
                                            ViReal64  startStimulus,
                                            ViReal64  stopStimulus,
                                            ViReal64  startResponse,
                                            ViReal64  stopResponse);

ViStatus _VI_FUNC rsznl_EditLimitLineSegment(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   segment,
                                             ViInt32   type,
                                             ViReal64  startStimulus,
                                             ViReal64  stopStimulus,
                                             ViReal64  startResponse,
                                             ViReal64  stopResponse);

ViStatus _VI_FUNC rsznl_QueryLimitLineSegmentCount(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32*  segmentCount);

ViStatus _VI_FUNC rsznl_ReadLimitLineSegmentList(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   listSize,
                                                 ViInt32*  segmentsCount,
                                                 ViInt32   type[],
                                                 ViReal64  startStimulus[],
                                                 ViReal64  stopStimulus[],
                                                 ViReal64  startResponse[],
                                                 ViReal64  stopResponse[]);

ViStatus _VI_FUNC rsznl_WriteLimitLineSegmentList(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   listSize,
                                                  ViInt32   type,
                                                  ViReal64  startStimulus[],
                                                  ViReal64  stopStimulus[],
                                                  ViReal64  startResponse[],
                                                  ViReal64  stopResponse[]);

ViStatus _VI_FUNC rsznl_DeleteLimitLineSegments(ViSession instrSession,
                                                ViInt32   channel);

ViStatus _VI_FUNC rsznl_RecallLimitLine(ViSession instrSession,
                                        ViString  traceName,
                                        ViString  fileName,
                                        ViString  sParameter,
                                        ViReal64  xOffset,
                                        ViReal64  yOffset,
                                        ViInt32   type);

ViStatus _VI_FUNC rsznl_SaveLimitLine(ViSession instrSession,
                                      ViString  traceName,
                                      ViString  fileName);

ViStatus _VI_FUNC rsznl_ImportTraceAsLimitLine(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   limitLineType,
                                               ViReal64  stimulusOffset,
                                               ViReal64  responseOffset,
                                               ViString  traceName);

ViStatus _VI_FUNC rsznl_ConfigureLimitLineFormula(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViInt32   segment,
                                                  ViBoolean enabled,
                                                  ViString  formula);

ViStatus _VI_FUNC rsznl_ConfigureLimitLineInterpolation(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   segment,
                                                        ViInt32   interpolation);

ViStatus _VI_FUNC rsznl_ShowRippleLimits(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean showRippleLimits);

ViStatus _VI_FUNC rsznl_ConfigureRippleCheck(ViSession instrSession,
                                             ViInt32   channel,
                                             ViBoolean rippleCheck,
                                             ViInt32   horizontalPosition,
                                             ViInt32   verticalPosition);

ViStatus _VI_FUNC rsznl_QueryRippleLimitGlobalCheckResult(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32*  rippleLimitCheckResult);

ViStatus _VI_FUNC rsznl_ClearRippleLimitGlobalCheckResult(ViSession instrSession,
                                                          ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureRippleLimitRangeSegmentCheck(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   segment,
                            ViBoolean limitCheck);

ViStatus _VI_FUNC rsznl_QueryRippleLimitCheckSegmentResult(ViSession instrSession,
                                                           ViInt32   channel,
                                                           ViInt32   segment,
                                                           ViInt32*  fail,
                                                           ViReal64* limitCheckResult);

ViStatus _VI_FUNC rsznl_AddRippleLimitLineRangesSegment(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   noOfValues,
                                                        ViInt32   type[],
                                                        ViReal64  startStimulus[],
                                                        ViReal64  stopStimulus[],
                                                        ViReal64  limit[]);

ViStatus _VI_FUNC rsznl_EditRippleLimitLineSegment(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   segment,
                                                   ViReal64  startStimulus,
                                                   ViReal64  stopStimulus,
                                                   ViReal64  limit);

ViStatus _VI_FUNC rsznl_QueryRippleLimitRangesCount(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  rippleLimitRangesCount);

ViStatus _VI_FUNC rsznl_DeleteAllRippleLimitRanges(ViSession instrSession,
                                                   ViInt32   channel);

ViStatus _VI_FUNC rsznl_SaveRecallRippleLimit(ViSession instrSession,
                                              ViInt32   operationToBePerformed,
                                              ViString  traceName,
                                              ViString  fileName);

ViStatus _VI_FUNC rsznl_QueryRippleLimitCheckResultChannel(ViSession instrSession,
                                                           ViString  setup,
                                                           ViInt32*  result);

ViStatus _VI_FUNC rsznl_ConfigureRippleLimitLineFailBeep(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean failBeep);

ViStatus _VI_FUNC rsznl_ConfigureRippleLimitLineShowResultsAllTraces(
                            ViSession instrSession,
                            ViBoolean showResultsAllTraces);

ViStatus _VI_FUNC rsznl_ConfigureRippleLimitStimulusUnit(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   unit);

ViStatus _VI_FUNC rsznl_ConfigureRippleLimitResponseUnit(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViInt32   unit);

ViStatus _VI_FUNC rsznl_ShowCircleLimits(ViSession instrSession,
                                         ViInt32   channel,
                                         ViBoolean showCircleLimitLine);

ViStatus _VI_FUNC rsznl_ConfigureCircleLimitCheck(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViBoolean circleLimitCheck);

ViStatus _VI_FUNC rsznl_ConfigureCircleLimitLine(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  centerX,
                                                 ViReal64  centerY,
                                                 ViReal64  radius);

ViStatus _VI_FUNC rsznl_QueryCircleLimitCheckResult(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  circleLimitCheckResult);

ViStatus _VI_FUNC rsznl_ClearCircleLimitCheckResult(ViSession instrSession,
                                                    ViInt32   channel);

ViStatus _VI_FUNC rsznl_QueryCircleLimitCheckResultChannel(ViSession instrSession,
                                                           ViString  setup,
                                                           ViInt32*  result);

ViStatus _VI_FUNC rsznl_ConfigureCircleFailBeep(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean circleFailBeep);

ViStatus _VI_FUNC rsznl_ConfigureDisplayCircleShowBorder(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean showBorder);

ViStatus _VI_FUNC rsznl_ConfigureDisplayCircleLimitToCircle(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViBoolean limitToCircle);

ViStatus _VI_FUNC rsznl_ConfigureDisplayCircle(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64  centerX,
                                               ViReal64  centerY,
                                               ViReal64  radius);

ViStatus _VI_FUNC rsznl_DisplayCircleClear(ViSession instrSession,
                                           ViInt32   channel);

ViStatus _VI_FUNC rsznl_ConfigureDataSelectedStorageDevice(ViSession instrSession,
                                                           ViString  selectedStorageDevice);

ViStatus _VI_FUNC rsznl_ConfigureDataSelectedDirectory(ViSession instrSession,
                                                       ViString  selectedDirectory);

ViStatus _VI_FUNC rsznl_DataCreateDirectory(ViSession instrSession,
                                            ViString  directory);

ViStatus _VI_FUNC rsznl_QueryDataDirectoryContents(ViSession instrSession,
                                                   ViString  directory,
                                                   ViUInt32  arraySize,
                                                   ViChar    contents[],
                                                   ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QueryDataDirectoryAdditionalContents(ViSession instrSession,
                                                             ViString  directory,
                                                             ViUInt32  arraySize,
                                                             ViChar    contents[],
                                                             ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_DataDeleteDirectory(ViSession instrSession,
                                            ViString  directory);

ViStatus _VI_FUNC rsznl_ConfigureDataFileName(ViSession instrSession,
                                              ViString  dataFileName);

ViStatus _VI_FUNC rsznl_ConfigureDataFileNameComment(ViSession instrSession,
                                                     ViString  comment);

ViStatus _VI_FUNC rsznl_ConfigureDataDecimalSeparator(ViSession instrSession,
                                                      ViInt32   decimalSeparator);

ViStatus _VI_FUNC rsznl_DataCopyFile(ViSession instrSession,
                                     ViString  sourceFile,
                                     ViString  destinationFile);

ViStatus _VI_FUNC rsznl_DataMoveFile(ViSession instrSession,
                                     ViString  sourceFile,
                                     ViString  newFileName);

ViStatus _VI_FUNC rsznl_DataDeleteFile(ViSession instrSession,
                                       ViString  fileName);

ViStatus _VI_FUNC rsznl_DataNetworkMapDrive(ViSession instrSession,
                                            ViString  drive,
                                            ViString  hostName,
                                            ViString  userName,
                                            ViString  password,
                                            ViBoolean reconnect);

ViStatus _VI_FUNC rsznl_DataNetworkDisconnectDrive(ViSession instrSession,
                                                   ViString  drive,
                                                   ViBoolean force);

ViStatus _VI_FUNC rsznl_QueryDataNetworkUnusedDrives(ViSession instrSession,
                                                     ViUInt32  arraySize,
                                                     ViChar    unusedDrives[],
                                                     ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QueryDataNetworkUsedDrives(ViSession instrSession,
                                                   ViUInt32  arraySize,
                                                   ViChar    usedDrives[],
                                                   ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureDataInstrumentSettingsMode(ViSession instrSession,
                                                            ViInt32   settingsMode);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsDeleteAll(ViSession instrSession);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsDelete(ViSession instrSession,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsStartupRecall(ViSession instrSession,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsRecallMode(ViSession instrSession,
                                                         ViInt32   recallMode);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsRecall(ViSession instrSession,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsSave(ViSession instrSession,
                                                   ViString  fileName);

ViStatus _VI_FUNC rsznl_DataInstrumentSettingsSaveNext(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentDefault(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentAll(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ItemsToStoreInstrumentNone(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreInstrument(ViSession instrSession,
                                                        ViBoolean HWSettingsEnabled,
                                                        ViBoolean limitLinesEnabled,
                                                        ViBoolean spectrogramDataEnabled,
                                                        ViBoolean traceDataEnabled,
                                                        ViBoolean transducerFactorsEnabled);

ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreInstrumentCalibrationData(
                            ViSession instrSession,
                            ViBoolean calibrationData);

ViStatus _VI_FUNC rsznl_ItemsToStoreChannelDefault(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ItemsToStoreChannelAll(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ItemsToStoreChannelNone(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreChannel(ViSession instrSession,
                                                     ViBoolean HWSettingsEnabled,
                                                     ViBoolean limitLinesEnabled,
                                                     ViBoolean spectrogramDataEnabled,
                                                     ViBoolean traceDataEnabled,
                                                     ViBoolean transducerFactorsEnabled);

ViStatus _VI_FUNC rsznl_ConfigureItemsToStoreChannelCalibrationData(
                            ViSession instrSession,
                            ViBoolean calibrationData);

ViStatus _VI_FUNC rsznl_HcopyAbort(ViSession instrSession);

ViStatus _VI_FUNC rsznl_HcopyPrint(ViSession instrSession);

ViStatus _VI_FUNC rsznl_HcopyPrintNext(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureHcopyContent(ViSession instrSession,
                                              ViInt32   contentType,
                                              ViString  comment,
                                              ViBoolean logoEnabled,
                                              ViBoolean pageCountEnabled,
                                              ViBoolean dateAndTimeEnabled);

ViStatus _VI_FUNC rsznl_ConfigureHcopyWindowPrintout(ViSession instrSession,
                                                     ViString  channelName,
                                                     ViString  windowName,
                                                     ViBoolean windowEnabled);

ViStatus _VI_FUNC rsznl_ConfigureHcopyChannelPrintout(ViSession instrSession,
                                                      ViString  channelName,
                                                      ViBoolean channelEnabled);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintAllHeaders(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintHeaders(ViSession instrSession,
                                                   ViBoolean logoEnabled,
                                                   ViBoolean markerListEnabled,
                                                   ViBoolean timeEnabled);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPrintDiagramArea(ViSession instrSession,
                                                       ViInt32   printDiagramArea);

ViStatus _VI_FUNC rsznl_ConfigureHcopyDestination(ViSession instrSession,
                                                  ViInt32   destination);

ViStatus _VI_FUNC rsznl_ConfigureHcopySelectedPrinter(ViSession instrSession,
                                                      ViString  selectedPrinter);

ViStatus _VI_FUNC rsznl_HcopyFileFormat(ViSession instrSession,
                                        ViInt32   hcopyFileFormat);

ViStatus _VI_FUNC rsznl_QueryHcopyFirstPrinter(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    firstPrinter[],
                                               ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QueryHcopyNextPrinter(ViSession instrSession,
                                              ViUInt32  arraySize,
                                              ViChar    nextPrinter[],
                                              ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPageOrientation(ViSession instrSession,
                                                      ViInt32   pageOrientation);

ViStatus _VI_FUNC rsznl_ConfigureHcopyWindowsPerPage(ViSession instrSession,
                                                     ViInt32   windowsPerPage);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPageScaleToFitEnabled(ViSession instrSession,
                                                            ViBoolean scaleToFitEnabled);

ViStatus _VI_FUNC rsznl_ConfigureHcopyPageMargin(ViSession instrSession,
                                                 ViInt32   unit,
                                                 ViReal64  bottom,
                                                 ViReal64  left,
                                                 ViReal64  right,
                                                 ViReal64  top);

ViStatus _VI_FUNC rsznl_ConfigureHcopyColorPrinting(ViSession instrSession,
                                                    ViBoolean colorPrintingEnabled);

ViStatus _VI_FUNC rsznl_ResetHcopyColorScheme(ViSession instrSession,
                                              ViInt32   displayItem,
                                              ViInt32   color);

ViStatus _VI_FUNC rsznl_SelectHcopyColor(ViSession instrSession,
                                         ViInt32   displayItem,
                                         ViReal64  tint,
                                         ViReal64  saturation,
                                         ViReal64  brightness);

ViStatus _VI_FUNC rsznl_SelectHcopyPredefinedColor(ViSession instrSession,
                                                   ViInt32   displayItem,
                                                   ViInt32   color);

ViStatus _VI_FUNC rsznl_Calibrate(ViSession instrSession,
                                  ViInt32*  calibrate);

ViStatus _VI_FUNC rsznl_QueryCalibrationResult(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    calibrationResult[],
                                               ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationSignalFrequency(ViSession instrSession,
                                                            ViReal64  calibrationSignalFrequency);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationInputSource(ViSession instrSession,
                                                        ViInt32   calibrationInputSource);

ViStatus _VI_FUNC rsznl_QueryFrontendTemperature(ViSession instrSession,
                                                 ViReal64* frontendTemperature);

ViStatus _VI_FUNC rsznl_QuerySelfTestResults(ViSession instrSession,
                                             ViUInt32  arraySize,
                                             ViChar    selfTestResults[],
                                             ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueDays(ViSession instrSession,
                                                    ViInt32   arraySize,
                                                    ViInt32   calibrationDueDays[]);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueSchedule(ViSession instrSession,
                                                        ViBoolean schedule);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueShutdown(ViSession instrSession,
                                                        ViBoolean shutdown);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueTime(ViSession instrSession,
                                                    ViString  time);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationDueWarmup(ViSession instrSession,
                                                      ViBoolean warmup);

ViStatus _VI_FUNC rsznl_StartServiceFunction(ViSession instrSession,
                                             ViString  serviceFunction);

ViStatus _VI_FUNC rsznl_QueryServiceFunctionLastResult(ViSession instrSession,
                                                       ViUInt32  arraySize,
                                                       ViChar    lastResult[],
                                                       ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_ServiceFunctionDeleteLastResult(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SaveServiceFunctionResult(ViSession instrSession,
                                                  ViString  fileName);

ViStatus _VI_FUNC rsznl_QueryServiceSystemInformationFilePath(
                            ViSession instrSession,
                            ViUInt32  arraySize,
                            ViChar    filePath[],
                            ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QueryServiceFunctionBatteryLevel(ViSession instrSession,
                                                         ViInt32*  batteryLevel);

ViStatus _VI_FUNC rsznl_ConfigureReferenceOscillator(ViSession instrSession,
                                                     ViInt32   referenceOscillatorSource,
                                                     ViReal64  externalFrequency);

ViStatus _VI_FUNC rsznl_QueryCurrentReferenceType(ViSession instrSession,
                                                  ViInt32*  referenceType);

ViStatus _VI_FUNC rsznl_ConfigureAutoPowerReductionForCalUnit(
                            ViSession instrSession,
                            ViBoolean autoPowerReduction);

ViStatus _VI_FUNC rsznl_ConfigureCalibrationAutoAveraging(ViSession instrSession,
                                                          ViInt32   averaging);

ViStatus _VI_FUNC rsznl_ConfigureSearchPathForAdditionalCalKitsAndConnectorTypes(
                            ViSession instrSession,
                            ViString  path);

ViStatus _VI_FUNC rsznl_ConfigureCalculationOfBandfilterCenter(
                            ViSession instrSession,
                            ViBoolean bandfilterCenterCalculation);

ViStatus _VI_FUNC rsznl_ConfigureTouchstoneExport(ViSession instrSession,
                                                  ViInt32   positiveNumberPrefix,
                                                  ViBoolean skipSeparatorLines,
                                                  ViBoolean useTAB,
                                                  ViBoolean trimLeadingWhitespace);

ViStatus _VI_FUNC rsznl_ConfigureGeneralTouchstoneExportComment(
                            ViSession instrSession,
                            ViString  exportComment);

ViStatus _VI_FUNC rsznl_ConfigurePowerAtSweepEnd(ViSession instrSession,
                                                 ViInt32   powerModeAtSweepEnd,
                                                 ViReal64  settlingDelay);

ViStatus _VI_FUNC rsznl_ConfigureRemoteLoggingEnabled(ViSession instrSession,
                                                      ViBoolean remoteLoggingEnabled);

ViStatus _VI_FUNC rsznl_ConfigureRemoteDisplay(ViSession instrSession,
                                               ViBoolean displayUpdateEnabled,
                                               ViBoolean displayErrorEnabled);

ViStatus _VI_FUNC rsznl_ClearRemoteErrors(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ClearSystemMessages(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureLocalLockout(ViSession instrSession,
                                              ViBoolean generalLocalLockoutEnabled);

ViStatus _VI_FUNC rsznl_ConfigureRemoteControl(ViSession instrSession,
                                               ViBoolean remoteControl);

ViStatus _VI_FUNC rsznl_ConfigureDisplayLanguage(ViSession instrSession,
                                                 ViInt32   displayLanguage);

ViStatus _VI_FUNC rsznl_ConfigureRemoteLanguage(ViSession instrSession,
                                                ViString  language);

ViStatus _VI_FUNC rsznl_ResetRevisionToFactoryDefault(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ResetIDNQueryToFactoryDefault(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureIDNQueryString(ViSession instrSession,
                                                ViString  IDNQueryString);

ViStatus _VI_FUNC rsznl_ConfigureIDNFormat(ViSession instrSession,
                                           ViInt32   IDNFormat);

ViStatus _VI_FUNC rsznl_ConfigureFirmwareUpdate(ViSession instrSession,
                                                ViString  path);

ViStatus _VI_FUNC rsznl_QueryLXIInfo(ViSession instrSession,
                                     ViUInt32  arraySize,
                                     ViChar    LXIInfo[],
                                     ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_LXILANReset(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureLXIInstrumentDescription(ViSession instrSession,
                                                          ViString  LXIInstrumentDescription);

ViStatus _VI_FUNC rsznl_ConfigureLXIPassword(ViSession instrSession,
                                             ViString  LXIPassword);

ViStatus _VI_FUNC rsznl_ConfigureConductanceInEmbeddingNetworks(
                            ViSession instrSession,
                            ViBoolean conductanceInEmbedNetworks);

ViStatus _VI_FUNC rsznl_UpdateSettings(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureInstrumentHostname(ViSession instrSession,
                                                    ViString  hostname);

ViStatus _VI_FUNC rsznl_Preset(ViSession instrSession);

ViStatus _VI_FUNC rsznl_PresetChannel(ViSession instrSession);

ViStatus _VI_FUNC rsznl_PresetMode(ViSession instrSession,
                                   ViInt32   mode);

ViStatus _VI_FUNC rsznl_reset(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking);

ViStatus _VI_FUNC rsznl_self_test(ViSession instrSession,
                                  ViInt16*  selfTestResult,
                                  ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rsznl_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsznl_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[]);

ViStatus _VI_FUNC rsznl_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rsznl_QuerySystemBIOSInfo(ViSession instrSession,
                                            ViUInt32  arraySize,
                                            ViChar    systemBIOSInfo[],
                                            ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QuerySystemVersionInfo(ViSession instrSession,
                                               ViUInt32  arraySize,
                                               ViChar    systemVersionInfo[],
                                               ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_QuerySystemHWInfo(ViSession instrSession,
                                          ViUInt32  arraySize,
                                          ViChar    systemHWInfo[],
                                          ViUInt32* returnedValues);

ViStatus _VI_FUNC rsznl_SystemReboot(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SystemShutdown(ViSession instrSession);

ViStatus _VI_FUNC rsznl_DumpFileSize(ViSession instrSession,
                                     ViInt32   dumpFileSize);

ViStatus _VI_FUNC rsznl_RelaySwitchingCyclesCount(ViSession instrSession,
                                                  ViInt32   relay,
                                                  ViInt32*  cyclesCount);

ViStatus _VI_FUNC rsznl_SetTimeout(ViSession instrSession,
                                   ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rsznl_GetTimeout(ViSession instrSession,
                                   ViUInt32* timeout);

ViStatus _VI_FUNC rsznl_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsznl_IDQueryResponse(ViSession instrSession,
                                        ViUInt32  bufferSize,
                                        ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rsznl_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsznl_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC);

ViStatus _VI_FUNC rsznl_PasswordReset(ViSession instrSession);

ViStatus _VI_FUNC rsznl_ConfigureSystemPassword(ViSession instrSession,
                                                ViString  systemPassword);

ViStatus _VI_FUNC rsznl_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsznl_OPCSyncWriteEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsznl_OPCSyncQueryEnable(ViSession instrSession,
                                           ViBoolean enable);

ViStatus _VI_FUNC rsznl_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                 ViBoolean useEsb,
                                                 ViBoolean clsBefore,
                                                 ViBoolean useMav);

ViStatus _VI_FUNC rsznl_ExecuteProgram(ViSession instrSession,
                                       ViString  directory,
                                       ViString  fileToExecute,
                                       ViString  fileParameters,
                                       ViBoolean waitToFinish);

ViStatus _VI_FUNC rsznl_QueryProgramReturnValue(ViSession instrSession,
                                                ViInt32*  returnValue);

ViStatus _VI_FUNC rsznl_GetError(ViSession instrSession,
                                 ViStatus* code,
                                 ViInt32   bufferSize,
                                 ViChar    description[]);

ViStatus _VI_FUNC rsznl_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SetIOTimeout(ViSession instrSession,
                                     ViUInt32  VISATimeout);

ViStatus _VI_FUNC rsznl_GetIOTimeout(ViSession instrSession,
                                     ViUInt32* VISATimeout);

ViStatus _VI_FUNC rsznl_ReadToFileFromInstrument(ViSession instrSession,
                                                 ViString  source,
                                                 ViString  destination);

ViStatus _VI_FUNC rsznl_WriteFromFileToInstrument(ViSession instrSession,
                                                  ViString  source,
                                                  ViString  destination);

ViStatus _VI_FUNC rsznl_WriteInstrData(ViSession instrSession,
                                       ViString  writeBuffer);

ViStatus _VI_FUNC rsznl_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value);

ViStatus _VI_FUNC rsznl_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value);

ViStatus _VI_FUNC rsznl_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value);

ViStatus _VI_FUNC rsznl_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViUInt32  bufferSize,
                                      ViChar    value[],
                                      ViUInt32* returnCount);

ViStatus _VI_FUNC rsznl_WriteCommandWithOPCSync(ViSession instrSession,
                                                ViString  writeBuffer,
                                                ViUInt32  timeout);

ViStatus _VI_FUNC rsznl_QueryWithOPCSync(ViSession instrSession,
                                         ViString  writeBuffer,
                                         ViUInt32  timeout,
                                         ViUInt32  bufferSize,
                                         ViChar    readBuffer[],
                                         ViUInt32* numBytesRead);

ViStatus _VI_FUNC rsznl_SystemMemoryAdd(ViSession instrSession,
                                        ViString  traceName,
                                        ViInt32   dataFormat,
                                        ViInt32   numberOfPoints);

ViStatus _VI_FUNC rsznl_QuerySystemMemoryCatalog(ViSession instrSession,
                                                 ViInt32   bufferSize,
                                                 ViChar    catalog[]);

ViStatus _VI_FUNC rsznl_ConfigureSystemMemoryCommit(ViSession instrSession,
                                                    ViString  memoryCommit);

ViStatus _VI_FUNC rsznl_ConfigureSystemMemoryDelete(ViSession instrSession,
                                                    ViString  memoryDelete);

ViStatus _VI_FUNC rsznl_SystemMemoryInit(ViSession instrSession);

ViStatus _VI_FUNC rsznl_QuerySystemMemoryOffset(ViSession instrSession,
                                                ViReal64* offset);

ViStatus _VI_FUNC rsznl_SystemMemoryReset(ViSession instrSession);

ViStatus _VI_FUNC rsznl_QuerySystemMemorySize(ViSession instrSession,
                                              ViReal64* memorySize);

ViStatus _VI_FUNC rsznl_SetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32   attributeValue);

ViStatus _VI_FUNC rsznl_SetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt64   attributeValue);

ViStatus _VI_FUNC rsznl_SetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64  attributeValue);

ViStatus _VI_FUNC rsznl_SetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViString  attributeValue);

ViStatus _VI_FUNC rsznl_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  channelName,
                                              ViAttr    attributeID,
                                              ViBoolean attributeValue);

ViStatus _VI_FUNC rsznl_GetAttributeViInt32(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt32*  attributeValue);

ViStatus _VI_FUNC rsznl_GetAttributeViInt64(ViSession instrSession,
                                            ViString  channelName,
                                            ViAttr    attributeID,
                                            ViInt64*  attributeValue);

ViStatus _VI_FUNC rsznl_GetAttributeViReal64(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViReal64* attributeValue);

ViStatus _VI_FUNC rsznl_GetAttributeViString(ViSession instrSession,
                                             ViString  channelName,
                                             ViAttr    attributeID,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[]);

ViStatus _VI_FUNC rsznl_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   channelName,
                                              ViAttr     attributeID,
                                              ViBoolean* attributeValue);

ViStatus _VI_FUNC rsznl_SynchronizeDynamicRepeatedCapability(ViSession instrSession,
                                                             ViInt32   repeatedCapability);

ViStatus _VI_FUNC rsznl_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViUInt32  attributeID,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rsznl_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rsznl_PresetStatusRegister(ViSession instrSession);

ViStatus _VI_FUNC rsznl_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViUInt16  enable,
                                          ViUInt16  PTransition,
                                          ViUInt16  NTransition);

ViStatus _VI_FUNC rsznl_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerOperation,
                                          ViInt32   questionableRegister,
                                          ViInt32   registerPart,
                                          ViInt32*  registerValue);

ViStatus _VI_FUNC rsznl_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSZNL_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSZNL_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSZNL_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSZNL_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSZNL_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSZNL_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSZNL_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSZNL_ERRMSG_INCORRECT_STATE    "Instrument in incorrect state"
#define RSZNL_ERRMSG_INCORRECT_RESPONSE "Response incorrect; report problem to R&S support!"
#define RSZNL_ERRMSG_MAX_TIME_EXCEEDED  "Max Time Exceeded"

#define RSZNL_ERROR_CODES_AND_MSGS \
    {RSZNL_WARN_MEASURE_UNCALIBRATED,  RSZNL_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSZNL_WARN_OVER_RANGE,            RSZNL_WARNMSG_OVER_RANGE},\
    {RSZNL_ERROR_INCORRECT_STATE,      RSZNL_ERRMSG_INCORRECT_STATE},\
    {RSZNL_ERROR_INCORRECT_RESPONSE,   RSZNL_ERRMSG_INCORRECT_RESPONSE},\
    {RSZNL_ERROR_MAX_TIME_EXCEEDED,    RSZNL_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSZNL_HEADER */

